
#line 1 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
/*
 * Copyright (c) 2012 The Native Client Authors. All rights reserved.
 * Use of this source code is governed by a BSD-style license that can be
 * found in the LICENSE file.
 */

#include <assert.h>
#include <stddef.h>
#include <stdio.h>
#include <stdlib.h>
#include <string.h>

#include "native_client/src/shared/utils/types.h"
#include "native_client/src/trusted/validator_ragel/unreviewed/validator.h"

#if defined(_MSC_VER)
#define inline __inline
#endif

#include "native_client/src/trusted/validator_ragel/gen/validator-x86_64-instruction-consts.c"

#define check_jump_dest \
    if ((jump_dest & bundle_mask) != bundle_mask) { \
      if (jump_dest >= size) { \
        printf("direct jump out of range: %"NACL_PRIxS"\n", jump_dest); \
        result = 1; \
        goto error_detected; \
      } else { \
        BitmapSetBit(jump_dests, jump_dest + 1); \
      } \
    } \
    SET_OPERAND_NAME(0, JMP_TO); \
    SET_MODRM_BASE(REG_RIP); \
    SET_MODRM_INDEX(NO_REG);

static void PrintError(const char* msg, uintptr_t ptr) {
  printf("offset 0x%"NACL_PRIxS": %s", ptr, msg);
}


#line 349 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"



#line 48 "src/trusted/validator_ragel/gen/validator-x86_64.c"
static const int x86_64_decoder_start = 721;
static const int x86_64_decoder_first_final = 721;
static const int x86_64_decoder_error = 0;

static const int x86_64_decoder_en_main = 721;


#line 352 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"

#define GET_REX_PREFIX() rex_prefix
#define SET_REX_PREFIX(P) rex_prefix = (P)
#define GET_VEX_PREFIX2() vex_prefix2
#define SET_VEX_PREFIX2(P) vex_prefix2 = (P)
#define GET_VEX_PREFIX3() vex_prefix3
#define SET_VEX_PREFIX3(P) vex_prefix3 = (P)

/* Ignore this information for now.  */
#define SET_DATA16_PREFIX(S)
#define SET_LOCK_PREFIX(S)
#define SET_REPZ_PREFIX(S)
#define SET_REPNZ_PREFIX(S)
#define SET_BRANCH_TAKEN(S)
#define SET_BRANCH_NOT_TAKEN(S)

enum operand_kind {
  OperandSandboxIrrelevant = 0,
  /*
   * Currently we do not distinguish 8bit and 16bit modifications from
   * OperandSandboxUnrestricted to match the behavior of the old validator.
   *
   * 8bit operands must be distinguished from other types because the REX prefix
   * regulates the choice between %ah and %spl, as well as %ch and %bpl.
   */
  OperandSandbox8bit,
  OperandSandboxRestricted,
  OperandSandboxUnrestricted
};

/* Define SET_OPERAND_NAME as SET_OPERAND_NAME_0, SET_OPERAND_NAME_1 to detect
 * cases where more than two general purpose registers are affected.  This will
 * produce a compile-time error if an operand with unexpected number is
 * encountered. */
#define SET_OPERAND_NAME(N, S) SET_OPERAND_NAME_ ## N(S)
#define SET_OPERAND_NAME_0(S) operand_states |= (S)
#define SET_OPERAND_NAME_1(S) operand_states |= ((S) << 8)
#define SET_OPERAND_TYPE(N, T) SET_OPERAND_TYPE_ ## T(N)
#define SET_OPERAND_TYPE_OperandSize8bit(N) \
  operand_states |= OperandSandbox8bit << (5 + ((N) << 3))
#define SET_OPERAND_TYPE_OperandSize16bit(N) \
  operand_states |= OperandSandboxUnrestricted << (5 + ((N) << 3))
#define SET_OPERAND_TYPE_OperandSize32bit(N) \
  operand_states |= OperandSandboxRestricted << (5 + ((N) << 3))
#define SET_OPERAND_TYPE_OperandSize64bit(N) \
  operand_states |= OperandSandboxUnrestricted << (5 + ((N) << 3))
#define CHECK_OPERAND(N, S, T) \
  ((operand_states & (0xff << ((N) << 3))) == ((S | (T << 5)) << ((N) << 3)))
#define SET_OPERANDS_COUNT(N)
#define SET_MODRM_BASE(N) base = (N)
#define SET_MODRM_INDEX(N) index = (N)

/* Ignore this information for now.  */
#define SET_MODRM_SCALE(S)
#define SET_DISP_TYPE(T)
#define SET_DISP_PTR(P)
#define SET_IMM_TYPE(T)
#define SET_IMM_PTR(P)
#define SET_IMM2_TYPE(T)
#define SET_IMM2_PTR(P)

enum {
  REX_B = 1,
  REX_X = 2,
  REX_R = 4,
  REX_W = 8
};

static const int kBitsPerByte = 8;

static inline uint8_t *BitmapAllocate(size_t indexes) {
  size_t byte_count = (indexes + kBitsPerByte - 1) / kBitsPerByte;
  uint8_t *bitmap = malloc(byte_count);
  if (bitmap != NULL) {
    memset(bitmap, 0, byte_count);
  }
  return bitmap;
}

static inline int BitmapIsBitSet(uint8_t *bitmap, size_t index) {
  return (bitmap[index / kBitsPerByte] & (1 << (index % kBitsPerByte))) != 0;
}

static inline void BitmapSetBit(uint8_t *bitmap, size_t index) {
  bitmap[index / kBitsPerByte] |= 1 << (index % kBitsPerByte);
}

static inline void BitmapClearBit(uint8_t *bitmap, size_t index) {
  bitmap[index / kBitsPerByte] &= ~(1 << (index % kBitsPerByte));
}

static int CheckJumpTargets(uint8_t *valid_targets, uint8_t *jump_dests,
                            size_t size) {
  size_t i;
  for (i = 0; i < size / 32; i++) {
    uint32_t jump_dest_mask = ((uint32_t *) jump_dests)[i];
    uint32_t valid_target_mask = ((uint32_t *) valid_targets)[i];
    if ((jump_dest_mask & ~valid_target_mask) != 0) {
      printf("bad jump to around %x\n", (unsigned)(i * 32));
      return 1;
    }
  }
  return 0;
}

int ValidateChunkAMD64(const uint8_t *data, size_t size,
                       process_validation_error_func process_error,
                       void *userdata) {
  const size_t bundle_size = 32;
  const size_t bundle_mask = bundle_size - 1;

  uint8_t *valid_targets = BitmapAllocate(size);
  uint8_t *jump_dests = BitmapAllocate(size);

  const uint8_t *p = data;
  const uint8_t *begin = p;  /* Start of the instruction being processed.  */

  uint8_t rex_prefix = FALSE;
  uint8_t vex_prefix2 = 0xe0;
  uint8_t vex_prefix3 = 0x00;
  /* Keeps one byte of information per operand in the current instruction:
   *  2 bits for register kinds,
   *  5 bits for register numbers (16 regs plus RIZ). */
  int operand_states = 0;
  enum register_name base = NO_REG;
  enum register_name index = NO_REG;
  int result = 0;
  /*
   * These are borders of the appropriate instructions.  Initialize them to make
   * compiler happy: they are never used uninitialized even without explicit
   * initialization but GCC is not sophysicated enough to prove that.
   */
  const uint8_t *sandboxed_rsi = 0;
  const uint8_t *sandboxed_rsi_restricted_rdi = 0;
  const uint8_t *sandboxed_rdi = 0;

  assert(size % bundle_size == 0);

  while (p < data + size) {
    const uint8_t *pe = p + bundle_size;
    const uint8_t *eof = pe;
    int cs;
    enum {
      kNoRestrictedReg = 32,
      kSandboxedRsi,
      kSandboxedRdi,
      kSandboxedRsiRestrictedRdi,
      kSandboxedRsiSandboxedRdi
    }; uint8_t restricted_register = kNoRestrictedReg;

    
#line 208 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	{
	cs = x86_64_decoder_start;
	}

#line 503 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
    
#line 215 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	{
	if ( p == pe )
		goto _test_eof;
	switch ( cs )
	{
tr0:
#line 90 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_DISP_TYPE(DISPNONE);
    SET_MODRM_BASE(((*p) & 0x07) |
                   ((GET_REX_PREFIX() & 0x01) << 3) |
                   (((~GET_VEX_PREFIX2()) & 0x20) >> 2));
    SET_MODRM_INDEX(NO_REG);
    SET_MODRM_SCALE(0);
  }
#line 44 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    if ((base == REG_RIP) || (base == REG_R15) ||
        ((base == REG_RSP) && (restricted_register != REG_RSP)) ||
        ((base == REG_RBP) && (restricted_register != REG_RBP))) {
      if ((index == restricted_register) ||
          ((index == REG_RDI) &&
           (restricted_register == kSandboxedRsiRestrictedRdi))) {
        BitmapClearBit(valid_targets, begin - data);
      } else if ((index != NO_REG) && (index != REG_RIZ)) {
        PrintError("Improper sandboxing in instruction\n", begin - data);
        result = 1;
        goto error_detected;
      }
    } else if ((index == REG_RIP) || (index == REG_R15) ||
               ((index == REG_RSP) && (restricted_register != REG_RSP)) ||
               ((index == REG_RBP) && (restricted_register != REG_RBP))) {
      if ((base == restricted_register) ||
          ((base == REG_RDI) &&
           (restricted_register == kSandboxedRsiRestrictedRdi))) {
        BitmapClearBit(valid_targets, begin - data);
      } else if ((base != NO_REG) && (base != REG_RIZ)) {
        PrintError("Improper sandboxing in instruction\n", begin - data);
        result = 1;
        goto error_detected;
      }
    } else {
      PrintError("Improper sandboxing in instruction\n", begin - data);
      result = 1;
      goto error_detected;
    }
  }
#line 93 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    /* Restricted %rsp or %rbp must be processed by appropriate nacl-special
       instruction, not with regular instruction.  */
    if (restricted_register == REG_RSP) {
      PrintError("Incorrectly modified register %%rsp\n", begin - data);
      result = 1;
      goto error_detected;
    } else if (restricted_register == REG_RBP) {
      PrintError("Incorrectly modified register %%rbp\n", begin - data);
      result = 1;
      goto error_detected;
    }
    /* If Sandboxed Rsi is destroyed then we must note that.  */
    if (restricted_register == kSandboxedRsi) {
      if (CHECK_OPERAND(0, REG_RSI, OperandSandboxRestricted) ||
          CHECK_OPERAND(0, REG_RSI, OperandSandboxUnrestricted) ||
          CHECK_OPERAND(1, REG_RSI, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_RSI, OperandSandboxUnrestricted)) {
        restricted_register = kNoRestrictedReg;
      }
    }
    if (restricted_register == kSandboxedRsi) {
      if (CHECK_OPERAND(0, REG_RDI, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_RDI, OperandSandboxRestricted)) {
        sandboxed_rsi_restricted_rdi = begin;
        restricted_register = kSandboxedRsiRestrictedRdi;
      }
    }
    if (restricted_register != kSandboxedRsiRestrictedRdi) {
      restricted_register = kNoRestrictedReg;
      if (CHECK_OPERAND(0, REG_R15, OperandSandbox8bit) ||
          CHECK_OPERAND(0, REG_R15, OperandSandboxRestricted) ||
          CHECK_OPERAND(0, REG_R15, OperandSandboxUnrestricted) ||
          CHECK_OPERAND(1, REG_R15, OperandSandbox8bit) ||
          CHECK_OPERAND(1, REG_R15, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_R15, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%r15\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((CHECK_OPERAND(0, REG_RBP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(0, REG_RBP, OperandSandboxUnrestricted) ||
                 (CHECK_OPERAND(1, REG_RBP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(1, REG_RBP, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%rbp\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((CHECK_OPERAND(0, REG_RSP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(0, REG_RSP, OperandSandboxUnrestricted) ||
                 (CHECK_OPERAND(1, REG_RSP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(1, REG_RSP, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%rsp\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((operand_states & 0x70) == (OperandSandboxRestricted << 5)) {
        restricted_register = operand_states & 0x0f;
      } else if ((operand_states & 0x7000) ==
                                        (OperandSandboxRestricted << (5 + 8))) {
        restricted_register = (operand_states & 0x0f00) >> 8;
      }
    }
  }
#line 337 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
       /* On successful match the instruction start must point to the next byte
        * to be able to report the new offset as the start of instruction
        * causing error.  */
       begin = p + 1;
     }
	goto st721;
tr7:
#line 384 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_NAME(0, ((*p) & 0x07) |
                           ((GET_REX_PREFIX() & 0x01) << 3) |
                           (((~GET_VEX_PREFIX2()) & 0x20) >> 2));
  }
#line 93 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    /* Restricted %rsp or %rbp must be processed by appropriate nacl-special
       instruction, not with regular instruction.  */
    if (restricted_register == REG_RSP) {
      PrintError("Incorrectly modified register %%rsp\n", begin - data);
      result = 1;
      goto error_detected;
    } else if (restricted_register == REG_RBP) {
      PrintError("Incorrectly modified register %%rbp\n", begin - data);
      result = 1;
      goto error_detected;
    }
    /* If Sandboxed Rsi is destroyed then we must note that.  */
    if (restricted_register == kSandboxedRsi) {
      if (CHECK_OPERAND(0, REG_RSI, OperandSandboxRestricted) ||
          CHECK_OPERAND(0, REG_RSI, OperandSandboxUnrestricted) ||
          CHECK_OPERAND(1, REG_RSI, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_RSI, OperandSandboxUnrestricted)) {
        restricted_register = kNoRestrictedReg;
      }
    }
    if (restricted_register == kSandboxedRsi) {
      if (CHECK_OPERAND(0, REG_RDI, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_RDI, OperandSandboxRestricted)) {
        sandboxed_rsi_restricted_rdi = begin;
        restricted_register = kSandboxedRsiRestrictedRdi;
      }
    }
    if (restricted_register != kSandboxedRsiRestrictedRdi) {
      restricted_register = kNoRestrictedReg;
      if (CHECK_OPERAND(0, REG_R15, OperandSandbox8bit) ||
          CHECK_OPERAND(0, REG_R15, OperandSandboxRestricted) ||
          CHECK_OPERAND(0, REG_R15, OperandSandboxUnrestricted) ||
          CHECK_OPERAND(1, REG_R15, OperandSandbox8bit) ||
          CHECK_OPERAND(1, REG_R15, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_R15, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%r15\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((CHECK_OPERAND(0, REG_RBP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(0, REG_RBP, OperandSandboxUnrestricted) ||
                 (CHECK_OPERAND(1, REG_RBP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(1, REG_RBP, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%rbp\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((CHECK_OPERAND(0, REG_RSP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(0, REG_RSP, OperandSandboxUnrestricted) ||
                 (CHECK_OPERAND(1, REG_RSP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(1, REG_RSP, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%rsp\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((operand_states & 0x70) == (OperandSandboxRestricted << 5)) {
        restricted_register = operand_states & 0x0f;
      } else if ((operand_states & 0x7000) ==
                                        (OperandSandboxRestricted << (5 + 8))) {
        restricted_register = (operand_states & 0x0f00) >> 8;
      }
    }
  }
#line 337 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
       /* On successful match the instruction start must point to the next byte
        * to be able to report the new offset as the start of instruction
        * causing error.  */
       begin = p + 1;
     }
	goto st721;
tr8:
#line 118 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_DISP_TYPE(DISPNONE);
    SET_MODRM_BASE(((*p) & 0x7) |
                   ((GET_REX_PREFIX() & 0x01) << 3) |
                   (((~GET_VEX_PREFIX2()) & 0x20) >> 2));
    SET_MODRM_INDEX(index_registers[(((*p) & 0x38) >> 3) |
                                    ((GET_REX_PREFIX() & 0x02) << 2) |
                                    (((~GET_VEX_PREFIX2()) & 0x40) >> 3)]);
    SET_MODRM_SCALE(((*p) & 0xc0) >> 6);
  }
#line 44 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    if ((base == REG_RIP) || (base == REG_R15) ||
        ((base == REG_RSP) && (restricted_register != REG_RSP)) ||
        ((base == REG_RBP) && (restricted_register != REG_RBP))) {
      if ((index == restricted_register) ||
          ((index == REG_RDI) &&
           (restricted_register == kSandboxedRsiRestrictedRdi))) {
        BitmapClearBit(valid_targets, begin - data);
      } else if ((index != NO_REG) && (index != REG_RIZ)) {
        PrintError("Improper sandboxing in instruction\n", begin - data);
        result = 1;
        goto error_detected;
      }
    } else if ((index == REG_RIP) || (index == REG_R15) ||
               ((index == REG_RSP) && (restricted_register != REG_RSP)) ||
               ((index == REG_RBP) && (restricted_register != REG_RBP))) {
      if ((base == restricted_register) ||
          ((base == REG_RDI) &&
           (restricted_register == kSandboxedRsiRestrictedRdi))) {
        BitmapClearBit(valid_targets, begin - data);
      } else if ((base != NO_REG) && (base != REG_RIZ)) {
        PrintError("Improper sandboxing in instruction\n", begin - data);
        result = 1;
        goto error_detected;
      }
    } else {
      PrintError("Improper sandboxing in instruction\n", begin - data);
      result = 1;
      goto error_detected;
    }
  }
#line 93 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    /* Restricted %rsp or %rbp must be processed by appropriate nacl-special
       instruction, not with regular instruction.  */
    if (restricted_register == REG_RSP) {
      PrintError("Incorrectly modified register %%rsp\n", begin - data);
      result = 1;
      goto error_detected;
    } else if (restricted_register == REG_RBP) {
      PrintError("Incorrectly modified register %%rbp\n", begin - data);
      result = 1;
      goto error_detected;
    }
    /* If Sandboxed Rsi is destroyed then we must note that.  */
    if (restricted_register == kSandboxedRsi) {
      if (CHECK_OPERAND(0, REG_RSI, OperandSandboxRestricted) ||
          CHECK_OPERAND(0, REG_RSI, OperandSandboxUnrestricted) ||
          CHECK_OPERAND(1, REG_RSI, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_RSI, OperandSandboxUnrestricted)) {
        restricted_register = kNoRestrictedReg;
      }
    }
    if (restricted_register == kSandboxedRsi) {
      if (CHECK_OPERAND(0, REG_RDI, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_RDI, OperandSandboxRestricted)) {
        sandboxed_rsi_restricted_rdi = begin;
        restricted_register = kSandboxedRsiRestrictedRdi;
      }
    }
    if (restricted_register != kSandboxedRsiRestrictedRdi) {
      restricted_register = kNoRestrictedReg;
      if (CHECK_OPERAND(0, REG_R15, OperandSandbox8bit) ||
          CHECK_OPERAND(0, REG_R15, OperandSandboxRestricted) ||
          CHECK_OPERAND(0, REG_R15, OperandSandboxUnrestricted) ||
          CHECK_OPERAND(1, REG_R15, OperandSandbox8bit) ||
          CHECK_OPERAND(1, REG_R15, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_R15, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%r15\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((CHECK_OPERAND(0, REG_RBP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(0, REG_RBP, OperandSandboxUnrestricted) ||
                 (CHECK_OPERAND(1, REG_RBP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(1, REG_RBP, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%rbp\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((CHECK_OPERAND(0, REG_RSP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(0, REG_RSP, OperandSandboxUnrestricted) ||
                 (CHECK_OPERAND(1, REG_RSP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(1, REG_RSP, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%rsp\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((operand_states & 0x70) == (OperandSandboxRestricted << 5)) {
        restricted_register = operand_states & 0x0f;
      } else if ((operand_states & 0x7000) ==
                                        (OperandSandboxRestricted << (5 + 8))) {
        restricted_register = (operand_states & 0x0f00) >> 8;
      }
    }
  }
#line 337 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
       /* On successful match the instruction start must point to the next byte
        * to be able to report the new offset as the start of instruction
        * causing error.  */
       begin = p + 1;
     }
	goto st721;
tr13:
#line 46 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_DISP_TYPE(DISP32);
    SET_DISP_PTR(p - 3);
  }
#line 44 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    if ((base == REG_RIP) || (base == REG_R15) ||
        ((base == REG_RSP) && (restricted_register != REG_RSP)) ||
        ((base == REG_RBP) && (restricted_register != REG_RBP))) {
      if ((index == restricted_register) ||
          ((index == REG_RDI) &&
           (restricted_register == kSandboxedRsiRestrictedRdi))) {
        BitmapClearBit(valid_targets, begin - data);
      } else if ((index != NO_REG) && (index != REG_RIZ)) {
        PrintError("Improper sandboxing in instruction\n", begin - data);
        result = 1;
        goto error_detected;
      }
    } else if ((index == REG_RIP) || (index == REG_R15) ||
               ((index == REG_RSP) && (restricted_register != REG_RSP)) ||
               ((index == REG_RBP) && (restricted_register != REG_RBP))) {
      if ((base == restricted_register) ||
          ((base == REG_RDI) &&
           (restricted_register == kSandboxedRsiRestrictedRdi))) {
        BitmapClearBit(valid_targets, begin - data);
      } else if ((base != NO_REG) && (base != REG_RIZ)) {
        PrintError("Improper sandboxing in instruction\n", begin - data);
        result = 1;
        goto error_detected;
      }
    } else {
      PrintError("Improper sandboxing in instruction\n", begin - data);
      result = 1;
      goto error_detected;
    }
  }
#line 93 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    /* Restricted %rsp or %rbp must be processed by appropriate nacl-special
       instruction, not with regular instruction.  */
    if (restricted_register == REG_RSP) {
      PrintError("Incorrectly modified register %%rsp\n", begin - data);
      result = 1;
      goto error_detected;
    } else if (restricted_register == REG_RBP) {
      PrintError("Incorrectly modified register %%rbp\n", begin - data);
      result = 1;
      goto error_detected;
    }
    /* If Sandboxed Rsi is destroyed then we must note that.  */
    if (restricted_register == kSandboxedRsi) {
      if (CHECK_OPERAND(0, REG_RSI, OperandSandboxRestricted) ||
          CHECK_OPERAND(0, REG_RSI, OperandSandboxUnrestricted) ||
          CHECK_OPERAND(1, REG_RSI, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_RSI, OperandSandboxUnrestricted)) {
        restricted_register = kNoRestrictedReg;
      }
    }
    if (restricted_register == kSandboxedRsi) {
      if (CHECK_OPERAND(0, REG_RDI, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_RDI, OperandSandboxRestricted)) {
        sandboxed_rsi_restricted_rdi = begin;
        restricted_register = kSandboxedRsiRestrictedRdi;
      }
    }
    if (restricted_register != kSandboxedRsiRestrictedRdi) {
      restricted_register = kNoRestrictedReg;
      if (CHECK_OPERAND(0, REG_R15, OperandSandbox8bit) ||
          CHECK_OPERAND(0, REG_R15, OperandSandboxRestricted) ||
          CHECK_OPERAND(0, REG_R15, OperandSandboxUnrestricted) ||
          CHECK_OPERAND(1, REG_R15, OperandSandbox8bit) ||
          CHECK_OPERAND(1, REG_R15, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_R15, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%r15\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((CHECK_OPERAND(0, REG_RBP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(0, REG_RBP, OperandSandboxUnrestricted) ||
                 (CHECK_OPERAND(1, REG_RBP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(1, REG_RBP, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%rbp\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((CHECK_OPERAND(0, REG_RSP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(0, REG_RSP, OperandSandboxUnrestricted) ||
                 (CHECK_OPERAND(1, REG_RSP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(1, REG_RSP, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%rsp\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((operand_states & 0x70) == (OperandSandboxRestricted << 5)) {
        restricted_register = operand_states & 0x0f;
      } else if ((operand_states & 0x7000) ==
                                        (OperandSandboxRestricted << (5 + 8))) {
        restricted_register = (operand_states & 0x0f00) >> 8;
      }
    }
  }
#line 337 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
       /* On successful match the instruction start must point to the next byte
        * to be able to report the new offset as the start of instruction
        * causing error.  */
       begin = p + 1;
     }
	goto st721;
tr14:
#line 42 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_DISP_TYPE(DISP8);
    SET_DISP_PTR(p);
  }
#line 44 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    if ((base == REG_RIP) || (base == REG_R15) ||
        ((base == REG_RSP) && (restricted_register != REG_RSP)) ||
        ((base == REG_RBP) && (restricted_register != REG_RBP))) {
      if ((index == restricted_register) ||
          ((index == REG_RDI) &&
           (restricted_register == kSandboxedRsiRestrictedRdi))) {
        BitmapClearBit(valid_targets, begin - data);
      } else if ((index != NO_REG) && (index != REG_RIZ)) {
        PrintError("Improper sandboxing in instruction\n", begin - data);
        result = 1;
        goto error_detected;
      }
    } else if ((index == REG_RIP) || (index == REG_R15) ||
               ((index == REG_RSP) && (restricted_register != REG_RSP)) ||
               ((index == REG_RBP) && (restricted_register != REG_RBP))) {
      if ((base == restricted_register) ||
          ((base == REG_RDI) &&
           (restricted_register == kSandboxedRsiRestrictedRdi))) {
        BitmapClearBit(valid_targets, begin - data);
      } else if ((base != NO_REG) && (base != REG_RIZ)) {
        PrintError("Improper sandboxing in instruction\n", begin - data);
        result = 1;
        goto error_detected;
      }
    } else {
      PrintError("Improper sandboxing in instruction\n", begin - data);
      result = 1;
      goto error_detected;
    }
  }
#line 93 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    /* Restricted %rsp or %rbp must be processed by appropriate nacl-special
       instruction, not with regular instruction.  */
    if (restricted_register == REG_RSP) {
      PrintError("Incorrectly modified register %%rsp\n", begin - data);
      result = 1;
      goto error_detected;
    } else if (restricted_register == REG_RBP) {
      PrintError("Incorrectly modified register %%rbp\n", begin - data);
      result = 1;
      goto error_detected;
    }
    /* If Sandboxed Rsi is destroyed then we must note that.  */
    if (restricted_register == kSandboxedRsi) {
      if (CHECK_OPERAND(0, REG_RSI, OperandSandboxRestricted) ||
          CHECK_OPERAND(0, REG_RSI, OperandSandboxUnrestricted) ||
          CHECK_OPERAND(1, REG_RSI, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_RSI, OperandSandboxUnrestricted)) {
        restricted_register = kNoRestrictedReg;
      }
    }
    if (restricted_register == kSandboxedRsi) {
      if (CHECK_OPERAND(0, REG_RDI, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_RDI, OperandSandboxRestricted)) {
        sandboxed_rsi_restricted_rdi = begin;
        restricted_register = kSandboxedRsiRestrictedRdi;
      }
    }
    if (restricted_register != kSandboxedRsiRestrictedRdi) {
      restricted_register = kNoRestrictedReg;
      if (CHECK_OPERAND(0, REG_R15, OperandSandbox8bit) ||
          CHECK_OPERAND(0, REG_R15, OperandSandboxRestricted) ||
          CHECK_OPERAND(0, REG_R15, OperandSandboxUnrestricted) ||
          CHECK_OPERAND(1, REG_R15, OperandSandbox8bit) ||
          CHECK_OPERAND(1, REG_R15, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_R15, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%r15\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((CHECK_OPERAND(0, REG_RBP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(0, REG_RBP, OperandSandboxUnrestricted) ||
                 (CHECK_OPERAND(1, REG_RBP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(1, REG_RBP, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%rbp\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((CHECK_OPERAND(0, REG_RSP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(0, REG_RSP, OperandSandboxUnrestricted) ||
                 (CHECK_OPERAND(1, REG_RSP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(1, REG_RSP, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%rsp\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((operand_states & 0x70) == (OperandSandboxRestricted << 5)) {
        restricted_register = operand_states & 0x0f;
      } else if ((operand_states & 0x7000) ==
                                        (OperandSandboxRestricted << (5 + 8))) {
        restricted_register = (operand_states & 0x0f00) >> 8;
      }
    }
  }
#line 337 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
       /* On successful match the instruction start must point to the next byte
        * to be able to report the new offset as the start of instruction
        * causing error.  */
       begin = p + 1;
     }
	goto st721;
tr17:
#line 389 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_NAME(0, (((*p) & 0x38) >> 3) |
                           ((GET_REX_PREFIX() & 0x04) << 1) |
                           (((~GET_VEX_PREFIX2()) & 0x80) >> 4));
  }
#line 90 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_DISP_TYPE(DISPNONE);
    SET_MODRM_BASE(((*p) & 0x07) |
                   ((GET_REX_PREFIX() & 0x01) << 3) |
                   (((~GET_VEX_PREFIX2()) & 0x20) >> 2));
    SET_MODRM_INDEX(NO_REG);
    SET_MODRM_SCALE(0);
  }
#line 44 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    if ((base == REG_RIP) || (base == REG_R15) ||
        ((base == REG_RSP) && (restricted_register != REG_RSP)) ||
        ((base == REG_RBP) && (restricted_register != REG_RBP))) {
      if ((index == restricted_register) ||
          ((index == REG_RDI) &&
           (restricted_register == kSandboxedRsiRestrictedRdi))) {
        BitmapClearBit(valid_targets, begin - data);
      } else if ((index != NO_REG) && (index != REG_RIZ)) {
        PrintError("Improper sandboxing in instruction\n", begin - data);
        result = 1;
        goto error_detected;
      }
    } else if ((index == REG_RIP) || (index == REG_R15) ||
               ((index == REG_RSP) && (restricted_register != REG_RSP)) ||
               ((index == REG_RBP) && (restricted_register != REG_RBP))) {
      if ((base == restricted_register) ||
          ((base == REG_RDI) &&
           (restricted_register == kSandboxedRsiRestrictedRdi))) {
        BitmapClearBit(valid_targets, begin - data);
      } else if ((base != NO_REG) && (base != REG_RIZ)) {
        PrintError("Improper sandboxing in instruction\n", begin - data);
        result = 1;
        goto error_detected;
      }
    } else {
      PrintError("Improper sandboxing in instruction\n", begin - data);
      result = 1;
      goto error_detected;
    }
  }
#line 93 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    /* Restricted %rsp or %rbp must be processed by appropriate nacl-special
       instruction, not with regular instruction.  */
    if (restricted_register == REG_RSP) {
      PrintError("Incorrectly modified register %%rsp\n", begin - data);
      result = 1;
      goto error_detected;
    } else if (restricted_register == REG_RBP) {
      PrintError("Incorrectly modified register %%rbp\n", begin - data);
      result = 1;
      goto error_detected;
    }
    /* If Sandboxed Rsi is destroyed then we must note that.  */
    if (restricted_register == kSandboxedRsi) {
      if (CHECK_OPERAND(0, REG_RSI, OperandSandboxRestricted) ||
          CHECK_OPERAND(0, REG_RSI, OperandSandboxUnrestricted) ||
          CHECK_OPERAND(1, REG_RSI, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_RSI, OperandSandboxUnrestricted)) {
        restricted_register = kNoRestrictedReg;
      }
    }
    if (restricted_register == kSandboxedRsi) {
      if (CHECK_OPERAND(0, REG_RDI, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_RDI, OperandSandboxRestricted)) {
        sandboxed_rsi_restricted_rdi = begin;
        restricted_register = kSandboxedRsiRestrictedRdi;
      }
    }
    if (restricted_register != kSandboxedRsiRestrictedRdi) {
      restricted_register = kNoRestrictedReg;
      if (CHECK_OPERAND(0, REG_R15, OperandSandbox8bit) ||
          CHECK_OPERAND(0, REG_R15, OperandSandboxRestricted) ||
          CHECK_OPERAND(0, REG_R15, OperandSandboxUnrestricted) ||
          CHECK_OPERAND(1, REG_R15, OperandSandbox8bit) ||
          CHECK_OPERAND(1, REG_R15, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_R15, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%r15\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((CHECK_OPERAND(0, REG_RBP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(0, REG_RBP, OperandSandboxUnrestricted) ||
                 (CHECK_OPERAND(1, REG_RBP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(1, REG_RBP, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%rbp\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((CHECK_OPERAND(0, REG_RSP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(0, REG_RSP, OperandSandboxUnrestricted) ||
                 (CHECK_OPERAND(1, REG_RSP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(1, REG_RSP, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%rsp\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((operand_states & 0x70) == (OperandSandboxRestricted << 5)) {
        restricted_register = operand_states & 0x0f;
      } else if ((operand_states & 0x7000) ==
                                        (OperandSandboxRestricted << (5 + 8))) {
        restricted_register = (operand_states & 0x0f00) >> 8;
      }
    }
  }
#line 337 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
       /* On successful match the instruction start must point to the next byte
        * to be able to report the new offset as the start of instruction
        * causing error.  */
       begin = p + 1;
     }
	goto st721;
tr24:
#line 389 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_NAME(0, (((*p) & 0x38) >> 3) |
                           ((GET_REX_PREFIX() & 0x04) << 1) |
                           (((~GET_VEX_PREFIX2()) & 0x80) >> 4));
  }
#line 93 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    /* Restricted %rsp or %rbp must be processed by appropriate nacl-special
       instruction, not with regular instruction.  */
    if (restricted_register == REG_RSP) {
      PrintError("Incorrectly modified register %%rsp\n", begin - data);
      result = 1;
      goto error_detected;
    } else if (restricted_register == REG_RBP) {
      PrintError("Incorrectly modified register %%rbp\n", begin - data);
      result = 1;
      goto error_detected;
    }
    /* If Sandboxed Rsi is destroyed then we must note that.  */
    if (restricted_register == kSandboxedRsi) {
      if (CHECK_OPERAND(0, REG_RSI, OperandSandboxRestricted) ||
          CHECK_OPERAND(0, REG_RSI, OperandSandboxUnrestricted) ||
          CHECK_OPERAND(1, REG_RSI, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_RSI, OperandSandboxUnrestricted)) {
        restricted_register = kNoRestrictedReg;
      }
    }
    if (restricted_register == kSandboxedRsi) {
      if (CHECK_OPERAND(0, REG_RDI, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_RDI, OperandSandboxRestricted)) {
        sandboxed_rsi_restricted_rdi = begin;
        restricted_register = kSandboxedRsiRestrictedRdi;
      }
    }
    if (restricted_register != kSandboxedRsiRestrictedRdi) {
      restricted_register = kNoRestrictedReg;
      if (CHECK_OPERAND(0, REG_R15, OperandSandbox8bit) ||
          CHECK_OPERAND(0, REG_R15, OperandSandboxRestricted) ||
          CHECK_OPERAND(0, REG_R15, OperandSandboxUnrestricted) ||
          CHECK_OPERAND(1, REG_R15, OperandSandbox8bit) ||
          CHECK_OPERAND(1, REG_R15, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_R15, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%r15\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((CHECK_OPERAND(0, REG_RBP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(0, REG_RBP, OperandSandboxUnrestricted) ||
                 (CHECK_OPERAND(1, REG_RBP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(1, REG_RBP, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%rbp\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((CHECK_OPERAND(0, REG_RSP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(0, REG_RSP, OperandSandboxUnrestricted) ||
                 (CHECK_OPERAND(1, REG_RSP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(1, REG_RSP, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%rsp\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((operand_states & 0x70) == (OperandSandboxRestricted << 5)) {
        restricted_register = operand_states & 0x0f;
      } else if ((operand_states & 0x7000) ==
                                        (OperandSandboxRestricted << (5 + 8))) {
        restricted_register = (operand_states & 0x0f00) >> 8;
      }
    }
  }
#line 337 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
       /* On successful match the instruction start must point to the next byte
        * to be able to report the new offset as the start of instruction
        * causing error.  */
       begin = p + 1;
     }
	goto st721;
tr25:
#line 58 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_IMM_TYPE(IMM8);
    SET_IMM_PTR(p);
  }
#line 93 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    /* Restricted %rsp or %rbp must be processed by appropriate nacl-special
       instruction, not with regular instruction.  */
    if (restricted_register == REG_RSP) {
      PrintError("Incorrectly modified register %%rsp\n", begin - data);
      result = 1;
      goto error_detected;
    } else if (restricted_register == REG_RBP) {
      PrintError("Incorrectly modified register %%rbp\n", begin - data);
      result = 1;
      goto error_detected;
    }
    /* If Sandboxed Rsi is destroyed then we must note that.  */
    if (restricted_register == kSandboxedRsi) {
      if (CHECK_OPERAND(0, REG_RSI, OperandSandboxRestricted) ||
          CHECK_OPERAND(0, REG_RSI, OperandSandboxUnrestricted) ||
          CHECK_OPERAND(1, REG_RSI, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_RSI, OperandSandboxUnrestricted)) {
        restricted_register = kNoRestrictedReg;
      }
    }
    if (restricted_register == kSandboxedRsi) {
      if (CHECK_OPERAND(0, REG_RDI, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_RDI, OperandSandboxRestricted)) {
        sandboxed_rsi_restricted_rdi = begin;
        restricted_register = kSandboxedRsiRestrictedRdi;
      }
    }
    if (restricted_register != kSandboxedRsiRestrictedRdi) {
      restricted_register = kNoRestrictedReg;
      if (CHECK_OPERAND(0, REG_R15, OperandSandbox8bit) ||
          CHECK_OPERAND(0, REG_R15, OperandSandboxRestricted) ||
          CHECK_OPERAND(0, REG_R15, OperandSandboxUnrestricted) ||
          CHECK_OPERAND(1, REG_R15, OperandSandbox8bit) ||
          CHECK_OPERAND(1, REG_R15, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_R15, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%r15\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((CHECK_OPERAND(0, REG_RBP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(0, REG_RBP, OperandSandboxUnrestricted) ||
                 (CHECK_OPERAND(1, REG_RBP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(1, REG_RBP, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%rbp\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((CHECK_OPERAND(0, REG_RSP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(0, REG_RSP, OperandSandboxUnrestricted) ||
                 (CHECK_OPERAND(1, REG_RSP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(1, REG_RSP, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%rsp\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((operand_states & 0x70) == (OperandSandboxRestricted << 5)) {
        restricted_register = operand_states & 0x0f;
      } else if ((operand_states & 0x7000) ==
                                        (OperandSandboxRestricted << (5 + 8))) {
        restricted_register = (operand_states & 0x0f00) >> 8;
      }
    }
  }
#line 337 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
       /* On successful match the instruction start must point to the next byte
        * to be able to report the new offset as the start of instruction
        * causing error.  */
       begin = p + 1;
     }
	goto st721;
tr29:
#line 74 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_IMM_TYPE(IMM32);
    SET_IMM_PTR(p - 3);
  }
#line 93 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    /* Restricted %rsp or %rbp must be processed by appropriate nacl-special
       instruction, not with regular instruction.  */
    if (restricted_register == REG_RSP) {
      PrintError("Incorrectly modified register %%rsp\n", begin - data);
      result = 1;
      goto error_detected;
    } else if (restricted_register == REG_RBP) {
      PrintError("Incorrectly modified register %%rbp\n", begin - data);
      result = 1;
      goto error_detected;
    }
    /* If Sandboxed Rsi is destroyed then we must note that.  */
    if (restricted_register == kSandboxedRsi) {
      if (CHECK_OPERAND(0, REG_RSI, OperandSandboxRestricted) ||
          CHECK_OPERAND(0, REG_RSI, OperandSandboxUnrestricted) ||
          CHECK_OPERAND(1, REG_RSI, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_RSI, OperandSandboxUnrestricted)) {
        restricted_register = kNoRestrictedReg;
      }
    }
    if (restricted_register == kSandboxedRsi) {
      if (CHECK_OPERAND(0, REG_RDI, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_RDI, OperandSandboxRestricted)) {
        sandboxed_rsi_restricted_rdi = begin;
        restricted_register = kSandboxedRsiRestrictedRdi;
      }
    }
    if (restricted_register != kSandboxedRsiRestrictedRdi) {
      restricted_register = kNoRestrictedReg;
      if (CHECK_OPERAND(0, REG_R15, OperandSandbox8bit) ||
          CHECK_OPERAND(0, REG_R15, OperandSandboxRestricted) ||
          CHECK_OPERAND(0, REG_R15, OperandSandboxUnrestricted) ||
          CHECK_OPERAND(1, REG_R15, OperandSandbox8bit) ||
          CHECK_OPERAND(1, REG_R15, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_R15, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%r15\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((CHECK_OPERAND(0, REG_RBP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(0, REG_RBP, OperandSandboxUnrestricted) ||
                 (CHECK_OPERAND(1, REG_RBP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(1, REG_RBP, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%rbp\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((CHECK_OPERAND(0, REG_RSP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(0, REG_RSP, OperandSandboxUnrestricted) ||
                 (CHECK_OPERAND(1, REG_RSP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(1, REG_RSP, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%rsp\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((operand_states & 0x70) == (OperandSandboxRestricted << 5)) {
        restricted_register = operand_states & 0x0f;
      } else if ((operand_states & 0x7000) ==
                                        (OperandSandboxRestricted << (5 + 8))) {
        restricted_register = (operand_states & 0x0f00) >> 8;
      }
    }
  }
#line 337 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
       /* On successful match the instruction start must point to the next byte
        * to be able to report the new offset as the start of instruction
        * causing error.  */
       begin = p + 1;
     }
	goto st721;
tr34:
#line 93 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    /* Restricted %rsp or %rbp must be processed by appropriate nacl-special
       instruction, not with regular instruction.  */
    if (restricted_register == REG_RSP) {
      PrintError("Incorrectly modified register %%rsp\n", begin - data);
      result = 1;
      goto error_detected;
    } else if (restricted_register == REG_RBP) {
      PrintError("Incorrectly modified register %%rbp\n", begin - data);
      result = 1;
      goto error_detected;
    }
    /* If Sandboxed Rsi is destroyed then we must note that.  */
    if (restricted_register == kSandboxedRsi) {
      if (CHECK_OPERAND(0, REG_RSI, OperandSandboxRestricted) ||
          CHECK_OPERAND(0, REG_RSI, OperandSandboxUnrestricted) ||
          CHECK_OPERAND(1, REG_RSI, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_RSI, OperandSandboxUnrestricted)) {
        restricted_register = kNoRestrictedReg;
      }
    }
    if (restricted_register == kSandboxedRsi) {
      if (CHECK_OPERAND(0, REG_RDI, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_RDI, OperandSandboxRestricted)) {
        sandboxed_rsi_restricted_rdi = begin;
        restricted_register = kSandboxedRsiRestrictedRdi;
      }
    }
    if (restricted_register != kSandboxedRsiRestrictedRdi) {
      restricted_register = kNoRestrictedReg;
      if (CHECK_OPERAND(0, REG_R15, OperandSandbox8bit) ||
          CHECK_OPERAND(0, REG_R15, OperandSandboxRestricted) ||
          CHECK_OPERAND(0, REG_R15, OperandSandboxUnrestricted) ||
          CHECK_OPERAND(1, REG_R15, OperandSandbox8bit) ||
          CHECK_OPERAND(1, REG_R15, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_R15, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%r15\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((CHECK_OPERAND(0, REG_RBP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(0, REG_RBP, OperandSandboxUnrestricted) ||
                 (CHECK_OPERAND(1, REG_RBP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(1, REG_RBP, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%rbp\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((CHECK_OPERAND(0, REG_RSP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(0, REG_RSP, OperandSandboxUnrestricted) ||
                 (CHECK_OPERAND(1, REG_RSP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(1, REG_RSP, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%rsp\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((operand_states & 0x70) == (OperandSandboxRestricted << 5)) {
        restricted_register = operand_states & 0x0f;
      } else if ((operand_states & 0x7000) ==
                                        (OperandSandboxRestricted << (5 + 8))) {
        restricted_register = (operand_states & 0x0f00) >> 8;
      }
    }
  }
#line 337 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
       /* On successful match the instruction start must point to the next byte
        * to be able to report the new offset as the start of instruction
        * causing error.  */
       begin = p + 1;
     }
	goto st721;
tr54:
#line 376 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_NAME(0, ((*p) & 0x7) |
                            ((GET_REX_PREFIX() & 0x01) << 3) |
                            (((~GET_VEX_PREFIX2()) & 0x20) >> 2));
  }
#line 295 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(0, OperandSize32bit);
  }
#line 93 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    /* Restricted %rsp or %rbp must be processed by appropriate nacl-special
       instruction, not with regular instruction.  */
    if (restricted_register == REG_RSP) {
      PrintError("Incorrectly modified register %%rsp\n", begin - data);
      result = 1;
      goto error_detected;
    } else if (restricted_register == REG_RBP) {
      PrintError("Incorrectly modified register %%rbp\n", begin - data);
      result = 1;
      goto error_detected;
    }
    /* If Sandboxed Rsi is destroyed then we must note that.  */
    if (restricted_register == kSandboxedRsi) {
      if (CHECK_OPERAND(0, REG_RSI, OperandSandboxRestricted) ||
          CHECK_OPERAND(0, REG_RSI, OperandSandboxUnrestricted) ||
          CHECK_OPERAND(1, REG_RSI, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_RSI, OperandSandboxUnrestricted)) {
        restricted_register = kNoRestrictedReg;
      }
    }
    if (restricted_register == kSandboxedRsi) {
      if (CHECK_OPERAND(0, REG_RDI, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_RDI, OperandSandboxRestricted)) {
        sandboxed_rsi_restricted_rdi = begin;
        restricted_register = kSandboxedRsiRestrictedRdi;
      }
    }
    if (restricted_register != kSandboxedRsiRestrictedRdi) {
      restricted_register = kNoRestrictedReg;
      if (CHECK_OPERAND(0, REG_R15, OperandSandbox8bit) ||
          CHECK_OPERAND(0, REG_R15, OperandSandboxRestricted) ||
          CHECK_OPERAND(0, REG_R15, OperandSandboxUnrestricted) ||
          CHECK_OPERAND(1, REG_R15, OperandSandbox8bit) ||
          CHECK_OPERAND(1, REG_R15, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_R15, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%r15\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((CHECK_OPERAND(0, REG_RBP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(0, REG_RBP, OperandSandboxUnrestricted) ||
                 (CHECK_OPERAND(1, REG_RBP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(1, REG_RBP, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%rbp\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((CHECK_OPERAND(0, REG_RSP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(0, REG_RSP, OperandSandboxUnrestricted) ||
                 (CHECK_OPERAND(1, REG_RSP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(1, REG_RSP, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%rsp\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((operand_states & 0x70) == (OperandSandboxRestricted << 5)) {
        restricted_register = operand_states & 0x0f;
      } else if ((operand_states & 0x7000) ==
                                        (OperandSandboxRestricted << (5 + 8))) {
        restricted_register = (operand_states & 0x0f00) >> 8;
      }
    }
  }
#line 337 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
       /* On successful match the instruction start must point to the next byte
        * to be able to report the new offset as the start of instruction
        * causing error.  */
       begin = p + 1;
     }
	goto st721;
tr56:
#line 295 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(0, OperandSize32bit);
  }
#line 384 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_NAME(0, ((*p) & 0x07) |
                           ((GET_REX_PREFIX() & 0x01) << 3) |
                           (((~GET_VEX_PREFIX2()) & 0x20) >> 2));
  }
#line 93 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    /* Restricted %rsp or %rbp must be processed by appropriate nacl-special
       instruction, not with regular instruction.  */
    if (restricted_register == REG_RSP) {
      PrintError("Incorrectly modified register %%rsp\n", begin - data);
      result = 1;
      goto error_detected;
    } else if (restricted_register == REG_RBP) {
      PrintError("Incorrectly modified register %%rbp\n", begin - data);
      result = 1;
      goto error_detected;
    }
    /* If Sandboxed Rsi is destroyed then we must note that.  */
    if (restricted_register == kSandboxedRsi) {
      if (CHECK_OPERAND(0, REG_RSI, OperandSandboxRestricted) ||
          CHECK_OPERAND(0, REG_RSI, OperandSandboxUnrestricted) ||
          CHECK_OPERAND(1, REG_RSI, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_RSI, OperandSandboxUnrestricted)) {
        restricted_register = kNoRestrictedReg;
      }
    }
    if (restricted_register == kSandboxedRsi) {
      if (CHECK_OPERAND(0, REG_RDI, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_RDI, OperandSandboxRestricted)) {
        sandboxed_rsi_restricted_rdi = begin;
        restricted_register = kSandboxedRsiRestrictedRdi;
      }
    }
    if (restricted_register != kSandboxedRsiRestrictedRdi) {
      restricted_register = kNoRestrictedReg;
      if (CHECK_OPERAND(0, REG_R15, OperandSandbox8bit) ||
          CHECK_OPERAND(0, REG_R15, OperandSandboxRestricted) ||
          CHECK_OPERAND(0, REG_R15, OperandSandboxUnrestricted) ||
          CHECK_OPERAND(1, REG_R15, OperandSandbox8bit) ||
          CHECK_OPERAND(1, REG_R15, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_R15, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%r15\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((CHECK_OPERAND(0, REG_RBP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(0, REG_RBP, OperandSandboxUnrestricted) ||
                 (CHECK_OPERAND(1, REG_RBP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(1, REG_RBP, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%rbp\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((CHECK_OPERAND(0, REG_RSP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(0, REG_RSP, OperandSandboxUnrestricted) ||
                 (CHECK_OPERAND(1, REG_RSP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(1, REG_RSP, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%rsp\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((operand_states & 0x70) == (OperandSandboxRestricted << 5)) {
        restricted_register = operand_states & 0x0f;
      } else if ((operand_states & 0x7000) ==
                                        (OperandSandboxRestricted << (5 + 8))) {
        restricted_register = (operand_states & 0x0f00) >> 8;
      }
    }
  }
#line 337 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
       /* On successful match the instruction start must point to the next byte
        * to be able to report the new offset as the start of instruction
        * causing error.  */
       begin = p + 1;
     }
	goto st721;
tr57:
#line 292 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(0, OperandSize16bit);
  }
#line 384 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_NAME(0, ((*p) & 0x07) |
                           ((GET_REX_PREFIX() & 0x01) << 3) |
                           (((~GET_VEX_PREFIX2()) & 0x20) >> 2));
  }
#line 93 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    /* Restricted %rsp or %rbp must be processed by appropriate nacl-special
       instruction, not with regular instruction.  */
    if (restricted_register == REG_RSP) {
      PrintError("Incorrectly modified register %%rsp\n", begin - data);
      result = 1;
      goto error_detected;
    } else if (restricted_register == REG_RBP) {
      PrintError("Incorrectly modified register %%rbp\n", begin - data);
      result = 1;
      goto error_detected;
    }
    /* If Sandboxed Rsi is destroyed then we must note that.  */
    if (restricted_register == kSandboxedRsi) {
      if (CHECK_OPERAND(0, REG_RSI, OperandSandboxRestricted) ||
          CHECK_OPERAND(0, REG_RSI, OperandSandboxUnrestricted) ||
          CHECK_OPERAND(1, REG_RSI, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_RSI, OperandSandboxUnrestricted)) {
        restricted_register = kNoRestrictedReg;
      }
    }
    if (restricted_register == kSandboxedRsi) {
      if (CHECK_OPERAND(0, REG_RDI, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_RDI, OperandSandboxRestricted)) {
        sandboxed_rsi_restricted_rdi = begin;
        restricted_register = kSandboxedRsiRestrictedRdi;
      }
    }
    if (restricted_register != kSandboxedRsiRestrictedRdi) {
      restricted_register = kNoRestrictedReg;
      if (CHECK_OPERAND(0, REG_R15, OperandSandbox8bit) ||
          CHECK_OPERAND(0, REG_R15, OperandSandboxRestricted) ||
          CHECK_OPERAND(0, REG_R15, OperandSandboxUnrestricted) ||
          CHECK_OPERAND(1, REG_R15, OperandSandbox8bit) ||
          CHECK_OPERAND(1, REG_R15, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_R15, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%r15\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((CHECK_OPERAND(0, REG_RBP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(0, REG_RBP, OperandSandboxUnrestricted) ||
                 (CHECK_OPERAND(1, REG_RBP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(1, REG_RBP, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%rbp\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((CHECK_OPERAND(0, REG_RSP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(0, REG_RSP, OperandSandboxUnrestricted) ||
                 (CHECK_OPERAND(1, REG_RSP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(1, REG_RSP, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%rsp\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((operand_states & 0x70) == (OperandSandboxRestricted << 5)) {
        restricted_register = operand_states & 0x0f;
      } else if ((operand_states & 0x7000) ==
                                        (OperandSandboxRestricted << (5 + 8))) {
        restricted_register = (operand_states & 0x0f00) >> 8;
      }
    }
  }
#line 337 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
       /* On successful match the instruction start must point to the next byte
        * to be able to report the new offset as the start of instruction
        * causing error.  */
       begin = p + 1;
     }
	goto st721;
tr58:
#line 319 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(0, OperandSize64bit);
  }
#line 424 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_NAME(0, REG_RDX);
  }
#line 93 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    /* Restricted %rsp or %rbp must be processed by appropriate nacl-special
       instruction, not with regular instruction.  */
    if (restricted_register == REG_RSP) {
      PrintError("Incorrectly modified register %%rsp\n", begin - data);
      result = 1;
      goto error_detected;
    } else if (restricted_register == REG_RBP) {
      PrintError("Incorrectly modified register %%rbp\n", begin - data);
      result = 1;
      goto error_detected;
    }
    /* If Sandboxed Rsi is destroyed then we must note that.  */
    if (restricted_register == kSandboxedRsi) {
      if (CHECK_OPERAND(0, REG_RSI, OperandSandboxRestricted) ||
          CHECK_OPERAND(0, REG_RSI, OperandSandboxUnrestricted) ||
          CHECK_OPERAND(1, REG_RSI, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_RSI, OperandSandboxUnrestricted)) {
        restricted_register = kNoRestrictedReg;
      }
    }
    if (restricted_register == kSandboxedRsi) {
      if (CHECK_OPERAND(0, REG_RDI, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_RDI, OperandSandboxRestricted)) {
        sandboxed_rsi_restricted_rdi = begin;
        restricted_register = kSandboxedRsiRestrictedRdi;
      }
    }
    if (restricted_register != kSandboxedRsiRestrictedRdi) {
      restricted_register = kNoRestrictedReg;
      if (CHECK_OPERAND(0, REG_R15, OperandSandbox8bit) ||
          CHECK_OPERAND(0, REG_R15, OperandSandboxRestricted) ||
          CHECK_OPERAND(0, REG_R15, OperandSandboxUnrestricted) ||
          CHECK_OPERAND(1, REG_R15, OperandSandbox8bit) ||
          CHECK_OPERAND(1, REG_R15, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_R15, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%r15\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((CHECK_OPERAND(0, REG_RBP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(0, REG_RBP, OperandSandboxUnrestricted) ||
                 (CHECK_OPERAND(1, REG_RBP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(1, REG_RBP, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%rbp\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((CHECK_OPERAND(0, REG_RSP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(0, REG_RSP, OperandSandboxUnrestricted) ||
                 (CHECK_OPERAND(1, REG_RSP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(1, REG_RSP, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%rsp\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((operand_states & 0x70) == (OperandSandboxRestricted << 5)) {
        restricted_register = operand_states & 0x0f;
      } else if ((operand_states & 0x7000) ==
                                        (OperandSandboxRestricted << (5 + 8))) {
        restricted_register = (operand_states & 0x0f00) >> 8;
      }
    }
  }
#line 337 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
       /* On successful match the instruction start must point to the next byte
        * to be able to report the new offset as the start of instruction
        * causing error.  */
       begin = p + 1;
     }
	goto st721;
tr59:
#line 319 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(0, OperandSize64bit);
  }
#line 421 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_NAME(0, REG_RCX);
  }
#line 93 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    /* Restricted %rsp or %rbp must be processed by appropriate nacl-special
       instruction, not with regular instruction.  */
    if (restricted_register == REG_RSP) {
      PrintError("Incorrectly modified register %%rsp\n", begin - data);
      result = 1;
      goto error_detected;
    } else if (restricted_register == REG_RBP) {
      PrintError("Incorrectly modified register %%rbp\n", begin - data);
      result = 1;
      goto error_detected;
    }
    /* If Sandboxed Rsi is destroyed then we must note that.  */
    if (restricted_register == kSandboxedRsi) {
      if (CHECK_OPERAND(0, REG_RSI, OperandSandboxRestricted) ||
          CHECK_OPERAND(0, REG_RSI, OperandSandboxUnrestricted) ||
          CHECK_OPERAND(1, REG_RSI, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_RSI, OperandSandboxUnrestricted)) {
        restricted_register = kNoRestrictedReg;
      }
    }
    if (restricted_register == kSandboxedRsi) {
      if (CHECK_OPERAND(0, REG_RDI, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_RDI, OperandSandboxRestricted)) {
        sandboxed_rsi_restricted_rdi = begin;
        restricted_register = kSandboxedRsiRestrictedRdi;
      }
    }
    if (restricted_register != kSandboxedRsiRestrictedRdi) {
      restricted_register = kNoRestrictedReg;
      if (CHECK_OPERAND(0, REG_R15, OperandSandbox8bit) ||
          CHECK_OPERAND(0, REG_R15, OperandSandboxRestricted) ||
          CHECK_OPERAND(0, REG_R15, OperandSandboxUnrestricted) ||
          CHECK_OPERAND(1, REG_R15, OperandSandbox8bit) ||
          CHECK_OPERAND(1, REG_R15, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_R15, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%r15\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((CHECK_OPERAND(0, REG_RBP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(0, REG_RBP, OperandSandboxUnrestricted) ||
                 (CHECK_OPERAND(1, REG_RBP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(1, REG_RBP, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%rbp\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((CHECK_OPERAND(0, REG_RSP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(0, REG_RSP, OperandSandboxUnrestricted) ||
                 (CHECK_OPERAND(1, REG_RSP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(1, REG_RSP, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%rsp\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((operand_states & 0x70) == (OperandSandboxRestricted << 5)) {
        restricted_register = operand_states & 0x0f;
      } else if ((operand_states & 0x7000) ==
                                        (OperandSandboxRestricted << (5 + 8))) {
        restricted_register = (operand_states & 0x0f00) >> 8;
      }
    }
  }
#line 337 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
       /* On successful match the instruction start must point to the next byte
        * to be able to report the new offset as the start of instruction
        * causing error.  */
       begin = p + 1;
     }
	goto st721;
tr60:
#line 90 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_DISP_TYPE(DISPNONE);
    SET_MODRM_BASE(((*p) & 0x07) |
                   ((GET_REX_PREFIX() & 0x01) << 3) |
                   (((~GET_VEX_PREFIX2()) & 0x20) >> 2));
    SET_MODRM_INDEX(NO_REG);
    SET_MODRM_SCALE(0);
  }
#line 93 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    /* Restricted %rsp or %rbp must be processed by appropriate nacl-special
       instruction, not with regular instruction.  */
    if (restricted_register == REG_RSP) {
      PrintError("Incorrectly modified register %%rsp\n", begin - data);
      result = 1;
      goto error_detected;
    } else if (restricted_register == REG_RBP) {
      PrintError("Incorrectly modified register %%rbp\n", begin - data);
      result = 1;
      goto error_detected;
    }
    /* If Sandboxed Rsi is destroyed then we must note that.  */
    if (restricted_register == kSandboxedRsi) {
      if (CHECK_OPERAND(0, REG_RSI, OperandSandboxRestricted) ||
          CHECK_OPERAND(0, REG_RSI, OperandSandboxUnrestricted) ||
          CHECK_OPERAND(1, REG_RSI, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_RSI, OperandSandboxUnrestricted)) {
        restricted_register = kNoRestrictedReg;
      }
    }
    if (restricted_register == kSandboxedRsi) {
      if (CHECK_OPERAND(0, REG_RDI, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_RDI, OperandSandboxRestricted)) {
        sandboxed_rsi_restricted_rdi = begin;
        restricted_register = kSandboxedRsiRestrictedRdi;
      }
    }
    if (restricted_register != kSandboxedRsiRestrictedRdi) {
      restricted_register = kNoRestrictedReg;
      if (CHECK_OPERAND(0, REG_R15, OperandSandbox8bit) ||
          CHECK_OPERAND(0, REG_R15, OperandSandboxRestricted) ||
          CHECK_OPERAND(0, REG_R15, OperandSandboxUnrestricted) ||
          CHECK_OPERAND(1, REG_R15, OperandSandbox8bit) ||
          CHECK_OPERAND(1, REG_R15, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_R15, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%r15\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((CHECK_OPERAND(0, REG_RBP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(0, REG_RBP, OperandSandboxUnrestricted) ||
                 (CHECK_OPERAND(1, REG_RBP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(1, REG_RBP, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%rbp\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((CHECK_OPERAND(0, REG_RSP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(0, REG_RSP, OperandSandboxUnrestricted) ||
                 (CHECK_OPERAND(1, REG_RSP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(1, REG_RSP, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%rsp\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((operand_states & 0x70) == (OperandSandboxRestricted << 5)) {
        restricted_register = operand_states & 0x0f;
      } else if ((operand_states & 0x7000) ==
                                        (OperandSandboxRestricted << (5 + 8))) {
        restricted_register = (operand_states & 0x0f00) >> 8;
      }
    }
  }
#line 337 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
       /* On successful match the instruction start must point to the next byte
        * to be able to report the new offset as the start of instruction
        * causing error.  */
       begin = p + 1;
     }
	goto st721;
tr67:
#line 118 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_DISP_TYPE(DISPNONE);
    SET_MODRM_BASE(((*p) & 0x7) |
                   ((GET_REX_PREFIX() & 0x01) << 3) |
                   (((~GET_VEX_PREFIX2()) & 0x20) >> 2));
    SET_MODRM_INDEX(index_registers[(((*p) & 0x38) >> 3) |
                                    ((GET_REX_PREFIX() & 0x02) << 2) |
                                    (((~GET_VEX_PREFIX2()) & 0x40) >> 3)]);
    SET_MODRM_SCALE(((*p) & 0xc0) >> 6);
  }
#line 93 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    /* Restricted %rsp or %rbp must be processed by appropriate nacl-special
       instruction, not with regular instruction.  */
    if (restricted_register == REG_RSP) {
      PrintError("Incorrectly modified register %%rsp\n", begin - data);
      result = 1;
      goto error_detected;
    } else if (restricted_register == REG_RBP) {
      PrintError("Incorrectly modified register %%rbp\n", begin - data);
      result = 1;
      goto error_detected;
    }
    /* If Sandboxed Rsi is destroyed then we must note that.  */
    if (restricted_register == kSandboxedRsi) {
      if (CHECK_OPERAND(0, REG_RSI, OperandSandboxRestricted) ||
          CHECK_OPERAND(0, REG_RSI, OperandSandboxUnrestricted) ||
          CHECK_OPERAND(1, REG_RSI, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_RSI, OperandSandboxUnrestricted)) {
        restricted_register = kNoRestrictedReg;
      }
    }
    if (restricted_register == kSandboxedRsi) {
      if (CHECK_OPERAND(0, REG_RDI, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_RDI, OperandSandboxRestricted)) {
        sandboxed_rsi_restricted_rdi = begin;
        restricted_register = kSandboxedRsiRestrictedRdi;
      }
    }
    if (restricted_register != kSandboxedRsiRestrictedRdi) {
      restricted_register = kNoRestrictedReg;
      if (CHECK_OPERAND(0, REG_R15, OperandSandbox8bit) ||
          CHECK_OPERAND(0, REG_R15, OperandSandboxRestricted) ||
          CHECK_OPERAND(0, REG_R15, OperandSandboxUnrestricted) ||
          CHECK_OPERAND(1, REG_R15, OperandSandbox8bit) ||
          CHECK_OPERAND(1, REG_R15, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_R15, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%r15\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((CHECK_OPERAND(0, REG_RBP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(0, REG_RBP, OperandSandboxUnrestricted) ||
                 (CHECK_OPERAND(1, REG_RBP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(1, REG_RBP, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%rbp\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((CHECK_OPERAND(0, REG_RSP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(0, REG_RSP, OperandSandboxUnrestricted) ||
                 (CHECK_OPERAND(1, REG_RSP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(1, REG_RSP, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%rsp\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((operand_states & 0x70) == (OperandSandboxRestricted << 5)) {
        restricted_register = operand_states & 0x0f;
      } else if ((operand_states & 0x7000) ==
                                        (OperandSandboxRestricted << (5 + 8))) {
        restricted_register = (operand_states & 0x0f00) >> 8;
      }
    }
  }
#line 337 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
       /* On successful match the instruction start must point to the next byte
        * to be able to report the new offset as the start of instruction
        * causing error.  */
       begin = p + 1;
     }
	goto st721;
tr72:
#line 46 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_DISP_TYPE(DISP32);
    SET_DISP_PTR(p - 3);
  }
#line 93 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    /* Restricted %rsp or %rbp must be processed by appropriate nacl-special
       instruction, not with regular instruction.  */
    if (restricted_register == REG_RSP) {
      PrintError("Incorrectly modified register %%rsp\n", begin - data);
      result = 1;
      goto error_detected;
    } else if (restricted_register == REG_RBP) {
      PrintError("Incorrectly modified register %%rbp\n", begin - data);
      result = 1;
      goto error_detected;
    }
    /* If Sandboxed Rsi is destroyed then we must note that.  */
    if (restricted_register == kSandboxedRsi) {
      if (CHECK_OPERAND(0, REG_RSI, OperandSandboxRestricted) ||
          CHECK_OPERAND(0, REG_RSI, OperandSandboxUnrestricted) ||
          CHECK_OPERAND(1, REG_RSI, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_RSI, OperandSandboxUnrestricted)) {
        restricted_register = kNoRestrictedReg;
      }
    }
    if (restricted_register == kSandboxedRsi) {
      if (CHECK_OPERAND(0, REG_RDI, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_RDI, OperandSandboxRestricted)) {
        sandboxed_rsi_restricted_rdi = begin;
        restricted_register = kSandboxedRsiRestrictedRdi;
      }
    }
    if (restricted_register != kSandboxedRsiRestrictedRdi) {
      restricted_register = kNoRestrictedReg;
      if (CHECK_OPERAND(0, REG_R15, OperandSandbox8bit) ||
          CHECK_OPERAND(0, REG_R15, OperandSandboxRestricted) ||
          CHECK_OPERAND(0, REG_R15, OperandSandboxUnrestricted) ||
          CHECK_OPERAND(1, REG_R15, OperandSandbox8bit) ||
          CHECK_OPERAND(1, REG_R15, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_R15, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%r15\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((CHECK_OPERAND(0, REG_RBP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(0, REG_RBP, OperandSandboxUnrestricted) ||
                 (CHECK_OPERAND(1, REG_RBP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(1, REG_RBP, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%rbp\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((CHECK_OPERAND(0, REG_RSP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(0, REG_RSP, OperandSandboxUnrestricted) ||
                 (CHECK_OPERAND(1, REG_RSP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(1, REG_RSP, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%rsp\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((operand_states & 0x70) == (OperandSandboxRestricted << 5)) {
        restricted_register = operand_states & 0x0f;
      } else if ((operand_states & 0x7000) ==
                                        (OperandSandboxRestricted << (5 + 8))) {
        restricted_register = (operand_states & 0x0f00) >> 8;
      }
    }
  }
#line 337 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
       /* On successful match the instruction start must point to the next byte
        * to be able to report the new offset as the start of instruction
        * causing error.  */
       begin = p + 1;
     }
	goto st721;
tr73:
#line 42 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_DISP_TYPE(DISP8);
    SET_DISP_PTR(p);
  }
#line 93 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    /* Restricted %rsp or %rbp must be processed by appropriate nacl-special
       instruction, not with regular instruction.  */
    if (restricted_register == REG_RSP) {
      PrintError("Incorrectly modified register %%rsp\n", begin - data);
      result = 1;
      goto error_detected;
    } else if (restricted_register == REG_RBP) {
      PrintError("Incorrectly modified register %%rbp\n", begin - data);
      result = 1;
      goto error_detected;
    }
    /* If Sandboxed Rsi is destroyed then we must note that.  */
    if (restricted_register == kSandboxedRsi) {
      if (CHECK_OPERAND(0, REG_RSI, OperandSandboxRestricted) ||
          CHECK_OPERAND(0, REG_RSI, OperandSandboxUnrestricted) ||
          CHECK_OPERAND(1, REG_RSI, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_RSI, OperandSandboxUnrestricted)) {
        restricted_register = kNoRestrictedReg;
      }
    }
    if (restricted_register == kSandboxedRsi) {
      if (CHECK_OPERAND(0, REG_RDI, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_RDI, OperandSandboxRestricted)) {
        sandboxed_rsi_restricted_rdi = begin;
        restricted_register = kSandboxedRsiRestrictedRdi;
      }
    }
    if (restricted_register != kSandboxedRsiRestrictedRdi) {
      restricted_register = kNoRestrictedReg;
      if (CHECK_OPERAND(0, REG_R15, OperandSandbox8bit) ||
          CHECK_OPERAND(0, REG_R15, OperandSandboxRestricted) ||
          CHECK_OPERAND(0, REG_R15, OperandSandboxUnrestricted) ||
          CHECK_OPERAND(1, REG_R15, OperandSandbox8bit) ||
          CHECK_OPERAND(1, REG_R15, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_R15, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%r15\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((CHECK_OPERAND(0, REG_RBP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(0, REG_RBP, OperandSandboxUnrestricted) ||
                 (CHECK_OPERAND(1, REG_RBP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(1, REG_RBP, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%rbp\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((CHECK_OPERAND(0, REG_RSP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(0, REG_RSP, OperandSandboxUnrestricted) ||
                 (CHECK_OPERAND(1, REG_RSP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(1, REG_RSP, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%rsp\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((operand_states & 0x70) == (OperandSandboxRestricted << 5)) {
        restricted_register = operand_states & 0x0f;
      } else if ((operand_states & 0x7000) ==
                                        (OperandSandboxRestricted << (5 + 8))) {
        restricted_register = (operand_states & 0x0f00) >> 8;
      }
    }
  }
#line 337 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
       /* On successful match the instruction start must point to the next byte
        * to be able to report the new offset as the start of instruction
        * causing error.  */
       begin = p + 1;
     }
	goto st721;
tr113:
#line 84 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    int32_t offset =
           (uint32_t) (p[-3] + 256U * (p[-2] + 256U * (p[-1] + 256U * (p[0]))));
    size_t jump_dest = offset + (p - data);
    check_jump_dest;
  }
#line 93 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    /* Restricted %rsp or %rbp must be processed by appropriate nacl-special
       instruction, not with regular instruction.  */
    if (restricted_register == REG_RSP) {
      PrintError("Incorrectly modified register %%rsp\n", begin - data);
      result = 1;
      goto error_detected;
    } else if (restricted_register == REG_RBP) {
      PrintError("Incorrectly modified register %%rbp\n", begin - data);
      result = 1;
      goto error_detected;
    }
    /* If Sandboxed Rsi is destroyed then we must note that.  */
    if (restricted_register == kSandboxedRsi) {
      if (CHECK_OPERAND(0, REG_RSI, OperandSandboxRestricted) ||
          CHECK_OPERAND(0, REG_RSI, OperandSandboxUnrestricted) ||
          CHECK_OPERAND(1, REG_RSI, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_RSI, OperandSandboxUnrestricted)) {
        restricted_register = kNoRestrictedReg;
      }
    }
    if (restricted_register == kSandboxedRsi) {
      if (CHECK_OPERAND(0, REG_RDI, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_RDI, OperandSandboxRestricted)) {
        sandboxed_rsi_restricted_rdi = begin;
        restricted_register = kSandboxedRsiRestrictedRdi;
      }
    }
    if (restricted_register != kSandboxedRsiRestrictedRdi) {
      restricted_register = kNoRestrictedReg;
      if (CHECK_OPERAND(0, REG_R15, OperandSandbox8bit) ||
          CHECK_OPERAND(0, REG_R15, OperandSandboxRestricted) ||
          CHECK_OPERAND(0, REG_R15, OperandSandboxUnrestricted) ||
          CHECK_OPERAND(1, REG_R15, OperandSandbox8bit) ||
          CHECK_OPERAND(1, REG_R15, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_R15, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%r15\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((CHECK_OPERAND(0, REG_RBP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(0, REG_RBP, OperandSandboxUnrestricted) ||
                 (CHECK_OPERAND(1, REG_RBP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(1, REG_RBP, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%rbp\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((CHECK_OPERAND(0, REG_RSP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(0, REG_RSP, OperandSandboxUnrestricted) ||
                 (CHECK_OPERAND(1, REG_RSP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(1, REG_RSP, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%rsp\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((operand_states & 0x70) == (OperandSandboxRestricted << 5)) {
        restricted_register = operand_states & 0x0f;
      } else if ((operand_states & 0x7000) ==
                                        (OperandSandboxRestricted << (5 + 8))) {
        restricted_register = (operand_states & 0x0f00) >> 8;
      }
    }
  }
#line 337 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
       /* On successful match the instruction start must point to the next byte
        * to be able to report the new offset as the start of instruction
        * causing error.  */
       begin = p + 1;
     }
	goto st721;
tr119:
#line 76 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    int8_t offset = (uint8_t) (p[0]);
    size_t jump_dest = offset + (p - data);
    check_jump_dest;
  }
#line 93 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    /* Restricted %rsp or %rbp must be processed by appropriate nacl-special
       instruction, not with regular instruction.  */
    if (restricted_register == REG_RSP) {
      PrintError("Incorrectly modified register %%rsp\n", begin - data);
      result = 1;
      goto error_detected;
    } else if (restricted_register == REG_RBP) {
      PrintError("Incorrectly modified register %%rbp\n", begin - data);
      result = 1;
      goto error_detected;
    }
    /* If Sandboxed Rsi is destroyed then we must note that.  */
    if (restricted_register == kSandboxedRsi) {
      if (CHECK_OPERAND(0, REG_RSI, OperandSandboxRestricted) ||
          CHECK_OPERAND(0, REG_RSI, OperandSandboxUnrestricted) ||
          CHECK_OPERAND(1, REG_RSI, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_RSI, OperandSandboxUnrestricted)) {
        restricted_register = kNoRestrictedReg;
      }
    }
    if (restricted_register == kSandboxedRsi) {
      if (CHECK_OPERAND(0, REG_RDI, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_RDI, OperandSandboxRestricted)) {
        sandboxed_rsi_restricted_rdi = begin;
        restricted_register = kSandboxedRsiRestrictedRdi;
      }
    }
    if (restricted_register != kSandboxedRsiRestrictedRdi) {
      restricted_register = kNoRestrictedReg;
      if (CHECK_OPERAND(0, REG_R15, OperandSandbox8bit) ||
          CHECK_OPERAND(0, REG_R15, OperandSandboxRestricted) ||
          CHECK_OPERAND(0, REG_R15, OperandSandboxUnrestricted) ||
          CHECK_OPERAND(1, REG_R15, OperandSandbox8bit) ||
          CHECK_OPERAND(1, REG_R15, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_R15, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%r15\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((CHECK_OPERAND(0, REG_RBP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(0, REG_RBP, OperandSandboxUnrestricted) ||
                 (CHECK_OPERAND(1, REG_RBP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(1, REG_RBP, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%rbp\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((CHECK_OPERAND(0, REG_RSP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(0, REG_RSP, OperandSandboxUnrestricted) ||
                 (CHECK_OPERAND(1, REG_RSP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(1, REG_RSP, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%rsp\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((operand_states & 0x70) == (OperandSandboxRestricted << 5)) {
        restricted_register = operand_states & 0x0f;
      } else if ((operand_states & 0x7000) ==
                                        (OperandSandboxRestricted << (5 + 8))) {
        restricted_register = (operand_states & 0x0f00) >> 8;
      }
    }
  }
#line 337 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
       /* On successful match the instruction start must point to the next byte
        * to be able to report the new offset as the start of instruction
        * causing error.  */
       begin = p + 1;
     }
	goto st721;
tr122:
#line 376 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_NAME(0, ((*p) & 0x7) |
                            ((GET_REX_PREFIX() & 0x01) << 3) |
                            (((~GET_VEX_PREFIX2()) & 0x20) >> 2));
  }
#line 93 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    /* Restricted %rsp or %rbp must be processed by appropriate nacl-special
       instruction, not with regular instruction.  */
    if (restricted_register == REG_RSP) {
      PrintError("Incorrectly modified register %%rsp\n", begin - data);
      result = 1;
      goto error_detected;
    } else if (restricted_register == REG_RBP) {
      PrintError("Incorrectly modified register %%rbp\n", begin - data);
      result = 1;
      goto error_detected;
    }
    /* If Sandboxed Rsi is destroyed then we must note that.  */
    if (restricted_register == kSandboxedRsi) {
      if (CHECK_OPERAND(0, REG_RSI, OperandSandboxRestricted) ||
          CHECK_OPERAND(0, REG_RSI, OperandSandboxUnrestricted) ||
          CHECK_OPERAND(1, REG_RSI, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_RSI, OperandSandboxUnrestricted)) {
        restricted_register = kNoRestrictedReg;
      }
    }
    if (restricted_register == kSandboxedRsi) {
      if (CHECK_OPERAND(0, REG_RDI, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_RDI, OperandSandboxRestricted)) {
        sandboxed_rsi_restricted_rdi = begin;
        restricted_register = kSandboxedRsiRestrictedRdi;
      }
    }
    if (restricted_register != kSandboxedRsiRestrictedRdi) {
      restricted_register = kNoRestrictedReg;
      if (CHECK_OPERAND(0, REG_R15, OperandSandbox8bit) ||
          CHECK_OPERAND(0, REG_R15, OperandSandboxRestricted) ||
          CHECK_OPERAND(0, REG_R15, OperandSandboxUnrestricted) ||
          CHECK_OPERAND(1, REG_R15, OperandSandbox8bit) ||
          CHECK_OPERAND(1, REG_R15, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_R15, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%r15\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((CHECK_OPERAND(0, REG_RBP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(0, REG_RBP, OperandSandboxUnrestricted) ||
                 (CHECK_OPERAND(1, REG_RBP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(1, REG_RBP, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%rbp\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((CHECK_OPERAND(0, REG_RSP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(0, REG_RSP, OperandSandboxUnrestricted) ||
                 (CHECK_OPERAND(1, REG_RSP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(1, REG_RSP, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%rsp\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((operand_states & 0x70) == (OperandSandboxRestricted << 5)) {
        restricted_register = operand_states & 0x0f;
      } else if ((operand_states & 0x7000) ==
                                        (OperandSandboxRestricted << (5 + 8))) {
        restricted_register = (operand_states & 0x0f00) >> 8;
      }
    }
  }
#line 337 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
       /* On successful match the instruction start must point to the next byte
        * to be able to report the new offset as the start of instruction
        * causing error.  */
       begin = p + 1;
     }
	goto st721;
tr123:
#line 376 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_NAME(0, ((*p) & 0x7) |
                            ((GET_REX_PREFIX() & 0x01) << 3) |
                            (((~GET_VEX_PREFIX2()) & 0x20) >> 2));
  }
#line 319 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(0, OperandSize64bit);
  }
#line 93 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    /* Restricted %rsp or %rbp must be processed by appropriate nacl-special
       instruction, not with regular instruction.  */
    if (restricted_register == REG_RSP) {
      PrintError("Incorrectly modified register %%rsp\n", begin - data);
      result = 1;
      goto error_detected;
    } else if (restricted_register == REG_RBP) {
      PrintError("Incorrectly modified register %%rbp\n", begin - data);
      result = 1;
      goto error_detected;
    }
    /* If Sandboxed Rsi is destroyed then we must note that.  */
    if (restricted_register == kSandboxedRsi) {
      if (CHECK_OPERAND(0, REG_RSI, OperandSandboxRestricted) ||
          CHECK_OPERAND(0, REG_RSI, OperandSandboxUnrestricted) ||
          CHECK_OPERAND(1, REG_RSI, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_RSI, OperandSandboxUnrestricted)) {
        restricted_register = kNoRestrictedReg;
      }
    }
    if (restricted_register == kSandboxedRsi) {
      if (CHECK_OPERAND(0, REG_RDI, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_RDI, OperandSandboxRestricted)) {
        sandboxed_rsi_restricted_rdi = begin;
        restricted_register = kSandboxedRsiRestrictedRdi;
      }
    }
    if (restricted_register != kSandboxedRsiRestrictedRdi) {
      restricted_register = kNoRestrictedReg;
      if (CHECK_OPERAND(0, REG_R15, OperandSandbox8bit) ||
          CHECK_OPERAND(0, REG_R15, OperandSandboxRestricted) ||
          CHECK_OPERAND(0, REG_R15, OperandSandboxUnrestricted) ||
          CHECK_OPERAND(1, REG_R15, OperandSandbox8bit) ||
          CHECK_OPERAND(1, REG_R15, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_R15, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%r15\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((CHECK_OPERAND(0, REG_RBP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(0, REG_RBP, OperandSandboxUnrestricted) ||
                 (CHECK_OPERAND(1, REG_RBP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(1, REG_RBP, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%rbp\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((CHECK_OPERAND(0, REG_RSP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(0, REG_RSP, OperandSandboxUnrestricted) ||
                 (CHECK_OPERAND(1, REG_RSP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(1, REG_RSP, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%rsp\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((operand_states & 0x70) == (OperandSandboxRestricted << 5)) {
        restricted_register = operand_states & 0x0f;
      } else if ((operand_states & 0x7000) ==
                                        (OperandSandboxRestricted << (5 + 8))) {
        restricted_register = (operand_states & 0x0f00) >> 8;
      }
    }
  }
#line 337 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
       /* On successful match the instruction start must point to the next byte
        * to be able to report the new offset as the start of instruction
        * causing error.  */
       begin = p + 1;
     }
	goto st721;
tr133:
#line 376 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_NAME(0, ((*p) & 0x7) |
                            ((GET_REX_PREFIX() & 0x01) << 3) |
                            (((~GET_VEX_PREFIX2()) & 0x20) >> 2));
  }
#line 295 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(0, OperandSize32bit);
  }
#line 442 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(1, OperandSize32bit);
  }
#line 565 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_NAME(1, REG_RAX);
  }
#line 93 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    /* Restricted %rsp or %rbp must be processed by appropriate nacl-special
       instruction, not with regular instruction.  */
    if (restricted_register == REG_RSP) {
      PrintError("Incorrectly modified register %%rsp\n", begin - data);
      result = 1;
      goto error_detected;
    } else if (restricted_register == REG_RBP) {
      PrintError("Incorrectly modified register %%rbp\n", begin - data);
      result = 1;
      goto error_detected;
    }
    /* If Sandboxed Rsi is destroyed then we must note that.  */
    if (restricted_register == kSandboxedRsi) {
      if (CHECK_OPERAND(0, REG_RSI, OperandSandboxRestricted) ||
          CHECK_OPERAND(0, REG_RSI, OperandSandboxUnrestricted) ||
          CHECK_OPERAND(1, REG_RSI, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_RSI, OperandSandboxUnrestricted)) {
        restricted_register = kNoRestrictedReg;
      }
    }
    if (restricted_register == kSandboxedRsi) {
      if (CHECK_OPERAND(0, REG_RDI, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_RDI, OperandSandboxRestricted)) {
        sandboxed_rsi_restricted_rdi = begin;
        restricted_register = kSandboxedRsiRestrictedRdi;
      }
    }
    if (restricted_register != kSandboxedRsiRestrictedRdi) {
      restricted_register = kNoRestrictedReg;
      if (CHECK_OPERAND(0, REG_R15, OperandSandbox8bit) ||
          CHECK_OPERAND(0, REG_R15, OperandSandboxRestricted) ||
          CHECK_OPERAND(0, REG_R15, OperandSandboxUnrestricted) ||
          CHECK_OPERAND(1, REG_R15, OperandSandbox8bit) ||
          CHECK_OPERAND(1, REG_R15, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_R15, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%r15\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((CHECK_OPERAND(0, REG_RBP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(0, REG_RBP, OperandSandboxUnrestricted) ||
                 (CHECK_OPERAND(1, REG_RBP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(1, REG_RBP, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%rbp\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((CHECK_OPERAND(0, REG_RSP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(0, REG_RSP, OperandSandboxUnrestricted) ||
                 (CHECK_OPERAND(1, REG_RSP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(1, REG_RSP, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%rsp\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((operand_states & 0x70) == (OperandSandboxRestricted << 5)) {
        restricted_register = operand_states & 0x0f;
      } else if ((operand_states & 0x7000) ==
                                        (OperandSandboxRestricted << (5 + 8))) {
        restricted_register = (operand_states & 0x0f00) >> 8;
      }
    }
  }
#line 337 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
       /* On successful match the instruction start must point to the next byte
        * to be able to report the new offset as the start of instruction
        * causing error.  */
       begin = p + 1;
     }
	goto st721;
tr193:
#line 536 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_NAME(1, (((*p) & 0x38) >> 3) |
                           ((GET_REX_PREFIX() & 0x04) << 1) |
                           (((~GET_VEX_PREFIX2()) & 0x80) >> 4));
  }
#line 90 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_DISP_TYPE(DISPNONE);
    SET_MODRM_BASE(((*p) & 0x07) |
                   ((GET_REX_PREFIX() & 0x01) << 3) |
                   (((~GET_VEX_PREFIX2()) & 0x20) >> 2));
    SET_MODRM_INDEX(NO_REG);
    SET_MODRM_SCALE(0);
  }
#line 44 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    if ((base == REG_RIP) || (base == REG_R15) ||
        ((base == REG_RSP) && (restricted_register != REG_RSP)) ||
        ((base == REG_RBP) && (restricted_register != REG_RBP))) {
      if ((index == restricted_register) ||
          ((index == REG_RDI) &&
           (restricted_register == kSandboxedRsiRestrictedRdi))) {
        BitmapClearBit(valid_targets, begin - data);
      } else if ((index != NO_REG) && (index != REG_RIZ)) {
        PrintError("Improper sandboxing in instruction\n", begin - data);
        result = 1;
        goto error_detected;
      }
    } else if ((index == REG_RIP) || (index == REG_R15) ||
               ((index == REG_RSP) && (restricted_register != REG_RSP)) ||
               ((index == REG_RBP) && (restricted_register != REG_RBP))) {
      if ((base == restricted_register) ||
          ((base == REG_RDI) &&
           (restricted_register == kSandboxedRsiRestrictedRdi))) {
        BitmapClearBit(valid_targets, begin - data);
      } else if ((base != NO_REG) && (base != REG_RIZ)) {
        PrintError("Improper sandboxing in instruction\n", begin - data);
        result = 1;
        goto error_detected;
      }
    } else {
      PrintError("Improper sandboxing in instruction\n", begin - data);
      result = 1;
      goto error_detected;
    }
  }
#line 93 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    /* Restricted %rsp or %rbp must be processed by appropriate nacl-special
       instruction, not with regular instruction.  */
    if (restricted_register == REG_RSP) {
      PrintError("Incorrectly modified register %%rsp\n", begin - data);
      result = 1;
      goto error_detected;
    } else if (restricted_register == REG_RBP) {
      PrintError("Incorrectly modified register %%rbp\n", begin - data);
      result = 1;
      goto error_detected;
    }
    /* If Sandboxed Rsi is destroyed then we must note that.  */
    if (restricted_register == kSandboxedRsi) {
      if (CHECK_OPERAND(0, REG_RSI, OperandSandboxRestricted) ||
          CHECK_OPERAND(0, REG_RSI, OperandSandboxUnrestricted) ||
          CHECK_OPERAND(1, REG_RSI, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_RSI, OperandSandboxUnrestricted)) {
        restricted_register = kNoRestrictedReg;
      }
    }
    if (restricted_register == kSandboxedRsi) {
      if (CHECK_OPERAND(0, REG_RDI, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_RDI, OperandSandboxRestricted)) {
        sandboxed_rsi_restricted_rdi = begin;
        restricted_register = kSandboxedRsiRestrictedRdi;
      }
    }
    if (restricted_register != kSandboxedRsiRestrictedRdi) {
      restricted_register = kNoRestrictedReg;
      if (CHECK_OPERAND(0, REG_R15, OperandSandbox8bit) ||
          CHECK_OPERAND(0, REG_R15, OperandSandboxRestricted) ||
          CHECK_OPERAND(0, REG_R15, OperandSandboxUnrestricted) ||
          CHECK_OPERAND(1, REG_R15, OperandSandbox8bit) ||
          CHECK_OPERAND(1, REG_R15, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_R15, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%r15\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((CHECK_OPERAND(0, REG_RBP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(0, REG_RBP, OperandSandboxUnrestricted) ||
                 (CHECK_OPERAND(1, REG_RBP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(1, REG_RBP, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%rbp\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((CHECK_OPERAND(0, REG_RSP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(0, REG_RSP, OperandSandboxUnrestricted) ||
                 (CHECK_OPERAND(1, REG_RSP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(1, REG_RSP, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%rsp\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((operand_states & 0x70) == (OperandSandboxRestricted << 5)) {
        restricted_register = operand_states & 0x0f;
      } else if ((operand_states & 0x7000) ==
                                        (OperandSandboxRestricted << (5 + 8))) {
        restricted_register = (operand_states & 0x0f00) >> 8;
      }
    }
  }
#line 337 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
       /* On successful match the instruction start must point to the next byte
        * to be able to report the new offset as the start of instruction
        * causing error.  */
       begin = p + 1;
     }
	goto st721;
tr200:
#line 384 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_NAME(0, ((*p) & 0x07) |
                           ((GET_REX_PREFIX() & 0x01) << 3) |
                           (((~GET_VEX_PREFIX2()) & 0x20) >> 2));
  }
#line 536 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_NAME(1, (((*p) & 0x38) >> 3) |
                           ((GET_REX_PREFIX() & 0x04) << 1) |
                           (((~GET_VEX_PREFIX2()) & 0x80) >> 4));
  }
#line 93 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    /* Restricted %rsp or %rbp must be processed by appropriate nacl-special
       instruction, not with regular instruction.  */
    if (restricted_register == REG_RSP) {
      PrintError("Incorrectly modified register %%rsp\n", begin - data);
      result = 1;
      goto error_detected;
    } else if (restricted_register == REG_RBP) {
      PrintError("Incorrectly modified register %%rbp\n", begin - data);
      result = 1;
      goto error_detected;
    }
    /* If Sandboxed Rsi is destroyed then we must note that.  */
    if (restricted_register == kSandboxedRsi) {
      if (CHECK_OPERAND(0, REG_RSI, OperandSandboxRestricted) ||
          CHECK_OPERAND(0, REG_RSI, OperandSandboxUnrestricted) ||
          CHECK_OPERAND(1, REG_RSI, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_RSI, OperandSandboxUnrestricted)) {
        restricted_register = kNoRestrictedReg;
      }
    }
    if (restricted_register == kSandboxedRsi) {
      if (CHECK_OPERAND(0, REG_RDI, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_RDI, OperandSandboxRestricted)) {
        sandboxed_rsi_restricted_rdi = begin;
        restricted_register = kSandboxedRsiRestrictedRdi;
      }
    }
    if (restricted_register != kSandboxedRsiRestrictedRdi) {
      restricted_register = kNoRestrictedReg;
      if (CHECK_OPERAND(0, REG_R15, OperandSandbox8bit) ||
          CHECK_OPERAND(0, REG_R15, OperandSandboxRestricted) ||
          CHECK_OPERAND(0, REG_R15, OperandSandboxUnrestricted) ||
          CHECK_OPERAND(1, REG_R15, OperandSandbox8bit) ||
          CHECK_OPERAND(1, REG_R15, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_R15, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%r15\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((CHECK_OPERAND(0, REG_RBP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(0, REG_RBP, OperandSandboxUnrestricted) ||
                 (CHECK_OPERAND(1, REG_RBP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(1, REG_RBP, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%rbp\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((CHECK_OPERAND(0, REG_RSP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(0, REG_RSP, OperandSandboxUnrestricted) ||
                 (CHECK_OPERAND(1, REG_RSP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(1, REG_RSP, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%rsp\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((operand_states & 0x70) == (OperandSandboxRestricted << 5)) {
        restricted_register = operand_states & 0x0f;
      } else if ((operand_states & 0x7000) ==
                                        (OperandSandboxRestricted << (5 + 8))) {
        restricted_register = (operand_states & 0x0f00) >> 8;
      }
    }
  }
#line 337 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
       /* On successful match the instruction start must point to the next byte
        * to be able to report the new offset as the start of instruction
        * causing error.  */
       begin = p + 1;
     }
	goto st721;
tr201:
#line 389 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_NAME(0, (((*p) & 0x38) >> 3) |
                           ((GET_REX_PREFIX() & 0x04) << 1) |
                           (((~GET_VEX_PREFIX2()) & 0x80) >> 4));
  }
#line 90 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_DISP_TYPE(DISPNONE);
    SET_MODRM_BASE(((*p) & 0x07) |
                   ((GET_REX_PREFIX() & 0x01) << 3) |
                   (((~GET_VEX_PREFIX2()) & 0x20) >> 2));
    SET_MODRM_INDEX(NO_REG);
    SET_MODRM_SCALE(0);
  }
#line 93 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    /* Restricted %rsp or %rbp must be processed by appropriate nacl-special
       instruction, not with regular instruction.  */
    if (restricted_register == REG_RSP) {
      PrintError("Incorrectly modified register %%rsp\n", begin - data);
      result = 1;
      goto error_detected;
    } else if (restricted_register == REG_RBP) {
      PrintError("Incorrectly modified register %%rbp\n", begin - data);
      result = 1;
      goto error_detected;
    }
    /* If Sandboxed Rsi is destroyed then we must note that.  */
    if (restricted_register == kSandboxedRsi) {
      if (CHECK_OPERAND(0, REG_RSI, OperandSandboxRestricted) ||
          CHECK_OPERAND(0, REG_RSI, OperandSandboxUnrestricted) ||
          CHECK_OPERAND(1, REG_RSI, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_RSI, OperandSandboxUnrestricted)) {
        restricted_register = kNoRestrictedReg;
      }
    }
    if (restricted_register == kSandboxedRsi) {
      if (CHECK_OPERAND(0, REG_RDI, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_RDI, OperandSandboxRestricted)) {
        sandboxed_rsi_restricted_rdi = begin;
        restricted_register = kSandboxedRsiRestrictedRdi;
      }
    }
    if (restricted_register != kSandboxedRsiRestrictedRdi) {
      restricted_register = kNoRestrictedReg;
      if (CHECK_OPERAND(0, REG_R15, OperandSandbox8bit) ||
          CHECK_OPERAND(0, REG_R15, OperandSandboxRestricted) ||
          CHECK_OPERAND(0, REG_R15, OperandSandboxUnrestricted) ||
          CHECK_OPERAND(1, REG_R15, OperandSandbox8bit) ||
          CHECK_OPERAND(1, REG_R15, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_R15, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%r15\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((CHECK_OPERAND(0, REG_RBP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(0, REG_RBP, OperandSandboxUnrestricted) ||
                 (CHECK_OPERAND(1, REG_RBP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(1, REG_RBP, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%rbp\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((CHECK_OPERAND(0, REG_RSP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(0, REG_RSP, OperandSandboxUnrestricted) ||
                 (CHECK_OPERAND(1, REG_RSP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(1, REG_RSP, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%rsp\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((operand_states & 0x70) == (OperandSandboxRestricted << 5)) {
        restricted_register = operand_states & 0x0f;
      } else if ((operand_states & 0x7000) ==
                                        (OperandSandboxRestricted << (5 + 8))) {
        restricted_register = (operand_states & 0x0f00) >> 8;
      }
    }
  }
#line 337 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
       /* On successful match the instruction start must point to the next byte
        * to be able to report the new offset as the start of instruction
        * causing error.  */
       begin = p + 1;
     }
	goto st721;
tr208:
#line 298 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(0, OperandSize64bit);
  }
#line 384 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_NAME(0, ((*p) & 0x07) |
                           ((GET_REX_PREFIX() & 0x01) << 3) |
                           (((~GET_VEX_PREFIX2()) & 0x20) >> 2));
  }
#line 93 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    /* Restricted %rsp or %rbp must be processed by appropriate nacl-special
       instruction, not with regular instruction.  */
    if (restricted_register == REG_RSP) {
      PrintError("Incorrectly modified register %%rsp\n", begin - data);
      result = 1;
      goto error_detected;
    } else if (restricted_register == REG_RBP) {
      PrintError("Incorrectly modified register %%rbp\n", begin - data);
      result = 1;
      goto error_detected;
    }
    /* If Sandboxed Rsi is destroyed then we must note that.  */
    if (restricted_register == kSandboxedRsi) {
      if (CHECK_OPERAND(0, REG_RSI, OperandSandboxRestricted) ||
          CHECK_OPERAND(0, REG_RSI, OperandSandboxUnrestricted) ||
          CHECK_OPERAND(1, REG_RSI, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_RSI, OperandSandboxUnrestricted)) {
        restricted_register = kNoRestrictedReg;
      }
    }
    if (restricted_register == kSandboxedRsi) {
      if (CHECK_OPERAND(0, REG_RDI, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_RDI, OperandSandboxRestricted)) {
        sandboxed_rsi_restricted_rdi = begin;
        restricted_register = kSandboxedRsiRestrictedRdi;
      }
    }
    if (restricted_register != kSandboxedRsiRestrictedRdi) {
      restricted_register = kNoRestrictedReg;
      if (CHECK_OPERAND(0, REG_R15, OperandSandbox8bit) ||
          CHECK_OPERAND(0, REG_R15, OperandSandboxRestricted) ||
          CHECK_OPERAND(0, REG_R15, OperandSandboxUnrestricted) ||
          CHECK_OPERAND(1, REG_R15, OperandSandbox8bit) ||
          CHECK_OPERAND(1, REG_R15, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_R15, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%r15\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((CHECK_OPERAND(0, REG_RBP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(0, REG_RBP, OperandSandboxUnrestricted) ||
                 (CHECK_OPERAND(1, REG_RBP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(1, REG_RBP, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%rbp\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((CHECK_OPERAND(0, REG_RSP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(0, REG_RSP, OperandSandboxUnrestricted) ||
                 (CHECK_OPERAND(1, REG_RSP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(1, REG_RSP, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%rsp\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((operand_states & 0x70) == (OperandSandboxRestricted << 5)) {
        restricted_register = operand_states & 0x0f;
      } else if ((operand_states & 0x7000) ==
                                        (OperandSandboxRestricted << (5 + 8))) {
        restricted_register = (operand_states & 0x0f00) >> 8;
      }
    }
  }
#line 337 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
       /* On successful match the instruction start must point to the next byte
        * to be able to report the new offset as the start of instruction
        * causing error.  */
       begin = p + 1;
     }
	goto st721;
tr210:
#line 289 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(0, OperandSize8bit);
  }
#line 384 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_NAME(0, ((*p) & 0x07) |
                           ((GET_REX_PREFIX() & 0x01) << 3) |
                           (((~GET_VEX_PREFIX2()) & 0x20) >> 2));
  }
#line 93 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    /* Restricted %rsp or %rbp must be processed by appropriate nacl-special
       instruction, not with regular instruction.  */
    if (restricted_register == REG_RSP) {
      PrintError("Incorrectly modified register %%rsp\n", begin - data);
      result = 1;
      goto error_detected;
    } else if (restricted_register == REG_RBP) {
      PrintError("Incorrectly modified register %%rbp\n", begin - data);
      result = 1;
      goto error_detected;
    }
    /* If Sandboxed Rsi is destroyed then we must note that.  */
    if (restricted_register == kSandboxedRsi) {
      if (CHECK_OPERAND(0, REG_RSI, OperandSandboxRestricted) ||
          CHECK_OPERAND(0, REG_RSI, OperandSandboxUnrestricted) ||
          CHECK_OPERAND(1, REG_RSI, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_RSI, OperandSandboxUnrestricted)) {
        restricted_register = kNoRestrictedReg;
      }
    }
    if (restricted_register == kSandboxedRsi) {
      if (CHECK_OPERAND(0, REG_RDI, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_RDI, OperandSandboxRestricted)) {
        sandboxed_rsi_restricted_rdi = begin;
        restricted_register = kSandboxedRsiRestrictedRdi;
      }
    }
    if (restricted_register != kSandboxedRsiRestrictedRdi) {
      restricted_register = kNoRestrictedReg;
      if (CHECK_OPERAND(0, REG_R15, OperandSandbox8bit) ||
          CHECK_OPERAND(0, REG_R15, OperandSandboxRestricted) ||
          CHECK_OPERAND(0, REG_R15, OperandSandboxUnrestricted) ||
          CHECK_OPERAND(1, REG_R15, OperandSandbox8bit) ||
          CHECK_OPERAND(1, REG_R15, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_R15, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%r15\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((CHECK_OPERAND(0, REG_RBP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(0, REG_RBP, OperandSandboxUnrestricted) ||
                 (CHECK_OPERAND(1, REG_RBP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(1, REG_RBP, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%rbp\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((CHECK_OPERAND(0, REG_RSP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(0, REG_RSP, OperandSandboxUnrestricted) ||
                 (CHECK_OPERAND(1, REG_RSP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(1, REG_RSP, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%rsp\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((operand_states & 0x70) == (OperandSandboxRestricted << 5)) {
        restricted_register = operand_states & 0x0f;
      } else if ((operand_states & 0x7000) ==
                                        (OperandSandboxRestricted << (5 + 8))) {
        restricted_register = (operand_states & 0x0f00) >> 8;
      }
    }
  }
#line 337 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
       /* On successful match the instruction start must point to the next byte
        * to be able to report the new offset as the start of instruction
        * causing error.  */
       begin = p + 1;
     }
	goto st721;
tr231:
#line 376 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_NAME(0, ((*p) & 0x7) |
                            ((GET_REX_PREFIX() & 0x01) << 3) |
                            (((~GET_VEX_PREFIX2()) & 0x20) >> 2));
  }
#line 298 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(0, OperandSize64bit);
  }
#line 445 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(1, OperandSize64bit);
  }
#line 565 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_NAME(1, REG_RAX);
  }
#line 93 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    /* Restricted %rsp or %rbp must be processed by appropriate nacl-special
       instruction, not with regular instruction.  */
    if (restricted_register == REG_RSP) {
      PrintError("Incorrectly modified register %%rsp\n", begin - data);
      result = 1;
      goto error_detected;
    } else if (restricted_register == REG_RBP) {
      PrintError("Incorrectly modified register %%rbp\n", begin - data);
      result = 1;
      goto error_detected;
    }
    /* If Sandboxed Rsi is destroyed then we must note that.  */
    if (restricted_register == kSandboxedRsi) {
      if (CHECK_OPERAND(0, REG_RSI, OperandSandboxRestricted) ||
          CHECK_OPERAND(0, REG_RSI, OperandSandboxUnrestricted) ||
          CHECK_OPERAND(1, REG_RSI, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_RSI, OperandSandboxUnrestricted)) {
        restricted_register = kNoRestrictedReg;
      }
    }
    if (restricted_register == kSandboxedRsi) {
      if (CHECK_OPERAND(0, REG_RDI, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_RDI, OperandSandboxRestricted)) {
        sandboxed_rsi_restricted_rdi = begin;
        restricted_register = kSandboxedRsiRestrictedRdi;
      }
    }
    if (restricted_register != kSandboxedRsiRestrictedRdi) {
      restricted_register = kNoRestrictedReg;
      if (CHECK_OPERAND(0, REG_R15, OperandSandbox8bit) ||
          CHECK_OPERAND(0, REG_R15, OperandSandboxRestricted) ||
          CHECK_OPERAND(0, REG_R15, OperandSandboxUnrestricted) ||
          CHECK_OPERAND(1, REG_R15, OperandSandbox8bit) ||
          CHECK_OPERAND(1, REG_R15, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_R15, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%r15\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((CHECK_OPERAND(0, REG_RBP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(0, REG_RBP, OperandSandboxUnrestricted) ||
                 (CHECK_OPERAND(1, REG_RBP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(1, REG_RBP, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%rbp\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((CHECK_OPERAND(0, REG_RSP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(0, REG_RSP, OperandSandboxUnrestricted) ||
                 (CHECK_OPERAND(1, REG_RSP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(1, REG_RSP, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%rsp\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((operand_states & 0x70) == (OperandSandboxRestricted << 5)) {
        restricted_register = operand_states & 0x0f;
      } else if ((operand_states & 0x7000) ==
                                        (OperandSandboxRestricted << (5 + 8))) {
        restricted_register = (operand_states & 0x0f00) >> 8;
      }
    }
  }
#line 337 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
       /* On successful match the instruction start must point to the next byte
        * to be able to report the new offset as the start of instruction
        * causing error.  */
       begin = p + 1;
     }
	goto st721;
tr232:
#line 317 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{ if (restricted_register != kSandboxedRsiSandboxedRdi) {
         PrintError("Incorrectly sandboxed %%rsi or %%rdi\n", begin - data);
         result = 1;
         goto error_detected;
       }
       restricted_register = kNoRestrictedReg;
       BitmapClearBit(valid_targets, (begin - data));
       BitmapClearBit(valid_targets, (sandboxed_rsi - data));
       BitmapClearBit(valid_targets, (sandboxed_rsi_restricted_rdi - data));
       BitmapClearBit(valid_targets, (sandboxed_rdi - data));
    }
#line 337 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
       /* On successful match the instruction start must point to the next byte
        * to be able to report the new offset as the start of instruction
        * causing error.  */
       begin = p + 1;
     }
	goto st721;
tr233:
#line 300 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{ if (restricted_register != kSandboxedRdi &&
           restricted_register != kSandboxedRsiSandboxedRdi) {
         PrintError("Incorrectly sandboxed %%rdi\n", begin - data);
         result = 1;
         goto error_detected;
       }
       restricted_register = kNoRestrictedReg;
       BitmapClearBit(valid_targets, (begin - data));
       BitmapClearBit(valid_targets, (sandboxed_rdi - data));
    }
#line 337 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
       /* On successful match the instruction start must point to the next byte
        * to be able to report the new offset as the start of instruction
        * causing error.  */
       begin = p + 1;
     }
	goto st721;
tr234:
#line 284 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{ if (restricted_register != kSandboxedRsi) {
         PrintError("Incorrectly sandboxed %%rdi\n", begin - data);
         result = 1;
         goto error_detected;
       }
       restricted_register = kNoRestrictedReg;
       BitmapClearBit(valid_targets, (begin - data));
       BitmapClearBit(valid_targets, (sandboxed_rdi - data));
    }
#line 337 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
       /* On successful match the instruction start must point to the next byte
        * to be able to report the new offset as the start of instruction
        * causing error.  */
       begin = p + 1;
     }
	goto st721;
tr246:
#line 376 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_NAME(0, ((*p) & 0x7) |
                            ((GET_REX_PREFIX() & 0x01) << 3) |
                            (((~GET_VEX_PREFIX2()) & 0x20) >> 2));
  }
#line 298 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(0, OperandSize64bit);
  }
#line 93 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    /* Restricted %rsp or %rbp must be processed by appropriate nacl-special
       instruction, not with regular instruction.  */
    if (restricted_register == REG_RSP) {
      PrintError("Incorrectly modified register %%rsp\n", begin - data);
      result = 1;
      goto error_detected;
    } else if (restricted_register == REG_RBP) {
      PrintError("Incorrectly modified register %%rbp\n", begin - data);
      result = 1;
      goto error_detected;
    }
    /* If Sandboxed Rsi is destroyed then we must note that.  */
    if (restricted_register == kSandboxedRsi) {
      if (CHECK_OPERAND(0, REG_RSI, OperandSandboxRestricted) ||
          CHECK_OPERAND(0, REG_RSI, OperandSandboxUnrestricted) ||
          CHECK_OPERAND(1, REG_RSI, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_RSI, OperandSandboxUnrestricted)) {
        restricted_register = kNoRestrictedReg;
      }
    }
    if (restricted_register == kSandboxedRsi) {
      if (CHECK_OPERAND(0, REG_RDI, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_RDI, OperandSandboxRestricted)) {
        sandboxed_rsi_restricted_rdi = begin;
        restricted_register = kSandboxedRsiRestrictedRdi;
      }
    }
    if (restricted_register != kSandboxedRsiRestrictedRdi) {
      restricted_register = kNoRestrictedReg;
      if (CHECK_OPERAND(0, REG_R15, OperandSandbox8bit) ||
          CHECK_OPERAND(0, REG_R15, OperandSandboxRestricted) ||
          CHECK_OPERAND(0, REG_R15, OperandSandboxUnrestricted) ||
          CHECK_OPERAND(1, REG_R15, OperandSandbox8bit) ||
          CHECK_OPERAND(1, REG_R15, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_R15, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%r15\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((CHECK_OPERAND(0, REG_RBP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(0, REG_RBP, OperandSandboxUnrestricted) ||
                 (CHECK_OPERAND(1, REG_RBP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(1, REG_RBP, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%rbp\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((CHECK_OPERAND(0, REG_RSP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(0, REG_RSP, OperandSandboxUnrestricted) ||
                 (CHECK_OPERAND(1, REG_RSP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(1, REG_RSP, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%rsp\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((operand_states & 0x70) == (OperandSandboxRestricted << 5)) {
        restricted_register = operand_states & 0x0f;
      } else if ((operand_states & 0x7000) ==
                                        (OperandSandboxRestricted << (5 + 8))) {
        restricted_register = (operand_states & 0x0f00) >> 8;
      }
    }
  }
#line 337 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
       /* On successful match the instruction start must point to the next byte
        * to be able to report the new offset as the start of instruction
        * causing error.  */
       begin = p + 1;
     }
	goto st721;
tr254:
#line 337 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
       /* On successful match the instruction start must point to the next byte
        * to be able to report the new offset as the start of instruction
        * causing error.  */
       begin = p + 1;
     }
	goto st721;
tr257:
#line 183 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{ if (restricted_register == REG_RSP) {
         PrintError("Incorrectly modified register %%rsp\n", begin - data);
         result = 1;
         goto error_detected;
       }
       restricted_register = kNoRestrictedReg;
    }
#line 337 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
       /* On successful match the instruction start must point to the next byte
        * to be able to report the new offset as the start of instruction
        * causing error.  */
       begin = p + 1;
     }
	goto st721;
tr258:
#line 193 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{ if (restricted_register == REG_RBP) {
         PrintError("Incorrectly modified register %%rbp\n", begin - data);
         result = 1;
         goto error_detected;
       }
       restricted_register = kNoRestrictedReg;
    }
#line 337 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
       /* On successful match the instruction start must point to the next byte
        * to be able to report the new offset as the start of instruction
        * causing error.  */
       begin = p + 1;
     }
	goto st721;
tr266:
#line 82 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_IMM_TYPE(IMM64);
    SET_IMM_PTR(p - 7);
  }
#line 93 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    /* Restricted %rsp or %rbp must be processed by appropriate nacl-special
       instruction, not with regular instruction.  */
    if (restricted_register == REG_RSP) {
      PrintError("Incorrectly modified register %%rsp\n", begin - data);
      result = 1;
      goto error_detected;
    } else if (restricted_register == REG_RBP) {
      PrintError("Incorrectly modified register %%rbp\n", begin - data);
      result = 1;
      goto error_detected;
    }
    /* If Sandboxed Rsi is destroyed then we must note that.  */
    if (restricted_register == kSandboxedRsi) {
      if (CHECK_OPERAND(0, REG_RSI, OperandSandboxRestricted) ||
          CHECK_OPERAND(0, REG_RSI, OperandSandboxUnrestricted) ||
          CHECK_OPERAND(1, REG_RSI, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_RSI, OperandSandboxUnrestricted)) {
        restricted_register = kNoRestrictedReg;
      }
    }
    if (restricted_register == kSandboxedRsi) {
      if (CHECK_OPERAND(0, REG_RDI, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_RDI, OperandSandboxRestricted)) {
        sandboxed_rsi_restricted_rdi = begin;
        restricted_register = kSandboxedRsiRestrictedRdi;
      }
    }
    if (restricted_register != kSandboxedRsiRestrictedRdi) {
      restricted_register = kNoRestrictedReg;
      if (CHECK_OPERAND(0, REG_R15, OperandSandbox8bit) ||
          CHECK_OPERAND(0, REG_R15, OperandSandboxRestricted) ||
          CHECK_OPERAND(0, REG_R15, OperandSandboxUnrestricted) ||
          CHECK_OPERAND(1, REG_R15, OperandSandbox8bit) ||
          CHECK_OPERAND(1, REG_R15, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_R15, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%r15\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((CHECK_OPERAND(0, REG_RBP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(0, REG_RBP, OperandSandboxUnrestricted) ||
                 (CHECK_OPERAND(1, REG_RBP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(1, REG_RBP, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%rbp\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((CHECK_OPERAND(0, REG_RSP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(0, REG_RSP, OperandSandboxUnrestricted) ||
                 (CHECK_OPERAND(1, REG_RSP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(1, REG_RSP, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%rsp\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((operand_states & 0x70) == (OperandSandboxRestricted << 5)) {
        restricted_register = operand_states & 0x0f;
      } else if ((operand_states & 0x7000) ==
                                        (OperandSandboxRestricted << (5 + 8))) {
        restricted_register = (operand_states & 0x0f00) >> 8;
      }
    }
  }
#line 337 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
       /* On successful match the instruction start must point to the next byte
        * to be able to report the new offset as the start of instruction
        * causing error.  */
       begin = p + 1;
     }
	goto st721;
tr280:
#line 203 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{ if (restricted_register != REG_RBP) {
         PrintError("Incorrectly sandboxed %%rbp\n", begin - data);
         result = 1;
         goto error_detected;
       }
       restricted_register = kNoRestrictedReg;
       BitmapClearBit(valid_targets, (begin - data));
    }
#line 337 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
       /* On successful match the instruction start must point to the next byte
        * to be able to report the new offset as the start of instruction
        * causing error.  */
       begin = p + 1;
     }
	goto st721;
tr281:
#line 263 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{ if (restricted_register == REG_RSI) {
         sandboxed_rsi = begin;
         restricted_register = kSandboxedRsi;
       } else {
         restricted_register = kNoRestrictedReg;
       }
    }
#line 337 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
       /* On successful match the instruction start must point to the next byte
        * to be able to report the new offset as the start of instruction
        * causing error.  */
       begin = p + 1;
     }
	goto st721;
tr282:
#line 271 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{ if (restricted_register == REG_RDI) {
         sandboxed_rdi = begin;
         restricted_register = kSandboxedRdi;
       } else if (restricted_register == kSandboxedRsiRestrictedRdi) {
         sandboxed_rdi = begin;
         restricted_register = kSandboxedRsiSandboxedRdi;
       } else {
         restricted_register = kNoRestrictedReg;
       }
    }
#line 337 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
       /* On successful match the instruction start must point to the next byte
        * to be able to report the new offset as the start of instruction
        * causing error.  */
       begin = p + 1;
     }
	goto st721;
tr286:
#line 213 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{ if (restricted_register != REG_RSP) {
         PrintError("Incorrectly sandboxed %%rsp\n", begin - data);
         result = 1;
         goto error_detected;
       }
       restricted_register = kNoRestrictedReg;
       BitmapClearBit(valid_targets, (begin - data));
    }
#line 337 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
       /* On successful match the instruction start must point to the next byte
        * to be able to report the new offset as the start of instruction
        * causing error.  */
       begin = p + 1;
     }
	goto st721;
tr292:
#line 249 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{ if (restricted_register == REG_RSP) {
         PrintError("Incorrectly modified register %%rsp\n", begin - data);
         result = 1;
         goto error_detected;
       } else if (restricted_register == REG_RBP) {
         PrintError("Incorrectly modified register %%rbp\n", begin - data);
         result = 1;
         goto error_detected;
       }
       BitmapClearBit(valid_targets, (p - data) - 5);
       BitmapClearBit(valid_targets, (p - data) - 2);
       restricted_register = kNoRestrictedReg;
    }
#line 337 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
       /* On successful match the instruction start must point to the next byte
        * to be able to report the new offset as the start of instruction
        * causing error.  */
       begin = p + 1;
     }
	goto st721;
tr309:
#line 376 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_NAME(0, ((*p) & 0x7) |
                            ((GET_REX_PREFIX() & 0x01) << 3) |
                            (((~GET_VEX_PREFIX2()) & 0x20) >> 2));
  }
#line 292 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(0, OperandSize16bit);
  }
#line 439 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(1, OperandSize16bit);
  }
#line 565 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_NAME(1, REG_RAX);
  }
#line 93 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    /* Restricted %rsp or %rbp must be processed by appropriate nacl-special
       instruction, not with regular instruction.  */
    if (restricted_register == REG_RSP) {
      PrintError("Incorrectly modified register %%rsp\n", begin - data);
      result = 1;
      goto error_detected;
    } else if (restricted_register == REG_RBP) {
      PrintError("Incorrectly modified register %%rbp\n", begin - data);
      result = 1;
      goto error_detected;
    }
    /* If Sandboxed Rsi is destroyed then we must note that.  */
    if (restricted_register == kSandboxedRsi) {
      if (CHECK_OPERAND(0, REG_RSI, OperandSandboxRestricted) ||
          CHECK_OPERAND(0, REG_RSI, OperandSandboxUnrestricted) ||
          CHECK_OPERAND(1, REG_RSI, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_RSI, OperandSandboxUnrestricted)) {
        restricted_register = kNoRestrictedReg;
      }
    }
    if (restricted_register == kSandboxedRsi) {
      if (CHECK_OPERAND(0, REG_RDI, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_RDI, OperandSandboxRestricted)) {
        sandboxed_rsi_restricted_rdi = begin;
        restricted_register = kSandboxedRsiRestrictedRdi;
      }
    }
    if (restricted_register != kSandboxedRsiRestrictedRdi) {
      restricted_register = kNoRestrictedReg;
      if (CHECK_OPERAND(0, REG_R15, OperandSandbox8bit) ||
          CHECK_OPERAND(0, REG_R15, OperandSandboxRestricted) ||
          CHECK_OPERAND(0, REG_R15, OperandSandboxUnrestricted) ||
          CHECK_OPERAND(1, REG_R15, OperandSandbox8bit) ||
          CHECK_OPERAND(1, REG_R15, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_R15, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%r15\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((CHECK_OPERAND(0, REG_RBP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(0, REG_RBP, OperandSandboxUnrestricted) ||
                 (CHECK_OPERAND(1, REG_RBP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(1, REG_RBP, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%rbp\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((CHECK_OPERAND(0, REG_RSP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(0, REG_RSP, OperandSandboxUnrestricted) ||
                 (CHECK_OPERAND(1, REG_RSP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(1, REG_RSP, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%rsp\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((operand_states & 0x70) == (OperandSandboxRestricted << 5)) {
        restricted_register = operand_states & 0x0f;
      } else if ((operand_states & 0x7000) ==
                                        (OperandSandboxRestricted << (5 + 8))) {
        restricted_register = (operand_states & 0x0f00) >> 8;
      }
    }
  }
#line 337 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
       /* On successful match the instruction start must point to the next byte
        * to be able to report the new offset as the start of instruction
        * causing error.  */
       begin = p + 1;
     }
	goto st721;
tr320:
#line 66 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_IMM_TYPE(IMM16);
    SET_IMM_PTR(p - 1);
  }
#line 93 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    /* Restricted %rsp or %rbp must be processed by appropriate nacl-special
       instruction, not with regular instruction.  */
    if (restricted_register == REG_RSP) {
      PrintError("Incorrectly modified register %%rsp\n", begin - data);
      result = 1;
      goto error_detected;
    } else if (restricted_register == REG_RBP) {
      PrintError("Incorrectly modified register %%rbp\n", begin - data);
      result = 1;
      goto error_detected;
    }
    /* If Sandboxed Rsi is destroyed then we must note that.  */
    if (restricted_register == kSandboxedRsi) {
      if (CHECK_OPERAND(0, REG_RSI, OperandSandboxRestricted) ||
          CHECK_OPERAND(0, REG_RSI, OperandSandboxUnrestricted) ||
          CHECK_OPERAND(1, REG_RSI, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_RSI, OperandSandboxUnrestricted)) {
        restricted_register = kNoRestrictedReg;
      }
    }
    if (restricted_register == kSandboxedRsi) {
      if (CHECK_OPERAND(0, REG_RDI, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_RDI, OperandSandboxRestricted)) {
        sandboxed_rsi_restricted_rdi = begin;
        restricted_register = kSandboxedRsiRestrictedRdi;
      }
    }
    if (restricted_register != kSandboxedRsiRestrictedRdi) {
      restricted_register = kNoRestrictedReg;
      if (CHECK_OPERAND(0, REG_R15, OperandSandbox8bit) ||
          CHECK_OPERAND(0, REG_R15, OperandSandboxRestricted) ||
          CHECK_OPERAND(0, REG_R15, OperandSandboxUnrestricted) ||
          CHECK_OPERAND(1, REG_R15, OperandSandbox8bit) ||
          CHECK_OPERAND(1, REG_R15, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_R15, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%r15\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((CHECK_OPERAND(0, REG_RBP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(0, REG_RBP, OperandSandboxUnrestricted) ||
                 (CHECK_OPERAND(1, REG_RBP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(1, REG_RBP, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%rbp\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((CHECK_OPERAND(0, REG_RSP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(0, REG_RSP, OperandSandboxUnrestricted) ||
                 (CHECK_OPERAND(1, REG_RSP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(1, REG_RSP, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%rsp\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((operand_states & 0x70) == (OperandSandboxRestricted << 5)) {
        restricted_register = operand_states & 0x0f;
      } else if ((operand_states & 0x7000) ==
                                        (OperandSandboxRestricted << (5 + 8))) {
        restricted_register = (operand_states & 0x0f00) >> 8;
      }
    }
  }
#line 337 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
       /* On successful match the instruction start must point to the next byte
        * to be able to report the new offset as the start of instruction
        * causing error.  */
       begin = p + 1;
     }
	goto st721;
tr357:
#line 25 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_DATA16_PREFIX(FALSE);
  }
#line 93 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    /* Restricted %rsp or %rbp must be processed by appropriate nacl-special
       instruction, not with regular instruction.  */
    if (restricted_register == REG_RSP) {
      PrintError("Incorrectly modified register %%rsp\n", begin - data);
      result = 1;
      goto error_detected;
    } else if (restricted_register == REG_RBP) {
      PrintError("Incorrectly modified register %%rbp\n", begin - data);
      result = 1;
      goto error_detected;
    }
    /* If Sandboxed Rsi is destroyed then we must note that.  */
    if (restricted_register == kSandboxedRsi) {
      if (CHECK_OPERAND(0, REG_RSI, OperandSandboxRestricted) ||
          CHECK_OPERAND(0, REG_RSI, OperandSandboxUnrestricted) ||
          CHECK_OPERAND(1, REG_RSI, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_RSI, OperandSandboxUnrestricted)) {
        restricted_register = kNoRestrictedReg;
      }
    }
    if (restricted_register == kSandboxedRsi) {
      if (CHECK_OPERAND(0, REG_RDI, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_RDI, OperandSandboxRestricted)) {
        sandboxed_rsi_restricted_rdi = begin;
        restricted_register = kSandboxedRsiRestrictedRdi;
      }
    }
    if (restricted_register != kSandboxedRsiRestrictedRdi) {
      restricted_register = kNoRestrictedReg;
      if (CHECK_OPERAND(0, REG_R15, OperandSandbox8bit) ||
          CHECK_OPERAND(0, REG_R15, OperandSandboxRestricted) ||
          CHECK_OPERAND(0, REG_R15, OperandSandboxUnrestricted) ||
          CHECK_OPERAND(1, REG_R15, OperandSandbox8bit) ||
          CHECK_OPERAND(1, REG_R15, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_R15, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%r15\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((CHECK_OPERAND(0, REG_RBP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(0, REG_RBP, OperandSandboxUnrestricted) ||
                 (CHECK_OPERAND(1, REG_RBP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(1, REG_RBP, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%rbp\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((CHECK_OPERAND(0, REG_RSP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(0, REG_RSP, OperandSandboxUnrestricted) ||
                 (CHECK_OPERAND(1, REG_RSP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(1, REG_RSP, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%rsp\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((operand_states & 0x70) == (OperandSandboxRestricted << 5)) {
        restricted_register = operand_states & 0x0f;
      } else if ((operand_states & 0x7000) ==
                                        (OperandSandboxRestricted << (5 + 8))) {
        restricted_register = (operand_states & 0x0f00) >> 8;
      }
    }
  }
#line 337 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
       /* On successful match the instruction start must point to the next byte
        * to be able to report the new offset as the start of instruction
        * causing error.  */
       begin = p + 1;
     }
	goto st721;
tr392:
#line 25 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_DATA16_PREFIX(FALSE);
  }
#line 90 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_DISP_TYPE(DISPNONE);
    SET_MODRM_BASE(((*p) & 0x07) |
                   ((GET_REX_PREFIX() & 0x01) << 3) |
                   (((~GET_VEX_PREFIX2()) & 0x20) >> 2));
    SET_MODRM_INDEX(NO_REG);
    SET_MODRM_SCALE(0);
  }
#line 44 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    if ((base == REG_RIP) || (base == REG_R15) ||
        ((base == REG_RSP) && (restricted_register != REG_RSP)) ||
        ((base == REG_RBP) && (restricted_register != REG_RBP))) {
      if ((index == restricted_register) ||
          ((index == REG_RDI) &&
           (restricted_register == kSandboxedRsiRestrictedRdi))) {
        BitmapClearBit(valid_targets, begin - data);
      } else if ((index != NO_REG) && (index != REG_RIZ)) {
        PrintError("Improper sandboxing in instruction\n", begin - data);
        result = 1;
        goto error_detected;
      }
    } else if ((index == REG_RIP) || (index == REG_R15) ||
               ((index == REG_RSP) && (restricted_register != REG_RSP)) ||
               ((index == REG_RBP) && (restricted_register != REG_RBP))) {
      if ((base == restricted_register) ||
          ((base == REG_RDI) &&
           (restricted_register == kSandboxedRsiRestrictedRdi))) {
        BitmapClearBit(valid_targets, begin - data);
      } else if ((base != NO_REG) && (base != REG_RIZ)) {
        PrintError("Improper sandboxing in instruction\n", begin - data);
        result = 1;
        goto error_detected;
      }
    } else {
      PrintError("Improper sandboxing in instruction\n", begin - data);
      result = 1;
      goto error_detected;
    }
  }
#line 93 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    /* Restricted %rsp or %rbp must be processed by appropriate nacl-special
       instruction, not with regular instruction.  */
    if (restricted_register == REG_RSP) {
      PrintError("Incorrectly modified register %%rsp\n", begin - data);
      result = 1;
      goto error_detected;
    } else if (restricted_register == REG_RBP) {
      PrintError("Incorrectly modified register %%rbp\n", begin - data);
      result = 1;
      goto error_detected;
    }
    /* If Sandboxed Rsi is destroyed then we must note that.  */
    if (restricted_register == kSandboxedRsi) {
      if (CHECK_OPERAND(0, REG_RSI, OperandSandboxRestricted) ||
          CHECK_OPERAND(0, REG_RSI, OperandSandboxUnrestricted) ||
          CHECK_OPERAND(1, REG_RSI, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_RSI, OperandSandboxUnrestricted)) {
        restricted_register = kNoRestrictedReg;
      }
    }
    if (restricted_register == kSandboxedRsi) {
      if (CHECK_OPERAND(0, REG_RDI, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_RDI, OperandSandboxRestricted)) {
        sandboxed_rsi_restricted_rdi = begin;
        restricted_register = kSandboxedRsiRestrictedRdi;
      }
    }
    if (restricted_register != kSandboxedRsiRestrictedRdi) {
      restricted_register = kNoRestrictedReg;
      if (CHECK_OPERAND(0, REG_R15, OperandSandbox8bit) ||
          CHECK_OPERAND(0, REG_R15, OperandSandboxRestricted) ||
          CHECK_OPERAND(0, REG_R15, OperandSandboxUnrestricted) ||
          CHECK_OPERAND(1, REG_R15, OperandSandbox8bit) ||
          CHECK_OPERAND(1, REG_R15, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_R15, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%r15\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((CHECK_OPERAND(0, REG_RBP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(0, REG_RBP, OperandSandboxUnrestricted) ||
                 (CHECK_OPERAND(1, REG_RBP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(1, REG_RBP, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%rbp\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((CHECK_OPERAND(0, REG_RSP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(0, REG_RSP, OperandSandboxUnrestricted) ||
                 (CHECK_OPERAND(1, REG_RSP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(1, REG_RSP, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%rsp\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((operand_states & 0x70) == (OperandSandboxRestricted << 5)) {
        restricted_register = operand_states & 0x0f;
      } else if ((operand_states & 0x7000) ==
                                        (OperandSandboxRestricted << (5 + 8))) {
        restricted_register = (operand_states & 0x0f00) >> 8;
      }
    }
  }
#line 337 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
       /* On successful match the instruction start must point to the next byte
        * to be able to report the new offset as the start of instruction
        * causing error.  */
       begin = p + 1;
     }
	goto st721;
tr398:
#line 25 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_DATA16_PREFIX(FALSE);
  }
#line 292 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(0, OperandSize16bit);
  }
#line 384 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_NAME(0, ((*p) & 0x07) |
                           ((GET_REX_PREFIX() & 0x01) << 3) |
                           (((~GET_VEX_PREFIX2()) & 0x20) >> 2));
  }
#line 93 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    /* Restricted %rsp or %rbp must be processed by appropriate nacl-special
       instruction, not with regular instruction.  */
    if (restricted_register == REG_RSP) {
      PrintError("Incorrectly modified register %%rsp\n", begin - data);
      result = 1;
      goto error_detected;
    } else if (restricted_register == REG_RBP) {
      PrintError("Incorrectly modified register %%rbp\n", begin - data);
      result = 1;
      goto error_detected;
    }
    /* If Sandboxed Rsi is destroyed then we must note that.  */
    if (restricted_register == kSandboxedRsi) {
      if (CHECK_OPERAND(0, REG_RSI, OperandSandboxRestricted) ||
          CHECK_OPERAND(0, REG_RSI, OperandSandboxUnrestricted) ||
          CHECK_OPERAND(1, REG_RSI, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_RSI, OperandSandboxUnrestricted)) {
        restricted_register = kNoRestrictedReg;
      }
    }
    if (restricted_register == kSandboxedRsi) {
      if (CHECK_OPERAND(0, REG_RDI, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_RDI, OperandSandboxRestricted)) {
        sandboxed_rsi_restricted_rdi = begin;
        restricted_register = kSandboxedRsiRestrictedRdi;
      }
    }
    if (restricted_register != kSandboxedRsiRestrictedRdi) {
      restricted_register = kNoRestrictedReg;
      if (CHECK_OPERAND(0, REG_R15, OperandSandbox8bit) ||
          CHECK_OPERAND(0, REG_R15, OperandSandboxRestricted) ||
          CHECK_OPERAND(0, REG_R15, OperandSandboxUnrestricted) ||
          CHECK_OPERAND(1, REG_R15, OperandSandbox8bit) ||
          CHECK_OPERAND(1, REG_R15, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_R15, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%r15\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((CHECK_OPERAND(0, REG_RBP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(0, REG_RBP, OperandSandboxUnrestricted) ||
                 (CHECK_OPERAND(1, REG_RBP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(1, REG_RBP, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%rbp\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((CHECK_OPERAND(0, REG_RSP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(0, REG_RSP, OperandSandboxUnrestricted) ||
                 (CHECK_OPERAND(1, REG_RSP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(1, REG_RSP, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%rsp\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((operand_states & 0x70) == (OperandSandboxRestricted << 5)) {
        restricted_register = operand_states & 0x0f;
      } else if ((operand_states & 0x7000) ==
                                        (OperandSandboxRestricted << (5 + 8))) {
        restricted_register = (operand_states & 0x0f00) >> 8;
      }
    }
  }
#line 337 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
       /* On successful match the instruction start must point to the next byte
        * to be able to report the new offset as the start of instruction
        * causing error.  */
       begin = p + 1;
     }
	goto st721;
tr545:
#line 295 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(0, OperandSize32bit);
  }
#line 397 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_NAME(0, ((~GET_VEX_PREFIX3()) & 0x78) >> 3);
  }
#line 93 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    /* Restricted %rsp or %rbp must be processed by appropriate nacl-special
       instruction, not with regular instruction.  */
    if (restricted_register == REG_RSP) {
      PrintError("Incorrectly modified register %%rsp\n", begin - data);
      result = 1;
      goto error_detected;
    } else if (restricted_register == REG_RBP) {
      PrintError("Incorrectly modified register %%rbp\n", begin - data);
      result = 1;
      goto error_detected;
    }
    /* If Sandboxed Rsi is destroyed then we must note that.  */
    if (restricted_register == kSandboxedRsi) {
      if (CHECK_OPERAND(0, REG_RSI, OperandSandboxRestricted) ||
          CHECK_OPERAND(0, REG_RSI, OperandSandboxUnrestricted) ||
          CHECK_OPERAND(1, REG_RSI, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_RSI, OperandSandboxUnrestricted)) {
        restricted_register = kNoRestrictedReg;
      }
    }
    if (restricted_register == kSandboxedRsi) {
      if (CHECK_OPERAND(0, REG_RDI, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_RDI, OperandSandboxRestricted)) {
        sandboxed_rsi_restricted_rdi = begin;
        restricted_register = kSandboxedRsiRestrictedRdi;
      }
    }
    if (restricted_register != kSandboxedRsiRestrictedRdi) {
      restricted_register = kNoRestrictedReg;
      if (CHECK_OPERAND(0, REG_R15, OperandSandbox8bit) ||
          CHECK_OPERAND(0, REG_R15, OperandSandboxRestricted) ||
          CHECK_OPERAND(0, REG_R15, OperandSandboxUnrestricted) ||
          CHECK_OPERAND(1, REG_R15, OperandSandbox8bit) ||
          CHECK_OPERAND(1, REG_R15, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_R15, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%r15\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((CHECK_OPERAND(0, REG_RBP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(0, REG_RBP, OperandSandboxUnrestricted) ||
                 (CHECK_OPERAND(1, REG_RBP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(1, REG_RBP, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%rbp\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((CHECK_OPERAND(0, REG_RSP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(0, REG_RSP, OperandSandboxUnrestricted) ||
                 (CHECK_OPERAND(1, REG_RSP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(1, REG_RSP, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%rsp\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((operand_states & 0x70) == (OperandSandboxRestricted << 5)) {
        restricted_register = operand_states & 0x0f;
      } else if ((operand_states & 0x7000) ==
                                        (OperandSandboxRestricted << (5 + 8))) {
        restricted_register = (operand_states & 0x0f00) >> 8;
      }
    }
  }
#line 337 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
       /* On successful match the instruction start must point to the next byte
        * to be able to report the new offset as the start of instruction
        * causing error.  */
       begin = p + 1;
     }
	goto st721;
tr551:
#line 298 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(0, OperandSize64bit);
  }
#line 397 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_NAME(0, ((~GET_VEX_PREFIX3()) & 0x78) >> 3);
  }
#line 93 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    /* Restricted %rsp or %rbp must be processed by appropriate nacl-special
       instruction, not with regular instruction.  */
    if (restricted_register == REG_RSP) {
      PrintError("Incorrectly modified register %%rsp\n", begin - data);
      result = 1;
      goto error_detected;
    } else if (restricted_register == REG_RBP) {
      PrintError("Incorrectly modified register %%rbp\n", begin - data);
      result = 1;
      goto error_detected;
    }
    /* If Sandboxed Rsi is destroyed then we must note that.  */
    if (restricted_register == kSandboxedRsi) {
      if (CHECK_OPERAND(0, REG_RSI, OperandSandboxRestricted) ||
          CHECK_OPERAND(0, REG_RSI, OperandSandboxUnrestricted) ||
          CHECK_OPERAND(1, REG_RSI, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_RSI, OperandSandboxUnrestricted)) {
        restricted_register = kNoRestrictedReg;
      }
    }
    if (restricted_register == kSandboxedRsi) {
      if (CHECK_OPERAND(0, REG_RDI, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_RDI, OperandSandboxRestricted)) {
        sandboxed_rsi_restricted_rdi = begin;
        restricted_register = kSandboxedRsiRestrictedRdi;
      }
    }
    if (restricted_register != kSandboxedRsiRestrictedRdi) {
      restricted_register = kNoRestrictedReg;
      if (CHECK_OPERAND(0, REG_R15, OperandSandbox8bit) ||
          CHECK_OPERAND(0, REG_R15, OperandSandboxRestricted) ||
          CHECK_OPERAND(0, REG_R15, OperandSandboxUnrestricted) ||
          CHECK_OPERAND(1, REG_R15, OperandSandbox8bit) ||
          CHECK_OPERAND(1, REG_R15, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_R15, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%r15\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((CHECK_OPERAND(0, REG_RBP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(0, REG_RBP, OperandSandboxUnrestricted) ||
                 (CHECK_OPERAND(1, REG_RBP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(1, REG_RBP, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%rbp\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((CHECK_OPERAND(0, REG_RSP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(0, REG_RSP, OperandSandboxUnrestricted) ||
                 (CHECK_OPERAND(1, REG_RSP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(1, REG_RSP, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%rsp\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((operand_states & 0x70) == (OperandSandboxRestricted << 5)) {
        restricted_register = operand_states & 0x0f;
      } else if ((operand_states & 0x7000) ==
                                        (OperandSandboxRestricted << (5 + 8))) {
        restricted_register = (operand_states & 0x0f00) >> 8;
      }
    }
  }
#line 337 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
       /* On successful match the instruction start must point to the next byte
        * to be able to report the new offset as the start of instruction
        * causing error.  */
       begin = p + 1;
     }
	goto st721;
tr589:
#line 295 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(0, OperandSize32bit);
  }
#line 397 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_NAME(0, ((~GET_VEX_PREFIX3()) & 0x78) >> 3);
  }
#line 90 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_DISP_TYPE(DISPNONE);
    SET_MODRM_BASE(((*p) & 0x07) |
                   ((GET_REX_PREFIX() & 0x01) << 3) |
                   (((~GET_VEX_PREFIX2()) & 0x20) >> 2));
    SET_MODRM_INDEX(NO_REG);
    SET_MODRM_SCALE(0);
  }
#line 44 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    if ((base == REG_RIP) || (base == REG_R15) ||
        ((base == REG_RSP) && (restricted_register != REG_RSP)) ||
        ((base == REG_RBP) && (restricted_register != REG_RBP))) {
      if ((index == restricted_register) ||
          ((index == REG_RDI) &&
           (restricted_register == kSandboxedRsiRestrictedRdi))) {
        BitmapClearBit(valid_targets, begin - data);
      } else if ((index != NO_REG) && (index != REG_RIZ)) {
        PrintError("Improper sandboxing in instruction\n", begin - data);
        result = 1;
        goto error_detected;
      }
    } else if ((index == REG_RIP) || (index == REG_R15) ||
               ((index == REG_RSP) && (restricted_register != REG_RSP)) ||
               ((index == REG_RBP) && (restricted_register != REG_RBP))) {
      if ((base == restricted_register) ||
          ((base == REG_RDI) &&
           (restricted_register == kSandboxedRsiRestrictedRdi))) {
        BitmapClearBit(valid_targets, begin - data);
      } else if ((base != NO_REG) && (base != REG_RIZ)) {
        PrintError("Improper sandboxing in instruction\n", begin - data);
        result = 1;
        goto error_detected;
      }
    } else {
      PrintError("Improper sandboxing in instruction\n", begin - data);
      result = 1;
      goto error_detected;
    }
  }
#line 93 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    /* Restricted %rsp or %rbp must be processed by appropriate nacl-special
       instruction, not with regular instruction.  */
    if (restricted_register == REG_RSP) {
      PrintError("Incorrectly modified register %%rsp\n", begin - data);
      result = 1;
      goto error_detected;
    } else if (restricted_register == REG_RBP) {
      PrintError("Incorrectly modified register %%rbp\n", begin - data);
      result = 1;
      goto error_detected;
    }
    /* If Sandboxed Rsi is destroyed then we must note that.  */
    if (restricted_register == kSandboxedRsi) {
      if (CHECK_OPERAND(0, REG_RSI, OperandSandboxRestricted) ||
          CHECK_OPERAND(0, REG_RSI, OperandSandboxUnrestricted) ||
          CHECK_OPERAND(1, REG_RSI, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_RSI, OperandSandboxUnrestricted)) {
        restricted_register = kNoRestrictedReg;
      }
    }
    if (restricted_register == kSandboxedRsi) {
      if (CHECK_OPERAND(0, REG_RDI, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_RDI, OperandSandboxRestricted)) {
        sandboxed_rsi_restricted_rdi = begin;
        restricted_register = kSandboxedRsiRestrictedRdi;
      }
    }
    if (restricted_register != kSandboxedRsiRestrictedRdi) {
      restricted_register = kNoRestrictedReg;
      if (CHECK_OPERAND(0, REG_R15, OperandSandbox8bit) ||
          CHECK_OPERAND(0, REG_R15, OperandSandboxRestricted) ||
          CHECK_OPERAND(0, REG_R15, OperandSandboxUnrestricted) ||
          CHECK_OPERAND(1, REG_R15, OperandSandbox8bit) ||
          CHECK_OPERAND(1, REG_R15, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_R15, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%r15\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((CHECK_OPERAND(0, REG_RBP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(0, REG_RBP, OperandSandboxUnrestricted) ||
                 (CHECK_OPERAND(1, REG_RBP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(1, REG_RBP, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%rbp\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((CHECK_OPERAND(0, REG_RSP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(0, REG_RSP, OperandSandboxUnrestricted) ||
                 (CHECK_OPERAND(1, REG_RSP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(1, REG_RSP, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%rsp\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((operand_states & 0x70) == (OperandSandboxRestricted << 5)) {
        restricted_register = operand_states & 0x0f;
      } else if ((operand_states & 0x7000) ==
                                        (OperandSandboxRestricted << (5 + 8))) {
        restricted_register = (operand_states & 0x0f00) >> 8;
      }
    }
  }
#line 337 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
       /* On successful match the instruction start must point to the next byte
        * to be able to report the new offset as the start of instruction
        * causing error.  */
       begin = p + 1;
     }
	goto st721;
tr595:
#line 298 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(0, OperandSize64bit);
  }
#line 397 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_NAME(0, ((~GET_VEX_PREFIX3()) & 0x78) >> 3);
  }
#line 90 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_DISP_TYPE(DISPNONE);
    SET_MODRM_BASE(((*p) & 0x07) |
                   ((GET_REX_PREFIX() & 0x01) << 3) |
                   (((~GET_VEX_PREFIX2()) & 0x20) >> 2));
    SET_MODRM_INDEX(NO_REG);
    SET_MODRM_SCALE(0);
  }
#line 44 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    if ((base == REG_RIP) || (base == REG_R15) ||
        ((base == REG_RSP) && (restricted_register != REG_RSP)) ||
        ((base == REG_RBP) && (restricted_register != REG_RBP))) {
      if ((index == restricted_register) ||
          ((index == REG_RDI) &&
           (restricted_register == kSandboxedRsiRestrictedRdi))) {
        BitmapClearBit(valid_targets, begin - data);
      } else if ((index != NO_REG) && (index != REG_RIZ)) {
        PrintError("Improper sandboxing in instruction\n", begin - data);
        result = 1;
        goto error_detected;
      }
    } else if ((index == REG_RIP) || (index == REG_R15) ||
               ((index == REG_RSP) && (restricted_register != REG_RSP)) ||
               ((index == REG_RBP) && (restricted_register != REG_RBP))) {
      if ((base == restricted_register) ||
          ((base == REG_RDI) &&
           (restricted_register == kSandboxedRsiRestrictedRdi))) {
        BitmapClearBit(valid_targets, begin - data);
      } else if ((base != NO_REG) && (base != REG_RIZ)) {
        PrintError("Improper sandboxing in instruction\n", begin - data);
        result = 1;
        goto error_detected;
      }
    } else {
      PrintError("Improper sandboxing in instruction\n", begin - data);
      result = 1;
      goto error_detected;
    }
  }
#line 93 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    /* Restricted %rsp or %rbp must be processed by appropriate nacl-special
       instruction, not with regular instruction.  */
    if (restricted_register == REG_RSP) {
      PrintError("Incorrectly modified register %%rsp\n", begin - data);
      result = 1;
      goto error_detected;
    } else if (restricted_register == REG_RBP) {
      PrintError("Incorrectly modified register %%rbp\n", begin - data);
      result = 1;
      goto error_detected;
    }
    /* If Sandboxed Rsi is destroyed then we must note that.  */
    if (restricted_register == kSandboxedRsi) {
      if (CHECK_OPERAND(0, REG_RSI, OperandSandboxRestricted) ||
          CHECK_OPERAND(0, REG_RSI, OperandSandboxUnrestricted) ||
          CHECK_OPERAND(1, REG_RSI, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_RSI, OperandSandboxUnrestricted)) {
        restricted_register = kNoRestrictedReg;
      }
    }
    if (restricted_register == kSandboxedRsi) {
      if (CHECK_OPERAND(0, REG_RDI, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_RDI, OperandSandboxRestricted)) {
        sandboxed_rsi_restricted_rdi = begin;
        restricted_register = kSandboxedRsiRestrictedRdi;
      }
    }
    if (restricted_register != kSandboxedRsiRestrictedRdi) {
      restricted_register = kNoRestrictedReg;
      if (CHECK_OPERAND(0, REG_R15, OperandSandbox8bit) ||
          CHECK_OPERAND(0, REG_R15, OperandSandboxRestricted) ||
          CHECK_OPERAND(0, REG_R15, OperandSandboxUnrestricted) ||
          CHECK_OPERAND(1, REG_R15, OperandSandbox8bit) ||
          CHECK_OPERAND(1, REG_R15, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_R15, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%r15\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((CHECK_OPERAND(0, REG_RBP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(0, REG_RBP, OperandSandboxUnrestricted) ||
                 (CHECK_OPERAND(1, REG_RBP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(1, REG_RBP, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%rbp\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((CHECK_OPERAND(0, REG_RSP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(0, REG_RSP, OperandSandboxUnrestricted) ||
                 (CHECK_OPERAND(1, REG_RSP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(1, REG_RSP, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%rsp\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((operand_states & 0x70) == (OperandSandboxRestricted << 5)) {
        restricted_register = operand_states & 0x0f;
      } else if ((operand_states & 0x7000) ==
                                        (OperandSandboxRestricted << (5 + 8))) {
        restricted_register = (operand_states & 0x0f00) >> 8;
      }
    }
  }
#line 337 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
       /* On successful match the instruction start must point to the next byte
        * to be able to report the new offset as the start of instruction
        * causing error.  */
       begin = p + 1;
     }
	goto st721;
tr696:
#line 54 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_IMM_TYPE(IMM2);
    SET_IMM_PTR(p);
  }
#line 93 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    /* Restricted %rsp or %rbp must be processed by appropriate nacl-special
       instruction, not with regular instruction.  */
    if (restricted_register == REG_RSP) {
      PrintError("Incorrectly modified register %%rsp\n", begin - data);
      result = 1;
      goto error_detected;
    } else if (restricted_register == REG_RBP) {
      PrintError("Incorrectly modified register %%rbp\n", begin - data);
      result = 1;
      goto error_detected;
    }
    /* If Sandboxed Rsi is destroyed then we must note that.  */
    if (restricted_register == kSandboxedRsi) {
      if (CHECK_OPERAND(0, REG_RSI, OperandSandboxRestricted) ||
          CHECK_OPERAND(0, REG_RSI, OperandSandboxUnrestricted) ||
          CHECK_OPERAND(1, REG_RSI, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_RSI, OperandSandboxUnrestricted)) {
        restricted_register = kNoRestrictedReg;
      }
    }
    if (restricted_register == kSandboxedRsi) {
      if (CHECK_OPERAND(0, REG_RDI, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_RDI, OperandSandboxRestricted)) {
        sandboxed_rsi_restricted_rdi = begin;
        restricted_register = kSandboxedRsiRestrictedRdi;
      }
    }
    if (restricted_register != kSandboxedRsiRestrictedRdi) {
      restricted_register = kNoRestrictedReg;
      if (CHECK_OPERAND(0, REG_R15, OperandSandbox8bit) ||
          CHECK_OPERAND(0, REG_R15, OperandSandboxRestricted) ||
          CHECK_OPERAND(0, REG_R15, OperandSandboxUnrestricted) ||
          CHECK_OPERAND(1, REG_R15, OperandSandbox8bit) ||
          CHECK_OPERAND(1, REG_R15, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_R15, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%r15\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((CHECK_OPERAND(0, REG_RBP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(0, REG_RBP, OperandSandboxUnrestricted) ||
                 (CHECK_OPERAND(1, REG_RBP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(1, REG_RBP, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%rbp\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((CHECK_OPERAND(0, REG_RSP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(0, REG_RSP, OperandSandboxUnrestricted) ||
                 (CHECK_OPERAND(1, REG_RSP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(1, REG_RSP, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%rsp\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((operand_states & 0x70) == (OperandSandboxRestricted << 5)) {
        restricted_register = operand_states & 0x0f;
      } else if ((operand_states & 0x7000) ==
                                        (OperandSandboxRestricted << (5 + 8))) {
        restricted_register = (operand_states & 0x0f00) >> 8;
      }
    }
  }
#line 337 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
       /* On successful match the instruction start must point to the next byte
        * to be able to report the new offset as the start of instruction
        * causing error.  */
       begin = p + 1;
     }
	goto st721;
tr888:
#line 292 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(0, OperandSize16bit);
  }
#line 418 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_NAME(0, REG_RAX);
  }
#line 93 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    /* Restricted %rsp or %rbp must be processed by appropriate nacl-special
       instruction, not with regular instruction.  */
    if (restricted_register == REG_RSP) {
      PrintError("Incorrectly modified register %%rsp\n", begin - data);
      result = 1;
      goto error_detected;
    } else if (restricted_register == REG_RBP) {
      PrintError("Incorrectly modified register %%rbp\n", begin - data);
      result = 1;
      goto error_detected;
    }
    /* If Sandboxed Rsi is destroyed then we must note that.  */
    if (restricted_register == kSandboxedRsi) {
      if (CHECK_OPERAND(0, REG_RSI, OperandSandboxRestricted) ||
          CHECK_OPERAND(0, REG_RSI, OperandSandboxUnrestricted) ||
          CHECK_OPERAND(1, REG_RSI, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_RSI, OperandSandboxUnrestricted)) {
        restricted_register = kNoRestrictedReg;
      }
    }
    if (restricted_register == kSandboxedRsi) {
      if (CHECK_OPERAND(0, REG_RDI, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_RDI, OperandSandboxRestricted)) {
        sandboxed_rsi_restricted_rdi = begin;
        restricted_register = kSandboxedRsiRestrictedRdi;
      }
    }
    if (restricted_register != kSandboxedRsiRestrictedRdi) {
      restricted_register = kNoRestrictedReg;
      if (CHECK_OPERAND(0, REG_R15, OperandSandbox8bit) ||
          CHECK_OPERAND(0, REG_R15, OperandSandboxRestricted) ||
          CHECK_OPERAND(0, REG_R15, OperandSandboxUnrestricted) ||
          CHECK_OPERAND(1, REG_R15, OperandSandbox8bit) ||
          CHECK_OPERAND(1, REG_R15, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_R15, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%r15\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((CHECK_OPERAND(0, REG_RBP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(0, REG_RBP, OperandSandboxUnrestricted) ||
                 (CHECK_OPERAND(1, REG_RBP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(1, REG_RBP, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%rbp\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((CHECK_OPERAND(0, REG_RSP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(0, REG_RSP, OperandSandboxUnrestricted) ||
                 (CHECK_OPERAND(1, REG_RSP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(1, REG_RSP, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%rsp\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((operand_states & 0x70) == (OperandSandboxRestricted << 5)) {
        restricted_register = operand_states & 0x0f;
      } else if ((operand_states & 0x7000) ==
                                        (OperandSandboxRestricted << (5 + 8))) {
        restricted_register = (operand_states & 0x0f00) >> 8;
      }
    }
  }
#line 337 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
       /* On successful match the instruction start must point to the next byte
        * to be able to report the new offset as the start of instruction
        * causing error.  */
       begin = p + 1;
     }
	goto st721;
tr924:
#line 39 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_REPZ_PREFIX(FALSE);
  }
#line 93 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    /* Restricted %rsp or %rbp must be processed by appropriate nacl-special
       instruction, not with regular instruction.  */
    if (restricted_register == REG_RSP) {
      PrintError("Incorrectly modified register %%rsp\n", begin - data);
      result = 1;
      goto error_detected;
    } else if (restricted_register == REG_RBP) {
      PrintError("Incorrectly modified register %%rbp\n", begin - data);
      result = 1;
      goto error_detected;
    }
    /* If Sandboxed Rsi is destroyed then we must note that.  */
    if (restricted_register == kSandboxedRsi) {
      if (CHECK_OPERAND(0, REG_RSI, OperandSandboxRestricted) ||
          CHECK_OPERAND(0, REG_RSI, OperandSandboxUnrestricted) ||
          CHECK_OPERAND(1, REG_RSI, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_RSI, OperandSandboxUnrestricted)) {
        restricted_register = kNoRestrictedReg;
      }
    }
    if (restricted_register == kSandboxedRsi) {
      if (CHECK_OPERAND(0, REG_RDI, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_RDI, OperandSandboxRestricted)) {
        sandboxed_rsi_restricted_rdi = begin;
        restricted_register = kSandboxedRsiRestrictedRdi;
      }
    }
    if (restricted_register != kSandboxedRsiRestrictedRdi) {
      restricted_register = kNoRestrictedReg;
      if (CHECK_OPERAND(0, REG_R15, OperandSandbox8bit) ||
          CHECK_OPERAND(0, REG_R15, OperandSandboxRestricted) ||
          CHECK_OPERAND(0, REG_R15, OperandSandboxUnrestricted) ||
          CHECK_OPERAND(1, REG_R15, OperandSandbox8bit) ||
          CHECK_OPERAND(1, REG_R15, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_R15, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%r15\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((CHECK_OPERAND(0, REG_RBP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(0, REG_RBP, OperandSandboxUnrestricted) ||
                 (CHECK_OPERAND(1, REG_RBP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(1, REG_RBP, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%rbp\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((CHECK_OPERAND(0, REG_RSP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(0, REG_RSP, OperandSandboxUnrestricted) ||
                 (CHECK_OPERAND(1, REG_RSP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(1, REG_RSP, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%rsp\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((operand_states & 0x70) == (OperandSandboxRestricted << 5)) {
        restricted_register = operand_states & 0x0f;
      } else if ((operand_states & 0x7000) ==
                                        (OperandSandboxRestricted << (5 + 8))) {
        restricted_register = (operand_states & 0x0f00) >> 8;
      }
    }
  }
#line 337 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
       /* On successful match the instruction start must point to the next byte
        * to be able to report the new offset as the start of instruction
        * causing error.  */
       begin = p + 1;
     }
	goto st721;
tr932:
#line 229 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{ if (restricted_register == REG_RSP) {
         PrintError("Incorrectly modified register %%rsp\n", begin - data);
         result = 1;
         goto error_detected;
       } else if (restricted_register == REG_RBP) {
         PrintError("Incorrectly modified register %%rbp\n", begin - data);
         result = 1;
         goto error_detected;
       }
       BitmapClearBit(valid_targets, (p - data) - 4);
       BitmapClearBit(valid_targets, (p - data) - 1);
       restricted_register = kNoRestrictedReg;
    }
#line 337 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
       /* On successful match the instruction start must point to the next byte
        * to be able to report the new offset as the start of instruction
        * causing error.  */
       begin = p + 1;
     }
	goto st721;
tr997:
#line 329 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
        begin = p;
        BitmapSetBit(valid_targets, p - data);
        SET_REX_PREFIX(FALSE);
        SET_VEX_PREFIX2(0xe0);
        SET_VEX_PREFIX3(0x00);
        operand_states = 0;
     }
#line 376 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_NAME(0, ((*p) & 0x7) |
                            ((GET_REX_PREFIX() & 0x01) << 3) |
                            (((~GET_VEX_PREFIX2()) & 0x20) >> 2));
  }
#line 93 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    /* Restricted %rsp or %rbp must be processed by appropriate nacl-special
       instruction, not with regular instruction.  */
    if (restricted_register == REG_RSP) {
      PrintError("Incorrectly modified register %%rsp\n", begin - data);
      result = 1;
      goto error_detected;
    } else if (restricted_register == REG_RBP) {
      PrintError("Incorrectly modified register %%rbp\n", begin - data);
      result = 1;
      goto error_detected;
    }
    /* If Sandboxed Rsi is destroyed then we must note that.  */
    if (restricted_register == kSandboxedRsi) {
      if (CHECK_OPERAND(0, REG_RSI, OperandSandboxRestricted) ||
          CHECK_OPERAND(0, REG_RSI, OperandSandboxUnrestricted) ||
          CHECK_OPERAND(1, REG_RSI, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_RSI, OperandSandboxUnrestricted)) {
        restricted_register = kNoRestrictedReg;
      }
    }
    if (restricted_register == kSandboxedRsi) {
      if (CHECK_OPERAND(0, REG_RDI, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_RDI, OperandSandboxRestricted)) {
        sandboxed_rsi_restricted_rdi = begin;
        restricted_register = kSandboxedRsiRestrictedRdi;
      }
    }
    if (restricted_register != kSandboxedRsiRestrictedRdi) {
      restricted_register = kNoRestrictedReg;
      if (CHECK_OPERAND(0, REG_R15, OperandSandbox8bit) ||
          CHECK_OPERAND(0, REG_R15, OperandSandboxRestricted) ||
          CHECK_OPERAND(0, REG_R15, OperandSandboxUnrestricted) ||
          CHECK_OPERAND(1, REG_R15, OperandSandbox8bit) ||
          CHECK_OPERAND(1, REG_R15, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_R15, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%r15\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((CHECK_OPERAND(0, REG_RBP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(0, REG_RBP, OperandSandboxUnrestricted) ||
                 (CHECK_OPERAND(1, REG_RBP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(1, REG_RBP, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%rbp\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((CHECK_OPERAND(0, REG_RSP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(0, REG_RSP, OperandSandboxUnrestricted) ||
                 (CHECK_OPERAND(1, REG_RSP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(1, REG_RSP, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%rsp\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((operand_states & 0x70) == (OperandSandboxRestricted << 5)) {
        restricted_register = operand_states & 0x0f;
      } else if ((operand_states & 0x7000) ==
                                        (OperandSandboxRestricted << (5 + 8))) {
        restricted_register = (operand_states & 0x0f00) >> 8;
      }
    }
  }
#line 337 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
       /* On successful match the instruction start must point to the next byte
        * to be able to report the new offset as the start of instruction
        * causing error.  */
       begin = p + 1;
     }
	goto st721;
tr998:
#line 329 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
        begin = p;
        BitmapSetBit(valid_targets, p - data);
        SET_REX_PREFIX(FALSE);
        SET_VEX_PREFIX2(0xe0);
        SET_VEX_PREFIX3(0x00);
        operand_states = 0;
     }
#line 376 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_NAME(0, ((*p) & 0x7) |
                            ((GET_REX_PREFIX() & 0x01) << 3) |
                            (((~GET_VEX_PREFIX2()) & 0x20) >> 2));
  }
#line 319 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(0, OperandSize64bit);
  }
#line 93 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    /* Restricted %rsp or %rbp must be processed by appropriate nacl-special
       instruction, not with regular instruction.  */
    if (restricted_register == REG_RSP) {
      PrintError("Incorrectly modified register %%rsp\n", begin - data);
      result = 1;
      goto error_detected;
    } else if (restricted_register == REG_RBP) {
      PrintError("Incorrectly modified register %%rbp\n", begin - data);
      result = 1;
      goto error_detected;
    }
    /* If Sandboxed Rsi is destroyed then we must note that.  */
    if (restricted_register == kSandboxedRsi) {
      if (CHECK_OPERAND(0, REG_RSI, OperandSandboxRestricted) ||
          CHECK_OPERAND(0, REG_RSI, OperandSandboxUnrestricted) ||
          CHECK_OPERAND(1, REG_RSI, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_RSI, OperandSandboxUnrestricted)) {
        restricted_register = kNoRestrictedReg;
      }
    }
    if (restricted_register == kSandboxedRsi) {
      if (CHECK_OPERAND(0, REG_RDI, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_RDI, OperandSandboxRestricted)) {
        sandboxed_rsi_restricted_rdi = begin;
        restricted_register = kSandboxedRsiRestrictedRdi;
      }
    }
    if (restricted_register != kSandboxedRsiRestrictedRdi) {
      restricted_register = kNoRestrictedReg;
      if (CHECK_OPERAND(0, REG_R15, OperandSandbox8bit) ||
          CHECK_OPERAND(0, REG_R15, OperandSandboxRestricted) ||
          CHECK_OPERAND(0, REG_R15, OperandSandboxUnrestricted) ||
          CHECK_OPERAND(1, REG_R15, OperandSandbox8bit) ||
          CHECK_OPERAND(1, REG_R15, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_R15, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%r15\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((CHECK_OPERAND(0, REG_RBP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(0, REG_RBP, OperandSandboxUnrestricted) ||
                 (CHECK_OPERAND(1, REG_RBP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(1, REG_RBP, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%rbp\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((CHECK_OPERAND(0, REG_RSP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(0, REG_RSP, OperandSandboxUnrestricted) ||
                 (CHECK_OPERAND(1, REG_RSP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(1, REG_RSP, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%rsp\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((operand_states & 0x70) == (OperandSandboxRestricted << 5)) {
        restricted_register = operand_states & 0x0f;
      } else if ((operand_states & 0x7000) ==
                                        (OperandSandboxRestricted << (5 + 8))) {
        restricted_register = (operand_states & 0x0f00) >> 8;
      }
    }
  }
#line 337 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
       /* On successful match the instruction start must point to the next byte
        * to be able to report the new offset as the start of instruction
        * causing error.  */
       begin = p + 1;
     }
	goto st721;
tr1010:
#line 329 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
        begin = p;
        BitmapSetBit(valid_targets, p - data);
        SET_REX_PREFIX(FALSE);
        SET_VEX_PREFIX2(0xe0);
        SET_VEX_PREFIX3(0x00);
        operand_states = 0;
     }
#line 93 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    /* Restricted %rsp or %rbp must be processed by appropriate nacl-special
       instruction, not with regular instruction.  */
    if (restricted_register == REG_RSP) {
      PrintError("Incorrectly modified register %%rsp\n", begin - data);
      result = 1;
      goto error_detected;
    } else if (restricted_register == REG_RBP) {
      PrintError("Incorrectly modified register %%rbp\n", begin - data);
      result = 1;
      goto error_detected;
    }
    /* If Sandboxed Rsi is destroyed then we must note that.  */
    if (restricted_register == kSandboxedRsi) {
      if (CHECK_OPERAND(0, REG_RSI, OperandSandboxRestricted) ||
          CHECK_OPERAND(0, REG_RSI, OperandSandboxUnrestricted) ||
          CHECK_OPERAND(1, REG_RSI, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_RSI, OperandSandboxUnrestricted)) {
        restricted_register = kNoRestrictedReg;
      }
    }
    if (restricted_register == kSandboxedRsi) {
      if (CHECK_OPERAND(0, REG_RDI, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_RDI, OperandSandboxRestricted)) {
        sandboxed_rsi_restricted_rdi = begin;
        restricted_register = kSandboxedRsiRestrictedRdi;
      }
    }
    if (restricted_register != kSandboxedRsiRestrictedRdi) {
      restricted_register = kNoRestrictedReg;
      if (CHECK_OPERAND(0, REG_R15, OperandSandbox8bit) ||
          CHECK_OPERAND(0, REG_R15, OperandSandboxRestricted) ||
          CHECK_OPERAND(0, REG_R15, OperandSandboxUnrestricted) ||
          CHECK_OPERAND(1, REG_R15, OperandSandbox8bit) ||
          CHECK_OPERAND(1, REG_R15, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_R15, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%r15\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((CHECK_OPERAND(0, REG_RBP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(0, REG_RBP, OperandSandboxUnrestricted) ||
                 (CHECK_OPERAND(1, REG_RBP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(1, REG_RBP, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%rbp\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((CHECK_OPERAND(0, REG_RSP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(0, REG_RSP, OperandSandboxUnrestricted) ||
                 (CHECK_OPERAND(1, REG_RSP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(1, REG_RSP, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%rsp\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((operand_states & 0x70) == (OperandSandboxRestricted << 5)) {
        restricted_register = operand_states & 0x0f;
      } else if ((operand_states & 0x7000) ==
                                        (OperandSandboxRestricted << (5 + 8))) {
        restricted_register = (operand_states & 0x0f00) >> 8;
      }
    }
  }
#line 337 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
       /* On successful match the instruction start must point to the next byte
        * to be able to report the new offset as the start of instruction
        * causing error.  */
       begin = p + 1;
     }
	goto st721;
tr1011:
#line 329 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
        begin = p;
        BitmapSetBit(valid_targets, p - data);
        SET_REX_PREFIX(FALSE);
        SET_VEX_PREFIX2(0xe0);
        SET_VEX_PREFIX3(0x00);
        operand_states = 0;
     }
#line 376 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_NAME(0, ((*p) & 0x7) |
                            ((GET_REX_PREFIX() & 0x01) << 3) |
                            (((~GET_VEX_PREFIX2()) & 0x20) >> 2));
  }
#line 295 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(0, OperandSize32bit);
  }
#line 442 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(1, OperandSize32bit);
  }
#line 565 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_NAME(1, REG_RAX);
  }
#line 93 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    /* Restricted %rsp or %rbp must be processed by appropriate nacl-special
       instruction, not with regular instruction.  */
    if (restricted_register == REG_RSP) {
      PrintError("Incorrectly modified register %%rsp\n", begin - data);
      result = 1;
      goto error_detected;
    } else if (restricted_register == REG_RBP) {
      PrintError("Incorrectly modified register %%rbp\n", begin - data);
      result = 1;
      goto error_detected;
    }
    /* If Sandboxed Rsi is destroyed then we must note that.  */
    if (restricted_register == kSandboxedRsi) {
      if (CHECK_OPERAND(0, REG_RSI, OperandSandboxRestricted) ||
          CHECK_OPERAND(0, REG_RSI, OperandSandboxUnrestricted) ||
          CHECK_OPERAND(1, REG_RSI, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_RSI, OperandSandboxUnrestricted)) {
        restricted_register = kNoRestrictedReg;
      }
    }
    if (restricted_register == kSandboxedRsi) {
      if (CHECK_OPERAND(0, REG_RDI, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_RDI, OperandSandboxRestricted)) {
        sandboxed_rsi_restricted_rdi = begin;
        restricted_register = kSandboxedRsiRestrictedRdi;
      }
    }
    if (restricted_register != kSandboxedRsiRestrictedRdi) {
      restricted_register = kNoRestrictedReg;
      if (CHECK_OPERAND(0, REG_R15, OperandSandbox8bit) ||
          CHECK_OPERAND(0, REG_R15, OperandSandboxRestricted) ||
          CHECK_OPERAND(0, REG_R15, OperandSandboxUnrestricted) ||
          CHECK_OPERAND(1, REG_R15, OperandSandbox8bit) ||
          CHECK_OPERAND(1, REG_R15, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_R15, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%r15\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((CHECK_OPERAND(0, REG_RBP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(0, REG_RBP, OperandSandboxUnrestricted) ||
                 (CHECK_OPERAND(1, REG_RBP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(1, REG_RBP, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%rbp\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((CHECK_OPERAND(0, REG_RSP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(0, REG_RSP, OperandSandboxUnrestricted) ||
                 (CHECK_OPERAND(1, REG_RSP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(1, REG_RSP, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%rsp\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((operand_states & 0x70) == (OperandSandboxRestricted << 5)) {
        restricted_register = operand_states & 0x0f;
      } else if ((operand_states & 0x7000) ==
                                        (OperandSandboxRestricted << (5 + 8))) {
        restricted_register = (operand_states & 0x0f00) >> 8;
      }
    }
  }
#line 337 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
       /* On successful match the instruction start must point to the next byte
        * to be able to report the new offset as the start of instruction
        * causing error.  */
       begin = p + 1;
     }
	goto st721;
tr1012:
#line 329 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
        begin = p;
        BitmapSetBit(valid_targets, p - data);
        SET_REX_PREFIX(FALSE);
        SET_VEX_PREFIX2(0xe0);
        SET_VEX_PREFIX3(0x00);
        operand_states = 0;
     }
#line 317 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{ if (restricted_register != kSandboxedRsiSandboxedRdi) {
         PrintError("Incorrectly sandboxed %%rsi or %%rdi\n", begin - data);
         result = 1;
         goto error_detected;
       }
       restricted_register = kNoRestrictedReg;
       BitmapClearBit(valid_targets, (begin - data));
       BitmapClearBit(valid_targets, (sandboxed_rsi - data));
       BitmapClearBit(valid_targets, (sandboxed_rsi_restricted_rdi - data));
       BitmapClearBit(valid_targets, (sandboxed_rdi - data));
    }
#line 337 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
       /* On successful match the instruction start must point to the next byte
        * to be able to report the new offset as the start of instruction
        * causing error.  */
       begin = p + 1;
     }
	goto st721;
tr1013:
#line 329 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
        begin = p;
        BitmapSetBit(valid_targets, p - data);
        SET_REX_PREFIX(FALSE);
        SET_VEX_PREFIX2(0xe0);
        SET_VEX_PREFIX3(0x00);
        operand_states = 0;
     }
#line 300 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{ if (restricted_register != kSandboxedRdi &&
           restricted_register != kSandboxedRsiSandboxedRdi) {
         PrintError("Incorrectly sandboxed %%rdi\n", begin - data);
         result = 1;
         goto error_detected;
       }
       restricted_register = kNoRestrictedReg;
       BitmapClearBit(valid_targets, (begin - data));
       BitmapClearBit(valid_targets, (sandboxed_rdi - data));
    }
#line 337 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
       /* On successful match the instruction start must point to the next byte
        * to be able to report the new offset as the start of instruction
        * causing error.  */
       begin = p + 1;
     }
	goto st721;
tr1014:
#line 329 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
        begin = p;
        BitmapSetBit(valid_targets, p - data);
        SET_REX_PREFIX(FALSE);
        SET_VEX_PREFIX2(0xe0);
        SET_VEX_PREFIX3(0x00);
        operand_states = 0;
     }
#line 284 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{ if (restricted_register != kSandboxedRsi) {
         PrintError("Incorrectly sandboxed %%rdi\n", begin - data);
         result = 1;
         goto error_detected;
       }
       restricted_register = kNoRestrictedReg;
       BitmapClearBit(valid_targets, (begin - data));
       BitmapClearBit(valid_targets, (sandboxed_rdi - data));
    }
#line 337 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
       /* On successful match the instruction start must point to the next byte
        * to be able to report the new offset as the start of instruction
        * causing error.  */
       begin = p + 1;
     }
	goto st721;
st721:
	if ( ++p == pe )
		goto _test_eof721;
case 721:
#line 4898 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 0u: goto tr978;
		case 1u: goto tr979;
		case 2u: goto tr980;
		case 3u: goto tr981;
		case 4u: goto tr982;
		case 5u: goto tr983;
		case 8u: goto tr978;
		case 9u: goto tr979;
		case 10u: goto tr980;
		case 11u: goto tr981;
		case 12u: goto tr982;
		case 13u: goto tr983;
		case 15u: goto tr984;
		case 16u: goto tr978;
		case 17u: goto tr979;
		case 18u: goto tr980;
		case 19u: goto tr981;
		case 20u: goto tr982;
		case 21u: goto tr983;
		case 24u: goto tr978;
		case 25u: goto tr979;
		case 26u: goto tr980;
		case 27u: goto tr981;
		case 28u: goto tr982;
		case 29u: goto tr983;
		case 32u: goto tr978;
		case 33u: goto tr979;
		case 34u: goto tr980;
		case 35u: goto tr981;
		case 36u: goto tr982;
		case 37u: goto tr983;
		case 40u: goto tr978;
		case 41u: goto tr979;
		case 42u: goto tr980;
		case 43u: goto tr981;
		case 44u: goto tr982;
		case 45u: goto tr983;
		case 46u: goto tr985;
		case 48u: goto tr978;
		case 49u: goto tr979;
		case 50u: goto tr980;
		case 51u: goto tr981;
		case 52u: goto tr982;
		case 53u: goto tr983;
		case 60u: goto tr987;
		case 61u: goto tr988;
		case 62u: goto tr989;
		case 65u: goto tr991;
		case 72u: goto tr992;
		case 73u: goto tr993;
		case 74u: goto tr994;
		case 76u: goto tr996;
		case 99u: goto tr981;
		case 102u: goto tr999;
		case 104u: goto tr988;
		case 105u: goto tr1000;
		case 106u: goto tr987;
		case 107u: goto tr1001;
		case 128u: goto tr1003;
		case 129u: goto tr1004;
		case 131u: goto tr1005;
		case 133u: goto tr979;
		case 134u: goto tr1006;
		case 135u: goto tr1007;
		case 137u: goto tr979;
		case 138u: goto tr980;
		case 139u: goto tr981;
		case 141u: goto tr1008;
		case 143u: goto tr1009;
		case 144u: goto tr1010;
		case 155u: goto tr1010;
		case 168u: goto tr982;
		case 169u: goto tr983;
		case 192u: goto tr1017;
		case 193u: goto tr1018;
		case 196u: goto tr1019;
		case 197u: goto tr1020;
		case 198u: goto tr1021;
		case 199u: goto tr1022;
		case 200u: goto tr1023;
		case 202u: goto tr1024;
		case 203u: goto tr1010;
		case 209u: goto tr1026;
		case 211u: goto tr1026;
		case 216u: goto tr986;
		case 217u: goto tr1027;
		case 218u: goto tr1028;
		case 219u: goto tr1029;
		case 220u: goto tr1030;
		case 221u: goto tr1031;
		case 222u: goto tr1032;
		case 223u: goto tr1033;
		case 235u: goto tr1002;
		case 240u: goto tr1035;
		case 242u: goto tr1036;
		case 243u: goto tr1037;
		case 246u: goto tr1038;
		case 247u: goto tr1039;
		case 254u: goto tr1040;
		case 255u: goto tr1041;
	}
	if ( (*p) < 164u ) {
		if ( (*p) < 88u ) {
			if ( (*p) < 64u ) {
				if ( 56u <= (*p) && (*p) <= 59u )
					goto tr986;
			} else if ( (*p) > 71u ) {
				if ( (*p) > 79u ) {
					if ( 80u <= (*p) && (*p) <= 87u )
						goto tr997;
				} else if ( (*p) >= 75u )
					goto tr995;
			} else
				goto tr990;
		} else if ( (*p) > 95u ) {
			if ( (*p) < 132u ) {
				if ( 112u <= (*p) && (*p) <= 127u )
					goto tr1002;
			} else if ( (*p) > 136u ) {
				if ( (*p) > 151u ) {
					if ( 152u <= (*p) && (*p) <= 153u )
						goto tr1010;
				} else if ( (*p) >= 145u )
					goto tr1011;
			} else
				goto tr978;
		} else
			goto tr998;
	} else if ( (*p) > 167u ) {
		if ( (*p) < 184u ) {
			if ( (*p) < 172u ) {
				if ( 170u <= (*p) && (*p) <= 171u )
					goto tr1013;
			} else if ( (*p) > 173u ) {
				if ( (*p) > 175u ) {
					if ( 176u <= (*p) && (*p) <= 183u )
						goto tr1015;
				} else if ( (*p) >= 174u )
					goto tr1013;
			} else
				goto tr1014;
		} else if ( (*p) > 191u ) {
			if ( (*p) < 232u ) {
				if ( 208u <= (*p) && (*p) <= 210u )
					goto tr1025;
			} else if ( (*p) > 233u ) {
				if ( (*p) > 249u ) {
					if ( 252u <= (*p) && (*p) <= 253u )
						goto tr1010;
				} else if ( (*p) >= 244u )
					goto tr1010;
			} else
				goto tr1034;
		} else
			goto tr1016;
	} else
		goto tr1012;
	goto tr33;
tr45:
#line 295 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(0, OperandSize32bit);
  }
	goto st1;
tr47:
#line 289 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(0, OperandSize8bit);
  }
	goto st1;
tr220:
#line 298 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(0, OperandSize64bit);
  }
	goto st1;
tr293:
#line 292 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(0, OperandSize16bit);
  }
	goto st1;
tr332:
#line 25 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_DATA16_PREFIX(FALSE);
  }
#line 295 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(0, OperandSize32bit);
  }
	goto st1;
tr401:
#line 25 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_DATA16_PREFIX(FALSE);
  }
#line 298 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(0, OperandSize64bit);
  }
	goto st1;
tr978:
#line 329 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
        begin = p;
        BitmapSetBit(valid_targets, p - data);
        SET_REX_PREFIX(FALSE);
        SET_VEX_PREFIX2(0xe0);
        SET_VEX_PREFIX3(0x00);
        operand_states = 0;
     }
#line 289 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(0, OperandSize8bit);
  }
	goto st1;
tr979:
#line 329 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
        begin = p;
        BitmapSetBit(valid_targets, p - data);
        SET_REX_PREFIX(FALSE);
        SET_VEX_PREFIX2(0xe0);
        SET_VEX_PREFIX3(0x00);
        operand_states = 0;
     }
#line 295 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(0, OperandSize32bit);
  }
	goto st1;
st1:
	if ( ++p == pe )
		goto _test_eof1;
case 1:
#line 5136 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 4u: goto st2;
		case 5u: goto tr2;
		case 12u: goto st2;
		case 13u: goto tr2;
		case 20u: goto st2;
		case 21u: goto tr2;
		case 28u: goto st2;
		case 29u: goto tr2;
		case 36u: goto st2;
		case 37u: goto tr2;
		case 44u: goto st2;
		case 45u: goto tr2;
		case 52u: goto st2;
		case 53u: goto tr2;
		case 60u: goto st2;
		case 61u: goto tr2;
		case 68u: goto st8;
		case 76u: goto st8;
		case 84u: goto st8;
		case 92u: goto st8;
		case 100u: goto st8;
		case 108u: goto st8;
		case 116u: goto st8;
		case 124u: goto st8;
		case 132u: goto st9;
		case 140u: goto st9;
		case 148u: goto st9;
		case 156u: goto st9;
		case 164u: goto st9;
		case 172u: goto st9;
		case 180u: goto st9;
		case 188u: goto st9;
	}
	if ( (*p) < 64u ) {
		if ( (*p) <= 63u )
			goto tr0;
	} else if ( (*p) > 127u ) {
		if ( 128u <= (*p) && (*p) <= 191u )
			goto tr5;
	} else
		goto tr3;
	goto tr7;
tr18:
#line 389 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_NAME(0, (((*p) & 0x38) >> 3) |
                           ((GET_REX_PREFIX() & 0x04) << 1) |
                           (((~GET_VEX_PREFIX2()) & 0x80) >> 4));
  }
	goto st2;
tr194:
#line 536 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_NAME(1, (((*p) & 0x38) >> 3) |
                           ((GET_REX_PREFIX() & 0x04) << 1) |
                           (((~GET_VEX_PREFIX2()) & 0x80) >> 4));
  }
	goto st2;
tr393:
#line 25 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_DATA16_PREFIX(FALSE);
  }
	goto st2;
tr571:
#line 295 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(0, OperandSize32bit);
  }
#line 397 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_NAME(0, ((~GET_VEX_PREFIX3()) & 0x78) >> 3);
  }
	goto st2;
tr574:
#line 298 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(0, OperandSize64bit);
  }
#line 397 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_NAME(0, ((~GET_VEX_PREFIX3()) & 0x78) >> 3);
  }
	goto st2;
st2:
	if ( ++p == pe )
		goto _test_eof2;
case 2:
#line 5226 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 5u: goto tr9;
		case 13u: goto tr9;
		case 21u: goto tr9;
		case 29u: goto tr9;
		case 37u: goto tr9;
		case 45u: goto tr9;
		case 53u: goto tr9;
		case 61u: goto tr9;
		case 69u: goto tr9;
		case 77u: goto tr9;
		case 85u: goto tr9;
		case 93u: goto tr9;
		case 101u: goto tr9;
		case 109u: goto tr9;
		case 117u: goto tr9;
		case 125u: goto tr9;
		case 133u: goto tr9;
		case 141u: goto tr9;
		case 149u: goto tr9;
		case 157u: goto tr9;
		case 165u: goto tr9;
		case 173u: goto tr9;
		case 181u: goto tr9;
		case 189u: goto tr9;
		case 197u: goto tr9;
		case 205u: goto tr9;
		case 213u: goto tr9;
		case 221u: goto tr9;
		case 229u: goto tr9;
		case 237u: goto tr9;
		case 245u: goto tr9;
		case 253u: goto tr9;
	}
	goto tr8;
tr2:
#line 105 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_MODRM_BASE(REG_RIP);
    SET_MODRM_INDEX(NO_REG);
    SET_MODRM_SCALE(0);
  }
	goto st3;
tr5:
#line 98 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_MODRM_BASE(((*p) & 0x07) |
                   ((GET_REX_PREFIX() & 0x01) << 3) |
                   (((~GET_VEX_PREFIX2()) & 0x20) >> 2));
    SET_MODRM_INDEX(NO_REG);
    SET_MODRM_SCALE(0);
  }
	goto st3;
tr9:
#line 110 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_DISP_TYPE(DISPNONE);
    SET_MODRM_BASE(NO_REG);
    SET_MODRM_INDEX(index_registers[(((*p) & 0x38) >> 3) |
                                    ((GET_REX_PREFIX() & 0x02) << 2) |
                                    (((~GET_VEX_PREFIX2()) & 0x40) >> 3)]);
    SET_MODRM_SCALE(((*p) & 0xc0) >> 6);
  }
	goto st3;
tr16:
#line 118 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_DISP_TYPE(DISPNONE);
    SET_MODRM_BASE(((*p) & 0x7) |
                   ((GET_REX_PREFIX() & 0x01) << 3) |
                   (((~GET_VEX_PREFIX2()) & 0x20) >> 2));
    SET_MODRM_INDEX(index_registers[(((*p) & 0x38) >> 3) |
                                    ((GET_REX_PREFIX() & 0x02) << 2) |
                                    (((~GET_VEX_PREFIX2()) & 0x40) >> 3)]);
    SET_MODRM_SCALE(((*p) & 0xc0) >> 6);
  }
	goto st3;
tr19:
#line 389 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_NAME(0, (((*p) & 0x38) >> 3) |
                           ((GET_REX_PREFIX() & 0x04) << 1) |
                           (((~GET_VEX_PREFIX2()) & 0x80) >> 4));
  }
#line 105 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_MODRM_BASE(REG_RIP);
    SET_MODRM_INDEX(NO_REG);
    SET_MODRM_SCALE(0);
  }
	goto st3;
tr22:
#line 389 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_NAME(0, (((*p) & 0x38) >> 3) |
                           ((GET_REX_PREFIX() & 0x04) << 1) |
                           (((~GET_VEX_PREFIX2()) & 0x80) >> 4));
  }
#line 98 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_MODRM_BASE(((*p) & 0x07) |
                   ((GET_REX_PREFIX() & 0x01) << 3) |
                   (((~GET_VEX_PREFIX2()) & 0x20) >> 2));
    SET_MODRM_INDEX(NO_REG);
    SET_MODRM_SCALE(0);
  }
	goto st3;
tr195:
#line 536 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_NAME(1, (((*p) & 0x38) >> 3) |
                           ((GET_REX_PREFIX() & 0x04) << 1) |
                           (((~GET_VEX_PREFIX2()) & 0x80) >> 4));
  }
#line 105 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_MODRM_BASE(REG_RIP);
    SET_MODRM_INDEX(NO_REG);
    SET_MODRM_SCALE(0);
  }
	goto st3;
tr198:
#line 536 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_NAME(1, (((*p) & 0x38) >> 3) |
                           ((GET_REX_PREFIX() & 0x04) << 1) |
                           (((~GET_VEX_PREFIX2()) & 0x80) >> 4));
  }
#line 98 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_MODRM_BASE(((*p) & 0x07) |
                   ((GET_REX_PREFIX() & 0x01) << 3) |
                   (((~GET_VEX_PREFIX2()) & 0x20) >> 2));
    SET_MODRM_INDEX(NO_REG);
    SET_MODRM_SCALE(0);
  }
	goto st3;
tr411:
#line 25 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_DATA16_PREFIX(FALSE);
  }
#line 105 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_MODRM_BASE(REG_RIP);
    SET_MODRM_INDEX(NO_REG);
    SET_MODRM_SCALE(0);
  }
	goto st3;
tr396:
#line 25 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_DATA16_PREFIX(FALSE);
  }
#line 98 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_MODRM_BASE(((*p) & 0x07) |
                   ((GET_REX_PREFIX() & 0x01) << 3) |
                   (((~GET_VEX_PREFIX2()) & 0x20) >> 2));
    SET_MODRM_INDEX(NO_REG);
    SET_MODRM_SCALE(0);
  }
	goto st3;
tr591:
#line 295 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(0, OperandSize32bit);
  }
#line 397 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_NAME(0, ((~GET_VEX_PREFIX3()) & 0x78) >> 3);
  }
#line 98 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_MODRM_BASE(((*p) & 0x07) |
                   ((GET_REX_PREFIX() & 0x01) << 3) |
                   (((~GET_VEX_PREFIX2()) & 0x20) >> 2));
    SET_MODRM_INDEX(NO_REG);
    SET_MODRM_SCALE(0);
  }
	goto st3;
tr597:
#line 298 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(0, OperandSize64bit);
  }
#line 397 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_NAME(0, ((~GET_VEX_PREFIX3()) & 0x78) >> 3);
  }
#line 98 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_MODRM_BASE(((*p) & 0x07) |
                   ((GET_REX_PREFIX() & 0x01) << 3) |
                   (((~GET_VEX_PREFIX2()) & 0x20) >> 2));
    SET_MODRM_INDEX(NO_REG);
    SET_MODRM_SCALE(0);
  }
	goto st3;
tr617:
#line 295 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(0, OperandSize32bit);
  }
#line 397 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_NAME(0, ((~GET_VEX_PREFIX3()) & 0x78) >> 3);
  }
#line 105 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_MODRM_BASE(REG_RIP);
    SET_MODRM_INDEX(NO_REG);
    SET_MODRM_SCALE(0);
  }
	goto st3;
tr620:
#line 298 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(0, OperandSize64bit);
  }
#line 397 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_NAME(0, ((~GET_VEX_PREFIX3()) & 0x78) >> 3);
  }
#line 105 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_MODRM_BASE(REG_RIP);
    SET_MODRM_INDEX(NO_REG);
    SET_MODRM_SCALE(0);
  }
	goto st3;
st3:
	if ( ++p == pe )
		goto _test_eof3;
case 3:
#line 5462 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	goto st4;
st4:
	if ( ++p == pe )
		goto _test_eof4;
case 4:
	goto st5;
st5:
	if ( ++p == pe )
		goto _test_eof5;
case 5:
	goto st6;
st6:
	if ( ++p == pe )
		goto _test_eof6;
case 6:
	goto tr13;
tr3:
#line 98 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_MODRM_BASE(((*p) & 0x07) |
                   ((GET_REX_PREFIX() & 0x01) << 3) |
                   (((~GET_VEX_PREFIX2()) & 0x20) >> 2));
    SET_MODRM_INDEX(NO_REG);
    SET_MODRM_SCALE(0);
  }
	goto st7;
tr15:
#line 118 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_DISP_TYPE(DISPNONE);
    SET_MODRM_BASE(((*p) & 0x7) |
                   ((GET_REX_PREFIX() & 0x01) << 3) |
                   (((~GET_VEX_PREFIX2()) & 0x20) >> 2));
    SET_MODRM_INDEX(index_registers[(((*p) & 0x38) >> 3) |
                                    ((GET_REX_PREFIX() & 0x02) << 2) |
                                    (((~GET_VEX_PREFIX2()) & 0x40) >> 3)]);
    SET_MODRM_SCALE(((*p) & 0xc0) >> 6);
  }
	goto st7;
tr20:
#line 389 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_NAME(0, (((*p) & 0x38) >> 3) |
                           ((GET_REX_PREFIX() & 0x04) << 1) |
                           (((~GET_VEX_PREFIX2()) & 0x80) >> 4));
  }
#line 98 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_MODRM_BASE(((*p) & 0x07) |
                   ((GET_REX_PREFIX() & 0x01) << 3) |
                   (((~GET_VEX_PREFIX2()) & 0x20) >> 2));
    SET_MODRM_INDEX(NO_REG);
    SET_MODRM_SCALE(0);
  }
	goto st7;
tr196:
#line 536 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_NAME(1, (((*p) & 0x38) >> 3) |
                           ((GET_REX_PREFIX() & 0x04) << 1) |
                           (((~GET_VEX_PREFIX2()) & 0x80) >> 4));
  }
#line 98 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_MODRM_BASE(((*p) & 0x07) |
                   ((GET_REX_PREFIX() & 0x01) << 3) |
                   (((~GET_VEX_PREFIX2()) & 0x20) >> 2));
    SET_MODRM_INDEX(NO_REG);
    SET_MODRM_SCALE(0);
  }
	goto st7;
tr394:
#line 25 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_DATA16_PREFIX(FALSE);
  }
#line 98 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_MODRM_BASE(((*p) & 0x07) |
                   ((GET_REX_PREFIX() & 0x01) << 3) |
                   (((~GET_VEX_PREFIX2()) & 0x20) >> 2));
    SET_MODRM_INDEX(NO_REG);
    SET_MODRM_SCALE(0);
  }
	goto st7;
tr590:
#line 295 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(0, OperandSize32bit);
  }
#line 397 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_NAME(0, ((~GET_VEX_PREFIX3()) & 0x78) >> 3);
  }
#line 98 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_MODRM_BASE(((*p) & 0x07) |
                   ((GET_REX_PREFIX() & 0x01) << 3) |
                   (((~GET_VEX_PREFIX2()) & 0x20) >> 2));
    SET_MODRM_INDEX(NO_REG);
    SET_MODRM_SCALE(0);
  }
	goto st7;
tr596:
#line 298 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(0, OperandSize64bit);
  }
#line 397 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_NAME(0, ((~GET_VEX_PREFIX3()) & 0x78) >> 3);
  }
#line 98 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_MODRM_BASE(((*p) & 0x07) |
                   ((GET_REX_PREFIX() & 0x01) << 3) |
                   (((~GET_VEX_PREFIX2()) & 0x20) >> 2));
    SET_MODRM_INDEX(NO_REG);
    SET_MODRM_SCALE(0);
  }
	goto st7;
st7:
	if ( ++p == pe )
		goto _test_eof7;
case 7:
#line 5588 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	goto tr14;
tr21:
#line 389 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_NAME(0, (((*p) & 0x38) >> 3) |
                           ((GET_REX_PREFIX() & 0x04) << 1) |
                           (((~GET_VEX_PREFIX2()) & 0x80) >> 4));
  }
	goto st8;
tr197:
#line 536 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_NAME(1, (((*p) & 0x38) >> 3) |
                           ((GET_REX_PREFIX() & 0x04) << 1) |
                           (((~GET_VEX_PREFIX2()) & 0x80) >> 4));
  }
	goto st8;
tr395:
#line 25 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_DATA16_PREFIX(FALSE);
  }
	goto st8;
tr543:
#line 295 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(0, OperandSize32bit);
  }
#line 397 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_NAME(0, ((~GET_VEX_PREFIX3()) & 0x78) >> 3);
  }
	goto st8;
tr549:
#line 298 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(0, OperandSize64bit);
  }
#line 397 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_NAME(0, ((~GET_VEX_PREFIX3()) & 0x78) >> 3);
  }
	goto st8;
st8:
	if ( ++p == pe )
		goto _test_eof8;
case 8:
#line 5636 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	goto tr15;
tr23:
#line 389 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_NAME(0, (((*p) & 0x38) >> 3) |
                           ((GET_REX_PREFIX() & 0x04) << 1) |
                           (((~GET_VEX_PREFIX2()) & 0x80) >> 4));
  }
	goto st9;
tr199:
#line 536 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_NAME(1, (((*p) & 0x38) >> 3) |
                           ((GET_REX_PREFIX() & 0x04) << 1) |
                           (((~GET_VEX_PREFIX2()) & 0x80) >> 4));
  }
	goto st9;
tr397:
#line 25 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_DATA16_PREFIX(FALSE);
  }
	goto st9;
tr544:
#line 295 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(0, OperandSize32bit);
  }
#line 397 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_NAME(0, ((~GET_VEX_PREFIX3()) & 0x78) >> 3);
  }
	goto st9;
tr550:
#line 298 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(0, OperandSize64bit);
  }
#line 397 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_NAME(0, ((~GET_VEX_PREFIX3()) & 0x78) >> 3);
  }
	goto st9;
st9:
	if ( ++p == pe )
		goto _test_eof9;
case 9:
#line 5684 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	goto tr16;
tr32:
#line 295 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(0, OperandSize32bit);
  }
	goto st10;
tr120:
#line 289 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(0, OperandSize8bit);
  }
	goto st10;
tr221:
#line 298 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(0, OperandSize64bit);
  }
	goto st10;
tr294:
#line 292 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(0, OperandSize16bit);
  }
	goto st10;
tr429:
#line 36 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_REPNZ_PREFIX(FALSE);
  }
#line 295 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(0, OperandSize32bit);
  }
	goto st10;
tr432:
#line 39 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_REPZ_PREFIX(FALSE);
  }
#line 292 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(0, OperandSize16bit);
  }
	goto st10;
tr917:
#line 36 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_REPNZ_PREFIX(FALSE);
  }
#line 298 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(0, OperandSize64bit);
  }
	goto st10;
tr927:
#line 39 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_REPZ_PREFIX(FALSE);
  }
#line 295 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(0, OperandSize32bit);
  }
	goto st10;
tr931:
#line 39 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_REPZ_PREFIX(FALSE);
  }
#line 298 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(0, OperandSize64bit);
  }
	goto st10;
tr980:
#line 329 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
        begin = p;
        BitmapSetBit(valid_targets, p - data);
        SET_REX_PREFIX(FALSE);
        SET_VEX_PREFIX2(0xe0);
        SET_VEX_PREFIX3(0x00);
        operand_states = 0;
     }
#line 289 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(0, OperandSize8bit);
  }
	goto st10;
tr981:
#line 329 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
        begin = p;
        BitmapSetBit(valid_targets, p - data);
        SET_REX_PREFIX(FALSE);
        SET_VEX_PREFIX2(0xe0);
        SET_VEX_PREFIX3(0x00);
        operand_states = 0;
     }
#line 295 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(0, OperandSize32bit);
  }
	goto st10;
st10:
	if ( ++p == pe )
		goto _test_eof10;
case 10:
#line 5794 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 4u: goto tr18;
		case 5u: goto tr19;
		case 12u: goto tr18;
		case 13u: goto tr19;
		case 20u: goto tr18;
		case 21u: goto tr19;
		case 28u: goto tr18;
		case 29u: goto tr19;
		case 36u: goto tr18;
		case 37u: goto tr19;
		case 44u: goto tr18;
		case 45u: goto tr19;
		case 52u: goto tr18;
		case 53u: goto tr19;
		case 60u: goto tr18;
		case 61u: goto tr19;
		case 68u: goto tr21;
		case 76u: goto tr21;
		case 84u: goto tr21;
		case 92u: goto tr21;
		case 100u: goto tr21;
		case 108u: goto tr21;
		case 116u: goto tr21;
		case 124u: goto tr21;
		case 132u: goto tr23;
		case 140u: goto tr23;
		case 148u: goto tr23;
		case 156u: goto tr23;
		case 164u: goto tr23;
		case 172u: goto tr23;
		case 180u: goto tr23;
		case 188u: goto tr23;
	}
	if ( (*p) < 64u ) {
		if ( (*p) <= 63u )
			goto tr17;
	} else if ( (*p) > 127u ) {
		if ( 128u <= (*p) && (*p) <= 191u )
			goto tr22;
	} else
		goto tr20;
	goto tr24;
tr116:
#line 389 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_NAME(0, (((*p) & 0x38) >> 3) |
                           ((GET_REX_PREFIX() & 0x04) << 1) |
                           (((~GET_VEX_PREFIX2()) & 0x80) >> 4));
  }
	goto st11;
tr93:
#line 90 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_DISP_TYPE(DISPNONE);
    SET_MODRM_BASE(((*p) & 0x07) |
                   ((GET_REX_PREFIX() & 0x01) << 3) |
                   (((~GET_VEX_PREFIX2()) & 0x20) >> 2));
    SET_MODRM_INDEX(NO_REG);
    SET_MODRM_SCALE(0);
  }
#line 44 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    if ((base == REG_RIP) || (base == REG_R15) ||
        ((base == REG_RSP) && (restricted_register != REG_RSP)) ||
        ((base == REG_RBP) && (restricted_register != REG_RBP))) {
      if ((index == restricted_register) ||
          ((index == REG_RDI) &&
           (restricted_register == kSandboxedRsiRestrictedRdi))) {
        BitmapClearBit(valid_targets, begin - data);
      } else if ((index != NO_REG) && (index != REG_RIZ)) {
        PrintError("Improper sandboxing in instruction\n", begin - data);
        result = 1;
        goto error_detected;
      }
    } else if ((index == REG_RIP) || (index == REG_R15) ||
               ((index == REG_RSP) && (restricted_register != REG_RSP)) ||
               ((index == REG_RBP) && (restricted_register != REG_RBP))) {
      if ((base == restricted_register) ||
          ((base == REG_RDI) &&
           (restricted_register == kSandboxedRsiRestrictedRdi))) {
        BitmapClearBit(valid_targets, begin - data);
      } else if ((base != NO_REG) && (base != REG_RIZ)) {
        PrintError("Improper sandboxing in instruction\n", begin - data);
        result = 1;
        goto error_detected;
      }
    } else {
      PrintError("Improper sandboxing in instruction\n", begin - data);
      result = 1;
      goto error_detected;
    }
  }
	goto st11;
tr101:
#line 118 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_DISP_TYPE(DISPNONE);
    SET_MODRM_BASE(((*p) & 0x7) |
                   ((GET_REX_PREFIX() & 0x01) << 3) |
                   (((~GET_VEX_PREFIX2()) & 0x20) >> 2));
    SET_MODRM_INDEX(index_registers[(((*p) & 0x38) >> 3) |
                                    ((GET_REX_PREFIX() & 0x02) << 2) |
                                    (((~GET_VEX_PREFIX2()) & 0x40) >> 3)]);
    SET_MODRM_SCALE(((*p) & 0xc0) >> 6);
  }
#line 44 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    if ((base == REG_RIP) || (base == REG_R15) ||
        ((base == REG_RSP) && (restricted_register != REG_RSP)) ||
        ((base == REG_RBP) && (restricted_register != REG_RBP))) {
      if ((index == restricted_register) ||
          ((index == REG_RDI) &&
           (restricted_register == kSandboxedRsiRestrictedRdi))) {
        BitmapClearBit(valid_targets, begin - data);
      } else if ((index != NO_REG) && (index != REG_RIZ)) {
        PrintError("Improper sandboxing in instruction\n", begin - data);
        result = 1;
        goto error_detected;
      }
    } else if ((index == REG_RIP) || (index == REG_R15) ||
               ((index == REG_RSP) && (restricted_register != REG_RSP)) ||
               ((index == REG_RBP) && (restricted_register != REG_RBP))) {
      if ((base == restricted_register) ||
          ((base == REG_RDI) &&
           (restricted_register == kSandboxedRsiRestrictedRdi))) {
        BitmapClearBit(valid_targets, begin - data);
      } else if ((base != NO_REG) && (base != REG_RIZ)) {
        PrintError("Improper sandboxing in instruction\n", begin - data);
        result = 1;
        goto error_detected;
      }
    } else {
      PrintError("Improper sandboxing in instruction\n", begin - data);
      result = 1;
      goto error_detected;
    }
  }
	goto st11;
tr106:
#line 46 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_DISP_TYPE(DISP32);
    SET_DISP_PTR(p - 3);
  }
#line 44 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    if ((base == REG_RIP) || (base == REG_R15) ||
        ((base == REG_RSP) && (restricted_register != REG_RSP)) ||
        ((base == REG_RBP) && (restricted_register != REG_RBP))) {
      if ((index == restricted_register) ||
          ((index == REG_RDI) &&
           (restricted_register == kSandboxedRsiRestrictedRdi))) {
        BitmapClearBit(valid_targets, begin - data);
      } else if ((index != NO_REG) && (index != REG_RIZ)) {
        PrintError("Improper sandboxing in instruction\n", begin - data);
        result = 1;
        goto error_detected;
      }
    } else if ((index == REG_RIP) || (index == REG_R15) ||
               ((index == REG_RSP) && (restricted_register != REG_RSP)) ||
               ((index == REG_RBP) && (restricted_register != REG_RBP))) {
      if ((base == restricted_register) ||
          ((base == REG_RDI) &&
           (restricted_register == kSandboxedRsiRestrictedRdi))) {
        BitmapClearBit(valid_targets, begin - data);
      } else if ((base != NO_REG) && (base != REG_RIZ)) {
        PrintError("Improper sandboxing in instruction\n", begin - data);
        result = 1;
        goto error_detected;
      }
    } else {
      PrintError("Improper sandboxing in instruction\n", begin - data);
      result = 1;
      goto error_detected;
    }
  }
	goto st11;
tr107:
#line 42 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_DISP_TYPE(DISP8);
    SET_DISP_PTR(p);
  }
#line 44 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    if ((base == REG_RIP) || (base == REG_R15) ||
        ((base == REG_RSP) && (restricted_register != REG_RSP)) ||
        ((base == REG_RBP) && (restricted_register != REG_RBP))) {
      if ((index == restricted_register) ||
          ((index == REG_RDI) &&
           (restricted_register == kSandboxedRsiRestrictedRdi))) {
        BitmapClearBit(valid_targets, begin - data);
      } else if ((index != NO_REG) && (index != REG_RIZ)) {
        PrintError("Improper sandboxing in instruction\n", begin - data);
        result = 1;
        goto error_detected;
      }
    } else if ((index == REG_RIP) || (index == REG_R15) ||
               ((index == REG_RSP) && (restricted_register != REG_RSP)) ||
               ((index == REG_RBP) && (restricted_register != REG_RBP))) {
      if ((base == restricted_register) ||
          ((base == REG_RDI) &&
           (restricted_register == kSandboxedRsiRestrictedRdi))) {
        BitmapClearBit(valid_targets, begin - data);
      } else if ((base != NO_REG) && (base != REG_RIZ)) {
        PrintError("Improper sandboxing in instruction\n", begin - data);
        result = 1;
        goto error_detected;
      }
    } else {
      PrintError("Improper sandboxing in instruction\n", begin - data);
      result = 1;
      goto error_detected;
    }
  }
	goto st11;
tr114:
#line 384 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_NAME(0, ((*p) & 0x07) |
                           ((GET_REX_PREFIX() & 0x01) << 3) |
                           (((~GET_VEX_PREFIX2()) & 0x20) >> 2));
  }
	goto st11;
tr115:
#line 295 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(0, OperandSize32bit);
  }
#line 384 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_NAME(0, ((*p) & 0x07) |
                           ((GET_REX_PREFIX() & 0x01) << 3) |
                           (((~GET_VEX_PREFIX2()) & 0x20) >> 2));
  }
	goto st11;
tr135:
#line 376 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_NAME(0, ((*p) & 0x7) |
                            ((GET_REX_PREFIX() & 0x01) << 3) |
                            (((~GET_VEX_PREFIX2()) & 0x20) >> 2));
  }
#line 289 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(0, OperandSize8bit);
  }
	goto st11;
tr177:
#line 389 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_NAME(0, (((*p) & 0x38) >> 3) |
                           ((GET_REX_PREFIX() & 0x04) << 1) |
                           (((~GET_VEX_PREFIX2()) & 0x80) >> 4));
  }
#line 90 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_DISP_TYPE(DISPNONE);
    SET_MODRM_BASE(((*p) & 0x07) |
                   ((GET_REX_PREFIX() & 0x01) << 3) |
                   (((~GET_VEX_PREFIX2()) & 0x20) >> 2));
    SET_MODRM_INDEX(NO_REG);
    SET_MODRM_SCALE(0);
  }
#line 44 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    if ((base == REG_RIP) || (base == REG_R15) ||
        ((base == REG_RSP) && (restricted_register != REG_RSP)) ||
        ((base == REG_RBP) && (restricted_register != REG_RBP))) {
      if ((index == restricted_register) ||
          ((index == REG_RDI) &&
           (restricted_register == kSandboxedRsiRestrictedRdi))) {
        BitmapClearBit(valid_targets, begin - data);
      } else if ((index != NO_REG) && (index != REG_RIZ)) {
        PrintError("Improper sandboxing in instruction\n", begin - data);
        result = 1;
        goto error_detected;
      }
    } else if ((index == REG_RIP) || (index == REG_R15) ||
               ((index == REG_RSP) && (restricted_register != REG_RSP)) ||
               ((index == REG_RBP) && (restricted_register != REG_RBP))) {
      if ((base == restricted_register) ||
          ((base == REG_RDI) &&
           (restricted_register == kSandboxedRsiRestrictedRdi))) {
        BitmapClearBit(valid_targets, begin - data);
      } else if ((base != NO_REG) && (base != REG_RIZ)) {
        PrintError("Improper sandboxing in instruction\n", begin - data);
        result = 1;
        goto error_detected;
      }
    } else {
      PrintError("Improper sandboxing in instruction\n", begin - data);
      result = 1;
      goto error_detected;
    }
  }
	goto st11;
tr184:
#line 289 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(0, OperandSize8bit);
  }
#line 384 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_NAME(0, ((*p) & 0x07) |
                           ((GET_REX_PREFIX() & 0x01) << 3) |
                           (((~GET_VEX_PREFIX2()) & 0x20) >> 2));
  }
	goto st11;
tr247:
#line 298 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(0, OperandSize64bit);
  }
#line 384 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_NAME(0, ((*p) & 0x07) |
                           ((GET_REX_PREFIX() & 0x01) << 3) |
                           (((~GET_VEX_PREFIX2()) & 0x20) >> 2));
  }
	goto st11;
tr348:
#line 25 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_DATA16_PREFIX(FALSE);
  }
	goto st11;
tr340:
#line 25 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_DATA16_PREFIX(FALSE);
  }
#line 90 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_DISP_TYPE(DISPNONE);
    SET_MODRM_BASE(((*p) & 0x07) |
                   ((GET_REX_PREFIX() & 0x01) << 3) |
                   (((~GET_VEX_PREFIX2()) & 0x20) >> 2));
    SET_MODRM_INDEX(NO_REG);
    SET_MODRM_SCALE(0);
  }
#line 44 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    if ((base == REG_RIP) || (base == REG_R15) ||
        ((base == REG_RSP) && (restricted_register != REG_RSP)) ||
        ((base == REG_RBP) && (restricted_register != REG_RBP))) {
      if ((index == restricted_register) ||
          ((index == REG_RDI) &&
           (restricted_register == kSandboxedRsiRestrictedRdi))) {
        BitmapClearBit(valid_targets, begin - data);
      } else if ((index != NO_REG) && (index != REG_RIZ)) {
        PrintError("Improper sandboxing in instruction\n", begin - data);
        result = 1;
        goto error_detected;
      }
    } else if ((index == REG_RIP) || (index == REG_R15) ||
               ((index == REG_RSP) && (restricted_register != REG_RSP)) ||
               ((index == REG_RBP) && (restricted_register != REG_RBP))) {
      if ((base == restricted_register) ||
          ((base == REG_RDI) &&
           (restricted_register == kSandboxedRsiRestrictedRdi))) {
        BitmapClearBit(valid_targets, begin - data);
      } else if ((base != NO_REG) && (base != REG_RIZ)) {
        PrintError("Improper sandboxing in instruction\n", begin - data);
        result = 1;
        goto error_detected;
      }
    } else {
      PrintError("Improper sandboxing in instruction\n", begin - data);
      result = 1;
      goto error_detected;
    }
  }
	goto st11;
tr347:
#line 25 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_DATA16_PREFIX(FALSE);
  }
#line 295 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(0, OperandSize32bit);
  }
#line 384 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_NAME(0, ((*p) & 0x07) |
                           ((GET_REX_PREFIX() & 0x01) << 3) |
                           (((~GET_VEX_PREFIX2()) & 0x20) >> 2));
  }
	goto st11;
tr349:
#line 292 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(0, OperandSize16bit);
  }
#line 384 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_NAME(0, ((*p) & 0x07) |
                           ((GET_REX_PREFIX() & 0x01) << 3) |
                           (((~GET_VEX_PREFIX2()) & 0x20) >> 2));
  }
	goto st11;
tr405:
#line 25 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_DATA16_PREFIX(FALSE);
  }
#line 298 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(0, OperandSize64bit);
  }
#line 384 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_NAME(0, ((*p) & 0x07) |
                           ((GET_REX_PREFIX() & 0x01) << 3) |
                           (((~GET_VEX_PREFIX2()) & 0x20) >> 2));
  }
	goto st11;
tr887:
#line 70 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_IMM2_TYPE(IMM16);
    SET_IMM2_PTR(p - 1);
  }
	goto st11;
tr915:
#line 62 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_IMM2_TYPE(IMM8);
    SET_IMM2_PTR(p);
  }
	goto st11;
tr982:
#line 329 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
        begin = p;
        BitmapSetBit(valid_targets, p - data);
        SET_REX_PREFIX(FALSE);
        SET_VEX_PREFIX2(0xe0);
        SET_VEX_PREFIX3(0x00);
        operand_states = 0;
     }
#line 289 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(0, OperandSize8bit);
  }
#line 418 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_NAME(0, REG_RAX);
  }
	goto st11;
tr987:
#line 329 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
        begin = p;
        BitmapSetBit(valid_targets, p - data);
        SET_REX_PREFIX(FALSE);
        SET_VEX_PREFIX2(0xe0);
        SET_VEX_PREFIX3(0x00);
        operand_states = 0;
     }
	goto st11;
tr1015:
#line 329 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
        begin = p;
        BitmapSetBit(valid_targets, p - data);
        SET_REX_PREFIX(FALSE);
        SET_VEX_PREFIX2(0xe0);
        SET_VEX_PREFIX3(0x00);
        operand_states = 0;
     }
#line 376 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_NAME(0, ((*p) & 0x7) |
                            ((GET_REX_PREFIX() & 0x01) << 3) |
                            (((~GET_VEX_PREFIX2()) & 0x20) >> 2));
  }
#line 289 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(0, OperandSize8bit);
  }
	goto st11;
st11:
	if ( ++p == pe )
		goto _test_eof11;
case 11:
#line 6283 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	goto tr25;
tr167:
#line 389 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_NAME(0, (((*p) & 0x38) >> 3) |
                           ((GET_REX_PREFIX() & 0x04) << 1) |
                           (((~GET_VEX_PREFIX2()) & 0x80) >> 4));
  }
	goto st12;
tr185:
#line 90 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_DISP_TYPE(DISPNONE);
    SET_MODRM_BASE(((*p) & 0x07) |
                   ((GET_REX_PREFIX() & 0x01) << 3) |
                   (((~GET_VEX_PREFIX2()) & 0x20) >> 2));
    SET_MODRM_INDEX(NO_REG);
    SET_MODRM_SCALE(0);
  }
#line 44 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    if ((base == REG_RIP) || (base == REG_R15) ||
        ((base == REG_RSP) && (restricted_register != REG_RSP)) ||
        ((base == REG_RBP) && (restricted_register != REG_RBP))) {
      if ((index == restricted_register) ||
          ((index == REG_RDI) &&
           (restricted_register == kSandboxedRsiRestrictedRdi))) {
        BitmapClearBit(valid_targets, begin - data);
      } else if ((index != NO_REG) && (index != REG_RIZ)) {
        PrintError("Improper sandboxing in instruction\n", begin - data);
        result = 1;
        goto error_detected;
      }
    } else if ((index == REG_RIP) || (index == REG_R15) ||
               ((index == REG_RSP) && (restricted_register != REG_RSP)) ||
               ((index == REG_RBP) && (restricted_register != REG_RBP))) {
      if ((base == restricted_register) ||
          ((base == REG_RDI) &&
           (restricted_register == kSandboxedRsiRestrictedRdi))) {
        BitmapClearBit(valid_targets, begin - data);
      } else if ((base != NO_REG) && (base != REG_RIZ)) {
        PrintError("Improper sandboxing in instruction\n", begin - data);
        result = 1;
        goto error_detected;
      }
    } else {
      PrintError("Improper sandboxing in instruction\n", begin - data);
      result = 1;
      goto error_detected;
    }
  }
	goto st12;
tr168:
#line 118 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_DISP_TYPE(DISPNONE);
    SET_MODRM_BASE(((*p) & 0x7) |
                   ((GET_REX_PREFIX() & 0x01) << 3) |
                   (((~GET_VEX_PREFIX2()) & 0x20) >> 2));
    SET_MODRM_INDEX(index_registers[(((*p) & 0x38) >> 3) |
                                    ((GET_REX_PREFIX() & 0x02) << 2) |
                                    (((~GET_VEX_PREFIX2()) & 0x40) >> 3)]);
    SET_MODRM_SCALE(((*p) & 0xc0) >> 6);
  }
#line 44 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    if ((base == REG_RIP) || (base == REG_R15) ||
        ((base == REG_RSP) && (restricted_register != REG_RSP)) ||
        ((base == REG_RBP) && (restricted_register != REG_RBP))) {
      if ((index == restricted_register) ||
          ((index == REG_RDI) &&
           (restricted_register == kSandboxedRsiRestrictedRdi))) {
        BitmapClearBit(valid_targets, begin - data);
      } else if ((index != NO_REG) && (index != REG_RIZ)) {
        PrintError("Improper sandboxing in instruction\n", begin - data);
        result = 1;
        goto error_detected;
      }
    } else if ((index == REG_RIP) || (index == REG_R15) ||
               ((index == REG_RSP) && (restricted_register != REG_RSP)) ||
               ((index == REG_RBP) && (restricted_register != REG_RBP))) {
      if ((base == restricted_register) ||
          ((base == REG_RDI) &&
           (restricted_register == kSandboxedRsiRestrictedRdi))) {
        BitmapClearBit(valid_targets, begin - data);
      } else if ((base != NO_REG) && (base != REG_RIZ)) {
        PrintError("Improper sandboxing in instruction\n", begin - data);
        result = 1;
        goto error_detected;
      }
    } else {
      PrintError("Improper sandboxing in instruction\n", begin - data);
      result = 1;
      goto error_detected;
    }
  }
	goto st12;
tr173:
#line 46 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_DISP_TYPE(DISP32);
    SET_DISP_PTR(p - 3);
  }
#line 44 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    if ((base == REG_RIP) || (base == REG_R15) ||
        ((base == REG_RSP) && (restricted_register != REG_RSP)) ||
        ((base == REG_RBP) && (restricted_register != REG_RBP))) {
      if ((index == restricted_register) ||
          ((index == REG_RDI) &&
           (restricted_register == kSandboxedRsiRestrictedRdi))) {
        BitmapClearBit(valid_targets, begin - data);
      } else if ((index != NO_REG) && (index != REG_RIZ)) {
        PrintError("Improper sandboxing in instruction\n", begin - data);
        result = 1;
        goto error_detected;
      }
    } else if ((index == REG_RIP) || (index == REG_R15) ||
               ((index == REG_RSP) && (restricted_register != REG_RSP)) ||
               ((index == REG_RBP) && (restricted_register != REG_RBP))) {
      if ((base == restricted_register) ||
          ((base == REG_RDI) &&
           (restricted_register == kSandboxedRsiRestrictedRdi))) {
        BitmapClearBit(valid_targets, begin - data);
      } else if ((base != NO_REG) && (base != REG_RIZ)) {
        PrintError("Improper sandboxing in instruction\n", begin - data);
        result = 1;
        goto error_detected;
      }
    } else {
      PrintError("Improper sandboxing in instruction\n", begin - data);
      result = 1;
      goto error_detected;
    }
  }
	goto st12;
tr174:
#line 42 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_DISP_TYPE(DISP8);
    SET_DISP_PTR(p);
  }
#line 44 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    if ((base == REG_RIP) || (base == REG_R15) ||
        ((base == REG_RSP) && (restricted_register != REG_RSP)) ||
        ((base == REG_RBP) && (restricted_register != REG_RBP))) {
      if ((index == restricted_register) ||
          ((index == REG_RDI) &&
           (restricted_register == kSandboxedRsiRestrictedRdi))) {
        BitmapClearBit(valid_targets, begin - data);
      } else if ((index != NO_REG) && (index != REG_RIZ)) {
        PrintError("Improper sandboxing in instruction\n", begin - data);
        result = 1;
        goto error_detected;
      }
    } else if ((index == REG_RIP) || (index == REG_R15) ||
               ((index == REG_RSP) && (restricted_register != REG_RSP)) ||
               ((index == REG_RBP) && (restricted_register != REG_RBP))) {
      if ((base == restricted_register) ||
          ((base == REG_RDI) &&
           (restricted_register == kSandboxedRsiRestrictedRdi))) {
        BitmapClearBit(valid_targets, begin - data);
      } else if ((base != NO_REG) && (base != REG_RIZ)) {
        PrintError("Improper sandboxing in instruction\n", begin - data);
        result = 1;
        goto error_detected;
      }
    } else {
      PrintError("Improper sandboxing in instruction\n", begin - data);
      result = 1;
      goto error_detected;
    }
  }
	goto st12;
tr191:
#line 295 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(0, OperandSize32bit);
  }
#line 384 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_NAME(0, ((*p) & 0x07) |
                           ((GET_REX_PREFIX() & 0x01) << 3) |
                           (((~GET_VEX_PREFIX2()) & 0x20) >> 2));
  }
	goto st12;
tr136:
#line 376 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_NAME(0, ((*p) & 0x7) |
                            ((GET_REX_PREFIX() & 0x01) << 3) |
                            (((~GET_VEX_PREFIX2()) & 0x20) >> 2));
  }
#line 295 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(0, OperandSize32bit);
  }
	goto st12;
tr160:
#line 389 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_NAME(0, (((*p) & 0x38) >> 3) |
                           ((GET_REX_PREFIX() & 0x04) << 1) |
                           (((~GET_VEX_PREFIX2()) & 0x80) >> 4));
  }
#line 90 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_DISP_TYPE(DISPNONE);
    SET_MODRM_BASE(((*p) & 0x07) |
                   ((GET_REX_PREFIX() & 0x01) << 3) |
                   (((~GET_VEX_PREFIX2()) & 0x20) >> 2));
    SET_MODRM_INDEX(NO_REG);
    SET_MODRM_SCALE(0);
  }
#line 44 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    if ((base == REG_RIP) || (base == REG_R15) ||
        ((base == REG_RSP) && (restricted_register != REG_RSP)) ||
        ((base == REG_RBP) && (restricted_register != REG_RBP))) {
      if ((index == restricted_register) ||
          ((index == REG_RDI) &&
           (restricted_register == kSandboxedRsiRestrictedRdi))) {
        BitmapClearBit(valid_targets, begin - data);
      } else if ((index != NO_REG) && (index != REG_RIZ)) {
        PrintError("Improper sandboxing in instruction\n", begin - data);
        result = 1;
        goto error_detected;
      }
    } else if ((index == REG_RIP) || (index == REG_R15) ||
               ((index == REG_RSP) && (restricted_register != REG_RSP)) ||
               ((index == REG_RBP) && (restricted_register != REG_RBP))) {
      if ((base == restricted_register) ||
          ((base == REG_RDI) &&
           (restricted_register == kSandboxedRsiRestrictedRdi))) {
        BitmapClearBit(valid_targets, begin - data);
      } else if ((base != NO_REG) && (base != REG_RIZ)) {
        PrintError("Improper sandboxing in instruction\n", begin - data);
        result = 1;
        goto error_detected;
      }
    } else {
      PrintError("Improper sandboxing in instruction\n", begin - data);
      result = 1;
      goto error_detected;
    }
  }
	goto st12;
tr222:
#line 298 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(0, OperandSize64bit);
  }
#line 418 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_NAME(0, REG_RAX);
  }
	goto st12;
tr249:
#line 298 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(0, OperandSize64bit);
  }
#line 384 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_NAME(0, ((*p) & 0x07) |
                           ((GET_REX_PREFIX() & 0x01) << 3) |
                           (((~GET_VEX_PREFIX2()) & 0x20) >> 2));
  }
	goto st12;
tr560:
#line 295 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(0, OperandSize32bit);
  }
#line 397 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_NAME(0, ((~GET_VEX_PREFIX3()) & 0x78) >> 3);
  }
	goto st12;
tr565:
#line 298 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(0, OperandSize64bit);
  }
#line 397 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_NAME(0, ((~GET_VEX_PREFIX3()) & 0x78) >> 3);
  }
	goto st12;
tr604:
#line 295 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(0, OperandSize32bit);
  }
#line 397 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_NAME(0, ((~GET_VEX_PREFIX3()) & 0x78) >> 3);
  }
#line 90 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_DISP_TYPE(DISPNONE);
    SET_MODRM_BASE(((*p) & 0x07) |
                   ((GET_REX_PREFIX() & 0x01) << 3) |
                   (((~GET_VEX_PREFIX2()) & 0x20) >> 2));
    SET_MODRM_INDEX(NO_REG);
    SET_MODRM_SCALE(0);
  }
#line 44 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    if ((base == REG_RIP) || (base == REG_R15) ||
        ((base == REG_RSP) && (restricted_register != REG_RSP)) ||
        ((base == REG_RBP) && (restricted_register != REG_RBP))) {
      if ((index == restricted_register) ||
          ((index == REG_RDI) &&
           (restricted_register == kSandboxedRsiRestrictedRdi))) {
        BitmapClearBit(valid_targets, begin - data);
      } else if ((index != NO_REG) && (index != REG_RIZ)) {
        PrintError("Improper sandboxing in instruction\n", begin - data);
        result = 1;
        goto error_detected;
      }
    } else if ((index == REG_RIP) || (index == REG_R15) ||
               ((index == REG_RSP) && (restricted_register != REG_RSP)) ||
               ((index == REG_RBP) && (restricted_register != REG_RBP))) {
      if ((base == restricted_register) ||
          ((base == REG_RDI) &&
           (restricted_register == kSandboxedRsiRestrictedRdi))) {
        BitmapClearBit(valid_targets, begin - data);
      } else if ((base != NO_REG) && (base != REG_RIZ)) {
        PrintError("Improper sandboxing in instruction\n", begin - data);
        result = 1;
        goto error_detected;
      }
    } else {
      PrintError("Improper sandboxing in instruction\n", begin - data);
      result = 1;
      goto error_detected;
    }
  }
	goto st12;
tr608:
#line 298 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(0, OperandSize64bit);
  }
#line 397 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_NAME(0, ((~GET_VEX_PREFIX3()) & 0x78) >> 3);
  }
#line 90 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_DISP_TYPE(DISPNONE);
    SET_MODRM_BASE(((*p) & 0x07) |
                   ((GET_REX_PREFIX() & 0x01) << 3) |
                   (((~GET_VEX_PREFIX2()) & 0x20) >> 2));
    SET_MODRM_INDEX(NO_REG);
    SET_MODRM_SCALE(0);
  }
#line 44 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    if ((base == REG_RIP) || (base == REG_R15) ||
        ((base == REG_RSP) && (restricted_register != REG_RSP)) ||
        ((base == REG_RBP) && (restricted_register != REG_RBP))) {
      if ((index == restricted_register) ||
          ((index == REG_RDI) &&
           (restricted_register == kSandboxedRsiRestrictedRdi))) {
        BitmapClearBit(valid_targets, begin - data);
      } else if ((index != NO_REG) && (index != REG_RIZ)) {
        PrintError("Improper sandboxing in instruction\n", begin - data);
        result = 1;
        goto error_detected;
      }
    } else if ((index == REG_RIP) || (index == REG_R15) ||
               ((index == REG_RSP) && (restricted_register != REG_RSP)) ||
               ((index == REG_RBP) && (restricted_register != REG_RBP))) {
      if ((base == restricted_register) ||
          ((base == REG_RDI) &&
           (restricted_register == kSandboxedRsiRestrictedRdi))) {
        BitmapClearBit(valid_targets, begin - data);
      } else if ((base != NO_REG) && (base != REG_RIZ)) {
        PrintError("Improper sandboxing in instruction\n", begin - data);
        result = 1;
        goto error_detected;
      }
    } else {
      PrintError("Improper sandboxing in instruction\n", begin - data);
      result = 1;
      goto error_detected;
    }
  }
	goto st12;
tr983:
#line 329 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
        begin = p;
        BitmapSetBit(valid_targets, p - data);
        SET_REX_PREFIX(FALSE);
        SET_VEX_PREFIX2(0xe0);
        SET_VEX_PREFIX3(0x00);
        operand_states = 0;
     }
#line 295 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(0, OperandSize32bit);
  }
#line 418 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_NAME(0, REG_RAX);
  }
	goto st12;
tr988:
#line 329 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
        begin = p;
        BitmapSetBit(valid_targets, p - data);
        SET_REX_PREFIX(FALSE);
        SET_VEX_PREFIX2(0xe0);
        SET_VEX_PREFIX3(0x00);
        operand_states = 0;
     }
	goto st12;
tr1016:
#line 329 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
        begin = p;
        BitmapSetBit(valid_targets, p - data);
        SET_REX_PREFIX(FALSE);
        SET_VEX_PREFIX2(0xe0);
        SET_VEX_PREFIX3(0x00);
        operand_states = 0;
     }
#line 376 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_NAME(0, ((*p) & 0x7) |
                            ((GET_REX_PREFIX() & 0x01) << 3) |
                            (((~GET_VEX_PREFIX2()) & 0x20) >> 2));
  }
#line 295 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(0, OperandSize32bit);
  }
	goto st12;
st12:
	if ( ++p == pe )
		goto _test_eof12;
case 12:
#line 6731 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	goto st13;
st13:
	if ( ++p == pe )
		goto _test_eof13;
case 13:
	goto st14;
st14:
	if ( ++p == pe )
		goto _test_eof14;
case 14:
	goto st15;
st15:
	if ( ++p == pe )
		goto _test_eof15;
case 15:
	goto tr29;
tr33:
#line 343 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
        process_error(begin, userdata);
        result = 1;
        goto error_detected;
    }
	goto st0;
#line 6756 "src/trusted/validator_ragel/gen/validator-x86_64.c"
st0:
cs = 0;
	goto _out;
tr984:
#line 329 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
        begin = p;
        BitmapSetBit(valid_targets, p - data);
        SET_REX_PREFIX(FALSE);
        SET_VEX_PREFIX2(0xe0);
        SET_VEX_PREFIX3(0x00);
        operand_states = 0;
     }
	goto st16;
st16:
	if ( ++p == pe )
		goto _test_eof16;
case 16:
#line 6775 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 0u: goto st17;
		case 1u: goto st18;
		case 11u: goto tr34;
		case 13u: goto st19;
		case 14u: goto tr34;
		case 15u: goto st28;
		case 19u: goto st39;
		case 23u: goto st39;
		case 24u: goto st40;
		case 31u: goto st41;
		case 43u: goto st39;
		case 49u: goto tr34;
		case 80u: goto tr41;
		case 112u: goto st43;
		case 115u: goto st53;
		case 119u: goto tr34;
		case 126u: goto tr45;
		case 162u: goto tr34;
		case 164u: goto tr48;
		case 165u: goto tr45;
		case 172u: goto tr48;
		case 173u: goto tr45;
		case 174u: goto st59;
		case 175u: goto tr32;
		case 176u: goto tr47;
		case 177u: goto tr45;
		case 178u: goto tr50;
		case 186u: goto st61;
		case 192u: goto tr47;
		case 193u: goto tr45;
		case 195u: goto st39;
		case 197u: goto tr52;
		case 199u: goto st63;
		case 208u: goto tr33;
		case 214u: goto tr33;
		case 215u: goto tr41;
		case 240u: goto tr33;
		case 247u: goto st64;
		case 255u: goto tr33;
	}
	if ( (*p) < 128u ) {
		if ( (*p) < 48u ) {
			if ( (*p) < 4u ) {
				if ( 2u <= (*p) && (*p) <= 3u )
					goto tr32;
			} else if ( (*p) > 12u ) {
				if ( 25u <= (*p) && (*p) <= 39u )
					goto tr33;
			} else
				goto tr33;
		} else if ( (*p) > 63u ) {
			if ( (*p) < 108u ) {
				if ( 64u <= (*p) && (*p) <= 79u )
					goto tr32;
			} else if ( (*p) > 109u ) {
				if ( (*p) > 114u ) {
					if ( 120u <= (*p) && (*p) <= 125u )
						goto tr33;
				} else if ( (*p) >= 113u )
					goto st52;
			} else
				goto tr33;
		} else
			goto tr33;
	} else if ( (*p) > 143u ) {
		if ( (*p) < 184u ) {
			if ( (*p) < 160u ) {
				if ( 144u <= (*p) && (*p) <= 159u )
					goto tr47;
			} else if ( (*p) > 179u ) {
				if ( (*p) > 181u ) {
					if ( 182u <= (*p) && (*p) <= 183u )
						goto tr32;
				} else if ( (*p) >= 180u )
					goto tr50;
			} else
				goto tr33;
		} else if ( (*p) > 187u ) {
			if ( (*p) < 194u ) {
				if ( 188u <= (*p) && (*p) <= 191u )
					goto tr32;
			} else if ( (*p) > 198u ) {
				if ( (*p) > 207u ) {
					if ( 230u <= (*p) && (*p) <= 231u )
						goto tr33;
				} else if ( (*p) >= 200u )
					goto tr54;
			} else
				goto st43;
		} else
			goto tr33;
	} else
		goto st54;
	goto st38;
st17:
	if ( ++p == pe )
		goto _test_eof17;
case 17:
	switch( (*p) ) {
		case 12u: goto st2;
		case 13u: goto tr2;
		case 28u: goto st2;
		case 29u: goto tr2;
		case 36u: goto st2;
		case 37u: goto tr2;
		case 44u: goto st2;
		case 45u: goto tr2;
		case 76u: goto st8;
		case 92u: goto st8;
		case 100u: goto st8;
		case 108u: goto st8;
		case 140u: goto st9;
		case 156u: goto st9;
		case 164u: goto st9;
		case 172u: goto st9;
	}
	if ( (*p) < 88u ) {
		if ( (*p) < 24u ) {
			if ( 8u <= (*p) && (*p) <= 15u )
				goto tr0;
		} else if ( (*p) > 47u ) {
			if ( 72u <= (*p) && (*p) <= 79u )
				goto tr3;
		} else
			goto tr0;
	} else if ( (*p) > 111u ) {
		if ( (*p) < 152u ) {
			if ( 136u <= (*p) && (*p) <= 143u )
				goto tr5;
		} else if ( (*p) > 175u ) {
			if ( (*p) > 207u ) {
				if ( 216u <= (*p) && (*p) <= 239u )
					goto tr57;
			} else if ( (*p) >= 200u )
				goto tr56;
		} else
			goto tr5;
	} else
		goto tr3;
	goto tr33;
st18:
	if ( ++p == pe )
		goto _test_eof18;
case 18:
	switch( (*p) ) {
		case 36u: goto st2;
		case 37u: goto tr2;
		case 52u: goto st2;
		case 53u: goto tr2;
		case 60u: goto st2;
		case 61u: goto tr2;
		case 100u: goto st8;
		case 116u: goto st8;
		case 124u: goto st8;
		case 164u: goto st9;
		case 180u: goto st9;
		case 188u: goto st9;
		case 200u: goto tr58;
		case 201u: goto tr59;
	}
	if ( (*p) < 160u ) {
		if ( (*p) < 48u ) {
			if ( 32u <= (*p) && (*p) <= 39u )
				goto tr0;
		} else if ( (*p) > 63u ) {
			if ( (*p) > 103u ) {
				if ( 112u <= (*p) && (*p) <= 127u )
					goto tr3;
			} else if ( (*p) >= 96u )
				goto tr3;
		} else
			goto tr0;
	} else if ( (*p) > 167u ) {
		if ( (*p) < 208u ) {
			if ( 176u <= (*p) && (*p) <= 191u )
				goto tr5;
		} else if ( (*p) > 209u ) {
			if ( (*p) > 231u ) {
				if ( 240u <= (*p) && (*p) <= 247u )
					goto tr57;
			} else if ( (*p) >= 224u )
				goto tr56;
		} else
			goto tr34;
	} else
		goto tr5;
	goto tr33;
st19:
	if ( ++p == pe )
		goto _test_eof19;
case 19:
	switch( (*p) ) {
		case 4u: goto st20;
		case 5u: goto tr62;
		case 12u: goto st20;
		case 13u: goto tr62;
		case 68u: goto st26;
		case 76u: goto st26;
		case 132u: goto st27;
		case 140u: goto st27;
	}
	if ( (*p) < 64u ) {
		if ( (*p) <= 15u )
			goto tr60;
	} else if ( (*p) > 79u ) {
		if ( 128u <= (*p) && (*p) <= 143u )
			goto tr65;
	} else
		goto tr63;
	goto tr33;
tr202:
#line 389 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_NAME(0, (((*p) & 0x38) >> 3) |
                           ((GET_REX_PREFIX() & 0x04) << 1) |
                           (((~GET_VEX_PREFIX2()) & 0x80) >> 4));
  }
	goto st20;
st20:
	if ( ++p == pe )
		goto _test_eof20;
case 20:
#line 6999 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 5u: goto tr68;
		case 13u: goto tr68;
		case 21u: goto tr68;
		case 29u: goto tr68;
		case 37u: goto tr68;
		case 45u: goto tr68;
		case 53u: goto tr68;
		case 61u: goto tr68;
		case 69u: goto tr68;
		case 77u: goto tr68;
		case 85u: goto tr68;
		case 93u: goto tr68;
		case 101u: goto tr68;
		case 109u: goto tr68;
		case 117u: goto tr68;
		case 125u: goto tr68;
		case 133u: goto tr68;
		case 141u: goto tr68;
		case 149u: goto tr68;
		case 157u: goto tr68;
		case 165u: goto tr68;
		case 173u: goto tr68;
		case 181u: goto tr68;
		case 189u: goto tr68;
		case 197u: goto tr68;
		case 205u: goto tr68;
		case 213u: goto tr68;
		case 221u: goto tr68;
		case 229u: goto tr68;
		case 237u: goto tr68;
		case 245u: goto tr68;
		case 253u: goto tr68;
	}
	goto tr67;
tr62:
#line 105 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_MODRM_BASE(REG_RIP);
    SET_MODRM_INDEX(NO_REG);
    SET_MODRM_SCALE(0);
  }
	goto st21;
tr65:
#line 98 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_MODRM_BASE(((*p) & 0x07) |
                   ((GET_REX_PREFIX() & 0x01) << 3) |
                   (((~GET_VEX_PREFIX2()) & 0x20) >> 2));
    SET_MODRM_INDEX(NO_REG);
    SET_MODRM_SCALE(0);
  }
	goto st21;
tr68:
#line 110 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_DISP_TYPE(DISPNONE);
    SET_MODRM_BASE(NO_REG);
    SET_MODRM_INDEX(index_registers[(((*p) & 0x38) >> 3) |
                                    ((GET_REX_PREFIX() & 0x02) << 2) |
                                    (((~GET_VEX_PREFIX2()) & 0x40) >> 3)]);
    SET_MODRM_SCALE(((*p) & 0xc0) >> 6);
  }
	goto st21;
tr75:
#line 118 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_DISP_TYPE(DISPNONE);
    SET_MODRM_BASE(((*p) & 0x7) |
                   ((GET_REX_PREFIX() & 0x01) << 3) |
                   (((~GET_VEX_PREFIX2()) & 0x20) >> 2));
    SET_MODRM_INDEX(index_registers[(((*p) & 0x38) >> 3) |
                                    ((GET_REX_PREFIX() & 0x02) << 2) |
                                    (((~GET_VEX_PREFIX2()) & 0x40) >> 3)]);
    SET_MODRM_SCALE(((*p) & 0xc0) >> 6);
  }
	goto st21;
tr203:
#line 389 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_NAME(0, (((*p) & 0x38) >> 3) |
                           ((GET_REX_PREFIX() & 0x04) << 1) |
                           (((~GET_VEX_PREFIX2()) & 0x80) >> 4));
  }
#line 105 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_MODRM_BASE(REG_RIP);
    SET_MODRM_INDEX(NO_REG);
    SET_MODRM_SCALE(0);
  }
	goto st21;
tr206:
#line 389 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_NAME(0, (((*p) & 0x38) >> 3) |
                           ((GET_REX_PREFIX() & 0x04) << 1) |
                           (((~GET_VEX_PREFIX2()) & 0x80) >> 4));
  }
#line 98 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_MODRM_BASE(((*p) & 0x07) |
                   ((GET_REX_PREFIX() & 0x01) << 3) |
                   (((~GET_VEX_PREFIX2()) & 0x20) >> 2));
    SET_MODRM_INDEX(NO_REG);
    SET_MODRM_SCALE(0);
  }
	goto st21;
st21:
	if ( ++p == pe )
		goto _test_eof21;
case 21:
#line 7111 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	goto st22;
st22:
	if ( ++p == pe )
		goto _test_eof22;
case 22:
	goto st23;
st23:
	if ( ++p == pe )
		goto _test_eof23;
case 23:
	goto st24;
st24:
	if ( ++p == pe )
		goto _test_eof24;
case 24:
	goto tr72;
tr63:
#line 98 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_MODRM_BASE(((*p) & 0x07) |
                   ((GET_REX_PREFIX() & 0x01) << 3) |
                   (((~GET_VEX_PREFIX2()) & 0x20) >> 2));
    SET_MODRM_INDEX(NO_REG);
    SET_MODRM_SCALE(0);
  }
	goto st25;
tr74:
#line 118 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_DISP_TYPE(DISPNONE);
    SET_MODRM_BASE(((*p) & 0x7) |
                   ((GET_REX_PREFIX() & 0x01) << 3) |
                   (((~GET_VEX_PREFIX2()) & 0x20) >> 2));
    SET_MODRM_INDEX(index_registers[(((*p) & 0x38) >> 3) |
                                    ((GET_REX_PREFIX() & 0x02) << 2) |
                                    (((~GET_VEX_PREFIX2()) & 0x40) >> 3)]);
    SET_MODRM_SCALE(((*p) & 0xc0) >> 6);
  }
	goto st25;
tr204:
#line 389 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_NAME(0, (((*p) & 0x38) >> 3) |
                           ((GET_REX_PREFIX() & 0x04) << 1) |
                           (((~GET_VEX_PREFIX2()) & 0x80) >> 4));
  }
#line 98 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_MODRM_BASE(((*p) & 0x07) |
                   ((GET_REX_PREFIX() & 0x01) << 3) |
                   (((~GET_VEX_PREFIX2()) & 0x20) >> 2));
    SET_MODRM_INDEX(NO_REG);
    SET_MODRM_SCALE(0);
  }
	goto st25;
st25:
	if ( ++p == pe )
		goto _test_eof25;
case 25:
#line 7171 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	goto tr73;
tr205:
#line 389 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_NAME(0, (((*p) & 0x38) >> 3) |
                           ((GET_REX_PREFIX() & 0x04) << 1) |
                           (((~GET_VEX_PREFIX2()) & 0x80) >> 4));
  }
	goto st26;
st26:
	if ( ++p == pe )
		goto _test_eof26;
case 26:
#line 7185 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	goto tr74;
tr207:
#line 389 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_NAME(0, (((*p) & 0x38) >> 3) |
                           ((GET_REX_PREFIX() & 0x04) << 1) |
                           (((~GET_VEX_PREFIX2()) & 0x80) >> 4));
  }
	goto st27;
st27:
	if ( ++p == pe )
		goto _test_eof27;
case 27:
#line 7199 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	goto tr75;
st28:
	if ( ++p == pe )
		goto _test_eof28;
case 28:
	switch( (*p) ) {
		case 4u: goto st30;
		case 5u: goto tr78;
		case 12u: goto st30;
		case 13u: goto tr78;
		case 20u: goto st30;
		case 21u: goto tr78;
		case 28u: goto st30;
		case 29u: goto tr78;
		case 36u: goto st30;
		case 37u: goto tr78;
		case 44u: goto st30;
		case 45u: goto tr78;
		case 52u: goto st30;
		case 53u: goto tr78;
		case 60u: goto st30;
		case 61u: goto tr78;
		case 68u: goto st36;
		case 76u: goto st36;
		case 84u: goto st36;
		case 92u: goto st36;
		case 100u: goto st36;
		case 108u: goto st36;
		case 116u: goto st36;
		case 124u: goto st36;
		case 132u: goto st37;
		case 140u: goto st37;
		case 148u: goto st37;
		case 156u: goto st37;
		case 164u: goto st37;
		case 172u: goto st37;
		case 180u: goto st37;
		case 188u: goto st37;
	}
	if ( (*p) < 64u ) {
		if ( (*p) <= 63u )
			goto tr76;
	} else if ( (*p) > 127u ) {
		if ( 128u <= (*p) && (*p) <= 191u )
			goto tr81;
	} else
		goto tr79;
	goto st29;
tr76:
#line 90 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_DISP_TYPE(DISPNONE);
    SET_MODRM_BASE(((*p) & 0x07) |
                   ((GET_REX_PREFIX() & 0x01) << 3) |
                   (((~GET_VEX_PREFIX2()) & 0x20) >> 2));
    SET_MODRM_INDEX(NO_REG);
    SET_MODRM_SCALE(0);
  }
#line 44 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    if ((base == REG_RIP) || (base == REG_R15) ||
        ((base == REG_RSP) && (restricted_register != REG_RSP)) ||
        ((base == REG_RBP) && (restricted_register != REG_RBP))) {
      if ((index == restricted_register) ||
          ((index == REG_RDI) &&
           (restricted_register == kSandboxedRsiRestrictedRdi))) {
        BitmapClearBit(valid_targets, begin - data);
      } else if ((index != NO_REG) && (index != REG_RIZ)) {
        PrintError("Improper sandboxing in instruction\n", begin - data);
        result = 1;
        goto error_detected;
      }
    } else if ((index == REG_RIP) || (index == REG_R15) ||
               ((index == REG_RSP) && (restricted_register != REG_RSP)) ||
               ((index == REG_RBP) && (restricted_register != REG_RBP))) {
      if ((base == restricted_register) ||
          ((base == REG_RDI) &&
           (restricted_register == kSandboxedRsiRestrictedRdi))) {
        BitmapClearBit(valid_targets, begin - data);
      } else if ((base != NO_REG) && (base != REG_RIZ)) {
        PrintError("Improper sandboxing in instruction\n", begin - data);
        result = 1;
        goto error_detected;
      }
    } else {
      PrintError("Improper sandboxing in instruction\n", begin - data);
      result = 1;
      goto error_detected;
    }
  }
	goto st29;
tr84:
#line 118 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_DISP_TYPE(DISPNONE);
    SET_MODRM_BASE(((*p) & 0x7) |
                   ((GET_REX_PREFIX() & 0x01) << 3) |
                   (((~GET_VEX_PREFIX2()) & 0x20) >> 2));
    SET_MODRM_INDEX(index_registers[(((*p) & 0x38) >> 3) |
                                    ((GET_REX_PREFIX() & 0x02) << 2) |
                                    (((~GET_VEX_PREFIX2()) & 0x40) >> 3)]);
    SET_MODRM_SCALE(((*p) & 0xc0) >> 6);
  }
#line 44 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    if ((base == REG_RIP) || (base == REG_R15) ||
        ((base == REG_RSP) && (restricted_register != REG_RSP)) ||
        ((base == REG_RBP) && (restricted_register != REG_RBP))) {
      if ((index == restricted_register) ||
          ((index == REG_RDI) &&
           (restricted_register == kSandboxedRsiRestrictedRdi))) {
        BitmapClearBit(valid_targets, begin - data);
      } else if ((index != NO_REG) && (index != REG_RIZ)) {
        PrintError("Improper sandboxing in instruction\n", begin - data);
        result = 1;
        goto error_detected;
      }
    } else if ((index == REG_RIP) || (index == REG_R15) ||
               ((index == REG_RSP) && (restricted_register != REG_RSP)) ||
               ((index == REG_RBP) && (restricted_register != REG_RBP))) {
      if ((base == restricted_register) ||
          ((base == REG_RDI) &&
           (restricted_register == kSandboxedRsiRestrictedRdi))) {
        BitmapClearBit(valid_targets, begin - data);
      } else if ((base != NO_REG) && (base != REG_RIZ)) {
        PrintError("Improper sandboxing in instruction\n", begin - data);
        result = 1;
        goto error_detected;
      }
    } else {
      PrintError("Improper sandboxing in instruction\n", begin - data);
      result = 1;
      goto error_detected;
    }
  }
	goto st29;
tr89:
#line 46 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_DISP_TYPE(DISP32);
    SET_DISP_PTR(p - 3);
  }
#line 44 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    if ((base == REG_RIP) || (base == REG_R15) ||
        ((base == REG_RSP) && (restricted_register != REG_RSP)) ||
        ((base == REG_RBP) && (restricted_register != REG_RBP))) {
      if ((index == restricted_register) ||
          ((index == REG_RDI) &&
           (restricted_register == kSandboxedRsiRestrictedRdi))) {
        BitmapClearBit(valid_targets, begin - data);
      } else if ((index != NO_REG) && (index != REG_RIZ)) {
        PrintError("Improper sandboxing in instruction\n", begin - data);
        result = 1;
        goto error_detected;
      }
    } else if ((index == REG_RIP) || (index == REG_R15) ||
               ((index == REG_RSP) && (restricted_register != REG_RSP)) ||
               ((index == REG_RBP) && (restricted_register != REG_RBP))) {
      if ((base == restricted_register) ||
          ((base == REG_RDI) &&
           (restricted_register == kSandboxedRsiRestrictedRdi))) {
        BitmapClearBit(valid_targets, begin - data);
      } else if ((base != NO_REG) && (base != REG_RIZ)) {
        PrintError("Improper sandboxing in instruction\n", begin - data);
        result = 1;
        goto error_detected;
      }
    } else {
      PrintError("Improper sandboxing in instruction\n", begin - data);
      result = 1;
      goto error_detected;
    }
  }
	goto st29;
tr90:
#line 42 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_DISP_TYPE(DISP8);
    SET_DISP_PTR(p);
  }
#line 44 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    if ((base == REG_RIP) || (base == REG_R15) ||
        ((base == REG_RSP) && (restricted_register != REG_RSP)) ||
        ((base == REG_RBP) && (restricted_register != REG_RBP))) {
      if ((index == restricted_register) ||
          ((index == REG_RDI) &&
           (restricted_register == kSandboxedRsiRestrictedRdi))) {
        BitmapClearBit(valid_targets, begin - data);
      } else if ((index != NO_REG) && (index != REG_RIZ)) {
        PrintError("Improper sandboxing in instruction\n", begin - data);
        result = 1;
        goto error_detected;
      }
    } else if ((index == REG_RIP) || (index == REG_R15) ||
               ((index == REG_RSP) && (restricted_register != REG_RSP)) ||
               ((index == REG_RBP) && (restricted_register != REG_RBP))) {
      if ((base == restricted_register) ||
          ((base == REG_RDI) &&
           (restricted_register == kSandboxedRsiRestrictedRdi))) {
        BitmapClearBit(valid_targets, begin - data);
      } else if ((base != NO_REG) && (base != REG_RIZ)) {
        PrintError("Improper sandboxing in instruction\n", begin - data);
        result = 1;
        goto error_detected;
      }
    } else {
      PrintError("Improper sandboxing in instruction\n", begin - data);
      result = 1;
      goto error_detected;
    }
  }
	goto st29;
st29:
	if ( ++p == pe )
		goto _test_eof29;
case 29:
#line 7418 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 138u: goto tr34;
		case 142u: goto tr34;
		case 144u: goto tr34;
		case 148u: goto tr34;
		case 154u: goto tr34;
		case 158u: goto tr34;
		case 160u: goto tr34;
		case 164u: goto tr34;
		case 170u: goto tr34;
		case 174u: goto tr34;
		case 176u: goto tr34;
		case 180u: goto tr34;
		case 187u: goto tr34;
		case 191u: goto tr34;
	}
	if ( (*p) < 150u ) {
		if ( (*p) > 13u ) {
			if ( 28u <= (*p) && (*p) <= 29u )
				goto tr34;
		} else if ( (*p) >= 12u )
			goto tr34;
	} else if ( (*p) > 151u ) {
		if ( (*p) > 167u ) {
			if ( 182u <= (*p) && (*p) <= 183u )
				goto tr34;
		} else if ( (*p) >= 166u )
			goto tr34;
	} else
		goto tr34;
	goto tr33;
st30:
	if ( ++p == pe )
		goto _test_eof30;
case 30:
	switch( (*p) ) {
		case 5u: goto tr85;
		case 13u: goto tr85;
		case 21u: goto tr85;
		case 29u: goto tr85;
		case 37u: goto tr85;
		case 45u: goto tr85;
		case 53u: goto tr85;
		case 61u: goto tr85;
		case 69u: goto tr85;
		case 77u: goto tr85;
		case 85u: goto tr85;
		case 93u: goto tr85;
		case 101u: goto tr85;
		case 109u: goto tr85;
		case 117u: goto tr85;
		case 125u: goto tr85;
		case 133u: goto tr85;
		case 141u: goto tr85;
		case 149u: goto tr85;
		case 157u: goto tr85;
		case 165u: goto tr85;
		case 173u: goto tr85;
		case 181u: goto tr85;
		case 189u: goto tr85;
		case 197u: goto tr85;
		case 205u: goto tr85;
		case 213u: goto tr85;
		case 221u: goto tr85;
		case 229u: goto tr85;
		case 237u: goto tr85;
		case 245u: goto tr85;
		case 253u: goto tr85;
	}
	goto tr84;
tr78:
#line 105 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_MODRM_BASE(REG_RIP);
    SET_MODRM_INDEX(NO_REG);
    SET_MODRM_SCALE(0);
  }
	goto st31;
tr85:
#line 110 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_DISP_TYPE(DISPNONE);
    SET_MODRM_BASE(NO_REG);
    SET_MODRM_INDEX(index_registers[(((*p) & 0x38) >> 3) |
                                    ((GET_REX_PREFIX() & 0x02) << 2) |
                                    (((~GET_VEX_PREFIX2()) & 0x40) >> 3)]);
    SET_MODRM_SCALE(((*p) & 0xc0) >> 6);
  }
	goto st31;
tr92:
#line 118 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_DISP_TYPE(DISPNONE);
    SET_MODRM_BASE(((*p) & 0x7) |
                   ((GET_REX_PREFIX() & 0x01) << 3) |
                   (((~GET_VEX_PREFIX2()) & 0x20) >> 2));
    SET_MODRM_INDEX(index_registers[(((*p) & 0x38) >> 3) |
                                    ((GET_REX_PREFIX() & 0x02) << 2) |
                                    (((~GET_VEX_PREFIX2()) & 0x40) >> 3)]);
    SET_MODRM_SCALE(((*p) & 0xc0) >> 6);
  }
	goto st31;
tr81:
#line 389 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_NAME(0, (((*p) & 0x38) >> 3) |
                           ((GET_REX_PREFIX() & 0x04) << 1) |
                           (((~GET_VEX_PREFIX2()) & 0x80) >> 4));
  }
#line 98 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_MODRM_BASE(((*p) & 0x07) |
                   ((GET_REX_PREFIX() & 0x01) << 3) |
                   (((~GET_VEX_PREFIX2()) & 0x20) >> 2));
    SET_MODRM_INDEX(NO_REG);
    SET_MODRM_SCALE(0);
  }
	goto st31;
st31:
	if ( ++p == pe )
		goto _test_eof31;
case 31:
#line 7541 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	goto st32;
st32:
	if ( ++p == pe )
		goto _test_eof32;
case 32:
	goto st33;
st33:
	if ( ++p == pe )
		goto _test_eof33;
case 33:
	goto st34;
st34:
	if ( ++p == pe )
		goto _test_eof34;
case 34:
	goto tr89;
tr91:
#line 118 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_DISP_TYPE(DISPNONE);
    SET_MODRM_BASE(((*p) & 0x7) |
                   ((GET_REX_PREFIX() & 0x01) << 3) |
                   (((~GET_VEX_PREFIX2()) & 0x20) >> 2));
    SET_MODRM_INDEX(index_registers[(((*p) & 0x38) >> 3) |
                                    ((GET_REX_PREFIX() & 0x02) << 2) |
                                    (((~GET_VEX_PREFIX2()) & 0x40) >> 3)]);
    SET_MODRM_SCALE(((*p) & 0xc0) >> 6);
  }
	goto st35;
tr79:
#line 389 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_NAME(0, (((*p) & 0x38) >> 3) |
                           ((GET_REX_PREFIX() & 0x04) << 1) |
                           (((~GET_VEX_PREFIX2()) & 0x80) >> 4));
  }
#line 98 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_MODRM_BASE(((*p) & 0x07) |
                   ((GET_REX_PREFIX() & 0x01) << 3) |
                   (((~GET_VEX_PREFIX2()) & 0x20) >> 2));
    SET_MODRM_INDEX(NO_REG);
    SET_MODRM_SCALE(0);
  }
	goto st35;
st35:
	if ( ++p == pe )
		goto _test_eof35;
case 35:
#line 7591 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	goto tr90;
st36:
	if ( ++p == pe )
		goto _test_eof36;
case 36:
	goto tr91;
st37:
	if ( ++p == pe )
		goto _test_eof37;
case 37:
	goto tr92;
tr323:
#line 25 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_DATA16_PREFIX(FALSE);
  }
	goto st38;
tr908:
#line 36 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_REPNZ_PREFIX(FALSE);
  }
	goto st38;
tr925:
#line 39 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_REPZ_PREFIX(FALSE);
  }
	goto st38;
tr986:
#line 329 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
        begin = p;
        BitmapSetBit(valid_targets, p - data);
        SET_REX_PREFIX(FALSE);
        SET_VEX_PREFIX2(0xe0);
        SET_VEX_PREFIX3(0x00);
        operand_states = 0;
     }
	goto st38;
st38:
	if ( ++p == pe )
		goto _test_eof38;
case 38:
#line 7636 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 4u: goto st2;
		case 5u: goto tr2;
		case 12u: goto st2;
		case 13u: goto tr2;
		case 20u: goto st2;
		case 21u: goto tr2;
		case 28u: goto st2;
		case 29u: goto tr2;
		case 36u: goto st2;
		case 37u: goto tr2;
		case 44u: goto st2;
		case 45u: goto tr2;
		case 52u: goto st2;
		case 53u: goto tr2;
		case 60u: goto st2;
		case 61u: goto tr2;
		case 68u: goto st8;
		case 76u: goto st8;
		case 84u: goto st8;
		case 92u: goto st8;
		case 100u: goto st8;
		case 108u: goto st8;
		case 116u: goto st8;
		case 124u: goto st8;
		case 132u: goto st9;
		case 140u: goto st9;
		case 148u: goto st9;
		case 156u: goto st9;
		case 164u: goto st9;
		case 172u: goto st9;
		case 180u: goto st9;
		case 188u: goto st9;
	}
	if ( (*p) < 64u ) {
		if ( (*p) <= 63u )
			goto tr0;
	} else if ( (*p) > 127u ) {
		if ( 128u <= (*p) && (*p) <= 191u )
			goto tr5;
	} else
		goto tr3;
	goto tr34;
tr324:
#line 25 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_DATA16_PREFIX(FALSE);
  }
	goto st39;
tr909:
#line 36 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_REPNZ_PREFIX(FALSE);
  }
	goto st39;
tr926:
#line 39 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_REPZ_PREFIX(FALSE);
  }
	goto st39;
st39:
	if ( ++p == pe )
		goto _test_eof39;
case 39:
#line 7702 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 4u: goto st2;
		case 5u: goto tr2;
		case 12u: goto st2;
		case 13u: goto tr2;
		case 20u: goto st2;
		case 21u: goto tr2;
		case 28u: goto st2;
		case 29u: goto tr2;
		case 36u: goto st2;
		case 37u: goto tr2;
		case 44u: goto st2;
		case 45u: goto tr2;
		case 52u: goto st2;
		case 53u: goto tr2;
		case 60u: goto st2;
		case 61u: goto tr2;
		case 68u: goto st8;
		case 76u: goto st8;
		case 84u: goto st8;
		case 92u: goto st8;
		case 100u: goto st8;
		case 108u: goto st8;
		case 116u: goto st8;
		case 124u: goto st8;
		case 132u: goto st9;
		case 140u: goto st9;
		case 148u: goto st9;
		case 156u: goto st9;
		case 164u: goto st9;
		case 172u: goto st9;
		case 180u: goto st9;
		case 188u: goto st9;
	}
	if ( (*p) < 64u ) {
		if ( (*p) <= 63u )
			goto tr0;
	} else if ( (*p) > 127u ) {
		if ( 128u <= (*p) && (*p) <= 191u )
			goto tr5;
	} else
		goto tr3;
	goto tr33;
st40:
	if ( ++p == pe )
		goto _test_eof40;
case 40:
	switch( (*p) ) {
		case 4u: goto st20;
		case 5u: goto tr62;
		case 12u: goto st20;
		case 13u: goto tr62;
		case 20u: goto st20;
		case 21u: goto tr62;
		case 28u: goto st20;
		case 29u: goto tr62;
		case 68u: goto st26;
		case 76u: goto st26;
		case 84u: goto st26;
		case 92u: goto st26;
		case 132u: goto st27;
		case 140u: goto st27;
		case 148u: goto st27;
		case 156u: goto st27;
	}
	if ( (*p) < 64u ) {
		if ( (*p) <= 31u )
			goto tr60;
	} else if ( (*p) > 95u ) {
		if ( 128u <= (*p) && (*p) <= 159u )
			goto tr65;
	} else
		goto tr63;
	goto tr33;
st41:
	if ( ++p == pe )
		goto _test_eof41;
case 41:
	switch( (*p) ) {
		case 4u: goto st20;
		case 5u: goto tr62;
		case 68u: goto st26;
		case 132u: goto st27;
	}
	if ( (*p) < 64u ) {
		if ( (*p) <= 7u )
			goto tr60;
	} else if ( (*p) > 71u ) {
		if ( (*p) > 135u ) {
			if ( 192u <= (*p) && (*p) <= 199u )
				goto tr34;
		} else if ( (*p) >= 128u )
			goto tr65;
	} else
		goto tr63;
	goto tr33;
tr41:
#line 295 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(0, OperandSize32bit);
  }
	goto st42;
tr327:
#line 25 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_DATA16_PREFIX(FALSE);
  }
#line 295 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(0, OperandSize32bit);
  }
	goto st42;
st42:
	if ( ++p == pe )
		goto _test_eof42;
case 42:
#line 7819 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	if ( 192u <= (*p) )
		goto tr24;
	goto tr33;
tr328:
#line 25 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_DATA16_PREFIX(FALSE);
  }
	goto st43;
tr911:
#line 36 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_REPNZ_PREFIX(FALSE);
  }
	goto st43;
tr928:
#line 39 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_REPZ_PREFIX(FALSE);
  }
	goto st43;
st43:
	if ( ++p == pe )
		goto _test_eof43;
case 43:
#line 7845 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 4u: goto st44;
		case 5u: goto tr95;
		case 12u: goto st44;
		case 13u: goto tr95;
		case 20u: goto st44;
		case 21u: goto tr95;
		case 28u: goto st44;
		case 29u: goto tr95;
		case 36u: goto st44;
		case 37u: goto tr95;
		case 44u: goto st44;
		case 45u: goto tr95;
		case 52u: goto st44;
		case 53u: goto tr95;
		case 60u: goto st44;
		case 61u: goto tr95;
		case 68u: goto st50;
		case 76u: goto st50;
		case 84u: goto st50;
		case 92u: goto st50;
		case 100u: goto st50;
		case 108u: goto st50;
		case 116u: goto st50;
		case 124u: goto st50;
		case 132u: goto st51;
		case 140u: goto st51;
		case 148u: goto st51;
		case 156u: goto st51;
		case 164u: goto st51;
		case 172u: goto st51;
		case 180u: goto st51;
		case 188u: goto st51;
	}
	if ( (*p) < 64u ) {
		if ( (*p) <= 63u )
			goto tr93;
	} else if ( (*p) > 127u ) {
		if ( 128u <= (*p) && (*p) <= 191u )
			goto tr98;
	} else
		goto tr96;
	goto st11;
tr178:
#line 389 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_NAME(0, (((*p) & 0x38) >> 3) |
                           ((GET_REX_PREFIX() & 0x04) << 1) |
                           (((~GET_VEX_PREFIX2()) & 0x80) >> 4));
  }
	goto st44;
tr341:
#line 25 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_DATA16_PREFIX(FALSE);
  }
	goto st44;
st44:
	if ( ++p == pe )
		goto _test_eof44;
case 44:
#line 7907 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 5u: goto tr102;
		case 13u: goto tr102;
		case 21u: goto tr102;
		case 29u: goto tr102;
		case 37u: goto tr102;
		case 45u: goto tr102;
		case 53u: goto tr102;
		case 61u: goto tr102;
		case 69u: goto tr102;
		case 77u: goto tr102;
		case 85u: goto tr102;
		case 93u: goto tr102;
		case 101u: goto tr102;
		case 109u: goto tr102;
		case 117u: goto tr102;
		case 125u: goto tr102;
		case 133u: goto tr102;
		case 141u: goto tr102;
		case 149u: goto tr102;
		case 157u: goto tr102;
		case 165u: goto tr102;
		case 173u: goto tr102;
		case 181u: goto tr102;
		case 189u: goto tr102;
		case 197u: goto tr102;
		case 205u: goto tr102;
		case 213u: goto tr102;
		case 221u: goto tr102;
		case 229u: goto tr102;
		case 237u: goto tr102;
		case 245u: goto tr102;
		case 253u: goto tr102;
	}
	goto tr101;
tr95:
#line 105 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_MODRM_BASE(REG_RIP);
    SET_MODRM_INDEX(NO_REG);
    SET_MODRM_SCALE(0);
  }
	goto st45;
tr98:
#line 98 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_MODRM_BASE(((*p) & 0x07) |
                   ((GET_REX_PREFIX() & 0x01) << 3) |
                   (((~GET_VEX_PREFIX2()) & 0x20) >> 2));
    SET_MODRM_INDEX(NO_REG);
    SET_MODRM_SCALE(0);
  }
	goto st45;
tr102:
#line 110 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_DISP_TYPE(DISPNONE);
    SET_MODRM_BASE(NO_REG);
    SET_MODRM_INDEX(index_registers[(((*p) & 0x38) >> 3) |
                                    ((GET_REX_PREFIX() & 0x02) << 2) |
                                    (((~GET_VEX_PREFIX2()) & 0x40) >> 3)]);
    SET_MODRM_SCALE(((*p) & 0xc0) >> 6);
  }
	goto st45;
tr109:
#line 118 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_DISP_TYPE(DISPNONE);
    SET_MODRM_BASE(((*p) & 0x7) |
                   ((GET_REX_PREFIX() & 0x01) << 3) |
                   (((~GET_VEX_PREFIX2()) & 0x20) >> 2));
    SET_MODRM_INDEX(index_registers[(((*p) & 0x38) >> 3) |
                                    ((GET_REX_PREFIX() & 0x02) << 2) |
                                    (((~GET_VEX_PREFIX2()) & 0x40) >> 3)]);
    SET_MODRM_SCALE(((*p) & 0xc0) >> 6);
  }
	goto st45;
tr179:
#line 389 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_NAME(0, (((*p) & 0x38) >> 3) |
                           ((GET_REX_PREFIX() & 0x04) << 1) |
                           (((~GET_VEX_PREFIX2()) & 0x80) >> 4));
  }
#line 105 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_MODRM_BASE(REG_RIP);
    SET_MODRM_INDEX(NO_REG);
    SET_MODRM_SCALE(0);
  }
	goto st45;
tr182:
#line 389 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_NAME(0, (((*p) & 0x38) >> 3) |
                           ((GET_REX_PREFIX() & 0x04) << 1) |
                           (((~GET_VEX_PREFIX2()) & 0x80) >> 4));
  }
#line 98 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_MODRM_BASE(((*p) & 0x07) |
                   ((GET_REX_PREFIX() & 0x01) << 3) |
                   (((~GET_VEX_PREFIX2()) & 0x20) >> 2));
    SET_MODRM_INDEX(NO_REG);
    SET_MODRM_SCALE(0);
  }
	goto st45;
tr342:
#line 25 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_DATA16_PREFIX(FALSE);
  }
#line 105 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_MODRM_BASE(REG_RIP);
    SET_MODRM_INDEX(NO_REG);
    SET_MODRM_SCALE(0);
  }
	goto st45;
tr345:
#line 25 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_DATA16_PREFIX(FALSE);
  }
#line 98 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_MODRM_BASE(((*p) & 0x07) |
                   ((GET_REX_PREFIX() & 0x01) << 3) |
                   (((~GET_VEX_PREFIX2()) & 0x20) >> 2));
    SET_MODRM_INDEX(NO_REG);
    SET_MODRM_SCALE(0);
  }
	goto st45;
st45:
	if ( ++p == pe )
		goto _test_eof45;
case 45:
#line 8045 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	goto st46;
st46:
	if ( ++p == pe )
		goto _test_eof46;
case 46:
	goto st47;
st47:
	if ( ++p == pe )
		goto _test_eof47;
case 47:
	goto st48;
st48:
	if ( ++p == pe )
		goto _test_eof48;
case 48:
	goto tr106;
tr96:
#line 98 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_MODRM_BASE(((*p) & 0x07) |
                   ((GET_REX_PREFIX() & 0x01) << 3) |
                   (((~GET_VEX_PREFIX2()) & 0x20) >> 2));
    SET_MODRM_INDEX(NO_REG);
    SET_MODRM_SCALE(0);
  }
	goto st49;
tr108:
#line 118 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_DISP_TYPE(DISPNONE);
    SET_MODRM_BASE(((*p) & 0x7) |
                   ((GET_REX_PREFIX() & 0x01) << 3) |
                   (((~GET_VEX_PREFIX2()) & 0x20) >> 2));
    SET_MODRM_INDEX(index_registers[(((*p) & 0x38) >> 3) |
                                    ((GET_REX_PREFIX() & 0x02) << 2) |
                                    (((~GET_VEX_PREFIX2()) & 0x40) >> 3)]);
    SET_MODRM_SCALE(((*p) & 0xc0) >> 6);
  }
	goto st49;
tr180:
#line 389 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_NAME(0, (((*p) & 0x38) >> 3) |
                           ((GET_REX_PREFIX() & 0x04) << 1) |
                           (((~GET_VEX_PREFIX2()) & 0x80) >> 4));
  }
#line 98 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_MODRM_BASE(((*p) & 0x07) |
                   ((GET_REX_PREFIX() & 0x01) << 3) |
                   (((~GET_VEX_PREFIX2()) & 0x20) >> 2));
    SET_MODRM_INDEX(NO_REG);
    SET_MODRM_SCALE(0);
  }
	goto st49;
tr343:
#line 25 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_DATA16_PREFIX(FALSE);
  }
#line 98 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_MODRM_BASE(((*p) & 0x07) |
                   ((GET_REX_PREFIX() & 0x01) << 3) |
                   (((~GET_VEX_PREFIX2()) & 0x20) >> 2));
    SET_MODRM_INDEX(NO_REG);
    SET_MODRM_SCALE(0);
  }
	goto st49;
st49:
	if ( ++p == pe )
		goto _test_eof49;
case 49:
#line 8119 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	goto tr107;
tr181:
#line 389 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_NAME(0, (((*p) & 0x38) >> 3) |
                           ((GET_REX_PREFIX() & 0x04) << 1) |
                           (((~GET_VEX_PREFIX2()) & 0x80) >> 4));
  }
	goto st50;
tr344:
#line 25 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_DATA16_PREFIX(FALSE);
  }
	goto st50;
st50:
	if ( ++p == pe )
		goto _test_eof50;
case 50:
#line 8139 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	goto tr108;
tr183:
#line 389 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_NAME(0, (((*p) & 0x38) >> 3) |
                           ((GET_REX_PREFIX() & 0x04) << 1) |
                           (((~GET_VEX_PREFIX2()) & 0x80) >> 4));
  }
	goto st51;
tr346:
#line 25 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_DATA16_PREFIX(FALSE);
  }
	goto st51;
st51:
	if ( ++p == pe )
		goto _test_eof51;
case 51:
#line 8159 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	goto tr109;
st52:
	if ( ++p == pe )
		goto _test_eof52;
case 52:
	if ( (*p) < 224u ) {
		if ( 208u <= (*p) && (*p) <= 215u )
			goto st11;
	} else if ( (*p) > 231u ) {
		if ( 240u <= (*p) && (*p) <= 247u )
			goto st11;
	} else
		goto st11;
	goto tr33;
st53:
	if ( ++p == pe )
		goto _test_eof53;
case 53:
	if ( (*p) > 215u ) {
		if ( 240u <= (*p) && (*p) <= 247u )
			goto st11;
	} else if ( (*p) >= 208u )
		goto st11;
	goto tr33;
tr1034:
#line 329 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
        begin = p;
        BitmapSetBit(valid_targets, p - data);
        SET_REX_PREFIX(FALSE);
        SET_VEX_PREFIX2(0xe0);
        SET_VEX_PREFIX3(0x00);
        operand_states = 0;
     }
	goto st54;
st54:
	if ( ++p == pe )
		goto _test_eof54;
case 54:
#line 8199 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	goto st55;
st55:
	if ( ++p == pe )
		goto _test_eof55;
case 55:
	goto st56;
st56:
	if ( ++p == pe )
		goto _test_eof56;
case 56:
	goto st57;
st57:
	if ( ++p == pe )
		goto _test_eof57;
case 57:
	goto tr113;
tr48:
#line 295 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(0, OperandSize32bit);
  }
	goto st58;
tr243:
#line 298 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(0, OperandSize64bit);
  }
	goto st58;
tr333:
#line 292 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(0, OperandSize16bit);
  }
	goto st58;
tr339:
#line 25 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_DATA16_PREFIX(FALSE);
  }
#line 295 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(0, OperandSize32bit);
  }
	goto st58;
tr403:
#line 25 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_DATA16_PREFIX(FALSE);
  }
#line 298 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(0, OperandSize64bit);
  }
	goto st58;
st58:
	if ( ++p == pe )
		goto _test_eof58;
case 58:
#line 8258 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 4u: goto st44;
		case 5u: goto tr95;
		case 12u: goto st44;
		case 13u: goto tr95;
		case 20u: goto st44;
		case 21u: goto tr95;
		case 28u: goto st44;
		case 29u: goto tr95;
		case 36u: goto st44;
		case 37u: goto tr95;
		case 44u: goto st44;
		case 45u: goto tr95;
		case 52u: goto st44;
		case 53u: goto tr95;
		case 60u: goto st44;
		case 61u: goto tr95;
		case 68u: goto st50;
		case 76u: goto st50;
		case 84u: goto st50;
		case 92u: goto st50;
		case 100u: goto st50;
		case 108u: goto st50;
		case 116u: goto st50;
		case 124u: goto st50;
		case 132u: goto st51;
		case 140u: goto st51;
		case 148u: goto st51;
		case 156u: goto st51;
		case 164u: goto st51;
		case 172u: goto st51;
		case 180u: goto st51;
		case 188u: goto st51;
	}
	if ( (*p) < 64u ) {
		if ( (*p) <= 63u )
			goto tr93;
	} else if ( (*p) > 127u ) {
		if ( 128u <= (*p) && (*p) <= 191u )
			goto tr98;
	} else
		goto tr96;
	goto tr114;
st59:
	if ( ++p == pe )
		goto _test_eof59;
case 59:
	switch( (*p) ) {
		case 20u: goto st2;
		case 21u: goto tr2;
		case 28u: goto st2;
		case 29u: goto tr2;
		case 36u: goto st2;
		case 37u: goto tr2;
		case 44u: goto st2;
		case 45u: goto tr2;
		case 52u: goto st2;
		case 53u: goto tr2;
		case 60u: goto st2;
		case 61u: goto tr2;
		case 84u: goto st8;
		case 92u: goto st8;
		case 100u: goto st8;
		case 108u: goto st8;
		case 116u: goto st8;
		case 124u: goto st8;
		case 148u: goto st9;
		case 156u: goto st9;
		case 164u: goto st9;
		case 172u: goto st9;
		case 180u: goto st9;
		case 188u: goto st9;
		case 232u: goto tr34;
		case 240u: goto tr34;
		case 248u: goto tr34;
	}
	if ( (*p) < 80u ) {
		if ( 16u <= (*p) && (*p) <= 63u )
			goto tr0;
	} else if ( (*p) > 127u ) {
		if ( 144u <= (*p) && (*p) <= 191u )
			goto tr5;
	} else
		goto tr3;
	goto tr33;
tr50:
#line 295 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(0, OperandSize32bit);
  }
	goto st60;
tr889:
#line 289 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(0, OperandSize8bit);
  }
	goto st60;
tr244:
#line 298 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(0, OperandSize64bit);
  }
	goto st60;
tr334:
#line 292 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(0, OperandSize16bit);
  }
	goto st60;
st60:
	if ( ++p == pe )
		goto _test_eof60;
case 60:
#line 8372 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 4u: goto tr18;
		case 5u: goto tr19;
		case 12u: goto tr18;
		case 13u: goto tr19;
		case 20u: goto tr18;
		case 21u: goto tr19;
		case 28u: goto tr18;
		case 29u: goto tr19;
		case 36u: goto tr18;
		case 37u: goto tr19;
		case 44u: goto tr18;
		case 45u: goto tr19;
		case 52u: goto tr18;
		case 53u: goto tr19;
		case 60u: goto tr18;
		case 61u: goto tr19;
		case 68u: goto tr21;
		case 76u: goto tr21;
		case 84u: goto tr21;
		case 92u: goto tr21;
		case 100u: goto tr21;
		case 108u: goto tr21;
		case 116u: goto tr21;
		case 124u: goto tr21;
		case 132u: goto tr23;
		case 140u: goto tr23;
		case 148u: goto tr23;
		case 156u: goto tr23;
		case 164u: goto tr23;
		case 172u: goto tr23;
		case 180u: goto tr23;
		case 188u: goto tr23;
	}
	if ( (*p) < 64u ) {
		if ( (*p) <= 63u )
			goto tr17;
	} else if ( (*p) > 127u ) {
		if ( 128u <= (*p) && (*p) <= 191u )
			goto tr22;
	} else
		goto tr20;
	goto tr33;
st61:
	if ( ++p == pe )
		goto _test_eof61;
case 61:
	switch( (*p) ) {
		case 36u: goto st44;
		case 37u: goto tr95;
		case 44u: goto st44;
		case 45u: goto tr95;
		case 52u: goto st44;
		case 53u: goto tr95;
		case 60u: goto st44;
		case 61u: goto tr95;
		case 100u: goto st50;
		case 108u: goto st50;
		case 116u: goto st50;
		case 124u: goto st50;
		case 164u: goto st51;
		case 172u: goto st51;
		case 180u: goto st51;
		case 188u: goto st51;
	}
	if ( (*p) < 96u ) {
		if ( 32u <= (*p) && (*p) <= 63u )
			goto tr93;
	} else if ( (*p) > 127u ) {
		if ( (*p) > 191u ) {
			if ( 224u <= (*p) )
				goto tr115;
		} else if ( (*p) >= 160u )
			goto tr98;
	} else
		goto tr96;
	goto tr33;
tr52:
#line 295 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(0, OperandSize32bit);
  }
	goto st62;
tr337:
#line 25 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_DATA16_PREFIX(FALSE);
  }
#line 295 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(0, OperandSize32bit);
  }
	goto st62;
st62:
	if ( ++p == pe )
		goto _test_eof62;
case 62:
#line 8470 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	if ( 192u <= (*p) )
		goto tr116;
	goto tr33;
st63:
	if ( ++p == pe )
		goto _test_eof63;
case 63:
	switch( (*p) ) {
		case 12u: goto st2;
		case 13u: goto tr2;
		case 76u: goto st8;
		case 140u: goto st9;
	}
	if ( (*p) < 72u ) {
		if ( 8u <= (*p) && (*p) <= 15u )
			goto tr0;
	} else if ( (*p) > 79u ) {
		if ( 136u <= (*p) && (*p) <= 143u )
			goto tr5;
	} else
		goto tr3;
	goto tr33;
tr331:
#line 25 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_DATA16_PREFIX(FALSE);
  }
	goto st64;
tr913:
#line 36 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_REPNZ_PREFIX(FALSE);
  }
	goto st64;
tr929:
#line 39 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_REPZ_PREFIX(FALSE);
  }
	goto st64;
st64:
	if ( ++p == pe )
		goto _test_eof64;
case 64:
#line 8515 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	if ( 192u <= (*p) )
		goto tr34;
	goto tr33;
tr985:
#line 329 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
        begin = p;
        BitmapSetBit(valid_targets, p - data);
        SET_REX_PREFIX(FALSE);
        SET_VEX_PREFIX2(0xe0);
        SET_VEX_PREFIX3(0x00);
        operand_states = 0;
     }
#line 4 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_BRANCH_NOT_TAKEN(TRUE);
  }
	goto st65;
tr989:
#line 329 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
        begin = p;
        BitmapSetBit(valid_targets, p - data);
        SET_REX_PREFIX(FALSE);
        SET_VEX_PREFIX2(0xe0);
        SET_VEX_PREFIX3(0x00);
        operand_states = 0;
     }
#line 7 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_BRANCH_TAKEN(TRUE);
  }
	goto st65;
st65:
	if ( ++p == pe )
		goto _test_eof65;
case 65:
#line 8553 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	if ( (*p) == 15u )
		goto st66;
	if ( 112u <= (*p) && (*p) <= 127u )
		goto st67;
	goto tr33;
st66:
	if ( ++p == pe )
		goto _test_eof66;
case 66:
	if ( 128u <= (*p) && (*p) <= 143u )
		goto st54;
	goto tr33;
tr1002:
#line 329 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
        begin = p;
        BitmapSetBit(valid_targets, p - data);
        SET_REX_PREFIX(FALSE);
        SET_VEX_PREFIX2(0xe0);
        SET_VEX_PREFIX3(0x00);
        operand_states = 0;
     }
	goto st67;
st67:
	if ( ++p == pe )
		goto _test_eof67;
case 67:
#line 8581 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	goto tr119;
tr990:
#line 329 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
        begin = p;
        BitmapSetBit(valid_targets, p - data);
        SET_REX_PREFIX(FALSE);
        SET_VEX_PREFIX2(0xe0);
        SET_VEX_PREFIX3(0x00);
        operand_states = 0;
     }
#line 190 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_REX_PREFIX(*p);
  }
	goto st68;
st68:
	if ( ++p == pe )
		goto _test_eof68;
case 68:
#line 8602 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 0u: goto tr47;
		case 1u: goto tr45;
		case 2u: goto tr120;
		case 3u: goto tr32;
		case 8u: goto tr47;
		case 9u: goto tr45;
		case 10u: goto tr120;
		case 11u: goto tr32;
		case 15u: goto st69;
		case 16u: goto tr47;
		case 17u: goto tr45;
		case 18u: goto tr120;
		case 19u: goto tr32;
		case 24u: goto tr47;
		case 25u: goto tr45;
		case 26u: goto tr120;
		case 27u: goto tr32;
		case 32u: goto tr47;
		case 33u: goto tr45;
		case 34u: goto tr120;
		case 35u: goto tr32;
		case 40u: goto tr47;
		case 41u: goto tr45;
		case 42u: goto tr120;
		case 43u: goto tr32;
		case 48u: goto tr47;
		case 49u: goto tr45;
		case 50u: goto tr120;
		case 51u: goto tr32;
		case 99u: goto tr32;
		case 105u: goto tr124;
		case 107u: goto tr125;
		case 128u: goto st89;
		case 129u: goto st90;
		case 131u: goto st91;
		case 133u: goto tr45;
		case 134u: goto tr129;
		case 135u: goto tr130;
		case 137u: goto tr45;
		case 138u: goto tr120;
		case 139u: goto tr32;
		case 141u: goto tr131;
		case 143u: goto st94;
		case 155u: goto st95;
		case 192u: goto st97;
		case 193u: goto st98;
		case 198u: goto st99;
		case 199u: goto st100;
		case 209u: goto st102;
		case 211u: goto st102;
		case 217u: goto st104;
		case 219u: goto st105;
		case 221u: goto st106;
		case 246u: goto st107;
		case 247u: goto st108;
		case 254u: goto st109;
		case 255u: goto st110;
	}
	if ( (*p) < 145u ) {
		if ( (*p) < 80u ) {
			if ( 56u <= (*p) && (*p) <= 59u )
				goto st38;
		} else if ( (*p) > 87u ) {
			if ( (*p) > 95u ) {
				if ( 132u <= (*p) && (*p) <= 136u )
					goto tr47;
			} else if ( (*p) >= 88u )
				goto tr123;
		} else
			goto tr122;
	} else if ( (*p) > 151u ) {
		if ( (*p) < 184u ) {
			if ( 176u <= (*p) && (*p) <= 183u )
				goto tr135;
		} else if ( (*p) > 191u ) {
			if ( (*p) > 210u ) {
				if ( 216u <= (*p) && (*p) <= 223u )
					goto st103;
			} else if ( (*p) >= 208u )
				goto st101;
		} else
			goto tr136;
	} else
		goto tr133;
	goto tr33;
st69:
	if ( ++p == pe )
		goto _test_eof69;
case 69:
	switch( (*p) ) {
		case 0u: goto st70;
		case 1u: goto st71;
		case 13u: goto st72;
		case 15u: goto st28;
		case 19u: goto st39;
		case 23u: goto st39;
		case 24u: goto st73;
		case 31u: goto st74;
		case 43u: goto st39;
		case 80u: goto tr41;
		case 112u: goto st43;
		case 115u: goto st53;
		case 126u: goto tr45;
		case 164u: goto tr48;
		case 165u: goto tr45;
		case 172u: goto tr48;
		case 173u: goto tr45;
		case 174u: goto st76;
		case 175u: goto tr32;
		case 176u: goto tr47;
		case 177u: goto tr45;
		case 178u: goto tr50;
		case 186u: goto st77;
		case 192u: goto tr47;
		case 193u: goto tr45;
		case 195u: goto st39;
		case 197u: goto tr52;
		case 199u: goto st78;
		case 208u: goto tr33;
		case 214u: goto tr33;
		case 215u: goto tr41;
		case 240u: goto tr33;
		case 247u: goto st64;
		case 255u: goto tr33;
	}
	if ( (*p) < 128u ) {
		if ( (*p) < 48u ) {
			if ( (*p) < 4u ) {
				if ( 2u <= (*p) && (*p) <= 3u )
					goto tr32;
			} else if ( (*p) > 14u ) {
				if ( 25u <= (*p) && (*p) <= 39u )
					goto tr33;
			} else
				goto tr33;
		} else if ( (*p) > 63u ) {
			if ( (*p) < 108u ) {
				if ( 64u <= (*p) && (*p) <= 79u )
					goto tr32;
			} else if ( (*p) > 109u ) {
				if ( (*p) > 114u ) {
					if ( 119u <= (*p) && (*p) <= 125u )
						goto tr33;
				} else if ( (*p) >= 113u )
					goto st52;
			} else
				goto tr33;
		} else
			goto tr33;
	} else if ( (*p) > 143u ) {
		if ( (*p) < 184u ) {
			if ( (*p) < 160u ) {
				if ( 144u <= (*p) && (*p) <= 159u )
					goto tr156;
			} else if ( (*p) > 179u ) {
				if ( (*p) > 181u ) {
					if ( 182u <= (*p) && (*p) <= 183u )
						goto tr32;
				} else if ( (*p) >= 180u )
					goto tr50;
			} else
				goto tr33;
		} else if ( (*p) > 187u ) {
			if ( (*p) < 194u ) {
				if ( 188u <= (*p) && (*p) <= 191u )
					goto tr32;
			} else if ( (*p) > 198u ) {
				if ( (*p) > 207u ) {
					if ( 230u <= (*p) && (*p) <= 231u )
						goto tr33;
				} else if ( (*p) >= 200u )
					goto tr54;
			} else
				goto st43;
		} else
			goto tr33;
	} else
		goto tr33;
	goto st38;
st70:
	if ( ++p == pe )
		goto _test_eof70;
case 70:
	switch( (*p) ) {
		case 12u: goto st2;
		case 28u: goto st2;
		case 36u: goto st2;
		case 44u: goto st2;
		case 76u: goto st8;
		case 92u: goto st8;
		case 100u: goto st8;
		case 108u: goto st8;
		case 140u: goto st9;
		case 156u: goto st9;
		case 164u: goto st9;
		case 172u: goto st9;
	}
	if ( (*p) < 46u ) {
		if ( (*p) < 24u ) {
			if ( (*p) > 11u ) {
				if ( 14u <= (*p) && (*p) <= 15u )
					goto tr0;
			} else if ( (*p) >= 8u )
				goto tr0;
		} else if ( (*p) > 27u ) {
			if ( (*p) > 35u ) {
				if ( 38u <= (*p) && (*p) <= 43u )
					goto tr0;
			} else if ( (*p) >= 30u )
				goto tr0;
		} else
			goto tr0;
	} else if ( (*p) > 47u ) {
		if ( (*p) < 136u ) {
			if ( (*p) > 79u ) {
				if ( 88u <= (*p) && (*p) <= 111u )
					goto tr3;
			} else if ( (*p) >= 72u )
				goto tr3;
		} else if ( (*p) > 143u ) {
			if ( (*p) < 200u ) {
				if ( 152u <= (*p) && (*p) <= 175u )
					goto tr5;
			} else if ( (*p) > 207u ) {
				if ( 216u <= (*p) && (*p) <= 239u )
					goto tr57;
			} else
				goto tr56;
		} else
			goto tr5;
	} else
		goto tr0;
	goto tr33;
st71:
	if ( ++p == pe )
		goto _test_eof71;
case 71:
	switch( (*p) ) {
		case 36u: goto st2;
		case 52u: goto st2;
		case 60u: goto st2;
		case 100u: goto st8;
		case 116u: goto st8;
		case 124u: goto st8;
		case 164u: goto st9;
		case 180u: goto st9;
		case 188u: goto st9;
	}
	if ( (*p) < 96u ) {
		if ( (*p) < 48u ) {
			if ( (*p) > 35u ) {
				if ( 38u <= (*p) && (*p) <= 39u )
					goto tr0;
			} else if ( (*p) >= 32u )
				goto tr0;
		} else if ( (*p) > 51u ) {
			if ( (*p) > 59u ) {
				if ( 62u <= (*p) && (*p) <= 63u )
					goto tr0;
			} else if ( (*p) >= 54u )
				goto tr0;
		} else
			goto tr0;
	} else if ( (*p) > 103u ) {
		if ( (*p) < 176u ) {
			if ( (*p) > 127u ) {
				if ( 160u <= (*p) && (*p) <= 167u )
					goto tr5;
			} else if ( (*p) >= 112u )
				goto tr3;
		} else if ( (*p) > 191u ) {
			if ( (*p) > 231u ) {
				if ( 240u <= (*p) && (*p) <= 247u )
					goto tr57;
			} else if ( (*p) >= 224u )
				goto tr56;
		} else
			goto tr5;
	} else
		goto tr3;
	goto tr33;
st72:
	if ( ++p == pe )
		goto _test_eof72;
case 72:
	switch( (*p) ) {
		case 4u: goto st20;
		case 12u: goto st20;
		case 68u: goto st26;
		case 76u: goto st26;
		case 132u: goto st27;
		case 140u: goto st27;
	}
	if ( (*p) < 14u ) {
		if ( (*p) > 3u ) {
			if ( 6u <= (*p) && (*p) <= 11u )
				goto tr60;
		} else
			goto tr60;
	} else if ( (*p) > 15u ) {
		if ( (*p) > 79u ) {
			if ( 128u <= (*p) && (*p) <= 143u )
				goto tr65;
		} else if ( (*p) >= 64u )
			goto tr63;
	} else
		goto tr60;
	goto tr33;
st73:
	if ( ++p == pe )
		goto _test_eof73;
case 73:
	switch( (*p) ) {
		case 4u: goto st20;
		case 12u: goto st20;
		case 20u: goto st20;
		case 28u: goto st20;
		case 68u: goto st26;
		case 76u: goto st26;
		case 84u: goto st26;
		case 92u: goto st26;
		case 132u: goto st27;
		case 140u: goto st27;
		case 148u: goto st27;
		case 156u: goto st27;
	}
	if ( (*p) < 22u ) {
		if ( (*p) < 6u ) {
			if ( (*p) <= 3u )
				goto tr60;
		} else if ( (*p) > 11u ) {
			if ( 14u <= (*p) && (*p) <= 19u )
				goto tr60;
		} else
			goto tr60;
	} else if ( (*p) > 27u ) {
		if ( (*p) < 64u ) {
			if ( 30u <= (*p) && (*p) <= 31u )
				goto tr60;
		} else if ( (*p) > 95u ) {
			if ( 128u <= (*p) && (*p) <= 159u )
				goto tr65;
		} else
			goto tr63;
	} else
		goto tr60;
	goto tr33;
st74:
	if ( ++p == pe )
		goto _test_eof74;
case 74:
	switch( (*p) ) {
		case 4u: goto st20;
		case 68u: goto st26;
		case 132u: goto st27;
	}
	if ( (*p) < 64u ) {
		if ( (*p) > 3u ) {
			if ( 6u <= (*p) && (*p) <= 7u )
				goto tr60;
		} else
			goto tr60;
	} else if ( (*p) > 71u ) {
		if ( (*p) > 135u ) {
			if ( 192u <= (*p) && (*p) <= 199u )
				goto tr34;
		} else if ( (*p) >= 128u )
			goto tr65;
	} else
		goto tr63;
	goto tr33;
tr156:
#line 289 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(0, OperandSize8bit);
  }
	goto st75;
st75:
	if ( ++p == pe )
		goto _test_eof75;
case 75:
#line 8985 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 4u: goto st2;
		case 5u: goto tr33;
		case 12u: goto st2;
		case 13u: goto tr33;
		case 20u: goto st2;
		case 21u: goto tr33;
		case 28u: goto st2;
		case 29u: goto tr33;
		case 36u: goto st2;
		case 37u: goto tr33;
		case 44u: goto st2;
		case 45u: goto tr33;
		case 52u: goto st2;
		case 53u: goto tr33;
		case 60u: goto st2;
		case 61u: goto tr33;
		case 68u: goto st8;
		case 76u: goto st8;
		case 84u: goto st8;
		case 92u: goto st8;
		case 100u: goto st8;
		case 108u: goto st8;
		case 116u: goto st8;
		case 124u: goto st8;
		case 132u: goto st9;
		case 140u: goto st9;
		case 148u: goto st9;
		case 156u: goto st9;
		case 164u: goto st9;
		case 172u: goto st9;
		case 180u: goto st9;
		case 188u: goto st9;
	}
	if ( (*p) < 64u ) {
		if ( (*p) <= 63u )
			goto tr0;
	} else if ( (*p) > 127u ) {
		if ( 128u <= (*p) && (*p) <= 191u )
			goto tr5;
	} else
		goto tr3;
	goto tr7;
st76:
	if ( ++p == pe )
		goto _test_eof76;
case 76:
	switch( (*p) ) {
		case 20u: goto st2;
		case 28u: goto st2;
		case 36u: goto st2;
		case 44u: goto st2;
		case 52u: goto st2;
		case 60u: goto st2;
		case 84u: goto st8;
		case 92u: goto st8;
		case 100u: goto st8;
		case 108u: goto st8;
		case 116u: goto st8;
		case 124u: goto st8;
		case 148u: goto st9;
		case 156u: goto st9;
		case 164u: goto st9;
		case 172u: goto st9;
		case 180u: goto st9;
		case 188u: goto st9;
	}
	if ( (*p) < 46u ) {
		if ( (*p) < 22u ) {
			if ( 16u <= (*p) && (*p) <= 19u )
				goto tr0;
		} else if ( (*p) > 27u ) {
			if ( (*p) > 35u ) {
				if ( 38u <= (*p) && (*p) <= 43u )
					goto tr0;
			} else if ( (*p) >= 30u )
				goto tr0;
		} else
			goto tr0;
	} else if ( (*p) > 51u ) {
		if ( (*p) < 62u ) {
			if ( 54u <= (*p) && (*p) <= 59u )
				goto tr0;
		} else if ( (*p) > 63u ) {
			if ( (*p) > 127u ) {
				if ( 144u <= (*p) && (*p) <= 191u )
					goto tr5;
			} else if ( (*p) >= 80u )
				goto tr3;
		} else
			goto tr0;
	} else
		goto tr0;
	goto tr33;
st77:
	if ( ++p == pe )
		goto _test_eof77;
case 77:
	switch( (*p) ) {
		case 36u: goto st44;
		case 44u: goto st44;
		case 52u: goto st44;
		case 60u: goto st44;
		case 100u: goto st50;
		case 108u: goto st50;
		case 116u: goto st50;
		case 124u: goto st50;
		case 164u: goto st51;
		case 172u: goto st51;
		case 180u: goto st51;
		case 188u: goto st51;
	}
	if ( (*p) < 54u ) {
		if ( (*p) < 38u ) {
			if ( 32u <= (*p) && (*p) <= 35u )
				goto tr93;
		} else if ( (*p) > 43u ) {
			if ( 46u <= (*p) && (*p) <= 51u )
				goto tr93;
		} else
			goto tr93;
	} else if ( (*p) > 59u ) {
		if ( (*p) < 96u ) {
			if ( 62u <= (*p) && (*p) <= 63u )
				goto tr93;
		} else if ( (*p) > 127u ) {
			if ( (*p) > 191u ) {
				if ( 224u <= (*p) )
					goto tr115;
			} else if ( (*p) >= 160u )
				goto tr98;
		} else
			goto tr96;
	} else
		goto tr93;
	goto tr33;
st78:
	if ( ++p == pe )
		goto _test_eof78;
case 78:
	switch( (*p) ) {
		case 12u: goto st2;
		case 76u: goto st8;
		case 140u: goto st9;
	}
	if ( (*p) < 14u ) {
		if ( 8u <= (*p) && (*p) <= 11u )
			goto tr0;
	} else if ( (*p) > 15u ) {
		if ( (*p) > 79u ) {
			if ( 136u <= (*p) && (*p) <= 143u )
				goto tr5;
		} else if ( (*p) >= 72u )
			goto tr3;
	} else
		goto tr0;
	goto tr33;
tr124:
#line 295 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(0, OperandSize32bit);
  }
	goto st79;
tr224:
#line 298 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(0, OperandSize64bit);
  }
	goto st79;
tr1000:
#line 329 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
        begin = p;
        BitmapSetBit(valid_targets, p - data);
        SET_REX_PREFIX(FALSE);
        SET_VEX_PREFIX2(0xe0);
        SET_VEX_PREFIX3(0x00);
        operand_states = 0;
     }
#line 295 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(0, OperandSize32bit);
  }
	goto st79;
st79:
	if ( ++p == pe )
		goto _test_eof79;
case 79:
#line 9174 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 4u: goto tr161;
		case 5u: goto tr162;
		case 12u: goto tr161;
		case 13u: goto tr162;
		case 20u: goto tr161;
		case 21u: goto tr162;
		case 28u: goto tr161;
		case 29u: goto tr162;
		case 36u: goto tr161;
		case 37u: goto tr162;
		case 44u: goto tr161;
		case 45u: goto tr162;
		case 52u: goto tr161;
		case 53u: goto tr162;
		case 60u: goto tr161;
		case 61u: goto tr162;
		case 68u: goto tr164;
		case 76u: goto tr164;
		case 84u: goto tr164;
		case 92u: goto tr164;
		case 100u: goto tr164;
		case 108u: goto tr164;
		case 116u: goto tr164;
		case 124u: goto tr164;
		case 132u: goto tr166;
		case 140u: goto tr166;
		case 148u: goto tr166;
		case 156u: goto tr166;
		case 164u: goto tr166;
		case 172u: goto tr166;
		case 180u: goto tr166;
		case 188u: goto tr166;
	}
	if ( (*p) < 64u ) {
		if ( (*p) <= 63u )
			goto tr160;
	} else if ( (*p) > 127u ) {
		if ( 128u <= (*p) && (*p) <= 191u )
			goto tr165;
	} else
		goto tr163;
	goto tr167;
tr161:
#line 389 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_NAME(0, (((*p) & 0x38) >> 3) |
                           ((GET_REX_PREFIX() & 0x04) << 1) |
                           (((~GET_VEX_PREFIX2()) & 0x80) >> 4));
  }
	goto st80;
tr580:
#line 295 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(0, OperandSize32bit);
  }
#line 397 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_NAME(0, ((~GET_VEX_PREFIX3()) & 0x78) >> 3);
  }
	goto st80;
tr582:
#line 298 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(0, OperandSize64bit);
  }
#line 397 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_NAME(0, ((~GET_VEX_PREFIX3()) & 0x78) >> 3);
  }
	goto st80;
st80:
	if ( ++p == pe )
		goto _test_eof80;
case 80:
#line 9250 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 5u: goto tr169;
		case 13u: goto tr169;
		case 21u: goto tr169;
		case 29u: goto tr169;
		case 37u: goto tr169;
		case 45u: goto tr169;
		case 53u: goto tr169;
		case 61u: goto tr169;
		case 69u: goto tr169;
		case 77u: goto tr169;
		case 85u: goto tr169;
		case 93u: goto tr169;
		case 101u: goto tr169;
		case 109u: goto tr169;
		case 117u: goto tr169;
		case 125u: goto tr169;
		case 133u: goto tr169;
		case 141u: goto tr169;
		case 149u: goto tr169;
		case 157u: goto tr169;
		case 165u: goto tr169;
		case 173u: goto tr169;
		case 181u: goto tr169;
		case 189u: goto tr169;
		case 197u: goto tr169;
		case 205u: goto tr169;
		case 213u: goto tr169;
		case 221u: goto tr169;
		case 229u: goto tr169;
		case 237u: goto tr169;
		case 245u: goto tr169;
		case 253u: goto tr169;
	}
	goto tr168;
tr248:
#line 105 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_MODRM_BASE(REG_RIP);
    SET_MODRM_INDEX(NO_REG);
    SET_MODRM_SCALE(0);
  }
	goto st81;
tr189:
#line 98 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_MODRM_BASE(((*p) & 0x07) |
                   ((GET_REX_PREFIX() & 0x01) << 3) |
                   (((~GET_VEX_PREFIX2()) & 0x20) >> 2));
    SET_MODRM_INDEX(NO_REG);
    SET_MODRM_SCALE(0);
  }
	goto st81;
tr169:
#line 110 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_DISP_TYPE(DISPNONE);
    SET_MODRM_BASE(NO_REG);
    SET_MODRM_INDEX(index_registers[(((*p) & 0x38) >> 3) |
                                    ((GET_REX_PREFIX() & 0x02) << 2) |
                                    (((~GET_VEX_PREFIX2()) & 0x40) >> 3)]);
    SET_MODRM_SCALE(((*p) & 0xc0) >> 6);
  }
	goto st81;
tr176:
#line 118 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_DISP_TYPE(DISPNONE);
    SET_MODRM_BASE(((*p) & 0x7) |
                   ((GET_REX_PREFIX() & 0x01) << 3) |
                   (((~GET_VEX_PREFIX2()) & 0x20) >> 2));
    SET_MODRM_INDEX(index_registers[(((*p) & 0x38) >> 3) |
                                    ((GET_REX_PREFIX() & 0x02) << 2) |
                                    (((~GET_VEX_PREFIX2()) & 0x40) >> 3)]);
    SET_MODRM_SCALE(((*p) & 0xc0) >> 6);
  }
	goto st81;
tr162:
#line 389 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_NAME(0, (((*p) & 0x38) >> 3) |
                           ((GET_REX_PREFIX() & 0x04) << 1) |
                           (((~GET_VEX_PREFIX2()) & 0x80) >> 4));
  }
#line 105 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_MODRM_BASE(REG_RIP);
    SET_MODRM_INDEX(NO_REG);
    SET_MODRM_SCALE(0);
  }
	goto st81;
tr165:
#line 389 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_NAME(0, (((*p) & 0x38) >> 3) |
                           ((GET_REX_PREFIX() & 0x04) << 1) |
                           (((~GET_VEX_PREFIX2()) & 0x80) >> 4));
  }
#line 98 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_MODRM_BASE(((*p) & 0x07) |
                   ((GET_REX_PREFIX() & 0x01) << 3) |
                   (((~GET_VEX_PREFIX2()) & 0x20) >> 2));
    SET_MODRM_INDEX(NO_REG);
    SET_MODRM_SCALE(0);
  }
	goto st81;
tr606:
#line 295 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(0, OperandSize32bit);
  }
#line 397 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_NAME(0, ((~GET_VEX_PREFIX3()) & 0x78) >> 3);
  }
#line 98 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_MODRM_BASE(((*p) & 0x07) |
                   ((GET_REX_PREFIX() & 0x01) << 3) |
                   (((~GET_VEX_PREFIX2()) & 0x20) >> 2));
    SET_MODRM_INDEX(NO_REG);
    SET_MODRM_SCALE(0);
  }
	goto st81;
tr610:
#line 298 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(0, OperandSize64bit);
  }
#line 397 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_NAME(0, ((~GET_VEX_PREFIX3()) & 0x78) >> 3);
  }
#line 98 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_MODRM_BASE(((*p) & 0x07) |
                   ((GET_REX_PREFIX() & 0x01) << 3) |
                   (((~GET_VEX_PREFIX2()) & 0x20) >> 2));
    SET_MODRM_INDEX(NO_REG);
    SET_MODRM_SCALE(0);
  }
	goto st81;
tr626:
#line 295 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(0, OperandSize32bit);
  }
#line 397 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_NAME(0, ((~GET_VEX_PREFIX3()) & 0x78) >> 3);
  }
#line 105 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_MODRM_BASE(REG_RIP);
    SET_MODRM_INDEX(NO_REG);
    SET_MODRM_SCALE(0);
  }
	goto st81;
tr628:
#line 298 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(0, OperandSize64bit);
  }
#line 397 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_NAME(0, ((~GET_VEX_PREFIX3()) & 0x78) >> 3);
  }
#line 105 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_MODRM_BASE(REG_RIP);
    SET_MODRM_INDEX(NO_REG);
    SET_MODRM_SCALE(0);
  }
	goto st81;
st81:
	if ( ++p == pe )
		goto _test_eof81;
case 81:
#line 9430 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	goto st82;
st82:
	if ( ++p == pe )
		goto _test_eof82;
case 82:
	goto st83;
st83:
	if ( ++p == pe )
		goto _test_eof83;
case 83:
	goto st84;
st84:
	if ( ++p == pe )
		goto _test_eof84;
case 84:
	goto tr173;
tr187:
#line 98 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_MODRM_BASE(((*p) & 0x07) |
                   ((GET_REX_PREFIX() & 0x01) << 3) |
                   (((~GET_VEX_PREFIX2()) & 0x20) >> 2));
    SET_MODRM_INDEX(NO_REG);
    SET_MODRM_SCALE(0);
  }
	goto st85;
tr175:
#line 118 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_DISP_TYPE(DISPNONE);
    SET_MODRM_BASE(((*p) & 0x7) |
                   ((GET_REX_PREFIX() & 0x01) << 3) |
                   (((~GET_VEX_PREFIX2()) & 0x20) >> 2));
    SET_MODRM_INDEX(index_registers[(((*p) & 0x38) >> 3) |
                                    ((GET_REX_PREFIX() & 0x02) << 2) |
                                    (((~GET_VEX_PREFIX2()) & 0x40) >> 3)]);
    SET_MODRM_SCALE(((*p) & 0xc0) >> 6);
  }
	goto st85;
tr163:
#line 389 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_NAME(0, (((*p) & 0x38) >> 3) |
                           ((GET_REX_PREFIX() & 0x04) << 1) |
                           (((~GET_VEX_PREFIX2()) & 0x80) >> 4));
  }
#line 98 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_MODRM_BASE(((*p) & 0x07) |
                   ((GET_REX_PREFIX() & 0x01) << 3) |
                   (((~GET_VEX_PREFIX2()) & 0x20) >> 2));
    SET_MODRM_INDEX(NO_REG);
    SET_MODRM_SCALE(0);
  }
	goto st85;
tr605:
#line 295 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(0, OperandSize32bit);
  }
#line 397 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_NAME(0, ((~GET_VEX_PREFIX3()) & 0x78) >> 3);
  }
#line 98 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_MODRM_BASE(((*p) & 0x07) |
                   ((GET_REX_PREFIX() & 0x01) << 3) |
                   (((~GET_VEX_PREFIX2()) & 0x20) >> 2));
    SET_MODRM_INDEX(NO_REG);
    SET_MODRM_SCALE(0);
  }
	goto st85;
tr609:
#line 298 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(0, OperandSize64bit);
  }
#line 397 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_NAME(0, ((~GET_VEX_PREFIX3()) & 0x78) >> 3);
  }
#line 98 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_MODRM_BASE(((*p) & 0x07) |
                   ((GET_REX_PREFIX() & 0x01) << 3) |
                   (((~GET_VEX_PREFIX2()) & 0x20) >> 2));
    SET_MODRM_INDEX(NO_REG);
    SET_MODRM_SCALE(0);
  }
	goto st85;
st85:
	if ( ++p == pe )
		goto _test_eof85;
case 85:
#line 9526 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	goto tr174;
tr164:
#line 389 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_NAME(0, (((*p) & 0x38) >> 3) |
                           ((GET_REX_PREFIX() & 0x04) << 1) |
                           (((~GET_VEX_PREFIX2()) & 0x80) >> 4));
  }
	goto st86;
tr558:
#line 295 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(0, OperandSize32bit);
  }
#line 397 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_NAME(0, ((~GET_VEX_PREFIX3()) & 0x78) >> 3);
  }
	goto st86;
tr563:
#line 298 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(0, OperandSize64bit);
  }
#line 397 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_NAME(0, ((~GET_VEX_PREFIX3()) & 0x78) >> 3);
  }
	goto st86;
st86:
	if ( ++p == pe )
		goto _test_eof86;
case 86:
#line 9560 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	goto tr175;
tr166:
#line 389 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_NAME(0, (((*p) & 0x38) >> 3) |
                           ((GET_REX_PREFIX() & 0x04) << 1) |
                           (((~GET_VEX_PREFIX2()) & 0x80) >> 4));
  }
	goto st87;
tr559:
#line 295 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(0, OperandSize32bit);
  }
#line 397 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_NAME(0, ((~GET_VEX_PREFIX3()) & 0x78) >> 3);
  }
	goto st87;
tr564:
#line 298 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(0, OperandSize64bit);
  }
#line 397 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_NAME(0, ((~GET_VEX_PREFIX3()) & 0x78) >> 3);
  }
	goto st87;
st87:
	if ( ++p == pe )
		goto _test_eof87;
case 87:
#line 9594 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	goto tr176;
tr125:
#line 295 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(0, OperandSize32bit);
  }
	goto st88;
tr225:
#line 298 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(0, OperandSize64bit);
  }
	goto st88;
tr303:
#line 292 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(0, OperandSize16bit);
  }
	goto st88;
tr1001:
#line 329 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
        begin = p;
        BitmapSetBit(valid_targets, p - data);
        SET_REX_PREFIX(FALSE);
        SET_VEX_PREFIX2(0xe0);
        SET_VEX_PREFIX3(0x00);
        operand_states = 0;
     }
#line 295 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(0, OperandSize32bit);
  }
	goto st88;
st88:
	if ( ++p == pe )
		goto _test_eof88;
case 88:
#line 9633 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 4u: goto tr178;
		case 5u: goto tr179;
		case 12u: goto tr178;
		case 13u: goto tr179;
		case 20u: goto tr178;
		case 21u: goto tr179;
		case 28u: goto tr178;
		case 29u: goto tr179;
		case 36u: goto tr178;
		case 37u: goto tr179;
		case 44u: goto tr178;
		case 45u: goto tr179;
		case 52u: goto tr178;
		case 53u: goto tr179;
		case 60u: goto tr178;
		case 61u: goto tr179;
		case 68u: goto tr181;
		case 76u: goto tr181;
		case 84u: goto tr181;
		case 92u: goto tr181;
		case 100u: goto tr181;
		case 108u: goto tr181;
		case 116u: goto tr181;
		case 124u: goto tr181;
		case 132u: goto tr183;
		case 140u: goto tr183;
		case 148u: goto tr183;
		case 156u: goto tr183;
		case 164u: goto tr183;
		case 172u: goto tr183;
		case 180u: goto tr183;
		case 188u: goto tr183;
	}
	if ( (*p) < 64u ) {
		if ( (*p) <= 63u )
			goto tr177;
	} else if ( (*p) > 127u ) {
		if ( 128u <= (*p) && (*p) <= 191u )
			goto tr182;
	} else
		goto tr180;
	goto tr116;
st89:
	if ( ++p == pe )
		goto _test_eof89;
case 89:
	switch( (*p) ) {
		case 4u: goto st44;
		case 5u: goto tr33;
		case 12u: goto st44;
		case 13u: goto tr33;
		case 20u: goto st44;
		case 21u: goto tr33;
		case 28u: goto st44;
		case 29u: goto tr33;
		case 36u: goto st44;
		case 37u: goto tr33;
		case 44u: goto st44;
		case 45u: goto tr33;
		case 52u: goto st44;
		case 53u: goto tr33;
		case 60u: goto st44;
		case 61u: goto tr33;
		case 68u: goto st50;
		case 76u: goto st50;
		case 84u: goto st50;
		case 92u: goto st50;
		case 100u: goto st50;
		case 108u: goto st50;
		case 116u: goto st50;
		case 124u: goto st50;
		case 132u: goto st51;
		case 140u: goto st51;
		case 148u: goto st51;
		case 156u: goto st51;
		case 164u: goto st51;
		case 172u: goto st51;
		case 180u: goto st51;
		case 188u: goto st51;
	}
	if ( (*p) < 64u ) {
		if ( (*p) <= 63u )
			goto tr93;
	} else if ( (*p) > 127u ) {
		if ( (*p) > 191u ) {
			if ( 248u <= (*p) )
				goto st11;
		} else if ( (*p) >= 128u )
			goto tr98;
	} else
		goto tr96;
	goto tr184;
st90:
	if ( ++p == pe )
		goto _test_eof90;
case 90:
	switch( (*p) ) {
		case 4u: goto st80;
		case 5u: goto tr33;
		case 12u: goto st80;
		case 13u: goto tr33;
		case 20u: goto st80;
		case 21u: goto tr33;
		case 28u: goto st80;
		case 29u: goto tr33;
		case 36u: goto st80;
		case 37u: goto tr33;
		case 44u: goto st80;
		case 45u: goto tr33;
		case 52u: goto st80;
		case 53u: goto tr33;
		case 60u: goto st80;
		case 61u: goto tr33;
		case 68u: goto st86;
		case 76u: goto st86;
		case 84u: goto st86;
		case 92u: goto st86;
		case 100u: goto st86;
		case 108u: goto st86;
		case 116u: goto st86;
		case 124u: goto st86;
		case 132u: goto st87;
		case 140u: goto st87;
		case 148u: goto st87;
		case 156u: goto st87;
		case 164u: goto st87;
		case 172u: goto st87;
		case 180u: goto st87;
		case 188u: goto st87;
	}
	if ( (*p) < 64u ) {
		if ( (*p) <= 63u )
			goto tr185;
	} else if ( (*p) > 127u ) {
		if ( (*p) > 191u ) {
			if ( 248u <= (*p) )
				goto st12;
		} else if ( (*p) >= 128u )
			goto tr189;
	} else
		goto tr187;
	goto tr191;
st91:
	if ( ++p == pe )
		goto _test_eof91;
case 91:
	switch( (*p) ) {
		case 4u: goto st44;
		case 5u: goto tr33;
		case 12u: goto st44;
		case 13u: goto tr33;
		case 20u: goto st44;
		case 21u: goto tr33;
		case 28u: goto st44;
		case 29u: goto tr33;
		case 36u: goto st44;
		case 37u: goto tr33;
		case 44u: goto st44;
		case 45u: goto tr33;
		case 52u: goto st44;
		case 53u: goto tr33;
		case 60u: goto st44;
		case 61u: goto tr33;
		case 68u: goto st50;
		case 76u: goto st50;
		case 84u: goto st50;
		case 92u: goto st50;
		case 100u: goto st50;
		case 108u: goto st50;
		case 116u: goto st50;
		case 124u: goto st50;
		case 132u: goto st51;
		case 140u: goto st51;
		case 148u: goto st51;
		case 156u: goto st51;
		case 164u: goto st51;
		case 172u: goto st51;
		case 180u: goto st51;
		case 188u: goto st51;
	}
	if ( (*p) < 64u ) {
		if ( (*p) <= 63u )
			goto tr93;
	} else if ( (*p) > 127u ) {
		if ( (*p) > 191u ) {
			if ( 248u <= (*p) )
				goto st11;
		} else if ( (*p) >= 128u )
			goto tr98;
	} else
		goto tr96;
	goto tr115;
tr129:
#line 436 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(1, OperandSize8bit);
  }
#line 289 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(0, OperandSize8bit);
  }
	goto st92;
tr130:
#line 442 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(1, OperandSize32bit);
  }
#line 295 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(0, OperandSize32bit);
  }
	goto st92;
tr228:
#line 445 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(1, OperandSize64bit);
  }
#line 298 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(0, OperandSize64bit);
  }
	goto st92;
tr306:
#line 439 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(1, OperandSize16bit);
  }
#line 292 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(0, OperandSize16bit);
  }
	goto st92;
tr1006:
#line 329 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
        begin = p;
        BitmapSetBit(valid_targets, p - data);
        SET_REX_PREFIX(FALSE);
        SET_VEX_PREFIX2(0xe0);
        SET_VEX_PREFIX3(0x00);
        operand_states = 0;
     }
#line 436 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(1, OperandSize8bit);
  }
#line 289 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(0, OperandSize8bit);
  }
	goto st92;
tr1007:
#line 329 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
        begin = p;
        BitmapSetBit(valid_targets, p - data);
        SET_REX_PREFIX(FALSE);
        SET_VEX_PREFIX2(0xe0);
        SET_VEX_PREFIX3(0x00);
        operand_states = 0;
     }
#line 442 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(1, OperandSize32bit);
  }
#line 295 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(0, OperandSize32bit);
  }
	goto st92;
st92:
	if ( ++p == pe )
		goto _test_eof92;
case 92:
#line 9909 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 4u: goto tr194;
		case 5u: goto tr195;
		case 12u: goto tr194;
		case 13u: goto tr195;
		case 20u: goto tr194;
		case 21u: goto tr195;
		case 28u: goto tr194;
		case 29u: goto tr195;
		case 36u: goto tr194;
		case 37u: goto tr195;
		case 44u: goto tr194;
		case 45u: goto tr195;
		case 52u: goto tr194;
		case 53u: goto tr195;
		case 60u: goto tr194;
		case 61u: goto tr195;
		case 68u: goto tr197;
		case 76u: goto tr197;
		case 84u: goto tr197;
		case 92u: goto tr197;
		case 100u: goto tr197;
		case 108u: goto tr197;
		case 116u: goto tr197;
		case 124u: goto tr197;
		case 132u: goto tr199;
		case 140u: goto tr199;
		case 148u: goto tr199;
		case 156u: goto tr199;
		case 164u: goto tr199;
		case 172u: goto tr199;
		case 180u: goto tr199;
		case 188u: goto tr199;
	}
	if ( (*p) < 64u ) {
		if ( (*p) <= 63u )
			goto tr193;
	} else if ( (*p) > 127u ) {
		if ( 128u <= (*p) && (*p) <= 191u )
			goto tr198;
	} else
		goto tr196;
	goto tr200;
tr131:
#line 295 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(0, OperandSize32bit);
  }
	goto st93;
tr230:
#line 298 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(0, OperandSize64bit);
  }
	goto st93;
tr307:
#line 292 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(0, OperandSize16bit);
  }
	goto st93;
tr1008:
#line 329 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
        begin = p;
        BitmapSetBit(valid_targets, p - data);
        SET_REX_PREFIX(FALSE);
        SET_VEX_PREFIX2(0xe0);
        SET_VEX_PREFIX3(0x00);
        operand_states = 0;
     }
#line 295 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(0, OperandSize32bit);
  }
	goto st93;
st93:
	if ( ++p == pe )
		goto _test_eof93;
case 93:
#line 9990 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 4u: goto tr202;
		case 5u: goto tr203;
		case 12u: goto tr202;
		case 13u: goto tr203;
		case 20u: goto tr202;
		case 21u: goto tr203;
		case 28u: goto tr202;
		case 29u: goto tr203;
		case 36u: goto tr202;
		case 37u: goto tr203;
		case 44u: goto tr202;
		case 45u: goto tr203;
		case 52u: goto tr202;
		case 53u: goto tr203;
		case 60u: goto tr202;
		case 61u: goto tr203;
		case 68u: goto tr205;
		case 76u: goto tr205;
		case 84u: goto tr205;
		case 92u: goto tr205;
		case 100u: goto tr205;
		case 108u: goto tr205;
		case 116u: goto tr205;
		case 124u: goto tr205;
		case 132u: goto tr207;
		case 140u: goto tr207;
		case 148u: goto tr207;
		case 156u: goto tr207;
		case 164u: goto tr207;
		case 172u: goto tr207;
		case 180u: goto tr207;
		case 188u: goto tr207;
	}
	if ( (*p) < 64u ) {
		if ( (*p) <= 63u )
			goto tr201;
	} else if ( (*p) > 127u ) {
		if ( 128u <= (*p) && (*p) <= 191u )
			goto tr206;
	} else
		goto tr204;
	goto tr33;
st94:
	if ( ++p == pe )
		goto _test_eof94;
case 94:
	switch( (*p) ) {
		case 4u: goto st2;
		case 68u: goto st8;
		case 132u: goto st9;
	}
	if ( (*p) < 64u ) {
		if ( (*p) > 3u ) {
			if ( 6u <= (*p) && (*p) <= 7u )
				goto tr0;
		} else
			goto tr0;
	} else if ( (*p) > 71u ) {
		if ( (*p) > 135u ) {
			if ( 192u <= (*p) && (*p) <= 199u )
				goto tr208;
		} else if ( (*p) >= 128u )
			goto tr5;
	} else
		goto tr3;
	goto tr33;
st95:
	if ( ++p == pe )
		goto _test_eof95;
case 95:
	switch( (*p) ) {
		case 217u: goto st96;
		case 221u: goto st96;
	}
	goto tr33;
st96:
	if ( ++p == pe )
		goto _test_eof96;
case 96:
	switch( (*p) ) {
		case 52u: goto st2;
		case 60u: goto st2;
		case 116u: goto st8;
		case 124u: goto st8;
		case 180u: goto st9;
		case 188u: goto st9;
	}
	if ( (*p) < 62u ) {
		if ( (*p) > 51u ) {
			if ( 54u <= (*p) && (*p) <= 59u )
				goto tr0;
		} else if ( (*p) >= 48u )
			goto tr0;
	} else if ( (*p) > 63u ) {
		if ( (*p) > 127u ) {
			if ( 176u <= (*p) && (*p) <= 191u )
				goto tr5;
		} else if ( (*p) >= 112u )
			goto tr3;
	} else
		goto tr0;
	goto tr33;
st97:
	if ( ++p == pe )
		goto _test_eof97;
case 97:
	switch( (*p) ) {
		case 4u: goto st44;
		case 5u: goto tr33;
		case 12u: goto st44;
		case 13u: goto tr33;
		case 20u: goto st44;
		case 21u: goto tr33;
		case 28u: goto st44;
		case 29u: goto tr33;
		case 36u: goto st44;
		case 37u: goto tr33;
		case 44u: goto st44;
		case 45u: goto tr33;
		case 60u: goto st44;
		case 61u: goto tr33;
		case 68u: goto st50;
		case 76u: goto st50;
		case 84u: goto st50;
		case 92u: goto st50;
		case 100u: goto st50;
		case 108u: goto st50;
		case 124u: goto st50;
		case 132u: goto st51;
		case 140u: goto st51;
		case 148u: goto st51;
		case 156u: goto st51;
		case 164u: goto st51;
		case 172u: goto st51;
		case 188u: goto st51;
	}
	if ( (*p) < 112u ) {
		if ( (*p) < 48u ) {
			if ( (*p) <= 47u )
				goto tr93;
		} else if ( (*p) > 55u ) {
			if ( (*p) > 63u ) {
				if ( 64u <= (*p) && (*p) <= 111u )
					goto tr96;
			} else if ( (*p) >= 56u )
				goto tr93;
		} else
			goto tr33;
	} else if ( (*p) > 119u ) {
		if ( (*p) < 176u ) {
			if ( (*p) > 127u ) {
				if ( 128u <= (*p) && (*p) <= 175u )
					goto tr98;
			} else if ( (*p) >= 120u )
				goto tr96;
		} else if ( (*p) > 183u ) {
			if ( (*p) > 191u ) {
				if ( 240u <= (*p) && (*p) <= 247u )
					goto tr33;
			} else if ( (*p) >= 184u )
				goto tr98;
		} else
			goto tr33;
	} else
		goto tr33;
	goto tr184;
st98:
	if ( ++p == pe )
		goto _test_eof98;
case 98:
	switch( (*p) ) {
		case 4u: goto st44;
		case 5u: goto tr33;
		case 12u: goto st44;
		case 13u: goto tr33;
		case 20u: goto st44;
		case 21u: goto tr33;
		case 28u: goto st44;
		case 29u: goto tr33;
		case 36u: goto st44;
		case 37u: goto tr33;
		case 44u: goto st44;
		case 45u: goto tr33;
		case 60u: goto st44;
		case 61u: goto tr33;
		case 68u: goto st50;
		case 76u: goto st50;
		case 84u: goto st50;
		case 92u: goto st50;
		case 100u: goto st50;
		case 108u: goto st50;
		case 124u: goto st50;
		case 132u: goto st51;
		case 140u: goto st51;
		case 148u: goto st51;
		case 156u: goto st51;
		case 164u: goto st51;
		case 172u: goto st51;
		case 188u: goto st51;
	}
	if ( (*p) < 112u ) {
		if ( (*p) < 48u ) {
			if ( (*p) <= 47u )
				goto tr93;
		} else if ( (*p) > 55u ) {
			if ( (*p) > 63u ) {
				if ( 64u <= (*p) && (*p) <= 111u )
					goto tr96;
			} else if ( (*p) >= 56u )
				goto tr93;
		} else
			goto tr33;
	} else if ( (*p) > 119u ) {
		if ( (*p) < 176u ) {
			if ( (*p) > 127u ) {
				if ( 128u <= (*p) && (*p) <= 175u )
					goto tr98;
			} else if ( (*p) >= 120u )
				goto tr96;
		} else if ( (*p) > 183u ) {
			if ( (*p) > 191u ) {
				if ( 240u <= (*p) && (*p) <= 247u )
					goto tr33;
			} else if ( (*p) >= 184u )
				goto tr98;
		} else
			goto tr33;
	} else
		goto tr33;
	goto tr115;
st99:
	if ( ++p == pe )
		goto _test_eof99;
case 99:
	switch( (*p) ) {
		case 4u: goto st44;
		case 68u: goto st50;
		case 132u: goto st51;
	}
	if ( (*p) < 64u ) {
		if ( (*p) > 3u ) {
			if ( 6u <= (*p) && (*p) <= 7u )
				goto tr93;
		} else
			goto tr93;
	} else if ( (*p) > 71u ) {
		if ( (*p) > 135u ) {
			if ( 192u <= (*p) && (*p) <= 199u )
				goto tr184;
		} else if ( (*p) >= 128u )
			goto tr98;
	} else
		goto tr96;
	goto tr33;
st100:
	if ( ++p == pe )
		goto _test_eof100;
case 100:
	switch( (*p) ) {
		case 4u: goto st80;
		case 68u: goto st86;
		case 132u: goto st87;
	}
	if ( (*p) < 64u ) {
		if ( (*p) > 3u ) {
			if ( 6u <= (*p) && (*p) <= 7u )
				goto tr185;
		} else
			goto tr185;
	} else if ( (*p) > 71u ) {
		if ( (*p) > 135u ) {
			if ( 192u <= (*p) && (*p) <= 199u )
				goto tr191;
		} else if ( (*p) >= 128u )
			goto tr189;
	} else
		goto tr187;
	goto tr33;
st101:
	if ( ++p == pe )
		goto _test_eof101;
case 101:
	switch( (*p) ) {
		case 4u: goto st2;
		case 5u: goto tr33;
		case 12u: goto st2;
		case 13u: goto tr33;
		case 20u: goto st2;
		case 21u: goto tr33;
		case 28u: goto st2;
		case 29u: goto tr33;
		case 36u: goto st2;
		case 37u: goto tr33;
		case 44u: goto st2;
		case 45u: goto tr33;
		case 60u: goto st2;
		case 61u: goto tr33;
		case 68u: goto st8;
		case 76u: goto st8;
		case 84u: goto st8;
		case 92u: goto st8;
		case 100u: goto st8;
		case 108u: goto st8;
		case 124u: goto st8;
		case 132u: goto st9;
		case 140u: goto st9;
		case 148u: goto st9;
		case 156u: goto st9;
		case 164u: goto st9;
		case 172u: goto st9;
		case 188u: goto st9;
	}
	if ( (*p) < 112u ) {
		if ( (*p) < 48u ) {
			if ( (*p) <= 47u )
				goto tr0;
		} else if ( (*p) > 55u ) {
			if ( (*p) > 63u ) {
				if ( 64u <= (*p) && (*p) <= 111u )
					goto tr3;
			} else if ( (*p) >= 56u )
				goto tr0;
		} else
			goto tr33;
	} else if ( (*p) > 119u ) {
		if ( (*p) < 176u ) {
			if ( (*p) > 127u ) {
				if ( 128u <= (*p) && (*p) <= 175u )
					goto tr5;
			} else if ( (*p) >= 120u )
				goto tr3;
		} else if ( (*p) > 183u ) {
			if ( (*p) > 191u ) {
				if ( 240u <= (*p) && (*p) <= 247u )
					goto tr33;
			} else if ( (*p) >= 184u )
				goto tr5;
		} else
			goto tr33;
	} else
		goto tr33;
	goto tr210;
st102:
	if ( ++p == pe )
		goto _test_eof102;
case 102:
	switch( (*p) ) {
		case 4u: goto st2;
		case 5u: goto tr33;
		case 12u: goto st2;
		case 13u: goto tr33;
		case 20u: goto st2;
		case 21u: goto tr33;
		case 28u: goto st2;
		case 29u: goto tr33;
		case 36u: goto st2;
		case 37u: goto tr33;
		case 44u: goto st2;
		case 45u: goto tr33;
		case 60u: goto st2;
		case 61u: goto tr33;
		case 68u: goto st8;
		case 76u: goto st8;
		case 84u: goto st8;
		case 92u: goto st8;
		case 100u: goto st8;
		case 108u: goto st8;
		case 124u: goto st8;
		case 132u: goto st9;
		case 140u: goto st9;
		case 148u: goto st9;
		case 156u: goto st9;
		case 164u: goto st9;
		case 172u: goto st9;
		case 188u: goto st9;
	}
	if ( (*p) < 112u ) {
		if ( (*p) < 48u ) {
			if ( (*p) <= 47u )
				goto tr0;
		} else if ( (*p) > 55u ) {
			if ( (*p) > 63u ) {
				if ( 64u <= (*p) && (*p) <= 111u )
					goto tr3;
			} else if ( (*p) >= 56u )
				goto tr0;
		} else
			goto tr33;
	} else if ( (*p) > 119u ) {
		if ( (*p) < 176u ) {
			if ( (*p) > 127u ) {
				if ( 128u <= (*p) && (*p) <= 175u )
					goto tr5;
			} else if ( (*p) >= 120u )
				goto tr3;
		} else if ( (*p) > 183u ) {
			if ( (*p) > 191u ) {
				if ( 240u <= (*p) && (*p) <= 247u )
					goto tr33;
			} else if ( (*p) >= 184u )
				goto tr5;
		} else
			goto tr33;
	} else
		goto tr33;
	goto tr56;
st103:
	if ( ++p == pe )
		goto _test_eof103;
case 103:
	switch( (*p) ) {
		case 4u: goto st2;
		case 12u: goto st2;
		case 20u: goto st2;
		case 28u: goto st2;
		case 36u: goto st2;
		case 44u: goto st2;
		case 52u: goto st2;
		case 60u: goto st2;
		case 68u: goto st8;
		case 76u: goto st8;
		case 84u: goto st8;
		case 92u: goto st8;
		case 100u: goto st8;
		case 108u: goto st8;
		case 116u: goto st8;
		case 124u: goto st8;
		case 132u: goto st9;
		case 140u: goto st9;
		case 148u: goto st9;
		case 156u: goto st9;
		case 164u: goto st9;
		case 172u: goto st9;
		case 180u: goto st9;
		case 188u: goto st9;
	}
	if ( (*p) < 38u ) {
		if ( (*p) < 14u ) {
			if ( (*p) > 3u ) {
				if ( 6u <= (*p) && (*p) <= 11u )
					goto tr0;
			} else
				goto tr0;
		} else if ( (*p) > 19u ) {
			if ( (*p) > 27u ) {
				if ( 30u <= (*p) && (*p) <= 35u )
					goto tr0;
			} else if ( (*p) >= 22u )
				goto tr0;
		} else
			goto tr0;
	} else if ( (*p) > 43u ) {
		if ( (*p) < 62u ) {
			if ( (*p) > 51u ) {
				if ( 54u <= (*p) && (*p) <= 59u )
					goto tr0;
			} else if ( (*p) >= 46u )
				goto tr0;
		} else if ( (*p) > 63u ) {
			if ( (*p) > 127u ) {
				if ( 128u <= (*p) && (*p) <= 191u )
					goto tr5;
			} else if ( (*p) >= 64u )
				goto tr3;
		} else
			goto tr0;
	} else
		goto tr0;
	goto tr33;
st104:
	if ( ++p == pe )
		goto _test_eof104;
case 104:
	switch( (*p) ) {
		case 4u: goto st2;
		case 20u: goto st2;
		case 28u: goto st2;
		case 36u: goto st2;
		case 44u: goto st2;
		case 52u: goto st2;
		case 60u: goto st2;
		case 68u: goto st8;
		case 84u: goto st8;
		case 92u: goto st8;
		case 100u: goto st8;
		case 108u: goto st8;
		case 116u: goto st8;
		case 124u: goto st8;
		case 132u: goto st9;
		case 148u: goto st9;
		case 156u: goto st9;
		case 164u: goto st9;
		case 172u: goto st9;
		case 180u: goto st9;
		case 188u: goto st9;
	}
	if ( (*p) < 46u ) {
		if ( (*p) < 16u ) {
			if ( (*p) > 3u ) {
				if ( 6u <= (*p) && (*p) <= 7u )
					goto tr0;
			} else
				goto tr0;
		} else if ( (*p) > 19u ) {
			if ( (*p) < 30u ) {
				if ( 22u <= (*p) && (*p) <= 27u )
					goto tr0;
			} else if ( (*p) > 35u ) {
				if ( 38u <= (*p) && (*p) <= 43u )
					goto tr0;
			} else
				goto tr0;
		} else
			goto tr0;
	} else if ( (*p) > 51u ) {
		if ( (*p) < 64u ) {
			if ( (*p) > 59u ) {
				if ( 62u <= (*p) && (*p) <= 63u )
					goto tr0;
			} else if ( (*p) >= 54u )
				goto tr0;
		} else if ( (*p) > 71u ) {
			if ( (*p) < 128u ) {
				if ( 80u <= (*p) && (*p) <= 127u )
					goto tr3;
			} else if ( (*p) > 135u ) {
				if ( 144u <= (*p) && (*p) <= 191u )
					goto tr5;
			} else
				goto tr5;
		} else
			goto tr3;
	} else
		goto tr0;
	goto tr33;
st105:
	if ( ++p == pe )
		goto _test_eof105;
case 105:
	switch( (*p) ) {
		case 4u: goto st2;
		case 12u: goto st2;
		case 20u: goto st2;
		case 28u: goto st2;
		case 44u: goto st2;
		case 60u: goto st2;
		case 68u: goto st8;
		case 76u: goto st8;
		case 84u: goto st8;
		case 92u: goto st8;
		case 108u: goto st8;
		case 124u: goto st8;
		case 132u: goto st9;
		case 140u: goto st9;
		case 148u: goto st9;
		case 156u: goto st9;
		case 172u: goto st9;
		case 188u: goto st9;
	}
	if ( (*p) < 56u ) {
		if ( (*p) < 22u ) {
			if ( (*p) < 6u ) {
				if ( (*p) <= 3u )
					goto tr0;
			} else if ( (*p) > 11u ) {
				if ( 14u <= (*p) && (*p) <= 19u )
					goto tr0;
			} else
				goto tr0;
		} else if ( (*p) > 27u ) {
			if ( (*p) < 40u ) {
				if ( 30u <= (*p) && (*p) <= 31u )
					goto tr0;
			} else if ( (*p) > 43u ) {
				if ( 46u <= (*p) && (*p) <= 47u )
					goto tr0;
			} else
				goto tr0;
		} else
			goto tr0;
	} else if ( (*p) > 59u ) {
		if ( (*p) < 120u ) {
			if ( (*p) < 64u ) {
				if ( 62u <= (*p) && (*p) <= 63u )
					goto tr0;
			} else if ( (*p) > 95u ) {
				if ( 104u <= (*p) && (*p) <= 111u )
					goto tr3;
			} else
				goto tr3;
		} else if ( (*p) > 127u ) {
			if ( (*p) < 168u ) {
				if ( 128u <= (*p) && (*p) <= 159u )
					goto tr5;
			} else if ( (*p) > 175u ) {
				if ( 184u <= (*p) && (*p) <= 191u )
					goto tr5;
			} else
				goto tr5;
		} else
			goto tr3;
	} else
		goto tr0;
	goto tr33;
st106:
	if ( ++p == pe )
		goto _test_eof106;
case 106:
	switch( (*p) ) {
		case 4u: goto st2;
		case 12u: goto st2;
		case 20u: goto st2;
		case 28u: goto st2;
		case 36u: goto st2;
		case 52u: goto st2;
		case 60u: goto st2;
		case 68u: goto st8;
		case 76u: goto st8;
		case 84u: goto st8;
		case 92u: goto st8;
		case 100u: goto st8;
		case 116u: goto st8;
		case 124u: goto st8;
		case 132u: goto st9;
		case 140u: goto st9;
		case 148u: goto st9;
		case 156u: goto st9;
		case 164u: goto st9;
		case 180u: goto st9;
		case 188u: goto st9;
	}
	if ( (*p) < 48u ) {
		if ( (*p) < 14u ) {
			if ( (*p) > 3u ) {
				if ( 6u <= (*p) && (*p) <= 11u )
					goto tr0;
			} else
				goto tr0;
		} else if ( (*p) > 19u ) {
			if ( (*p) < 30u ) {
				if ( 22u <= (*p) && (*p) <= 27u )
					goto tr0;
			} else if ( (*p) > 35u ) {
				if ( 38u <= (*p) && (*p) <= 39u )
					goto tr0;
			} else
				goto tr0;
		} else
			goto tr0;
	} else if ( (*p) > 51u ) {
		if ( (*p) < 64u ) {
			if ( (*p) > 59u ) {
				if ( 62u <= (*p) && (*p) <= 63u )
					goto tr0;
			} else if ( (*p) >= 54u )
				goto tr0;
		} else if ( (*p) > 103u ) {
			if ( (*p) < 128u ) {
				if ( 112u <= (*p) && (*p) <= 127u )
					goto tr3;
			} else if ( (*p) > 167u ) {
				if ( 176u <= (*p) && (*p) <= 191u )
					goto tr5;
			} else
				goto tr5;
		} else
			goto tr3;
	} else
		goto tr0;
	goto tr33;
st107:
	if ( ++p == pe )
		goto _test_eof107;
case 107:
	switch( (*p) ) {
		case 4u: goto st44;
		case 5u: goto tr33;
		case 20u: goto st2;
		case 21u: goto tr33;
		case 28u: goto st2;
		case 29u: goto tr33;
		case 36u: goto st2;
		case 37u: goto tr33;
		case 44u: goto st2;
		case 45u: goto tr33;
		case 52u: goto st2;
		case 53u: goto tr33;
		case 60u: goto st2;
		case 61u: goto tr33;
		case 68u: goto st50;
		case 84u: goto st8;
		case 92u: goto st8;
		case 100u: goto st8;
		case 108u: goto st8;
		case 116u: goto st8;
		case 124u: goto st8;
		case 132u: goto st51;
		case 148u: goto st9;
		case 156u: goto st9;
		case 164u: goto st9;
		case 172u: goto st9;
		case 180u: goto st9;
		case 188u: goto st9;
	}
	if ( (*p) < 80u ) {
		if ( (*p) < 16u ) {
			if ( (*p) > 7u ) {
				if ( 8u <= (*p) && (*p) <= 15u )
					goto tr33;
			} else
				goto tr93;
		} else if ( (*p) > 63u ) {
			if ( (*p) > 71u ) {
				if ( 72u <= (*p) && (*p) <= 79u )
					goto tr33;
			} else if ( (*p) >= 64u )
				goto tr96;
		} else
			goto tr0;
	} else if ( (*p) > 127u ) {
		if ( (*p) < 144u ) {
			if ( (*p) > 135u ) {
				if ( 136u <= (*p) && (*p) <= 143u )
					goto tr33;
			} else if ( (*p) >= 128u )
				goto tr98;
		} else if ( (*p) > 191u ) {
			if ( (*p) > 199u ) {
				if ( 200u <= (*p) && (*p) <= 207u )
					goto tr33;
			} else if ( (*p) >= 192u )
				goto tr184;
		} else
			goto tr5;
	} else
		goto tr3;
	goto tr210;
st108:
	if ( ++p == pe )
		goto _test_eof108;
case 108:
	switch( (*p) ) {
		case 4u: goto st80;
		case 5u: goto tr33;
		case 20u: goto st2;
		case 21u: goto tr33;
		case 28u: goto st2;
		case 29u: goto tr33;
		case 36u: goto st2;
		case 37u: goto tr33;
		case 44u: goto st2;
		case 45u: goto tr33;
		case 52u: goto st2;
		case 53u: goto tr33;
		case 60u: goto st2;
		case 61u: goto tr33;
		case 68u: goto st86;
		case 84u: goto st8;
		case 92u: goto st8;
		case 100u: goto st8;
		case 108u: goto st8;
		case 116u: goto st8;
		case 124u: goto st8;
		case 132u: goto st87;
		case 148u: goto st9;
		case 156u: goto st9;
		case 164u: goto st9;
		case 172u: goto st9;
		case 180u: goto st9;
		case 188u: goto st9;
	}
	if ( (*p) < 80u ) {
		if ( (*p) < 16u ) {
			if ( (*p) > 7u ) {
				if ( 8u <= (*p) && (*p) <= 15u )
					goto tr33;
			} else
				goto tr185;
		} else if ( (*p) > 63u ) {
			if ( (*p) > 71u ) {
				if ( 72u <= (*p) && (*p) <= 79u )
					goto tr33;
			} else if ( (*p) >= 64u )
				goto tr187;
		} else
			goto tr0;
	} else if ( (*p) > 127u ) {
		if ( (*p) < 144u ) {
			if ( (*p) > 135u ) {
				if ( 136u <= (*p) && (*p) <= 143u )
					goto tr33;
			} else if ( (*p) >= 128u )
				goto tr189;
		} else if ( (*p) > 191u ) {
			if ( (*p) > 199u ) {
				if ( 200u <= (*p) && (*p) <= 207u )
					goto tr33;
			} else if ( (*p) >= 192u )
				goto tr191;
		} else
			goto tr5;
	} else
		goto tr3;
	goto tr56;
st109:
	if ( ++p == pe )
		goto _test_eof109;
case 109:
	switch( (*p) ) {
		case 4u: goto st2;
		case 12u: goto st2;
		case 68u: goto st8;
		case 76u: goto st8;
		case 132u: goto st9;
		case 140u: goto st9;
	}
	if ( (*p) < 14u ) {
		if ( (*p) > 3u ) {
			if ( 6u <= (*p) && (*p) <= 11u )
				goto tr0;
		} else
			goto tr0;
	} else if ( (*p) > 15u ) {
		if ( (*p) < 128u ) {
			if ( 64u <= (*p) && (*p) <= 79u )
				goto tr3;
		} else if ( (*p) > 143u ) {
			if ( 192u <= (*p) && (*p) <= 207u )
				goto tr210;
		} else
			goto tr5;
	} else
		goto tr0;
	goto tr33;
st110:
	if ( ++p == pe )
		goto _test_eof110;
case 110:
	switch( (*p) ) {
		case 4u: goto st2;
		case 12u: goto st2;
		case 52u: goto st2;
		case 68u: goto st8;
		case 76u: goto st8;
		case 116u: goto st8;
		case 132u: goto st9;
		case 140u: goto st9;
		case 180u: goto st9;
	}
	if ( (*p) < 64u ) {
		if ( (*p) < 14u ) {
			if ( (*p) > 3u ) {
				if ( 6u <= (*p) && (*p) <= 11u )
					goto tr0;
			} else
				goto tr0;
		} else if ( (*p) > 15u ) {
			if ( (*p) > 51u ) {
				if ( 54u <= (*p) && (*p) <= 55u )
					goto tr0;
			} else if ( (*p) >= 48u )
				goto tr0;
		} else
			goto tr0;
	} else if ( (*p) > 79u ) {
		if ( (*p) < 176u ) {
			if ( (*p) > 119u ) {
				if ( 128u <= (*p) && (*p) <= 143u )
					goto tr5;
			} else if ( (*p) >= 112u )
				goto tr3;
		} else if ( (*p) > 183u ) {
			if ( (*p) > 207u ) {
				if ( 240u <= (*p) && (*p) <= 247u )
					goto tr34;
			} else if ( (*p) >= 192u )
				goto tr56;
		} else
			goto tr5;
	} else
		goto tr3;
	goto tr33;
tr991:
#line 329 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
        begin = p;
        BitmapSetBit(valid_targets, p - data);
        SET_REX_PREFIX(FALSE);
        SET_VEX_PREFIX2(0xe0);
        SET_VEX_PREFIX3(0x00);
        operand_states = 0;
     }
#line 190 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_REX_PREFIX(*p);
  }
	goto st111;
st111:
	if ( ++p == pe )
		goto _test_eof111;
case 111:
#line 10893 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 0u: goto tr47;
		case 1u: goto tr45;
		case 2u: goto tr120;
		case 3u: goto tr32;
		case 8u: goto tr47;
		case 9u: goto tr45;
		case 10u: goto tr120;
		case 11u: goto tr32;
		case 15u: goto st69;
		case 16u: goto tr47;
		case 17u: goto tr45;
		case 18u: goto tr120;
		case 19u: goto tr32;
		case 24u: goto tr47;
		case 25u: goto tr45;
		case 26u: goto tr120;
		case 27u: goto tr32;
		case 32u: goto tr47;
		case 33u: goto tr45;
		case 34u: goto tr120;
		case 35u: goto tr32;
		case 40u: goto tr47;
		case 41u: goto tr45;
		case 42u: goto tr120;
		case 43u: goto tr32;
		case 48u: goto tr47;
		case 49u: goto tr45;
		case 50u: goto tr120;
		case 51u: goto tr32;
		case 99u: goto tr32;
		case 105u: goto tr124;
		case 107u: goto tr125;
		case 128u: goto st89;
		case 129u: goto st90;
		case 131u: goto st112;
		case 133u: goto tr45;
		case 134u: goto tr129;
		case 135u: goto tr130;
		case 137u: goto tr45;
		case 138u: goto tr120;
		case 139u: goto tr32;
		case 141u: goto tr131;
		case 143u: goto st94;
		case 155u: goto st95;
		case 192u: goto st97;
		case 193u: goto st98;
		case 198u: goto st99;
		case 199u: goto st100;
		case 209u: goto st102;
		case 211u: goto st102;
		case 217u: goto st104;
		case 219u: goto st105;
		case 221u: goto st106;
		case 246u: goto st107;
		case 247u: goto st108;
		case 254u: goto st109;
		case 255u: goto st110;
	}
	if ( (*p) < 145u ) {
		if ( (*p) < 80u ) {
			if ( 56u <= (*p) && (*p) <= 59u )
				goto st38;
		} else if ( (*p) > 87u ) {
			if ( (*p) > 95u ) {
				if ( 132u <= (*p) && (*p) <= 136u )
					goto tr47;
			} else if ( (*p) >= 88u )
				goto tr123;
		} else
			goto tr122;
	} else if ( (*p) > 151u ) {
		if ( (*p) < 184u ) {
			if ( 176u <= (*p) && (*p) <= 183u )
				goto tr135;
		} else if ( (*p) > 191u ) {
			if ( (*p) > 210u ) {
				if ( 216u <= (*p) && (*p) <= 223u )
					goto st103;
			} else if ( (*p) >= 208u )
				goto st101;
		} else
			goto tr136;
	} else
		goto tr133;
	goto tr33;
st112:
	if ( ++p == pe )
		goto _test_eof112;
case 112:
	switch( (*p) ) {
		case 4u: goto st44;
		case 5u: goto tr33;
		case 12u: goto st44;
		case 13u: goto tr33;
		case 20u: goto st44;
		case 21u: goto tr33;
		case 28u: goto st44;
		case 29u: goto tr33;
		case 36u: goto st44;
		case 37u: goto tr33;
		case 44u: goto st44;
		case 45u: goto tr33;
		case 52u: goto st44;
		case 53u: goto tr33;
		case 60u: goto st44;
		case 61u: goto tr33;
		case 68u: goto st50;
		case 76u: goto st50;
		case 84u: goto st50;
		case 92u: goto st50;
		case 100u: goto st50;
		case 108u: goto st50;
		case 116u: goto st50;
		case 124u: goto st50;
		case 132u: goto st51;
		case 140u: goto st51;
		case 148u: goto st51;
		case 156u: goto st51;
		case 164u: goto st51;
		case 172u: goto st51;
		case 180u: goto st51;
		case 188u: goto st51;
		case 224u: goto tr212;
		case 225u: goto tr213;
		case 226u: goto tr214;
		case 227u: goto tr215;
		case 228u: goto tr216;
		case 229u: goto tr217;
		case 230u: goto tr218;
	}
	if ( (*p) < 64u ) {
		if ( (*p) <= 63u )
			goto tr93;
	} else if ( (*p) > 127u ) {
		if ( (*p) > 247u ) {
			if ( 248u <= (*p) )
				goto st11;
		} else if ( (*p) >= 192u )
			goto tr115;
	} else
		goto tr96;
	goto tr98;
tr212:
#line 295 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(0, OperandSize32bit);
  }
#line 384 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_NAME(0, ((*p) & 0x07) |
                           ((GET_REX_PREFIX() & 0x01) << 3) |
                           (((~GET_VEX_PREFIX2()) & 0x20) >> 2));
  }
	goto st113;
st113:
	if ( ++p == pe )
		goto _test_eof113;
case 113:
#line 11053 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	if ( (*p) == 224u )
		goto tr219;
	goto tr25;
tr219:
#line 58 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_IMM_TYPE(IMM8);
    SET_IMM_PTR(p);
  }
#line 93 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    /* Restricted %rsp or %rbp must be processed by appropriate nacl-special
       instruction, not with regular instruction.  */
    if (restricted_register == REG_RSP) {
      PrintError("Incorrectly modified register %%rsp\n", begin - data);
      result = 1;
      goto error_detected;
    } else if (restricted_register == REG_RBP) {
      PrintError("Incorrectly modified register %%rbp\n", begin - data);
      result = 1;
      goto error_detected;
    }
    /* If Sandboxed Rsi is destroyed then we must note that.  */
    if (restricted_register == kSandboxedRsi) {
      if (CHECK_OPERAND(0, REG_RSI, OperandSandboxRestricted) ||
          CHECK_OPERAND(0, REG_RSI, OperandSandboxUnrestricted) ||
          CHECK_OPERAND(1, REG_RSI, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_RSI, OperandSandboxUnrestricted)) {
        restricted_register = kNoRestrictedReg;
      }
    }
    if (restricted_register == kSandboxedRsi) {
      if (CHECK_OPERAND(0, REG_RDI, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_RDI, OperandSandboxRestricted)) {
        sandboxed_rsi_restricted_rdi = begin;
        restricted_register = kSandboxedRsiRestrictedRdi;
      }
    }
    if (restricted_register != kSandboxedRsiRestrictedRdi) {
      restricted_register = kNoRestrictedReg;
      if (CHECK_OPERAND(0, REG_R15, OperandSandbox8bit) ||
          CHECK_OPERAND(0, REG_R15, OperandSandboxRestricted) ||
          CHECK_OPERAND(0, REG_R15, OperandSandboxUnrestricted) ||
          CHECK_OPERAND(1, REG_R15, OperandSandbox8bit) ||
          CHECK_OPERAND(1, REG_R15, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_R15, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%r15\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((CHECK_OPERAND(0, REG_RBP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(0, REG_RBP, OperandSandboxUnrestricted) ||
                 (CHECK_OPERAND(1, REG_RBP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(1, REG_RBP, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%rbp\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((CHECK_OPERAND(0, REG_RSP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(0, REG_RSP, OperandSandboxUnrestricted) ||
                 (CHECK_OPERAND(1, REG_RSP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(1, REG_RSP, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%rsp\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((operand_states & 0x70) == (OperandSandboxRestricted << 5)) {
        restricted_register = operand_states & 0x0f;
      } else if ((operand_states & 0x7000) ==
                                        (OperandSandboxRestricted << (5 + 8))) {
        restricted_register = (operand_states & 0x0f00) >> 8;
      }
    }
  }
#line 337 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
       /* On successful match the instruction start must point to the next byte
        * to be able to report the new offset as the start of instruction
        * causing error.  */
       begin = p + 1;
     }
	goto st722;
st722:
	if ( ++p == pe )
		goto _test_eof722;
case 722:
#line 11141 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 0u: goto tr978;
		case 1u: goto tr979;
		case 2u: goto tr980;
		case 3u: goto tr981;
		case 4u: goto tr982;
		case 5u: goto tr983;
		case 8u: goto tr978;
		case 9u: goto tr979;
		case 10u: goto tr980;
		case 11u: goto tr981;
		case 12u: goto tr982;
		case 13u: goto tr983;
		case 15u: goto tr984;
		case 16u: goto tr978;
		case 17u: goto tr979;
		case 18u: goto tr980;
		case 19u: goto tr981;
		case 20u: goto tr982;
		case 21u: goto tr983;
		case 24u: goto tr978;
		case 25u: goto tr979;
		case 26u: goto tr980;
		case 27u: goto tr981;
		case 28u: goto tr982;
		case 29u: goto tr983;
		case 32u: goto tr978;
		case 33u: goto tr979;
		case 34u: goto tr980;
		case 35u: goto tr981;
		case 36u: goto tr982;
		case 37u: goto tr983;
		case 40u: goto tr978;
		case 41u: goto tr979;
		case 42u: goto tr980;
		case 43u: goto tr981;
		case 44u: goto tr982;
		case 45u: goto tr983;
		case 46u: goto tr985;
		case 48u: goto tr978;
		case 49u: goto tr979;
		case 50u: goto tr980;
		case 51u: goto tr981;
		case 52u: goto tr982;
		case 53u: goto tr983;
		case 60u: goto tr987;
		case 61u: goto tr988;
		case 62u: goto tr989;
		case 65u: goto tr991;
		case 72u: goto tr992;
		case 73u: goto tr993;
		case 74u: goto tr994;
		case 76u: goto tr996;
		case 77u: goto tr1042;
		case 99u: goto tr981;
		case 102u: goto tr999;
		case 104u: goto tr988;
		case 105u: goto tr1000;
		case 106u: goto tr987;
		case 107u: goto tr1001;
		case 128u: goto tr1003;
		case 129u: goto tr1004;
		case 131u: goto tr1005;
		case 133u: goto tr979;
		case 134u: goto tr1006;
		case 135u: goto tr1007;
		case 137u: goto tr979;
		case 138u: goto tr980;
		case 139u: goto tr981;
		case 141u: goto tr1008;
		case 143u: goto tr1009;
		case 144u: goto tr1010;
		case 155u: goto tr1010;
		case 168u: goto tr982;
		case 169u: goto tr983;
		case 192u: goto tr1017;
		case 193u: goto tr1018;
		case 196u: goto tr1019;
		case 197u: goto tr1020;
		case 198u: goto tr1021;
		case 199u: goto tr1022;
		case 200u: goto tr1023;
		case 202u: goto tr1024;
		case 203u: goto tr1010;
		case 209u: goto tr1026;
		case 211u: goto tr1026;
		case 216u: goto tr986;
		case 217u: goto tr1027;
		case 218u: goto tr1028;
		case 219u: goto tr1029;
		case 220u: goto tr1030;
		case 221u: goto tr1031;
		case 222u: goto tr1032;
		case 223u: goto tr1033;
		case 235u: goto tr1002;
		case 240u: goto tr1035;
		case 242u: goto tr1036;
		case 243u: goto tr1037;
		case 246u: goto tr1038;
		case 247u: goto tr1039;
		case 254u: goto tr1040;
		case 255u: goto tr1041;
	}
	if ( (*p) < 164u ) {
		if ( (*p) < 88u ) {
			if ( (*p) < 64u ) {
				if ( 56u <= (*p) && (*p) <= 59u )
					goto tr986;
			} else if ( (*p) > 71u ) {
				if ( (*p) > 79u ) {
					if ( 80u <= (*p) && (*p) <= 87u )
						goto tr997;
				} else if ( (*p) >= 75u )
					goto tr995;
			} else
				goto tr990;
		} else if ( (*p) > 95u ) {
			if ( (*p) < 132u ) {
				if ( 112u <= (*p) && (*p) <= 127u )
					goto tr1002;
			} else if ( (*p) > 136u ) {
				if ( (*p) > 151u ) {
					if ( 152u <= (*p) && (*p) <= 153u )
						goto tr1010;
				} else if ( (*p) >= 145u )
					goto tr1011;
			} else
				goto tr978;
		} else
			goto tr998;
	} else if ( (*p) > 167u ) {
		if ( (*p) < 184u ) {
			if ( (*p) < 172u ) {
				if ( 170u <= (*p) && (*p) <= 171u )
					goto tr1013;
			} else if ( (*p) > 173u ) {
				if ( (*p) > 175u ) {
					if ( 176u <= (*p) && (*p) <= 183u )
						goto tr1015;
				} else if ( (*p) >= 174u )
					goto tr1013;
			} else
				goto tr1014;
		} else if ( (*p) > 191u ) {
			if ( (*p) < 232u ) {
				if ( 208u <= (*p) && (*p) <= 210u )
					goto tr1025;
			} else if ( (*p) > 233u ) {
				if ( (*p) > 249u ) {
					if ( 252u <= (*p) && (*p) <= 253u )
						goto tr1010;
				} else if ( (*p) >= 244u )
					goto tr1010;
			} else
				goto tr1034;
		} else
			goto tr1016;
	} else
		goto tr1012;
	goto tr33;
tr992:
#line 329 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
        begin = p;
        BitmapSetBit(valid_targets, p - data);
        SET_REX_PREFIX(FALSE);
        SET_VEX_PREFIX2(0xe0);
        SET_VEX_PREFIX3(0x00);
        operand_states = 0;
     }
#line 190 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_REX_PREFIX(*p);
  }
	goto st114;
st114:
	if ( ++p == pe )
		goto _test_eof114;
case 114:
#line 11321 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 1u: goto tr220;
		case 3u: goto tr221;
		case 5u: goto tr222;
		case 9u: goto tr220;
		case 11u: goto tr221;
		case 13u: goto tr222;
		case 15u: goto st115;
		case 17u: goto tr220;
		case 19u: goto tr221;
		case 21u: goto tr222;
		case 25u: goto tr220;
		case 27u: goto tr221;
		case 29u: goto tr222;
		case 33u: goto tr220;
		case 35u: goto tr221;
		case 37u: goto tr222;
		case 41u: goto tr220;
		case 43u: goto tr221;
		case 45u: goto tr222;
		case 49u: goto tr220;
		case 51u: goto tr221;
		case 53u: goto tr222;
		case 57u: goto st38;
		case 59u: goto st38;
		case 61u: goto st12;
		case 99u: goto tr221;
		case 104u: goto st12;
		case 105u: goto tr224;
		case 107u: goto tr225;
		case 129u: goto st119;
		case 131u: goto st124;
		case 133u: goto tr220;
		case 135u: goto tr228;
		case 137u: goto tr229;
		case 139u: goto tr221;
		case 141u: goto tr230;
		case 165u: goto tr232;
		case 167u: goto tr232;
		case 169u: goto tr222;
		case 171u: goto tr233;
		case 173u: goto tr234;
		case 175u: goto tr233;
		case 193u: goto st136;
		case 199u: goto st137;
		case 209u: goto st138;
		case 211u: goto st138;
		case 247u: goto st139;
		case 255u: goto st140;
	}
	if ( (*p) < 152u ) {
		if ( 145u <= (*p) && (*p) <= 151u )
			goto tr231;
	} else if ( (*p) > 153u ) {
		if ( 184u <= (*p) && (*p) <= 191u )
			goto tr235;
	} else
		goto tr34;
	goto tr33;
st115:
	if ( ++p == pe )
		goto _test_eof115;
case 115:
	switch( (*p) ) {
		case 0u: goto st116;
		case 1u: goto st117;
		case 31u: goto st41;
		case 110u: goto st38;
		case 126u: goto tr220;
		case 164u: goto tr243;
		case 165u: goto tr220;
		case 172u: goto tr243;
		case 173u: goto tr220;
		case 175u: goto tr221;
		case 177u: goto tr220;
		case 178u: goto tr244;
		case 186u: goto st118;
		case 193u: goto tr220;
		case 195u: goto st39;
		case 199u: goto st63;
	}
	if ( (*p) < 180u ) {
		if ( (*p) > 3u ) {
			if ( 64u <= (*p) && (*p) <= 79u )
				goto tr221;
		} else if ( (*p) >= 2u )
			goto tr221;
	} else if ( (*p) > 181u ) {
		if ( (*p) < 188u ) {
			if ( 182u <= (*p) && (*p) <= 183u )
				goto tr221;
		} else if ( (*p) > 191u ) {
			if ( 200u <= (*p) && (*p) <= 207u )
				goto tr246;
		} else
			goto tr221;
	} else
		goto tr244;
	goto tr33;
st116:
	if ( ++p == pe )
		goto _test_eof116;
case 116:
	if ( 200u <= (*p) && (*p) <= 207u )
		goto tr208;
	goto tr33;
st117:
	if ( ++p == pe )
		goto _test_eof117;
case 117:
	if ( 224u <= (*p) && (*p) <= 231u )
		goto tr208;
	goto tr33;
st118:
	if ( ++p == pe )
		goto _test_eof118;
case 118:
	switch( (*p) ) {
		case 36u: goto st44;
		case 37u: goto tr95;
		case 44u: goto st44;
		case 45u: goto tr95;
		case 52u: goto st44;
		case 53u: goto tr95;
		case 60u: goto st44;
		case 61u: goto tr95;
		case 100u: goto st50;
		case 108u: goto st50;
		case 116u: goto st50;
		case 124u: goto st50;
		case 164u: goto st51;
		case 172u: goto st51;
		case 180u: goto st51;
		case 188u: goto st51;
	}
	if ( (*p) < 96u ) {
		if ( 32u <= (*p) && (*p) <= 63u )
			goto tr93;
	} else if ( (*p) > 127u ) {
		if ( (*p) > 191u ) {
			if ( 224u <= (*p) )
				goto tr247;
		} else if ( (*p) >= 160u )
			goto tr98;
	} else
		goto tr96;
	goto tr33;
st119:
	if ( ++p == pe )
		goto _test_eof119;
case 119:
	switch( (*p) ) {
		case 4u: goto st80;
		case 5u: goto tr248;
		case 12u: goto st80;
		case 13u: goto tr248;
		case 20u: goto st80;
		case 21u: goto tr248;
		case 28u: goto st80;
		case 29u: goto tr248;
		case 36u: goto st80;
		case 37u: goto tr248;
		case 44u: goto st80;
		case 45u: goto tr248;
		case 52u: goto st80;
		case 53u: goto tr248;
		case 60u: goto st80;
		case 61u: goto tr248;
		case 68u: goto st86;
		case 76u: goto st86;
		case 84u: goto st86;
		case 92u: goto st86;
		case 100u: goto st86;
		case 108u: goto st86;
		case 116u: goto st86;
		case 124u: goto st86;
		case 132u: goto st87;
		case 140u: goto st87;
		case 148u: goto st87;
		case 156u: goto st87;
		case 164u: goto st87;
		case 172u: goto st87;
		case 180u: goto st87;
		case 188u: goto st87;
	}
	if ( (*p) < 192u ) {
		if ( (*p) > 63u ) {
			if ( 64u <= (*p) && (*p) <= 127u )
				goto tr187;
		} else
			goto tr185;
	} else if ( (*p) > 227u ) {
		if ( (*p) < 230u ) {
			if ( 228u <= (*p) && (*p) <= 229u )
				goto st120;
		} else if ( (*p) > 247u ) {
			if ( 248u <= (*p) )
				goto st12;
		} else
			goto tr249;
	} else
		goto tr249;
	goto tr189;
st120:
	if ( ++p == pe )
		goto _test_eof120;
case 120:
	goto st121;
st121:
	if ( ++p == pe )
		goto _test_eof121;
case 121:
	goto st122;
st122:
	if ( ++p == pe )
		goto _test_eof122;
case 122:
	goto st123;
st123:
	if ( ++p == pe )
		goto _test_eof123;
case 123:
	if ( (*p) <= 127u )
		goto tr33;
	goto tr254;
st124:
	if ( ++p == pe )
		goto _test_eof124;
case 124:
	switch( (*p) ) {
		case 4u: goto st44;
		case 5u: goto tr95;
		case 12u: goto st44;
		case 13u: goto tr95;
		case 20u: goto st44;
		case 21u: goto tr95;
		case 28u: goto st44;
		case 29u: goto tr95;
		case 36u: goto st44;
		case 37u: goto tr95;
		case 44u: goto st44;
		case 45u: goto tr95;
		case 52u: goto st44;
		case 53u: goto tr95;
		case 60u: goto st44;
		case 61u: goto tr95;
		case 68u: goto st50;
		case 76u: goto st50;
		case 84u: goto st50;
		case 92u: goto st50;
		case 100u: goto st50;
		case 108u: goto st50;
		case 116u: goto st50;
		case 124u: goto st50;
		case 132u: goto st51;
		case 140u: goto st51;
		case 148u: goto st51;
		case 156u: goto st51;
		case 164u: goto st51;
		case 172u: goto st51;
		case 180u: goto st51;
		case 188u: goto st51;
		case 228u: goto st125;
		case 229u: goto st126;
	}
	if ( (*p) < 64u ) {
		if ( (*p) <= 63u )
			goto tr93;
	} else if ( (*p) > 127u ) {
		if ( (*p) > 247u ) {
			if ( 248u <= (*p) )
				goto st11;
		} else if ( (*p) >= 192u )
			goto tr247;
	} else
		goto tr96;
	goto tr98;
st125:
	if ( ++p == pe )
		goto _test_eof125;
case 125:
	if ( (*p) <= 127u )
		goto tr33;
	goto tr257;
st126:
	if ( ++p == pe )
		goto _test_eof126;
case 126:
	if ( (*p) <= 127u )
		goto tr33;
	goto tr258;
tr229:
#line 298 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(0, OperandSize64bit);
  }
	goto st127;
st127:
	if ( ++p == pe )
		goto _test_eof127;
case 127:
#line 11623 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 4u: goto st2;
		case 5u: goto tr2;
		case 12u: goto st2;
		case 13u: goto tr2;
		case 20u: goto st2;
		case 21u: goto tr2;
		case 28u: goto st2;
		case 29u: goto tr2;
		case 36u: goto st2;
		case 37u: goto tr2;
		case 44u: goto st2;
		case 45u: goto tr2;
		case 52u: goto st2;
		case 53u: goto tr2;
		case 60u: goto st2;
		case 61u: goto tr2;
		case 68u: goto st8;
		case 76u: goto st8;
		case 84u: goto st8;
		case 92u: goto st8;
		case 100u: goto st8;
		case 108u: goto st8;
		case 116u: goto st8;
		case 124u: goto st8;
		case 132u: goto st9;
		case 140u: goto st9;
		case 148u: goto st9;
		case 156u: goto st9;
		case 164u: goto st9;
		case 172u: goto st9;
		case 180u: goto st9;
		case 188u: goto st9;
		case 229u: goto tr254;
		case 236u: goto tr254;
	}
	if ( (*p) < 64u ) {
		if ( (*p) <= 63u )
			goto tr0;
	} else if ( (*p) > 127u ) {
		if ( 128u <= (*p) && (*p) <= 191u )
			goto tr5;
	} else
		goto tr3;
	goto tr7;
tr235:
#line 376 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_NAME(0, ((*p) & 0x7) |
                            ((GET_REX_PREFIX() & 0x01) << 3) |
                            (((~GET_VEX_PREFIX2()) & 0x20) >> 2));
  }
#line 298 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(0, OperandSize64bit);
  }
	goto st128;
st128:
	if ( ++p == pe )
		goto _test_eof128;
case 128:
#line 11685 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	goto st129;
st129:
	if ( ++p == pe )
		goto _test_eof129;
case 129:
	goto st130;
st130:
	if ( ++p == pe )
		goto _test_eof130;
case 130:
	goto st131;
st131:
	if ( ++p == pe )
		goto _test_eof131;
case 131:
	goto st132;
st132:
	if ( ++p == pe )
		goto _test_eof132;
case 132:
	goto st133;
st133:
	if ( ++p == pe )
		goto _test_eof133;
case 133:
	goto st134;
st134:
	if ( ++p == pe )
		goto _test_eof134;
case 134:
	goto st135;
st135:
	if ( ++p == pe )
		goto _test_eof135;
case 135:
	goto tr266;
st136:
	if ( ++p == pe )
		goto _test_eof136;
case 136:
	switch( (*p) ) {
		case 4u: goto st44;
		case 5u: goto tr95;
		case 12u: goto st44;
		case 13u: goto tr95;
		case 20u: goto st44;
		case 21u: goto tr95;
		case 28u: goto st44;
		case 29u: goto tr95;
		case 36u: goto st44;
		case 37u: goto tr95;
		case 44u: goto st44;
		case 45u: goto tr95;
		case 60u: goto st44;
		case 61u: goto tr95;
		case 68u: goto st50;
		case 76u: goto st50;
		case 84u: goto st50;
		case 92u: goto st50;
		case 100u: goto st50;
		case 108u: goto st50;
		case 124u: goto st50;
		case 132u: goto st51;
		case 140u: goto st51;
		case 148u: goto st51;
		case 156u: goto st51;
		case 164u: goto st51;
		case 172u: goto st51;
		case 188u: goto st51;
	}
	if ( (*p) < 112u ) {
		if ( (*p) < 48u ) {
			if ( (*p) <= 47u )
				goto tr93;
		} else if ( (*p) > 55u ) {
			if ( (*p) > 63u ) {
				if ( 64u <= (*p) && (*p) <= 111u )
					goto tr96;
			} else if ( (*p) >= 56u )
				goto tr93;
		} else
			goto tr33;
	} else if ( (*p) > 119u ) {
		if ( (*p) < 176u ) {
			if ( (*p) > 127u ) {
				if ( 128u <= (*p) && (*p) <= 175u )
					goto tr98;
			} else if ( (*p) >= 120u )
				goto tr96;
		} else if ( (*p) > 183u ) {
			if ( (*p) > 191u ) {
				if ( 240u <= (*p) && (*p) <= 247u )
					goto tr33;
			} else if ( (*p) >= 184u )
				goto tr98;
		} else
			goto tr33;
	} else
		goto tr33;
	goto tr247;
st137:
	if ( ++p == pe )
		goto _test_eof137;
case 137:
	switch( (*p) ) {
		case 4u: goto st80;
		case 5u: goto tr248;
		case 68u: goto st86;
		case 132u: goto st87;
	}
	if ( (*p) < 64u ) {
		if ( (*p) <= 7u )
			goto tr185;
	} else if ( (*p) > 71u ) {
		if ( (*p) > 135u ) {
			if ( 192u <= (*p) && (*p) <= 199u )
				goto tr249;
		} else if ( (*p) >= 128u )
			goto tr189;
	} else
		goto tr187;
	goto tr33;
st138:
	if ( ++p == pe )
		goto _test_eof138;
case 138:
	switch( (*p) ) {
		case 4u: goto st2;
		case 5u: goto tr2;
		case 12u: goto st2;
		case 13u: goto tr2;
		case 20u: goto st2;
		case 21u: goto tr2;
		case 28u: goto st2;
		case 29u: goto tr2;
		case 36u: goto st2;
		case 37u: goto tr2;
		case 44u: goto st2;
		case 45u: goto tr2;
		case 60u: goto st2;
		case 61u: goto tr2;
		case 68u: goto st8;
		case 76u: goto st8;
		case 84u: goto st8;
		case 92u: goto st8;
		case 100u: goto st8;
		case 108u: goto st8;
		case 124u: goto st8;
		case 132u: goto st9;
		case 140u: goto st9;
		case 148u: goto st9;
		case 156u: goto st9;
		case 164u: goto st9;
		case 172u: goto st9;
		case 188u: goto st9;
	}
	if ( (*p) < 112u ) {
		if ( (*p) < 48u ) {
			if ( (*p) <= 47u )
				goto tr0;
		} else if ( (*p) > 55u ) {
			if ( (*p) > 63u ) {
				if ( 64u <= (*p) && (*p) <= 111u )
					goto tr3;
			} else if ( (*p) >= 56u )
				goto tr0;
		} else
			goto tr33;
	} else if ( (*p) > 119u ) {
		if ( (*p) < 176u ) {
			if ( (*p) > 127u ) {
				if ( 128u <= (*p) && (*p) <= 175u )
					goto tr5;
			} else if ( (*p) >= 120u )
				goto tr3;
		} else if ( (*p) > 183u ) {
			if ( (*p) > 191u ) {
				if ( 240u <= (*p) && (*p) <= 247u )
					goto tr33;
			} else if ( (*p) >= 184u )
				goto tr5;
		} else
			goto tr33;
	} else
		goto tr33;
	goto tr208;
st139:
	if ( ++p == pe )
		goto _test_eof139;
case 139:
	switch( (*p) ) {
		case 4u: goto st80;
		case 5u: goto tr248;
		case 20u: goto st2;
		case 21u: goto tr2;
		case 28u: goto st2;
		case 29u: goto tr2;
		case 36u: goto st2;
		case 37u: goto tr2;
		case 44u: goto st2;
		case 45u: goto tr2;
		case 52u: goto st2;
		case 53u: goto tr2;
		case 60u: goto st2;
		case 61u: goto tr2;
		case 68u: goto st86;
		case 84u: goto st8;
		case 92u: goto st8;
		case 100u: goto st8;
		case 108u: goto st8;
		case 116u: goto st8;
		case 124u: goto st8;
		case 132u: goto st87;
		case 148u: goto st9;
		case 156u: goto st9;
		case 164u: goto st9;
		case 172u: goto st9;
		case 180u: goto st9;
		case 188u: goto st9;
	}
	if ( (*p) < 80u ) {
		if ( (*p) < 16u ) {
			if ( (*p) > 7u ) {
				if ( 8u <= (*p) && (*p) <= 15u )
					goto tr33;
			} else
				goto tr185;
		} else if ( (*p) > 63u ) {
			if ( (*p) > 71u ) {
				if ( 72u <= (*p) && (*p) <= 79u )
					goto tr33;
			} else if ( (*p) >= 64u )
				goto tr187;
		} else
			goto tr0;
	} else if ( (*p) > 127u ) {
		if ( (*p) < 144u ) {
			if ( (*p) > 135u ) {
				if ( 136u <= (*p) && (*p) <= 143u )
					goto tr33;
			} else if ( (*p) >= 128u )
				goto tr189;
		} else if ( (*p) > 191u ) {
			if ( (*p) > 199u ) {
				if ( 200u <= (*p) && (*p) <= 207u )
					goto tr33;
			} else if ( (*p) >= 192u )
				goto tr249;
		} else
			goto tr5;
	} else
		goto tr3;
	goto tr208;
st140:
	if ( ++p == pe )
		goto _test_eof140;
case 140:
	switch( (*p) ) {
		case 4u: goto st2;
		case 5u: goto tr2;
		case 12u: goto st2;
		case 13u: goto tr2;
		case 68u: goto st8;
		case 76u: goto st8;
		case 132u: goto st9;
		case 140u: goto st9;
	}
	if ( (*p) < 64u ) {
		if ( (*p) <= 15u )
			goto tr0;
	} else if ( (*p) > 79u ) {
		if ( (*p) > 143u ) {
			if ( 192u <= (*p) && (*p) <= 207u )
				goto tr208;
		} else if ( (*p) >= 128u )
			goto tr5;
	} else
		goto tr3;
	goto tr33;
tr993:
#line 329 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
        begin = p;
        BitmapSetBit(valid_targets, p - data);
        SET_REX_PREFIX(FALSE);
        SET_VEX_PREFIX2(0xe0);
        SET_VEX_PREFIX3(0x00);
        operand_states = 0;
     }
#line 190 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_REX_PREFIX(*p);
  }
	goto st141;
st141:
	if ( ++p == pe )
		goto _test_eof141;
case 141:
#line 11984 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 1u: goto tr220;
		case 3u: goto tr221;
		case 9u: goto tr220;
		case 11u: goto tr221;
		case 15u: goto st142;
		case 17u: goto tr220;
		case 19u: goto tr221;
		case 25u: goto tr220;
		case 27u: goto tr221;
		case 33u: goto tr220;
		case 35u: goto tr221;
		case 41u: goto tr220;
		case 43u: goto tr221;
		case 49u: goto tr220;
		case 51u: goto tr221;
		case 57u: goto st38;
		case 59u: goto st38;
		case 99u: goto tr221;
		case 105u: goto tr224;
		case 107u: goto tr225;
		case 129u: goto st144;
		case 131u: goto st145;
		case 133u: goto tr220;
		case 135u: goto tr228;
		case 137u: goto tr220;
		case 139u: goto tr221;
		case 141u: goto tr270;
		case 193u: goto st150;
		case 199u: goto st151;
		case 209u: goto st152;
		case 211u: goto st152;
		case 247u: goto st153;
		case 255u: goto st154;
	}
	if ( (*p) > 151u ) {
		if ( 184u <= (*p) && (*p) <= 191u )
			goto tr235;
	} else if ( (*p) >= 145u )
		goto tr231;
	goto tr33;
st142:
	if ( ++p == pe )
		goto _test_eof142;
case 142:
	switch( (*p) ) {
		case 0u: goto st116;
		case 1u: goto st117;
		case 31u: goto st74;
		case 110u: goto st38;
		case 126u: goto tr220;
		case 164u: goto tr243;
		case 165u: goto tr220;
		case 172u: goto tr243;
		case 173u: goto tr220;
		case 175u: goto tr221;
		case 177u: goto tr220;
		case 178u: goto tr244;
		case 186u: goto st143;
		case 193u: goto tr220;
		case 195u: goto st39;
		case 199u: goto st78;
	}
	if ( (*p) < 180u ) {
		if ( (*p) > 3u ) {
			if ( 64u <= (*p) && (*p) <= 79u )
				goto tr221;
		} else if ( (*p) >= 2u )
			goto tr221;
	} else if ( (*p) > 181u ) {
		if ( (*p) < 188u ) {
			if ( 182u <= (*p) && (*p) <= 183u )
				goto tr221;
		} else if ( (*p) > 191u ) {
			if ( 200u <= (*p) && (*p) <= 207u )
				goto tr246;
		} else
			goto tr221;
	} else
		goto tr244;
	goto tr33;
st143:
	if ( ++p == pe )
		goto _test_eof143;
case 143:
	switch( (*p) ) {
		case 36u: goto st44;
		case 44u: goto st44;
		case 52u: goto st44;
		case 60u: goto st44;
		case 100u: goto st50;
		case 108u: goto st50;
		case 116u: goto st50;
		case 124u: goto st50;
		case 164u: goto st51;
		case 172u: goto st51;
		case 180u: goto st51;
		case 188u: goto st51;
	}
	if ( (*p) < 54u ) {
		if ( (*p) < 38u ) {
			if ( 32u <= (*p) && (*p) <= 35u )
				goto tr93;
		} else if ( (*p) > 43u ) {
			if ( 46u <= (*p) && (*p) <= 51u )
				goto tr93;
		} else
			goto tr93;
	} else if ( (*p) > 59u ) {
		if ( (*p) < 96u ) {
			if ( 62u <= (*p) && (*p) <= 63u )
				goto tr93;
		} else if ( (*p) > 127u ) {
			if ( (*p) > 191u ) {
				if ( 224u <= (*p) )
					goto tr247;
			} else if ( (*p) >= 160u )
				goto tr98;
		} else
			goto tr96;
	} else
		goto tr93;
	goto tr33;
st144:
	if ( ++p == pe )
		goto _test_eof144;
case 144:
	switch( (*p) ) {
		case 4u: goto st80;
		case 5u: goto tr33;
		case 12u: goto st80;
		case 13u: goto tr33;
		case 20u: goto st80;
		case 21u: goto tr33;
		case 28u: goto st80;
		case 29u: goto tr33;
		case 36u: goto st80;
		case 37u: goto tr33;
		case 44u: goto st80;
		case 45u: goto tr33;
		case 52u: goto st80;
		case 53u: goto tr33;
		case 60u: goto st80;
		case 61u: goto tr33;
		case 68u: goto st86;
		case 76u: goto st86;
		case 84u: goto st86;
		case 92u: goto st86;
		case 100u: goto st86;
		case 108u: goto st86;
		case 116u: goto st86;
		case 124u: goto st86;
		case 132u: goto st87;
		case 140u: goto st87;
		case 148u: goto st87;
		case 156u: goto st87;
		case 164u: goto st87;
		case 172u: goto st87;
		case 180u: goto st87;
		case 188u: goto st87;
	}
	if ( (*p) < 64u ) {
		if ( (*p) <= 63u )
			goto tr185;
	} else if ( (*p) > 127u ) {
		if ( (*p) > 191u ) {
			if ( 248u <= (*p) )
				goto st12;
		} else if ( (*p) >= 128u )
			goto tr189;
	} else
		goto tr187;
	goto tr249;
st145:
	if ( ++p == pe )
		goto _test_eof145;
case 145:
	switch( (*p) ) {
		case 4u: goto st44;
		case 5u: goto tr33;
		case 12u: goto st44;
		case 13u: goto tr33;
		case 20u: goto st44;
		case 21u: goto tr33;
		case 28u: goto st44;
		case 29u: goto tr33;
		case 36u: goto st44;
		case 37u: goto tr33;
		case 44u: goto st44;
		case 45u: goto tr33;
		case 52u: goto st44;
		case 53u: goto tr33;
		case 60u: goto st44;
		case 61u: goto tr33;
		case 68u: goto st50;
		case 76u: goto st50;
		case 84u: goto st50;
		case 92u: goto st50;
		case 100u: goto st50;
		case 108u: goto st50;
		case 116u: goto st50;
		case 124u: goto st50;
		case 132u: goto st51;
		case 140u: goto st51;
		case 148u: goto st51;
		case 156u: goto st51;
		case 164u: goto st51;
		case 172u: goto st51;
		case 180u: goto st51;
		case 188u: goto st51;
	}
	if ( (*p) < 64u ) {
		if ( (*p) <= 63u )
			goto tr93;
	} else if ( (*p) > 127u ) {
		if ( (*p) > 191u ) {
			if ( 248u <= (*p) )
				goto st11;
		} else if ( (*p) >= 128u )
			goto tr98;
	} else
		goto tr96;
	goto tr247;
tr270:
#line 298 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(0, OperandSize64bit);
  }
	goto st146;
st146:
	if ( ++p == pe )
		goto _test_eof146;
case 146:
#line 12218 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 4u: goto tr202;
		case 5u: goto tr203;
		case 12u: goto tr202;
		case 13u: goto tr203;
		case 20u: goto tr202;
		case 21u: goto tr203;
		case 28u: goto tr202;
		case 29u: goto tr203;
		case 36u: goto tr202;
		case 37u: goto tr203;
		case 44u: goto tr277;
		case 45u: goto tr203;
		case 52u: goto tr278;
		case 53u: goto tr203;
		case 60u: goto tr279;
		case 61u: goto tr203;
		case 68u: goto tr205;
		case 76u: goto tr205;
		case 84u: goto tr205;
		case 92u: goto tr205;
		case 100u: goto tr205;
		case 108u: goto tr205;
		case 116u: goto tr205;
		case 124u: goto tr205;
		case 132u: goto tr207;
		case 140u: goto tr207;
		case 148u: goto tr207;
		case 156u: goto tr207;
		case 164u: goto tr207;
		case 172u: goto tr207;
		case 180u: goto tr207;
		case 188u: goto tr207;
	}
	if ( (*p) < 64u ) {
		if ( (*p) <= 63u )
			goto tr201;
	} else if ( (*p) > 127u ) {
		if ( 128u <= (*p) && (*p) <= 191u )
			goto tr206;
	} else
		goto tr204;
	goto tr33;
tr277:
#line 389 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_NAME(0, (((*p) & 0x38) >> 3) |
                           ((GET_REX_PREFIX() & 0x04) << 1) |
                           (((~GET_VEX_PREFIX2()) & 0x80) >> 4));
  }
	goto st147;
st147:
	if ( ++p == pe )
		goto _test_eof147;
case 147:
#line 12274 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 5u: goto tr68;
		case 13u: goto tr68;
		case 21u: goto tr68;
		case 29u: goto tr68;
		case 37u: goto tr68;
		case 45u: goto tr68;
		case 47u: goto tr280;
		case 53u: goto tr68;
		case 61u: goto tr68;
		case 69u: goto tr68;
		case 77u: goto tr68;
		case 85u: goto tr68;
		case 93u: goto tr68;
		case 101u: goto tr68;
		case 109u: goto tr68;
		case 117u: goto tr68;
		case 125u: goto tr68;
		case 133u: goto tr68;
		case 141u: goto tr68;
		case 149u: goto tr68;
		case 157u: goto tr68;
		case 165u: goto tr68;
		case 173u: goto tr68;
		case 181u: goto tr68;
		case 189u: goto tr68;
		case 197u: goto tr68;
		case 205u: goto tr68;
		case 213u: goto tr68;
		case 221u: goto tr68;
		case 229u: goto tr68;
		case 237u: goto tr68;
		case 245u: goto tr68;
		case 253u: goto tr68;
	}
	goto tr67;
tr278:
#line 389 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_NAME(0, (((*p) & 0x38) >> 3) |
                           ((GET_REX_PREFIX() & 0x04) << 1) |
                           (((~GET_VEX_PREFIX2()) & 0x80) >> 4));
  }
	goto st148;
st148:
	if ( ++p == pe )
		goto _test_eof148;
case 148:
#line 12323 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 5u: goto tr68;
		case 13u: goto tr68;
		case 21u: goto tr68;
		case 29u: goto tr68;
		case 37u: goto tr68;
		case 45u: goto tr68;
		case 53u: goto tr68;
		case 55u: goto tr281;
		case 61u: goto tr68;
		case 69u: goto tr68;
		case 77u: goto tr68;
		case 85u: goto tr68;
		case 93u: goto tr68;
		case 101u: goto tr68;
		case 109u: goto tr68;
		case 117u: goto tr68;
		case 125u: goto tr68;
		case 133u: goto tr68;
		case 141u: goto tr68;
		case 149u: goto tr68;
		case 157u: goto tr68;
		case 165u: goto tr68;
		case 173u: goto tr68;
		case 181u: goto tr68;
		case 189u: goto tr68;
		case 197u: goto tr68;
		case 205u: goto tr68;
		case 213u: goto tr68;
		case 221u: goto tr68;
		case 229u: goto tr68;
		case 237u: goto tr68;
		case 245u: goto tr68;
		case 253u: goto tr68;
	}
	goto tr67;
tr279:
#line 389 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_NAME(0, (((*p) & 0x38) >> 3) |
                           ((GET_REX_PREFIX() & 0x04) << 1) |
                           (((~GET_VEX_PREFIX2()) & 0x80) >> 4));
  }
	goto st149;
st149:
	if ( ++p == pe )
		goto _test_eof149;
case 149:
#line 12372 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 5u: goto tr68;
		case 13u: goto tr68;
		case 21u: goto tr68;
		case 29u: goto tr68;
		case 37u: goto tr68;
		case 45u: goto tr68;
		case 53u: goto tr68;
		case 61u: goto tr68;
		case 63u: goto tr282;
		case 69u: goto tr68;
		case 77u: goto tr68;
		case 85u: goto tr68;
		case 93u: goto tr68;
		case 101u: goto tr68;
		case 109u: goto tr68;
		case 117u: goto tr68;
		case 125u: goto tr68;
		case 133u: goto tr68;
		case 141u: goto tr68;
		case 149u: goto tr68;
		case 157u: goto tr68;
		case 165u: goto tr68;
		case 173u: goto tr68;
		case 181u: goto tr68;
		case 189u: goto tr68;
		case 197u: goto tr68;
		case 205u: goto tr68;
		case 213u: goto tr68;
		case 221u: goto tr68;
		case 229u: goto tr68;
		case 237u: goto tr68;
		case 245u: goto tr68;
		case 253u: goto tr68;
	}
	goto tr67;
st150:
	if ( ++p == pe )
		goto _test_eof150;
case 150:
	switch( (*p) ) {
		case 4u: goto st44;
		case 5u: goto tr33;
		case 12u: goto st44;
		case 13u: goto tr33;
		case 20u: goto st44;
		case 21u: goto tr33;
		case 28u: goto st44;
		case 29u: goto tr33;
		case 36u: goto st44;
		case 37u: goto tr33;
		case 44u: goto st44;
		case 45u: goto tr33;
		case 60u: goto st44;
		case 61u: goto tr33;
		case 68u: goto st50;
		case 76u: goto st50;
		case 84u: goto st50;
		case 92u: goto st50;
		case 100u: goto st50;
		case 108u: goto st50;
		case 124u: goto st50;
		case 132u: goto st51;
		case 140u: goto st51;
		case 148u: goto st51;
		case 156u: goto st51;
		case 164u: goto st51;
		case 172u: goto st51;
		case 188u: goto st51;
	}
	if ( (*p) < 112u ) {
		if ( (*p) < 48u ) {
			if ( (*p) <= 47u )
				goto tr93;
		} else if ( (*p) > 55u ) {
			if ( (*p) > 63u ) {
				if ( 64u <= (*p) && (*p) <= 111u )
					goto tr96;
			} else if ( (*p) >= 56u )
				goto tr93;
		} else
			goto tr33;
	} else if ( (*p) > 119u ) {
		if ( (*p) < 176u ) {
			if ( (*p) > 127u ) {
				if ( 128u <= (*p) && (*p) <= 175u )
					goto tr98;
			} else if ( (*p) >= 120u )
				goto tr96;
		} else if ( (*p) > 183u ) {
			if ( (*p) > 191u ) {
				if ( 240u <= (*p) && (*p) <= 247u )
					goto tr33;
			} else if ( (*p) >= 184u )
				goto tr98;
		} else
			goto tr33;
	} else
		goto tr33;
	goto tr247;
st151:
	if ( ++p == pe )
		goto _test_eof151;
case 151:
	switch( (*p) ) {
		case 4u: goto st80;
		case 68u: goto st86;
		case 132u: goto st87;
	}
	if ( (*p) < 64u ) {
		if ( (*p) > 3u ) {
			if ( 6u <= (*p) && (*p) <= 7u )
				goto tr185;
		} else
			goto tr185;
	} else if ( (*p) > 71u ) {
		if ( (*p) > 135u ) {
			if ( 192u <= (*p) && (*p) <= 199u )
				goto tr249;
		} else if ( (*p) >= 128u )
			goto tr189;
	} else
		goto tr187;
	goto tr33;
st152:
	if ( ++p == pe )
		goto _test_eof152;
case 152:
	switch( (*p) ) {
		case 4u: goto st2;
		case 5u: goto tr33;
		case 12u: goto st2;
		case 13u: goto tr33;
		case 20u: goto st2;
		case 21u: goto tr33;
		case 28u: goto st2;
		case 29u: goto tr33;
		case 36u: goto st2;
		case 37u: goto tr33;
		case 44u: goto st2;
		case 45u: goto tr33;
		case 60u: goto st2;
		case 61u: goto tr33;
		case 68u: goto st8;
		case 76u: goto st8;
		case 84u: goto st8;
		case 92u: goto st8;
		case 100u: goto st8;
		case 108u: goto st8;
		case 124u: goto st8;
		case 132u: goto st9;
		case 140u: goto st9;
		case 148u: goto st9;
		case 156u: goto st9;
		case 164u: goto st9;
		case 172u: goto st9;
		case 188u: goto st9;
	}
	if ( (*p) < 112u ) {
		if ( (*p) < 48u ) {
			if ( (*p) <= 47u )
				goto tr0;
		} else if ( (*p) > 55u ) {
			if ( (*p) > 63u ) {
				if ( 64u <= (*p) && (*p) <= 111u )
					goto tr3;
			} else if ( (*p) >= 56u )
				goto tr0;
		} else
			goto tr33;
	} else if ( (*p) > 119u ) {
		if ( (*p) < 176u ) {
			if ( (*p) > 127u ) {
				if ( 128u <= (*p) && (*p) <= 175u )
					goto tr5;
			} else if ( (*p) >= 120u )
				goto tr3;
		} else if ( (*p) > 183u ) {
			if ( (*p) > 191u ) {
				if ( 240u <= (*p) && (*p) <= 247u )
					goto tr33;
			} else if ( (*p) >= 184u )
				goto tr5;
		} else
			goto tr33;
	} else
		goto tr33;
	goto tr208;
st153:
	if ( ++p == pe )
		goto _test_eof153;
case 153:
	switch( (*p) ) {
		case 4u: goto st80;
		case 5u: goto tr33;
		case 20u: goto st2;
		case 21u: goto tr33;
		case 28u: goto st2;
		case 29u: goto tr33;
		case 36u: goto st2;
		case 37u: goto tr33;
		case 44u: goto st2;
		case 45u: goto tr33;
		case 52u: goto st2;
		case 53u: goto tr33;
		case 60u: goto st2;
		case 61u: goto tr33;
		case 68u: goto st86;
		case 84u: goto st8;
		case 92u: goto st8;
		case 100u: goto st8;
		case 108u: goto st8;
		case 116u: goto st8;
		case 124u: goto st8;
		case 132u: goto st87;
		case 148u: goto st9;
		case 156u: goto st9;
		case 164u: goto st9;
		case 172u: goto st9;
		case 180u: goto st9;
		case 188u: goto st9;
	}
	if ( (*p) < 80u ) {
		if ( (*p) < 16u ) {
			if ( (*p) > 7u ) {
				if ( 8u <= (*p) && (*p) <= 15u )
					goto tr33;
			} else
				goto tr185;
		} else if ( (*p) > 63u ) {
			if ( (*p) > 71u ) {
				if ( 72u <= (*p) && (*p) <= 79u )
					goto tr33;
			} else if ( (*p) >= 64u )
				goto tr187;
		} else
			goto tr0;
	} else if ( (*p) > 127u ) {
		if ( (*p) < 144u ) {
			if ( (*p) > 135u ) {
				if ( 136u <= (*p) && (*p) <= 143u )
					goto tr33;
			} else if ( (*p) >= 128u )
				goto tr189;
		} else if ( (*p) > 191u ) {
			if ( (*p) > 199u ) {
				if ( 200u <= (*p) && (*p) <= 207u )
					goto tr33;
			} else if ( (*p) >= 192u )
				goto tr249;
		} else
			goto tr5;
	} else
		goto tr3;
	goto tr208;
st154:
	if ( ++p == pe )
		goto _test_eof154;
case 154:
	switch( (*p) ) {
		case 4u: goto st2;
		case 12u: goto st2;
		case 68u: goto st8;
		case 76u: goto st8;
		case 132u: goto st9;
		case 140u: goto st9;
	}
	if ( (*p) < 14u ) {
		if ( (*p) > 3u ) {
			if ( 6u <= (*p) && (*p) <= 11u )
				goto tr0;
		} else
			goto tr0;
	} else if ( (*p) > 15u ) {
		if ( (*p) < 128u ) {
			if ( 64u <= (*p) && (*p) <= 79u )
				goto tr3;
		} else if ( (*p) > 143u ) {
			if ( 192u <= (*p) && (*p) <= 207u )
				goto tr208;
		} else
			goto tr5;
	} else
		goto tr0;
	goto tr33;
tr994:
#line 329 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
        begin = p;
        BitmapSetBit(valid_targets, p - data);
        SET_REX_PREFIX(FALSE);
        SET_VEX_PREFIX2(0xe0);
        SET_VEX_PREFIX3(0x00);
        operand_states = 0;
     }
#line 190 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_REX_PREFIX(*p);
  }
	goto st155;
st155:
	if ( ++p == pe )
		goto _test_eof155;
case 155:
#line 12677 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 1u: goto tr220;
		case 3u: goto tr221;
		case 9u: goto tr220;
		case 11u: goto tr221;
		case 15u: goto st142;
		case 17u: goto tr220;
		case 19u: goto tr221;
		case 25u: goto tr220;
		case 27u: goto tr221;
		case 33u: goto tr220;
		case 35u: goto tr221;
		case 41u: goto tr220;
		case 43u: goto tr221;
		case 49u: goto tr220;
		case 51u: goto tr221;
		case 57u: goto st38;
		case 59u: goto st38;
		case 99u: goto tr221;
		case 105u: goto tr224;
		case 107u: goto tr225;
		case 129u: goto st144;
		case 131u: goto st145;
		case 133u: goto tr220;
		case 135u: goto tr228;
		case 137u: goto tr220;
		case 139u: goto tr221;
		case 141u: goto tr283;
		case 193u: goto st150;
		case 199u: goto st151;
		case 209u: goto st152;
		case 211u: goto st152;
		case 247u: goto st153;
		case 255u: goto st154;
	}
	if ( (*p) > 151u ) {
		if ( 184u <= (*p) && (*p) <= 191u )
			goto tr235;
	} else if ( (*p) >= 145u )
		goto tr231;
	goto tr33;
tr283:
#line 298 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(0, OperandSize64bit);
  }
	goto st156;
st156:
	if ( ++p == pe )
		goto _test_eof156;
case 156:
#line 12729 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 4u: goto tr202;
		case 5u: goto tr203;
		case 12u: goto tr202;
		case 13u: goto tr203;
		case 20u: goto tr202;
		case 21u: goto tr203;
		case 28u: goto tr202;
		case 29u: goto tr203;
		case 36u: goto tr284;
		case 37u: goto tr203;
		case 44u: goto tr202;
		case 45u: goto tr203;
		case 52u: goto tr202;
		case 53u: goto tr203;
		case 60u: goto tr202;
		case 61u: goto tr203;
		case 68u: goto tr205;
		case 76u: goto tr205;
		case 84u: goto tr205;
		case 92u: goto tr205;
		case 100u: goto tr205;
		case 108u: goto tr285;
		case 116u: goto tr205;
		case 124u: goto tr205;
		case 132u: goto tr207;
		case 140u: goto tr207;
		case 148u: goto tr207;
		case 156u: goto tr207;
		case 164u: goto tr207;
		case 172u: goto tr207;
		case 180u: goto tr207;
		case 188u: goto tr207;
	}
	if ( (*p) < 64u ) {
		if ( (*p) <= 63u )
			goto tr201;
	} else if ( (*p) > 127u ) {
		if ( 128u <= (*p) && (*p) <= 191u )
			goto tr206;
	} else
		goto tr204;
	goto tr33;
tr284:
#line 389 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_NAME(0, (((*p) & 0x38) >> 3) |
                           ((GET_REX_PREFIX() & 0x04) << 1) |
                           (((~GET_VEX_PREFIX2()) & 0x80) >> 4));
  }
	goto st157;
st157:
	if ( ++p == pe )
		goto _test_eof157;
case 157:
#line 12785 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 5u: goto tr68;
		case 13u: goto tr68;
		case 21u: goto tr68;
		case 29u: goto tr68;
		case 37u: goto tr68;
		case 45u: goto tr68;
		case 53u: goto tr68;
		case 60u: goto tr286;
		case 61u: goto tr68;
		case 69u: goto tr68;
		case 77u: goto tr68;
		case 85u: goto tr68;
		case 93u: goto tr68;
		case 101u: goto tr68;
		case 109u: goto tr68;
		case 117u: goto tr68;
		case 125u: goto tr68;
		case 133u: goto tr68;
		case 141u: goto tr68;
		case 149u: goto tr68;
		case 157u: goto tr68;
		case 165u: goto tr68;
		case 173u: goto tr68;
		case 181u: goto tr68;
		case 189u: goto tr68;
		case 197u: goto tr68;
		case 205u: goto tr68;
		case 213u: goto tr68;
		case 221u: goto tr68;
		case 229u: goto tr68;
		case 237u: goto tr68;
		case 245u: goto tr68;
		case 253u: goto tr68;
	}
	goto tr67;
tr285:
#line 389 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_NAME(0, (((*p) & 0x38) >> 3) |
                           ((GET_REX_PREFIX() & 0x04) << 1) |
                           (((~GET_VEX_PREFIX2()) & 0x80) >> 4));
  }
	goto st158;
st158:
	if ( ++p == pe )
		goto _test_eof158;
case 158:
#line 12834 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	if ( (*p) == 61u )
		goto st159;
	goto tr74;
st159:
	if ( ++p == pe )
		goto _test_eof159;
case 159:
	if ( (*p) == 0u )
		goto tr280;
	goto tr33;
tr995:
#line 329 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
        begin = p;
        BitmapSetBit(valid_targets, p - data);
        SET_REX_PREFIX(FALSE);
        SET_VEX_PREFIX2(0xe0);
        SET_VEX_PREFIX3(0x00);
        operand_states = 0;
     }
#line 190 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_REX_PREFIX(*p);
  }
	goto st160;
st160:
	if ( ++p == pe )
		goto _test_eof160;
case 160:
#line 12864 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 1u: goto tr220;
		case 3u: goto tr221;
		case 9u: goto tr220;
		case 11u: goto tr221;
		case 15u: goto st142;
		case 17u: goto tr220;
		case 19u: goto tr221;
		case 25u: goto tr220;
		case 27u: goto tr221;
		case 33u: goto tr220;
		case 35u: goto tr221;
		case 41u: goto tr220;
		case 43u: goto tr221;
		case 49u: goto tr220;
		case 51u: goto tr221;
		case 57u: goto st38;
		case 59u: goto st38;
		case 99u: goto tr221;
		case 105u: goto tr224;
		case 107u: goto tr225;
		case 129u: goto st144;
		case 131u: goto st145;
		case 133u: goto tr220;
		case 135u: goto tr228;
		case 137u: goto tr220;
		case 139u: goto tr221;
		case 141u: goto tr230;
		case 193u: goto st150;
		case 199u: goto st151;
		case 209u: goto st152;
		case 211u: goto st152;
		case 247u: goto st153;
		case 255u: goto st154;
	}
	if ( (*p) > 151u ) {
		if ( 184u <= (*p) && (*p) <= 191u )
			goto tr235;
	} else if ( (*p) >= 145u )
		goto tr231;
	goto tr33;
tr996:
#line 329 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
        begin = p;
        BitmapSetBit(valid_targets, p - data);
        SET_REX_PREFIX(FALSE);
        SET_VEX_PREFIX2(0xe0);
        SET_VEX_PREFIX3(0x00);
        operand_states = 0;
     }
#line 190 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_REX_PREFIX(*p);
  }
	goto st161;
st161:
	if ( ++p == pe )
		goto _test_eof161;
case 161:
#line 12925 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 1u: goto tr288;
		case 3u: goto tr221;
		case 9u: goto tr220;
		case 11u: goto tr221;
		case 15u: goto st142;
		case 17u: goto tr220;
		case 19u: goto tr221;
		case 25u: goto tr220;
		case 27u: goto tr221;
		case 33u: goto tr220;
		case 35u: goto tr221;
		case 41u: goto tr220;
		case 43u: goto tr221;
		case 49u: goto tr220;
		case 51u: goto tr221;
		case 57u: goto st38;
		case 59u: goto st38;
		case 99u: goto tr221;
		case 105u: goto tr224;
		case 107u: goto tr225;
		case 129u: goto st144;
		case 131u: goto st145;
		case 133u: goto tr220;
		case 135u: goto tr228;
		case 137u: goto tr220;
		case 139u: goto tr221;
		case 141u: goto tr230;
		case 193u: goto st150;
		case 199u: goto st151;
		case 209u: goto st152;
		case 211u: goto st152;
		case 247u: goto st153;
		case 255u: goto st154;
	}
	if ( (*p) > 151u ) {
		if ( 184u <= (*p) && (*p) <= 191u )
			goto tr235;
	} else if ( (*p) >= 145u )
		goto tr231;
	goto tr33;
tr288:
#line 298 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(0, OperandSize64bit);
  }
	goto st162;
st162:
	if ( ++p == pe )
		goto _test_eof162;
case 162:
#line 12977 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 4u: goto st2;
		case 5u: goto tr2;
		case 12u: goto st2;
		case 13u: goto tr2;
		case 20u: goto st2;
		case 21u: goto tr2;
		case 28u: goto st2;
		case 29u: goto tr2;
		case 36u: goto st2;
		case 37u: goto tr2;
		case 44u: goto st2;
		case 45u: goto tr2;
		case 52u: goto st2;
		case 53u: goto tr2;
		case 60u: goto st2;
		case 61u: goto tr2;
		case 68u: goto st8;
		case 76u: goto st8;
		case 84u: goto st8;
		case 92u: goto st8;
		case 100u: goto st8;
		case 108u: goto st8;
		case 116u: goto st8;
		case 124u: goto st8;
		case 132u: goto st9;
		case 140u: goto st9;
		case 148u: goto st9;
		case 156u: goto st9;
		case 164u: goto st9;
		case 172u: goto st9;
		case 180u: goto st9;
		case 188u: goto st9;
		case 252u: goto tr286;
		case 253u: goto tr280;
	}
	if ( (*p) < 64u ) {
		if ( (*p) <= 63u )
			goto tr0;
	} else if ( (*p) > 127u ) {
		if ( 128u <= (*p) && (*p) <= 191u )
			goto tr5;
	} else
		goto tr3;
	goto tr7;
tr1042:
#line 329 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
        begin = p;
        BitmapSetBit(valid_targets, p - data);
        SET_REX_PREFIX(FALSE);
        SET_VEX_PREFIX2(0xe0);
        SET_VEX_PREFIX3(0x00);
        operand_states = 0;
     }
#line 190 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_REX_PREFIX(*p);
  }
	goto st163;
st163:
	if ( ++p == pe )
		goto _test_eof163;
case 163:
#line 13042 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 1u: goto tr289;
		case 3u: goto tr221;
		case 9u: goto tr220;
		case 11u: goto tr221;
		case 15u: goto st142;
		case 17u: goto tr220;
		case 19u: goto tr221;
		case 25u: goto tr220;
		case 27u: goto tr221;
		case 33u: goto tr220;
		case 35u: goto tr221;
		case 41u: goto tr220;
		case 43u: goto tr221;
		case 49u: goto tr220;
		case 51u: goto tr221;
		case 57u: goto st38;
		case 59u: goto st38;
		case 99u: goto tr221;
		case 105u: goto tr224;
		case 107u: goto tr225;
		case 129u: goto st144;
		case 131u: goto st145;
		case 133u: goto tr220;
		case 135u: goto tr228;
		case 137u: goto tr220;
		case 139u: goto tr221;
		case 141u: goto tr230;
		case 193u: goto st150;
		case 199u: goto st151;
		case 209u: goto st152;
		case 211u: goto st152;
		case 247u: goto st153;
		case 255u: goto st154;
	}
	if ( (*p) > 151u ) {
		if ( 184u <= (*p) && (*p) <= 191u )
			goto tr235;
	} else if ( (*p) >= 145u )
		goto tr231;
	goto tr33;
tr289:
#line 298 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(0, OperandSize64bit);
  }
	goto st164;
st164:
	if ( ++p == pe )
		goto _test_eof164;
case 164:
#line 13094 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 4u: goto st2;
		case 5u: goto tr2;
		case 12u: goto st2;
		case 13u: goto tr2;
		case 20u: goto st2;
		case 21u: goto tr2;
		case 28u: goto st2;
		case 29u: goto tr2;
		case 36u: goto st2;
		case 37u: goto tr2;
		case 44u: goto st2;
		case 45u: goto tr2;
		case 52u: goto st2;
		case 53u: goto tr2;
		case 60u: goto st2;
		case 61u: goto tr2;
		case 68u: goto st8;
		case 76u: goto st8;
		case 84u: goto st8;
		case 92u: goto st8;
		case 100u: goto st8;
		case 108u: goto st8;
		case 116u: goto st8;
		case 124u: goto st8;
		case 132u: goto st9;
		case 140u: goto st9;
		case 148u: goto st9;
		case 156u: goto st9;
		case 164u: goto st9;
		case 172u: goto st9;
		case 180u: goto st9;
		case 188u: goto st9;
		case 248u: goto tr290;
	}
	if ( (*p) < 64u ) {
		if ( (*p) <= 63u )
			goto tr0;
	} else if ( (*p) > 127u ) {
		if ( 128u <= (*p) && (*p) <= 191u )
			goto tr5;
	} else
		goto tr3;
	goto tr7;
tr290:
#line 384 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_NAME(0, ((*p) & 0x07) |
                           ((GET_REX_PREFIX() & 0x01) << 3) |
                           (((~GET_VEX_PREFIX2()) & 0x20) >> 2));
  }
#line 93 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    /* Restricted %rsp or %rbp must be processed by appropriate nacl-special
       instruction, not with regular instruction.  */
    if (restricted_register == REG_RSP) {
      PrintError("Incorrectly modified register %%rsp\n", begin - data);
      result = 1;
      goto error_detected;
    } else if (restricted_register == REG_RBP) {
      PrintError("Incorrectly modified register %%rbp\n", begin - data);
      result = 1;
      goto error_detected;
    }
    /* If Sandboxed Rsi is destroyed then we must note that.  */
    if (restricted_register == kSandboxedRsi) {
      if (CHECK_OPERAND(0, REG_RSI, OperandSandboxRestricted) ||
          CHECK_OPERAND(0, REG_RSI, OperandSandboxUnrestricted) ||
          CHECK_OPERAND(1, REG_RSI, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_RSI, OperandSandboxUnrestricted)) {
        restricted_register = kNoRestrictedReg;
      }
    }
    if (restricted_register == kSandboxedRsi) {
      if (CHECK_OPERAND(0, REG_RDI, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_RDI, OperandSandboxRestricted)) {
        sandboxed_rsi_restricted_rdi = begin;
        restricted_register = kSandboxedRsiRestrictedRdi;
      }
    }
    if (restricted_register != kSandboxedRsiRestrictedRdi) {
      restricted_register = kNoRestrictedReg;
      if (CHECK_OPERAND(0, REG_R15, OperandSandbox8bit) ||
          CHECK_OPERAND(0, REG_R15, OperandSandboxRestricted) ||
          CHECK_OPERAND(0, REG_R15, OperandSandboxUnrestricted) ||
          CHECK_OPERAND(1, REG_R15, OperandSandbox8bit) ||
          CHECK_OPERAND(1, REG_R15, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_R15, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%r15\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((CHECK_OPERAND(0, REG_RBP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(0, REG_RBP, OperandSandboxUnrestricted) ||
                 (CHECK_OPERAND(1, REG_RBP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(1, REG_RBP, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%rbp\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((CHECK_OPERAND(0, REG_RSP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(0, REG_RSP, OperandSandboxUnrestricted) ||
                 (CHECK_OPERAND(1, REG_RSP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(1, REG_RSP, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%rsp\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((operand_states & 0x70) == (OperandSandboxRestricted << 5)) {
        restricted_register = operand_states & 0x0f;
      } else if ((operand_states & 0x7000) ==
                                        (OperandSandboxRestricted << (5 + 8))) {
        restricted_register = (operand_states & 0x0f00) >> 8;
      }
    }
  }
#line 337 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
       /* On successful match the instruction start must point to the next byte
        * to be able to report the new offset as the start of instruction
        * causing error.  */
       begin = p + 1;
     }
	goto st723;
st723:
	if ( ++p == pe )
		goto _test_eof723;
case 723:
#line 13224 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 0u: goto tr978;
		case 1u: goto tr979;
		case 2u: goto tr980;
		case 3u: goto tr981;
		case 4u: goto tr982;
		case 5u: goto tr983;
		case 8u: goto tr978;
		case 9u: goto tr979;
		case 10u: goto tr980;
		case 11u: goto tr981;
		case 12u: goto tr982;
		case 13u: goto tr983;
		case 15u: goto tr984;
		case 16u: goto tr978;
		case 17u: goto tr979;
		case 18u: goto tr980;
		case 19u: goto tr981;
		case 20u: goto tr982;
		case 21u: goto tr983;
		case 24u: goto tr978;
		case 25u: goto tr979;
		case 26u: goto tr980;
		case 27u: goto tr981;
		case 28u: goto tr982;
		case 29u: goto tr983;
		case 32u: goto tr978;
		case 33u: goto tr979;
		case 34u: goto tr980;
		case 35u: goto tr981;
		case 36u: goto tr982;
		case 37u: goto tr983;
		case 40u: goto tr978;
		case 41u: goto tr979;
		case 42u: goto tr980;
		case 43u: goto tr981;
		case 44u: goto tr982;
		case 45u: goto tr983;
		case 46u: goto tr985;
		case 48u: goto tr978;
		case 49u: goto tr979;
		case 50u: goto tr980;
		case 51u: goto tr981;
		case 52u: goto tr982;
		case 53u: goto tr983;
		case 60u: goto tr987;
		case 61u: goto tr988;
		case 62u: goto tr989;
		case 65u: goto tr1043;
		case 72u: goto tr992;
		case 73u: goto tr993;
		case 74u: goto tr994;
		case 76u: goto tr996;
		case 99u: goto tr981;
		case 102u: goto tr999;
		case 104u: goto tr988;
		case 105u: goto tr1000;
		case 106u: goto tr987;
		case 107u: goto tr1001;
		case 128u: goto tr1003;
		case 129u: goto tr1004;
		case 131u: goto tr1005;
		case 133u: goto tr979;
		case 134u: goto tr1006;
		case 135u: goto tr1007;
		case 137u: goto tr979;
		case 138u: goto tr980;
		case 139u: goto tr981;
		case 141u: goto tr1008;
		case 143u: goto tr1009;
		case 144u: goto tr1010;
		case 155u: goto tr1010;
		case 168u: goto tr982;
		case 169u: goto tr983;
		case 192u: goto tr1017;
		case 193u: goto tr1018;
		case 196u: goto tr1019;
		case 197u: goto tr1020;
		case 198u: goto tr1021;
		case 199u: goto tr1022;
		case 200u: goto tr1023;
		case 202u: goto tr1024;
		case 203u: goto tr1010;
		case 209u: goto tr1026;
		case 211u: goto tr1026;
		case 216u: goto tr986;
		case 217u: goto tr1027;
		case 218u: goto tr1028;
		case 219u: goto tr1029;
		case 220u: goto tr1030;
		case 221u: goto tr1031;
		case 222u: goto tr1032;
		case 223u: goto tr1033;
		case 235u: goto tr1002;
		case 240u: goto tr1035;
		case 242u: goto tr1036;
		case 243u: goto tr1037;
		case 246u: goto tr1038;
		case 247u: goto tr1039;
		case 254u: goto tr1040;
		case 255u: goto tr1041;
	}
	if ( (*p) < 164u ) {
		if ( (*p) < 88u ) {
			if ( (*p) < 64u ) {
				if ( 56u <= (*p) && (*p) <= 59u )
					goto tr986;
			} else if ( (*p) > 71u ) {
				if ( (*p) > 79u ) {
					if ( 80u <= (*p) && (*p) <= 87u )
						goto tr997;
				} else if ( (*p) >= 75u )
					goto tr995;
			} else
				goto tr990;
		} else if ( (*p) > 95u ) {
			if ( (*p) < 132u ) {
				if ( 112u <= (*p) && (*p) <= 127u )
					goto tr1002;
			} else if ( (*p) > 136u ) {
				if ( (*p) > 151u ) {
					if ( 152u <= (*p) && (*p) <= 153u )
						goto tr1010;
				} else if ( (*p) >= 145u )
					goto tr1011;
			} else
				goto tr978;
		} else
			goto tr998;
	} else if ( (*p) > 167u ) {
		if ( (*p) < 184u ) {
			if ( (*p) < 172u ) {
				if ( 170u <= (*p) && (*p) <= 171u )
					goto tr1013;
			} else if ( (*p) > 173u ) {
				if ( (*p) > 175u ) {
					if ( 176u <= (*p) && (*p) <= 183u )
						goto tr1015;
				} else if ( (*p) >= 174u )
					goto tr1013;
			} else
				goto tr1014;
		} else if ( (*p) > 191u ) {
			if ( (*p) < 232u ) {
				if ( 208u <= (*p) && (*p) <= 210u )
					goto tr1025;
			} else if ( (*p) > 233u ) {
				if ( (*p) > 249u ) {
					if ( 252u <= (*p) && (*p) <= 253u )
						goto tr1010;
				} else if ( (*p) >= 244u )
					goto tr1010;
			} else
				goto tr1034;
		} else
			goto tr1016;
	} else
		goto tr1012;
	goto tr33;
tr1043:
#line 329 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
        begin = p;
        BitmapSetBit(valid_targets, p - data);
        SET_REX_PREFIX(FALSE);
        SET_VEX_PREFIX2(0xe0);
        SET_VEX_PREFIX3(0x00);
        operand_states = 0;
     }
#line 190 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_REX_PREFIX(*p);
  }
	goto st165;
st165:
	if ( ++p == pe )
		goto _test_eof165;
case 165:
#line 13403 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 0u: goto tr47;
		case 1u: goto tr45;
		case 2u: goto tr120;
		case 3u: goto tr32;
		case 8u: goto tr47;
		case 9u: goto tr45;
		case 10u: goto tr120;
		case 11u: goto tr32;
		case 15u: goto st69;
		case 16u: goto tr47;
		case 17u: goto tr45;
		case 18u: goto tr120;
		case 19u: goto tr32;
		case 24u: goto tr47;
		case 25u: goto tr45;
		case 26u: goto tr120;
		case 27u: goto tr32;
		case 32u: goto tr47;
		case 33u: goto tr45;
		case 34u: goto tr120;
		case 35u: goto tr32;
		case 40u: goto tr47;
		case 41u: goto tr45;
		case 42u: goto tr120;
		case 43u: goto tr32;
		case 48u: goto tr47;
		case 49u: goto tr45;
		case 50u: goto tr120;
		case 51u: goto tr32;
		case 99u: goto tr32;
		case 105u: goto tr124;
		case 107u: goto tr125;
		case 128u: goto st89;
		case 129u: goto st90;
		case 131u: goto st112;
		case 133u: goto tr45;
		case 134u: goto tr129;
		case 135u: goto tr130;
		case 137u: goto tr45;
		case 138u: goto tr120;
		case 139u: goto tr32;
		case 141u: goto tr131;
		case 143u: goto st94;
		case 155u: goto st95;
		case 192u: goto st97;
		case 193u: goto st98;
		case 198u: goto st99;
		case 199u: goto st100;
		case 209u: goto st102;
		case 211u: goto st102;
		case 217u: goto st104;
		case 219u: goto st105;
		case 221u: goto st106;
		case 246u: goto st107;
		case 247u: goto st108;
		case 254u: goto st109;
		case 255u: goto st166;
	}
	if ( (*p) < 145u ) {
		if ( (*p) < 80u ) {
			if ( 56u <= (*p) && (*p) <= 59u )
				goto st38;
		} else if ( (*p) > 87u ) {
			if ( (*p) > 95u ) {
				if ( 132u <= (*p) && (*p) <= 136u )
					goto tr47;
			} else if ( (*p) >= 88u )
				goto tr123;
		} else
			goto tr122;
	} else if ( (*p) > 151u ) {
		if ( (*p) < 184u ) {
			if ( 176u <= (*p) && (*p) <= 183u )
				goto tr135;
		} else if ( (*p) > 191u ) {
			if ( (*p) > 210u ) {
				if ( 216u <= (*p) && (*p) <= 223u )
					goto st103;
			} else if ( (*p) >= 208u )
				goto st101;
		} else
			goto tr136;
	} else
		goto tr133;
	goto tr33;
st166:
	if ( ++p == pe )
		goto _test_eof166;
case 166:
	switch( (*p) ) {
		case 4u: goto st2;
		case 12u: goto st2;
		case 52u: goto st2;
		case 68u: goto st8;
		case 76u: goto st8;
		case 116u: goto st8;
		case 132u: goto st9;
		case 140u: goto st9;
		case 180u: goto st9;
		case 208u: goto tr292;
		case 224u: goto tr292;
	}
	if ( (*p) < 64u ) {
		if ( (*p) < 14u ) {
			if ( (*p) > 3u ) {
				if ( 6u <= (*p) && (*p) <= 11u )
					goto tr0;
			} else
				goto tr0;
		} else if ( (*p) > 15u ) {
			if ( (*p) > 51u ) {
				if ( 54u <= (*p) && (*p) <= 55u )
					goto tr0;
			} else if ( (*p) >= 48u )
				goto tr0;
		} else
			goto tr0;
	} else if ( (*p) > 79u ) {
		if ( (*p) < 176u ) {
			if ( (*p) > 119u ) {
				if ( 128u <= (*p) && (*p) <= 143u )
					goto tr5;
			} else if ( (*p) >= 112u )
				goto tr3;
		} else if ( (*p) > 183u ) {
			if ( (*p) > 207u ) {
				if ( 240u <= (*p) && (*p) <= 247u )
					goto tr34;
			} else if ( (*p) >= 192u )
				goto tr56;
		} else
			goto tr5;
	} else
		goto tr3;
	goto tr33;
tr999:
#line 329 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
        begin = p;
        BitmapSetBit(valid_targets, p - data);
        SET_REX_PREFIX(FALSE);
        SET_VEX_PREFIX2(0xe0);
        SET_VEX_PREFIX3(0x00);
        operand_states = 0;
     }
#line 10 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_DATA16_PREFIX(TRUE);
  }
	goto st167;
st167:
	if ( ++p == pe )
		goto _test_eof167;
case 167:
#line 13559 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 1u: goto tr293;
		case 3u: goto tr294;
		case 5u: goto tr295;
		case 9u: goto tr293;
		case 11u: goto tr294;
		case 13u: goto tr295;
		case 15u: goto st170;
		case 17u: goto tr293;
		case 19u: goto tr294;
		case 21u: goto tr295;
		case 25u: goto tr293;
		case 27u: goto tr294;
		case 29u: goto tr295;
		case 33u: goto tr293;
		case 35u: goto tr294;
		case 37u: goto tr295;
		case 41u: goto tr293;
		case 43u: goto tr294;
		case 45u: goto tr295;
		case 46u: goto st180;
		case 49u: goto tr293;
		case 51u: goto tr294;
		case 53u: goto tr295;
		case 57u: goto st38;
		case 59u: goto st38;
		case 61u: goto st168;
		case 99u: goto tr294;
		case 102u: goto st213;
		case 104u: goto st168;
		case 105u: goto tr302;
		case 107u: goto tr303;
		case 129u: goto st218;
		case 131u: goto st219;
		case 133u: goto tr293;
		case 135u: goto tr306;
		case 137u: goto tr293;
		case 139u: goto tr294;
		case 141u: goto tr307;
		case 143u: goto st220;
		case 165u: goto tr232;
		case 167u: goto tr232;
		case 169u: goto tr295;
		case 171u: goto tr233;
		case 173u: goto tr234;
		case 175u: goto tr233;
		case 193u: goto st221;
		case 199u: goto st222;
		case 209u: goto st223;
		case 211u: goto st223;
		case 240u: goto tr314;
		case 242u: goto tr315;
		case 243u: goto tr316;
		case 247u: goto st246;
		case 255u: goto st247;
	}
	if ( (*p) < 144u ) {
		if ( (*p) > 71u ) {
			if ( 72u <= (*p) && (*p) <= 79u )
				goto tr300;
		} else if ( (*p) >= 64u )
			goto tr299;
	} else if ( (*p) > 151u ) {
		if ( (*p) < 156u ) {
			if ( 152u <= (*p) && (*p) <= 153u )
				goto tr34;
		} else if ( (*p) > 157u ) {
			if ( 184u <= (*p) && (*p) <= 191u )
				goto tr310;
		} else
			goto tr34;
	} else
		goto tr309;
	goto tr33;
tr375:
#line 389 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_NAME(0, (((*p) & 0x38) >> 3) |
                           ((GET_REX_PREFIX() & 0x04) << 1) |
                           (((~GET_VEX_PREFIX2()) & 0x80) >> 4));
  }
	goto st168;
tr385:
#line 90 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_DISP_TYPE(DISPNONE);
    SET_MODRM_BASE(((*p) & 0x07) |
                   ((GET_REX_PREFIX() & 0x01) << 3) |
                   (((~GET_VEX_PREFIX2()) & 0x20) >> 2));
    SET_MODRM_INDEX(NO_REG);
    SET_MODRM_SCALE(0);
  }
#line 44 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    if ((base == REG_RIP) || (base == REG_R15) ||
        ((base == REG_RSP) && (restricted_register != REG_RSP)) ||
        ((base == REG_RBP) && (restricted_register != REG_RBP))) {
      if ((index == restricted_register) ||
          ((index == REG_RDI) &&
           (restricted_register == kSandboxedRsiRestrictedRdi))) {
        BitmapClearBit(valid_targets, begin - data);
      } else if ((index != NO_REG) && (index != REG_RIZ)) {
        PrintError("Improper sandboxing in instruction\n", begin - data);
        result = 1;
        goto error_detected;
      }
    } else if ((index == REG_RIP) || (index == REG_R15) ||
               ((index == REG_RSP) && (restricted_register != REG_RSP)) ||
               ((index == REG_RBP) && (restricted_register != REG_RBP))) {
      if ((base == restricted_register) ||
          ((base == REG_RDI) &&
           (restricted_register == kSandboxedRsiRestrictedRdi))) {
        BitmapClearBit(valid_targets, begin - data);
      } else if ((base != NO_REG) && (base != REG_RIZ)) {
        PrintError("Improper sandboxing in instruction\n", begin - data);
        result = 1;
        goto error_detected;
      }
    } else {
      PrintError("Improper sandboxing in instruction\n", begin - data);
      result = 1;
      goto error_detected;
    }
  }
	goto st168;
tr376:
#line 118 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_DISP_TYPE(DISPNONE);
    SET_MODRM_BASE(((*p) & 0x7) |
                   ((GET_REX_PREFIX() & 0x01) << 3) |
                   (((~GET_VEX_PREFIX2()) & 0x20) >> 2));
    SET_MODRM_INDEX(index_registers[(((*p) & 0x38) >> 3) |
                                    ((GET_REX_PREFIX() & 0x02) << 2) |
                                    (((~GET_VEX_PREFIX2()) & 0x40) >> 3)]);
    SET_MODRM_SCALE(((*p) & 0xc0) >> 6);
  }
#line 44 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    if ((base == REG_RIP) || (base == REG_R15) ||
        ((base == REG_RSP) && (restricted_register != REG_RSP)) ||
        ((base == REG_RBP) && (restricted_register != REG_RBP))) {
      if ((index == restricted_register) ||
          ((index == REG_RDI) &&
           (restricted_register == kSandboxedRsiRestrictedRdi))) {
        BitmapClearBit(valid_targets, begin - data);
      } else if ((index != NO_REG) && (index != REG_RIZ)) {
        PrintError("Improper sandboxing in instruction\n", begin - data);
        result = 1;
        goto error_detected;
      }
    } else if ((index == REG_RIP) || (index == REG_R15) ||
               ((index == REG_RSP) && (restricted_register != REG_RSP)) ||
               ((index == REG_RBP) && (restricted_register != REG_RBP))) {
      if ((base == restricted_register) ||
          ((base == REG_RDI) &&
           (restricted_register == kSandboxedRsiRestrictedRdi))) {
        BitmapClearBit(valid_targets, begin - data);
      } else if ((base != NO_REG) && (base != REG_RIZ)) {
        PrintError("Improper sandboxing in instruction\n", begin - data);
        result = 1;
        goto error_detected;
      }
    } else {
      PrintError("Improper sandboxing in instruction\n", begin - data);
      result = 1;
      goto error_detected;
    }
  }
	goto st168;
tr381:
#line 46 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_DISP_TYPE(DISP32);
    SET_DISP_PTR(p - 3);
  }
#line 44 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    if ((base == REG_RIP) || (base == REG_R15) ||
        ((base == REG_RSP) && (restricted_register != REG_RSP)) ||
        ((base == REG_RBP) && (restricted_register != REG_RBP))) {
      if ((index == restricted_register) ||
          ((index == REG_RDI) &&
           (restricted_register == kSandboxedRsiRestrictedRdi))) {
        BitmapClearBit(valid_targets, begin - data);
      } else if ((index != NO_REG) && (index != REG_RIZ)) {
        PrintError("Improper sandboxing in instruction\n", begin - data);
        result = 1;
        goto error_detected;
      }
    } else if ((index == REG_RIP) || (index == REG_R15) ||
               ((index == REG_RSP) && (restricted_register != REG_RSP)) ||
               ((index == REG_RBP) && (restricted_register != REG_RBP))) {
      if ((base == restricted_register) ||
          ((base == REG_RDI) &&
           (restricted_register == kSandboxedRsiRestrictedRdi))) {
        BitmapClearBit(valid_targets, begin - data);
      } else if ((base != NO_REG) && (base != REG_RIZ)) {
        PrintError("Improper sandboxing in instruction\n", begin - data);
        result = 1;
        goto error_detected;
      }
    } else {
      PrintError("Improper sandboxing in instruction\n", begin - data);
      result = 1;
      goto error_detected;
    }
  }
	goto st168;
tr382:
#line 42 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_DISP_TYPE(DISP8);
    SET_DISP_PTR(p);
  }
#line 44 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    if ((base == REG_RIP) || (base == REG_R15) ||
        ((base == REG_RSP) && (restricted_register != REG_RSP)) ||
        ((base == REG_RBP) && (restricted_register != REG_RBP))) {
      if ((index == restricted_register) ||
          ((index == REG_RDI) &&
           (restricted_register == kSandboxedRsiRestrictedRdi))) {
        BitmapClearBit(valid_targets, begin - data);
      } else if ((index != NO_REG) && (index != REG_RIZ)) {
        PrintError("Improper sandboxing in instruction\n", begin - data);
        result = 1;
        goto error_detected;
      }
    } else if ((index == REG_RIP) || (index == REG_R15) ||
               ((index == REG_RSP) && (restricted_register != REG_RSP)) ||
               ((index == REG_RBP) && (restricted_register != REG_RBP))) {
      if ((base == restricted_register) ||
          ((base == REG_RDI) &&
           (restricted_register == kSandboxedRsiRestrictedRdi))) {
        BitmapClearBit(valid_targets, begin - data);
      } else if ((base != NO_REG) && (base != REG_RIZ)) {
        PrintError("Improper sandboxing in instruction\n", begin - data);
        result = 1;
        goto error_detected;
      }
    } else {
      PrintError("Improper sandboxing in instruction\n", begin - data);
      result = 1;
      goto error_detected;
    }
  }
	goto st168;
tr368:
#line 389 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_NAME(0, (((*p) & 0x38) >> 3) |
                           ((GET_REX_PREFIX() & 0x04) << 1) |
                           (((~GET_VEX_PREFIX2()) & 0x80) >> 4));
  }
#line 90 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_DISP_TYPE(DISPNONE);
    SET_MODRM_BASE(((*p) & 0x07) |
                   ((GET_REX_PREFIX() & 0x01) << 3) |
                   (((~GET_VEX_PREFIX2()) & 0x20) >> 2));
    SET_MODRM_INDEX(NO_REG);
    SET_MODRM_SCALE(0);
  }
#line 44 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    if ((base == REG_RIP) || (base == REG_R15) ||
        ((base == REG_RSP) && (restricted_register != REG_RSP)) ||
        ((base == REG_RBP) && (restricted_register != REG_RBP))) {
      if ((index == restricted_register) ||
          ((index == REG_RDI) &&
           (restricted_register == kSandboxedRsiRestrictedRdi))) {
        BitmapClearBit(valid_targets, begin - data);
      } else if ((index != NO_REG) && (index != REG_RIZ)) {
        PrintError("Improper sandboxing in instruction\n", begin - data);
        result = 1;
        goto error_detected;
      }
    } else if ((index == REG_RIP) || (index == REG_R15) ||
               ((index == REG_RSP) && (restricted_register != REG_RSP)) ||
               ((index == REG_RBP) && (restricted_register != REG_RBP))) {
      if ((base == restricted_register) ||
          ((base == REG_RDI) &&
           (restricted_register == kSandboxedRsiRestrictedRdi))) {
        BitmapClearBit(valid_targets, begin - data);
      } else if ((base != NO_REG) && (base != REG_RIZ)) {
        PrintError("Improper sandboxing in instruction\n", begin - data);
        result = 1;
        goto error_detected;
      }
    } else {
      PrintError("Improper sandboxing in instruction\n", begin - data);
      result = 1;
      goto error_detected;
    }
  }
	goto st168;
tr295:
#line 292 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(0, OperandSize16bit);
  }
#line 418 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_NAME(0, REG_RAX);
  }
	goto st168;
tr310:
#line 376 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_NAME(0, ((*p) & 0x7) |
                            ((GET_REX_PREFIX() & 0x01) << 3) |
                            (((~GET_VEX_PREFIX2()) & 0x20) >> 2));
  }
#line 292 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(0, OperandSize16bit);
  }
	goto st168;
tr391:
#line 292 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(0, OperandSize16bit);
  }
#line 384 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_NAME(0, ((*p) & 0x07) |
                           ((GET_REX_PREFIX() & 0x01) << 3) |
                           (((~GET_VEX_PREFIX2()) & 0x20) >> 2));
  }
	goto st168;
tr1024:
#line 329 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
        begin = p;
        BitmapSetBit(valid_targets, p - data);
        SET_REX_PREFIX(FALSE);
        SET_VEX_PREFIX2(0xe0);
        SET_VEX_PREFIX3(0x00);
        operand_states = 0;
     }
	goto st168;
st168:
	if ( ++p == pe )
		goto _test_eof168;
case 168:
#line 13906 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	goto st169;
st169:
	if ( ++p == pe )
		goto _test_eof169;
case 169:
	goto tr320;
st170:
	if ( ++p == pe )
		goto _test_eof170;
case 170:
	switch( (*p) ) {
		case 0u: goto st171;
		case 1u: goto st172;
		case 31u: goto st41;
		case 43u: goto tr324;
		case 56u: goto st173;
		case 58u: goto st174;
		case 80u: goto tr327;
		case 81u: goto tr323;
		case 112u: goto tr328;
		case 115u: goto st178;
		case 121u: goto tr331;
		case 126u: goto tr332;
		case 164u: goto tr333;
		case 165u: goto tr293;
		case 172u: goto tr333;
		case 173u: goto tr293;
		case 175u: goto tr294;
		case 177u: goto tr293;
		case 178u: goto tr334;
		case 182u: goto tr294;
		case 186u: goto st179;
		case 193u: goto tr293;
		case 194u: goto tr328;
		case 196u: goto st176;
		case 197u: goto tr337;
		case 198u: goto tr328;
		case 215u: goto tr327;
		case 231u: goto tr324;
		case 247u: goto tr331;
	}
	if ( (*p) < 84u ) {
		if ( (*p) < 20u ) {
			if ( (*p) < 16u ) {
				if ( 2u <= (*p) && (*p) <= 3u )
					goto tr294;
			} else if ( (*p) > 17u ) {
				if ( 18u <= (*p) && (*p) <= 19u )
					goto tr324;
			} else
				goto tr323;
		} else if ( (*p) > 21u ) {
			if ( (*p) < 40u ) {
				if ( 22u <= (*p) && (*p) <= 23u )
					goto tr324;
			} else if ( (*p) > 47u ) {
				if ( 64u <= (*p) && (*p) <= 79u )
					goto tr294;
			} else
				goto tr323;
		} else
			goto tr323;
	} else if ( (*p) > 111u ) {
		if ( (*p) < 180u ) {
			if ( (*p) < 116u ) {
				if ( 113u <= (*p) && (*p) <= 114u )
					goto st177;
			} else if ( (*p) > 118u ) {
				if ( 124u <= (*p) && (*p) <= 127u )
					goto tr323;
			} else
				goto tr323;
		} else if ( (*p) > 181u ) {
			if ( (*p) < 208u ) {
				if ( 188u <= (*p) && (*p) <= 190u )
					goto tr294;
			} else if ( (*p) > 239u ) {
				if ( 241u <= (*p) && (*p) <= 254u )
					goto tr323;
			} else
				goto tr323;
		} else
			goto tr334;
	} else
		goto tr323;
	goto tr33;
st171:
	if ( ++p == pe )
		goto _test_eof171;
case 171:
	if ( 200u <= (*p) && (*p) <= 207u )
		goto tr57;
	goto tr33;
st172:
	if ( ++p == pe )
		goto _test_eof172;
case 172:
	if ( 224u <= (*p) && (*p) <= 231u )
		goto tr57;
	goto tr33;
st173:
	if ( ++p == pe )
		goto _test_eof173;
case 173:
	switch( (*p) ) {
		case 16u: goto tr323;
		case 23u: goto tr323;
		case 42u: goto tr324;
	}
	if ( (*p) < 32u ) {
		if ( (*p) < 20u ) {
			if ( (*p) <= 11u )
				goto tr323;
		} else if ( (*p) > 21u ) {
			if ( 28u <= (*p) && (*p) <= 30u )
				goto tr323;
		} else
			goto tr323;
	} else if ( (*p) > 37u ) {
		if ( (*p) < 48u ) {
			if ( 40u <= (*p) && (*p) <= 43u )
				goto tr323;
		} else if ( (*p) > 53u ) {
			if ( (*p) > 65u ) {
				if ( 219u <= (*p) && (*p) <= 223u )
					goto tr323;
			} else if ( (*p) >= 55u )
				goto tr323;
		} else
			goto tr323;
	} else
		goto tr323;
	goto tr33;
st174:
	if ( ++p == pe )
		goto _test_eof174;
case 174:
	switch( (*p) ) {
		case 23u: goto tr339;
		case 32u: goto st176;
		case 68u: goto tr328;
		case 223u: goto tr328;
	}
	if ( (*p) < 33u ) {
		if ( (*p) > 15u ) {
			if ( 20u <= (*p) && (*p) <= 22u )
				goto st175;
		} else if ( (*p) >= 8u )
			goto tr328;
	} else if ( (*p) > 34u ) {
		if ( (*p) > 66u ) {
			if ( 96u <= (*p) && (*p) <= 99u )
				goto tr328;
		} else if ( (*p) >= 64u )
			goto tr328;
	} else
		goto tr328;
	goto tr33;
st175:
	if ( ++p == pe )
		goto _test_eof175;
case 175:
	switch( (*p) ) {
		case 4u: goto tr341;
		case 5u: goto tr342;
		case 12u: goto tr341;
		case 13u: goto tr342;
		case 20u: goto tr341;
		case 21u: goto tr342;
		case 28u: goto tr341;
		case 29u: goto tr342;
		case 36u: goto tr341;
		case 37u: goto tr342;
		case 44u: goto tr341;
		case 45u: goto tr342;
		case 52u: goto tr341;
		case 53u: goto tr342;
		case 60u: goto tr341;
		case 61u: goto tr342;
		case 68u: goto tr344;
		case 76u: goto tr344;
		case 84u: goto tr344;
		case 92u: goto tr344;
		case 100u: goto tr344;
		case 108u: goto tr344;
		case 116u: goto tr344;
		case 124u: goto tr344;
		case 132u: goto tr346;
		case 140u: goto tr346;
		case 148u: goto tr346;
		case 156u: goto tr346;
		case 164u: goto tr346;
		case 172u: goto tr346;
		case 180u: goto tr346;
		case 188u: goto tr346;
	}
	if ( (*p) < 64u ) {
		if ( (*p) <= 63u )
			goto tr340;
	} else if ( (*p) > 127u ) {
		if ( 128u <= (*p) && (*p) <= 191u )
			goto tr345;
	} else
		goto tr343;
	goto tr347;
st176:
	if ( ++p == pe )
		goto _test_eof176;
case 176:
	switch( (*p) ) {
		case 4u: goto tr341;
		case 5u: goto tr342;
		case 12u: goto tr341;
		case 13u: goto tr342;
		case 20u: goto tr341;
		case 21u: goto tr342;
		case 28u: goto tr341;
		case 29u: goto tr342;
		case 36u: goto tr341;
		case 37u: goto tr342;
		case 44u: goto tr341;
		case 45u: goto tr342;
		case 52u: goto tr341;
		case 53u: goto tr342;
		case 60u: goto tr341;
		case 61u: goto tr342;
		case 68u: goto tr344;
		case 76u: goto tr344;
		case 84u: goto tr344;
		case 92u: goto tr344;
		case 100u: goto tr344;
		case 108u: goto tr344;
		case 116u: goto tr344;
		case 124u: goto tr344;
		case 132u: goto tr346;
		case 140u: goto tr346;
		case 148u: goto tr346;
		case 156u: goto tr346;
		case 164u: goto tr346;
		case 172u: goto tr346;
		case 180u: goto tr346;
		case 188u: goto tr346;
	}
	if ( (*p) < 64u ) {
		if ( (*p) <= 63u )
			goto tr340;
	} else if ( (*p) > 127u ) {
		if ( 128u <= (*p) && (*p) <= 191u )
			goto tr345;
	} else
		goto tr343;
	goto tr348;
st177:
	if ( ++p == pe )
		goto _test_eof177;
case 177:
	if ( (*p) < 224u ) {
		if ( 208u <= (*p) && (*p) <= 215u )
			goto tr348;
	} else if ( (*p) > 231u ) {
		if ( 240u <= (*p) && (*p) <= 247u )
			goto tr348;
	} else
		goto tr348;
	goto tr33;
st178:
	if ( ++p == pe )
		goto _test_eof178;
case 178:
	if ( (*p) > 223u ) {
		if ( 240u <= (*p) )
			goto tr348;
	} else if ( (*p) >= 208u )
		goto tr348;
	goto tr33;
st179:
	if ( ++p == pe )
		goto _test_eof179;
case 179:
	switch( (*p) ) {
		case 36u: goto st44;
		case 37u: goto tr95;
		case 44u: goto st44;
		case 45u: goto tr95;
		case 52u: goto st44;
		case 53u: goto tr95;
		case 60u: goto st44;
		case 61u: goto tr95;
		case 100u: goto st50;
		case 108u: goto st50;
		case 116u: goto st50;
		case 124u: goto st50;
		case 164u: goto st51;
		case 172u: goto st51;
		case 180u: goto st51;
		case 188u: goto st51;
	}
	if ( (*p) < 96u ) {
		if ( 32u <= (*p) && (*p) <= 63u )
			goto tr93;
	} else if ( (*p) > 127u ) {
		if ( (*p) > 191u ) {
			if ( 224u <= (*p) )
				goto tr349;
		} else if ( (*p) >= 160u )
			goto tr98;
	} else
		goto tr96;
	goto tr33;
st180:
	if ( ++p == pe )
		goto _test_eof180;
case 180:
	if ( (*p) == 15u )
		goto st181;
	goto tr33;
st181:
	if ( ++p == pe )
		goto _test_eof181;
case 181:
	if ( (*p) == 31u )
		goto st182;
	goto tr33;
st182:
	if ( ++p == pe )
		goto _test_eof182;
case 182:
	if ( (*p) == 132u )
		goto st183;
	goto tr33;
st183:
	if ( ++p == pe )
		goto _test_eof183;
case 183:
	if ( (*p) == 0u )
		goto st184;
	goto tr33;
st184:
	if ( ++p == pe )
		goto _test_eof184;
case 184:
	if ( (*p) == 0u )
		goto st185;
	goto tr33;
st185:
	if ( ++p == pe )
		goto _test_eof185;
case 185:
	if ( (*p) == 0u )
		goto st186;
	goto tr33;
st186:
	if ( ++p == pe )
		goto _test_eof186;
case 186:
	if ( (*p) == 0u )
		goto st187;
	goto tr33;
st187:
	if ( ++p == pe )
		goto _test_eof187;
case 187:
	if ( (*p) == 0u )
		goto tr357;
	goto tr33;
tr299:
#line 190 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_REX_PREFIX(*p);
  }
	goto st188;
st188:
	if ( ++p == pe )
		goto _test_eof188;
case 188:
#line 14282 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 1u: goto tr293;
		case 3u: goto tr294;
		case 9u: goto tr293;
		case 11u: goto tr294;
		case 15u: goto st189;
		case 17u: goto tr293;
		case 19u: goto tr294;
		case 25u: goto tr293;
		case 27u: goto tr294;
		case 33u: goto tr293;
		case 35u: goto tr294;
		case 41u: goto tr293;
		case 43u: goto tr294;
		case 49u: goto tr293;
		case 51u: goto tr294;
		case 57u: goto st38;
		case 59u: goto st38;
		case 99u: goto tr294;
		case 105u: goto tr302;
		case 107u: goto tr303;
		case 129u: goto st200;
		case 131u: goto st201;
		case 133u: goto tr293;
		case 135u: goto tr306;
		case 137u: goto tr293;
		case 139u: goto tr294;
		case 141u: goto tr307;
		case 143u: goto st202;
		case 193u: goto st203;
		case 199u: goto st204;
		case 209u: goto st205;
		case 211u: goto st205;
		case 247u: goto st206;
		case 255u: goto st207;
	}
	if ( (*p) > 151u ) {
		if ( 184u <= (*p) && (*p) <= 191u )
			goto tr310;
	} else if ( (*p) >= 144u )
		goto tr309;
	goto tr33;
st189:
	if ( ++p == pe )
		goto _test_eof189;
case 189:
	switch( (*p) ) {
		case 0u: goto st171;
		case 1u: goto st172;
		case 31u: goto st74;
		case 43u: goto tr324;
		case 56u: goto st173;
		case 58u: goto st174;
		case 80u: goto tr327;
		case 81u: goto tr323;
		case 112u: goto tr328;
		case 115u: goto st178;
		case 121u: goto tr331;
		case 126u: goto tr332;
		case 164u: goto tr333;
		case 165u: goto tr293;
		case 172u: goto tr333;
		case 173u: goto tr293;
		case 175u: goto tr294;
		case 177u: goto tr293;
		case 178u: goto tr334;
		case 182u: goto tr294;
		case 186u: goto st190;
		case 193u: goto tr293;
		case 194u: goto tr328;
		case 196u: goto st176;
		case 197u: goto tr337;
		case 198u: goto tr328;
		case 215u: goto tr327;
		case 231u: goto tr324;
		case 247u: goto tr331;
	}
	if ( (*p) < 84u ) {
		if ( (*p) < 20u ) {
			if ( (*p) < 16u ) {
				if ( 2u <= (*p) && (*p) <= 3u )
					goto tr294;
			} else if ( (*p) > 17u ) {
				if ( 18u <= (*p) && (*p) <= 19u )
					goto tr324;
			} else
				goto tr323;
		} else if ( (*p) > 21u ) {
			if ( (*p) < 40u ) {
				if ( 22u <= (*p) && (*p) <= 23u )
					goto tr324;
			} else if ( (*p) > 47u ) {
				if ( 64u <= (*p) && (*p) <= 79u )
					goto tr294;
			} else
				goto tr323;
		} else
			goto tr323;
	} else if ( (*p) > 111u ) {
		if ( (*p) < 180u ) {
			if ( (*p) < 116u ) {
				if ( 113u <= (*p) && (*p) <= 114u )
					goto st177;
			} else if ( (*p) > 118u ) {
				if ( 124u <= (*p) && (*p) <= 127u )
					goto tr323;
			} else
				goto tr323;
		} else if ( (*p) > 181u ) {
			if ( (*p) < 208u ) {
				if ( 188u <= (*p) && (*p) <= 190u )
					goto tr294;
			} else if ( (*p) > 239u ) {
				if ( 241u <= (*p) && (*p) <= 254u )
					goto tr323;
			} else
				goto tr323;
		} else
			goto tr334;
	} else
		goto tr323;
	goto tr33;
st190:
	if ( ++p == pe )
		goto _test_eof190;
case 190:
	switch( (*p) ) {
		case 36u: goto st44;
		case 44u: goto st44;
		case 52u: goto st44;
		case 60u: goto st44;
		case 100u: goto st50;
		case 108u: goto st50;
		case 116u: goto st50;
		case 124u: goto st50;
		case 164u: goto st51;
		case 172u: goto st51;
		case 180u: goto st51;
		case 188u: goto st51;
	}
	if ( (*p) < 54u ) {
		if ( (*p) < 38u ) {
			if ( 32u <= (*p) && (*p) <= 35u )
				goto tr93;
		} else if ( (*p) > 43u ) {
			if ( 46u <= (*p) && (*p) <= 51u )
				goto tr93;
		} else
			goto tr93;
	} else if ( (*p) > 59u ) {
		if ( (*p) < 96u ) {
			if ( 62u <= (*p) && (*p) <= 63u )
				goto tr93;
		} else if ( (*p) > 127u ) {
			if ( (*p) > 191u ) {
				if ( 224u <= (*p) )
					goto tr349;
			} else if ( (*p) >= 160u )
				goto tr98;
		} else
			goto tr96;
	} else
		goto tr93;
	goto tr33;
tr302:
#line 292 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(0, OperandSize16bit);
  }
	goto st191;
st191:
	if ( ++p == pe )
		goto _test_eof191;
case 191:
#line 14457 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 4u: goto tr369;
		case 5u: goto tr370;
		case 12u: goto tr369;
		case 13u: goto tr370;
		case 20u: goto tr369;
		case 21u: goto tr370;
		case 28u: goto tr369;
		case 29u: goto tr370;
		case 36u: goto tr369;
		case 37u: goto tr370;
		case 44u: goto tr369;
		case 45u: goto tr370;
		case 52u: goto tr369;
		case 53u: goto tr370;
		case 60u: goto tr369;
		case 61u: goto tr370;
		case 68u: goto tr372;
		case 76u: goto tr372;
		case 84u: goto tr372;
		case 92u: goto tr372;
		case 100u: goto tr372;
		case 108u: goto tr372;
		case 116u: goto tr372;
		case 124u: goto tr372;
		case 132u: goto tr374;
		case 140u: goto tr374;
		case 148u: goto tr374;
		case 156u: goto tr374;
		case 164u: goto tr374;
		case 172u: goto tr374;
		case 180u: goto tr374;
		case 188u: goto tr374;
	}
	if ( (*p) < 64u ) {
		if ( (*p) <= 63u )
			goto tr368;
	} else if ( (*p) > 127u ) {
		if ( 128u <= (*p) && (*p) <= 191u )
			goto tr373;
	} else
		goto tr371;
	goto tr375;
tr369:
#line 389 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_NAME(0, (((*p) & 0x38) >> 3) |
                           ((GET_REX_PREFIX() & 0x04) << 1) |
                           (((~GET_VEX_PREFIX2()) & 0x80) >> 4));
  }
	goto st192;
st192:
	if ( ++p == pe )
		goto _test_eof192;
case 192:
#line 14513 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 5u: goto tr377;
		case 13u: goto tr377;
		case 21u: goto tr377;
		case 29u: goto tr377;
		case 37u: goto tr377;
		case 45u: goto tr377;
		case 53u: goto tr377;
		case 61u: goto tr377;
		case 69u: goto tr377;
		case 77u: goto tr377;
		case 85u: goto tr377;
		case 93u: goto tr377;
		case 101u: goto tr377;
		case 109u: goto tr377;
		case 117u: goto tr377;
		case 125u: goto tr377;
		case 133u: goto tr377;
		case 141u: goto tr377;
		case 149u: goto tr377;
		case 157u: goto tr377;
		case 165u: goto tr377;
		case 173u: goto tr377;
		case 181u: goto tr377;
		case 189u: goto tr377;
		case 197u: goto tr377;
		case 205u: goto tr377;
		case 213u: goto tr377;
		case 221u: goto tr377;
		case 229u: goto tr377;
		case 237u: goto tr377;
		case 245u: goto tr377;
		case 253u: goto tr377;
	}
	goto tr376;
tr410:
#line 105 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_MODRM_BASE(REG_RIP);
    SET_MODRM_INDEX(NO_REG);
    SET_MODRM_SCALE(0);
  }
	goto st193;
tr389:
#line 98 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_MODRM_BASE(((*p) & 0x07) |
                   ((GET_REX_PREFIX() & 0x01) << 3) |
                   (((~GET_VEX_PREFIX2()) & 0x20) >> 2));
    SET_MODRM_INDEX(NO_REG);
    SET_MODRM_SCALE(0);
  }
	goto st193;
tr377:
#line 110 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_DISP_TYPE(DISPNONE);
    SET_MODRM_BASE(NO_REG);
    SET_MODRM_INDEX(index_registers[(((*p) & 0x38) >> 3) |
                                    ((GET_REX_PREFIX() & 0x02) << 2) |
                                    (((~GET_VEX_PREFIX2()) & 0x40) >> 3)]);
    SET_MODRM_SCALE(((*p) & 0xc0) >> 6);
  }
	goto st193;
tr384:
#line 118 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_DISP_TYPE(DISPNONE);
    SET_MODRM_BASE(((*p) & 0x7) |
                   ((GET_REX_PREFIX() & 0x01) << 3) |
                   (((~GET_VEX_PREFIX2()) & 0x20) >> 2));
    SET_MODRM_INDEX(index_registers[(((*p) & 0x38) >> 3) |
                                    ((GET_REX_PREFIX() & 0x02) << 2) |
                                    (((~GET_VEX_PREFIX2()) & 0x40) >> 3)]);
    SET_MODRM_SCALE(((*p) & 0xc0) >> 6);
  }
	goto st193;
tr370:
#line 389 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_NAME(0, (((*p) & 0x38) >> 3) |
                           ((GET_REX_PREFIX() & 0x04) << 1) |
                           (((~GET_VEX_PREFIX2()) & 0x80) >> 4));
  }
#line 105 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_MODRM_BASE(REG_RIP);
    SET_MODRM_INDEX(NO_REG);
    SET_MODRM_SCALE(0);
  }
	goto st193;
tr373:
#line 389 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_NAME(0, (((*p) & 0x38) >> 3) |
                           ((GET_REX_PREFIX() & 0x04) << 1) |
                           (((~GET_VEX_PREFIX2()) & 0x80) >> 4));
  }
#line 98 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_MODRM_BASE(((*p) & 0x07) |
                   ((GET_REX_PREFIX() & 0x01) << 3) |
                   (((~GET_VEX_PREFIX2()) & 0x20) >> 2));
    SET_MODRM_INDEX(NO_REG);
    SET_MODRM_SCALE(0);
  }
	goto st193;
st193:
	if ( ++p == pe )
		goto _test_eof193;
case 193:
#line 14625 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	goto st194;
st194:
	if ( ++p == pe )
		goto _test_eof194;
case 194:
	goto st195;
st195:
	if ( ++p == pe )
		goto _test_eof195;
case 195:
	goto st196;
st196:
	if ( ++p == pe )
		goto _test_eof196;
case 196:
	goto tr381;
tr387:
#line 98 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_MODRM_BASE(((*p) & 0x07) |
                   ((GET_REX_PREFIX() & 0x01) << 3) |
                   (((~GET_VEX_PREFIX2()) & 0x20) >> 2));
    SET_MODRM_INDEX(NO_REG);
    SET_MODRM_SCALE(0);
  }
	goto st197;
tr383:
#line 118 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_DISP_TYPE(DISPNONE);
    SET_MODRM_BASE(((*p) & 0x7) |
                   ((GET_REX_PREFIX() & 0x01) << 3) |
                   (((~GET_VEX_PREFIX2()) & 0x20) >> 2));
    SET_MODRM_INDEX(index_registers[(((*p) & 0x38) >> 3) |
                                    ((GET_REX_PREFIX() & 0x02) << 2) |
                                    (((~GET_VEX_PREFIX2()) & 0x40) >> 3)]);
    SET_MODRM_SCALE(((*p) & 0xc0) >> 6);
  }
	goto st197;
tr371:
#line 389 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_NAME(0, (((*p) & 0x38) >> 3) |
                           ((GET_REX_PREFIX() & 0x04) << 1) |
                           (((~GET_VEX_PREFIX2()) & 0x80) >> 4));
  }
#line 98 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_MODRM_BASE(((*p) & 0x07) |
                   ((GET_REX_PREFIX() & 0x01) << 3) |
                   (((~GET_VEX_PREFIX2()) & 0x20) >> 2));
    SET_MODRM_INDEX(NO_REG);
    SET_MODRM_SCALE(0);
  }
	goto st197;
st197:
	if ( ++p == pe )
		goto _test_eof197;
case 197:
#line 14685 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	goto tr382;
tr372:
#line 389 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_NAME(0, (((*p) & 0x38) >> 3) |
                           ((GET_REX_PREFIX() & 0x04) << 1) |
                           (((~GET_VEX_PREFIX2()) & 0x80) >> 4));
  }
	goto st198;
st198:
	if ( ++p == pe )
		goto _test_eof198;
case 198:
#line 14699 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	goto tr383;
tr374:
#line 389 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_NAME(0, (((*p) & 0x38) >> 3) |
                           ((GET_REX_PREFIX() & 0x04) << 1) |
                           (((~GET_VEX_PREFIX2()) & 0x80) >> 4));
  }
	goto st199;
st199:
	if ( ++p == pe )
		goto _test_eof199;
case 199:
#line 14713 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	goto tr384;
st200:
	if ( ++p == pe )
		goto _test_eof200;
case 200:
	switch( (*p) ) {
		case 4u: goto st192;
		case 5u: goto tr33;
		case 12u: goto st192;
		case 13u: goto tr33;
		case 20u: goto st192;
		case 21u: goto tr33;
		case 28u: goto st192;
		case 29u: goto tr33;
		case 36u: goto st192;
		case 37u: goto tr33;
		case 44u: goto st192;
		case 45u: goto tr33;
		case 52u: goto st192;
		case 53u: goto tr33;
		case 60u: goto st192;
		case 61u: goto tr33;
		case 68u: goto st198;
		case 76u: goto st198;
		case 84u: goto st198;
		case 92u: goto st198;
		case 100u: goto st198;
		case 108u: goto st198;
		case 116u: goto st198;
		case 124u: goto st198;
		case 132u: goto st199;
		case 140u: goto st199;
		case 148u: goto st199;
		case 156u: goto st199;
		case 164u: goto st199;
		case 172u: goto st199;
		case 180u: goto st199;
		case 188u: goto st199;
	}
	if ( (*p) < 64u ) {
		if ( (*p) <= 63u )
			goto tr385;
	} else if ( (*p) > 127u ) {
		if ( (*p) > 191u ) {
			if ( 248u <= (*p) )
				goto st168;
		} else if ( (*p) >= 128u )
			goto tr389;
	} else
		goto tr387;
	goto tr391;
st201:
	if ( ++p == pe )
		goto _test_eof201;
case 201:
	switch( (*p) ) {
		case 4u: goto st44;
		case 5u: goto tr33;
		case 12u: goto st44;
		case 13u: goto tr33;
		case 20u: goto st44;
		case 21u: goto tr33;
		case 28u: goto st44;
		case 29u: goto tr33;
		case 36u: goto st44;
		case 37u: goto tr33;
		case 44u: goto st44;
		case 45u: goto tr33;
		case 52u: goto st44;
		case 53u: goto tr33;
		case 60u: goto st44;
		case 61u: goto tr33;
		case 68u: goto st50;
		case 76u: goto st50;
		case 84u: goto st50;
		case 92u: goto st50;
		case 100u: goto st50;
		case 108u: goto st50;
		case 116u: goto st50;
		case 124u: goto st50;
		case 132u: goto st51;
		case 140u: goto st51;
		case 148u: goto st51;
		case 156u: goto st51;
		case 164u: goto st51;
		case 172u: goto st51;
		case 180u: goto st51;
		case 188u: goto st51;
	}
	if ( (*p) < 64u ) {
		if ( (*p) <= 63u )
			goto tr93;
	} else if ( (*p) > 127u ) {
		if ( (*p) > 191u ) {
			if ( 248u <= (*p) )
				goto st11;
		} else if ( (*p) >= 128u )
			goto tr98;
	} else
		goto tr96;
	goto tr349;
st202:
	if ( ++p == pe )
		goto _test_eof202;
case 202:
	switch( (*p) ) {
		case 4u: goto tr393;
		case 68u: goto tr395;
		case 132u: goto tr397;
	}
	if ( (*p) < 64u ) {
		if ( (*p) > 3u ) {
			if ( 6u <= (*p) && (*p) <= 7u )
				goto tr392;
		} else
			goto tr392;
	} else if ( (*p) > 71u ) {
		if ( (*p) > 135u ) {
			if ( 192u <= (*p) && (*p) <= 199u )
				goto tr398;
		} else if ( (*p) >= 128u )
			goto tr396;
	} else
		goto tr394;
	goto tr33;
st203:
	if ( ++p == pe )
		goto _test_eof203;
case 203:
	switch( (*p) ) {
		case 4u: goto st44;
		case 5u: goto tr33;
		case 12u: goto st44;
		case 13u: goto tr33;
		case 20u: goto st44;
		case 21u: goto tr33;
		case 28u: goto st44;
		case 29u: goto tr33;
		case 36u: goto st44;
		case 37u: goto tr33;
		case 44u: goto st44;
		case 45u: goto tr33;
		case 60u: goto st44;
		case 61u: goto tr33;
		case 68u: goto st50;
		case 76u: goto st50;
		case 84u: goto st50;
		case 92u: goto st50;
		case 100u: goto st50;
		case 108u: goto st50;
		case 124u: goto st50;
		case 132u: goto st51;
		case 140u: goto st51;
		case 148u: goto st51;
		case 156u: goto st51;
		case 164u: goto st51;
		case 172u: goto st51;
		case 188u: goto st51;
	}
	if ( (*p) < 112u ) {
		if ( (*p) < 48u ) {
			if ( (*p) <= 47u )
				goto tr93;
		} else if ( (*p) > 55u ) {
			if ( (*p) > 63u ) {
				if ( 64u <= (*p) && (*p) <= 111u )
					goto tr96;
			} else if ( (*p) >= 56u )
				goto tr93;
		} else
			goto tr33;
	} else if ( (*p) > 119u ) {
		if ( (*p) < 176u ) {
			if ( (*p) > 127u ) {
				if ( 128u <= (*p) && (*p) <= 175u )
					goto tr98;
			} else if ( (*p) >= 120u )
				goto tr96;
		} else if ( (*p) > 183u ) {
			if ( (*p) > 191u ) {
				if ( 240u <= (*p) && (*p) <= 247u )
					goto tr33;
			} else if ( (*p) >= 184u )
				goto tr98;
		} else
			goto tr33;
	} else
		goto tr33;
	goto tr349;
st204:
	if ( ++p == pe )
		goto _test_eof204;
case 204:
	switch( (*p) ) {
		case 4u: goto st192;
		case 68u: goto st198;
		case 132u: goto st199;
	}
	if ( (*p) < 64u ) {
		if ( (*p) > 3u ) {
			if ( 6u <= (*p) && (*p) <= 7u )
				goto tr385;
		} else
			goto tr385;
	} else if ( (*p) > 71u ) {
		if ( (*p) > 135u ) {
			if ( 192u <= (*p) && (*p) <= 199u )
				goto tr391;
		} else if ( (*p) >= 128u )
			goto tr389;
	} else
		goto tr387;
	goto tr33;
st205:
	if ( ++p == pe )
		goto _test_eof205;
case 205:
	switch( (*p) ) {
		case 4u: goto st2;
		case 5u: goto tr33;
		case 12u: goto st2;
		case 13u: goto tr33;
		case 20u: goto st2;
		case 21u: goto tr33;
		case 28u: goto st2;
		case 29u: goto tr33;
		case 36u: goto st2;
		case 37u: goto tr33;
		case 44u: goto st2;
		case 45u: goto tr33;
		case 60u: goto st2;
		case 61u: goto tr33;
		case 68u: goto st8;
		case 76u: goto st8;
		case 84u: goto st8;
		case 92u: goto st8;
		case 100u: goto st8;
		case 108u: goto st8;
		case 124u: goto st8;
		case 132u: goto st9;
		case 140u: goto st9;
		case 148u: goto st9;
		case 156u: goto st9;
		case 164u: goto st9;
		case 172u: goto st9;
		case 188u: goto st9;
	}
	if ( (*p) < 112u ) {
		if ( (*p) < 48u ) {
			if ( (*p) <= 47u )
				goto tr0;
		} else if ( (*p) > 55u ) {
			if ( (*p) > 63u ) {
				if ( 64u <= (*p) && (*p) <= 111u )
					goto tr3;
			} else if ( (*p) >= 56u )
				goto tr0;
		} else
			goto tr33;
	} else if ( (*p) > 119u ) {
		if ( (*p) < 176u ) {
			if ( (*p) > 127u ) {
				if ( 128u <= (*p) && (*p) <= 175u )
					goto tr5;
			} else if ( (*p) >= 120u )
				goto tr3;
		} else if ( (*p) > 183u ) {
			if ( (*p) > 191u ) {
				if ( 240u <= (*p) && (*p) <= 247u )
					goto tr33;
			} else if ( (*p) >= 184u )
				goto tr5;
		} else
			goto tr33;
	} else
		goto tr33;
	goto tr57;
st206:
	if ( ++p == pe )
		goto _test_eof206;
case 206:
	switch( (*p) ) {
		case 4u: goto st192;
		case 5u: goto tr33;
		case 20u: goto st2;
		case 21u: goto tr33;
		case 28u: goto st2;
		case 29u: goto tr33;
		case 36u: goto st2;
		case 37u: goto tr33;
		case 44u: goto st2;
		case 45u: goto tr33;
		case 52u: goto st2;
		case 53u: goto tr33;
		case 60u: goto st2;
		case 61u: goto tr33;
		case 68u: goto st198;
		case 84u: goto st8;
		case 92u: goto st8;
		case 100u: goto st8;
		case 108u: goto st8;
		case 116u: goto st8;
		case 124u: goto st8;
		case 132u: goto st199;
		case 148u: goto st9;
		case 156u: goto st9;
		case 164u: goto st9;
		case 172u: goto st9;
		case 180u: goto st9;
		case 188u: goto st9;
	}
	if ( (*p) < 80u ) {
		if ( (*p) < 16u ) {
			if ( (*p) > 7u ) {
				if ( 8u <= (*p) && (*p) <= 15u )
					goto tr33;
			} else
				goto tr385;
		} else if ( (*p) > 63u ) {
			if ( (*p) > 71u ) {
				if ( 72u <= (*p) && (*p) <= 79u )
					goto tr33;
			} else if ( (*p) >= 64u )
				goto tr387;
		} else
			goto tr0;
	} else if ( (*p) > 127u ) {
		if ( (*p) < 144u ) {
			if ( (*p) > 135u ) {
				if ( 136u <= (*p) && (*p) <= 143u )
					goto tr33;
			} else if ( (*p) >= 128u )
				goto tr389;
		} else if ( (*p) > 191u ) {
			if ( (*p) > 199u ) {
				if ( 200u <= (*p) && (*p) <= 207u )
					goto tr33;
			} else if ( (*p) >= 192u )
				goto tr391;
		} else
			goto tr5;
	} else
		goto tr3;
	goto tr57;
st207:
	if ( ++p == pe )
		goto _test_eof207;
case 207:
	switch( (*p) ) {
		case 4u: goto st2;
		case 12u: goto st2;
		case 68u: goto st8;
		case 76u: goto st8;
		case 132u: goto st9;
		case 140u: goto st9;
	}
	if ( (*p) < 14u ) {
		if ( (*p) > 3u ) {
			if ( 6u <= (*p) && (*p) <= 11u )
				goto tr0;
		} else
			goto tr0;
	} else if ( (*p) > 15u ) {
		if ( (*p) < 128u ) {
			if ( 64u <= (*p) && (*p) <= 79u )
				goto tr3;
		} else if ( (*p) > 143u ) {
			if ( 192u <= (*p) && (*p) <= 207u )
				goto tr57;
		} else
			goto tr5;
	} else
		goto tr0;
	goto tr33;
tr300:
#line 190 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_REX_PREFIX(*p);
  }
	goto st208;
st208:
	if ( ++p == pe )
		goto _test_eof208;
case 208:
#line 15098 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	if ( (*p) == 15u )
		goto st209;
	goto tr33;
st209:
	if ( ++p == pe )
		goto _test_eof209;
case 209:
	switch( (*p) ) {
		case 58u: goto st210;
		case 110u: goto tr323;
		case 126u: goto tr401;
	}
	goto tr33;
st210:
	if ( ++p == pe )
		goto _test_eof210;
case 210:
	switch( (*p) ) {
		case 21u: goto st211;
		case 22u: goto tr403;
		case 23u: goto tr404;
		case 34u: goto tr328;
	}
	goto tr33;
st211:
	if ( ++p == pe )
		goto _test_eof211;
case 211:
	if ( 192u <= (*p) )
		goto tr405;
	goto tr33;
tr404:
#line 25 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_DATA16_PREFIX(FALSE);
  }
#line 298 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(0, OperandSize64bit);
  }
	goto st212;
st212:
	if ( ++p == pe )
		goto _test_eof212;
case 212:
#line 15144 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	if ( 192u <= (*p) )
		goto tr114;
	goto tr33;
st213:
	if ( ++p == pe )
		goto _test_eof213;
case 213:
	switch( (*p) ) {
		case 46u: goto st180;
		case 102u: goto st214;
	}
	goto tr33;
st214:
	if ( ++p == pe )
		goto _test_eof214;
case 214:
	switch( (*p) ) {
		case 46u: goto st180;
		case 102u: goto st215;
	}
	goto tr33;
st215:
	if ( ++p == pe )
		goto _test_eof215;
case 215:
	switch( (*p) ) {
		case 46u: goto st180;
		case 102u: goto st216;
	}
	goto tr33;
st216:
	if ( ++p == pe )
		goto _test_eof216;
case 216:
	switch( (*p) ) {
		case 46u: goto st180;
		case 102u: goto st217;
	}
	goto tr33;
st217:
	if ( ++p == pe )
		goto _test_eof217;
case 217:
	if ( (*p) == 46u )
		goto st180;
	goto tr33;
st218:
	if ( ++p == pe )
		goto _test_eof218;
case 218:
	switch( (*p) ) {
		case 4u: goto st192;
		case 5u: goto tr410;
		case 12u: goto st192;
		case 13u: goto tr410;
		case 20u: goto st192;
		case 21u: goto tr410;
		case 28u: goto st192;
		case 29u: goto tr410;
		case 36u: goto st192;
		case 37u: goto tr410;
		case 44u: goto st192;
		case 45u: goto tr410;
		case 52u: goto st192;
		case 53u: goto tr410;
		case 60u: goto st192;
		case 61u: goto tr410;
		case 68u: goto st198;
		case 76u: goto st198;
		case 84u: goto st198;
		case 92u: goto st198;
		case 100u: goto st198;
		case 108u: goto st198;
		case 116u: goto st198;
		case 124u: goto st198;
		case 132u: goto st199;
		case 140u: goto st199;
		case 148u: goto st199;
		case 156u: goto st199;
		case 164u: goto st199;
		case 172u: goto st199;
		case 180u: goto st199;
		case 188u: goto st199;
	}
	if ( (*p) < 64u ) {
		if ( (*p) <= 63u )
			goto tr385;
	} else if ( (*p) > 127u ) {
		if ( (*p) > 191u ) {
			if ( 248u <= (*p) )
				goto st168;
		} else if ( (*p) >= 128u )
			goto tr389;
	} else
		goto tr387;
	goto tr391;
st219:
	if ( ++p == pe )
		goto _test_eof219;
case 219:
	switch( (*p) ) {
		case 4u: goto st44;
		case 5u: goto tr95;
		case 12u: goto st44;
		case 13u: goto tr95;
		case 20u: goto st44;
		case 21u: goto tr95;
		case 28u: goto st44;
		case 29u: goto tr95;
		case 36u: goto st44;
		case 37u: goto tr95;
		case 44u: goto st44;
		case 45u: goto tr95;
		case 52u: goto st44;
		case 53u: goto tr95;
		case 60u: goto st44;
		case 61u: goto tr95;
		case 68u: goto st50;
		case 76u: goto st50;
		case 84u: goto st50;
		case 92u: goto st50;
		case 100u: goto st50;
		case 108u: goto st50;
		case 116u: goto st50;
		case 124u: goto st50;
		case 132u: goto st51;
		case 140u: goto st51;
		case 148u: goto st51;
		case 156u: goto st51;
		case 164u: goto st51;
		case 172u: goto st51;
		case 180u: goto st51;
		case 188u: goto st51;
	}
	if ( (*p) < 64u ) {
		if ( (*p) <= 63u )
			goto tr93;
	} else if ( (*p) > 127u ) {
		if ( (*p) > 191u ) {
			if ( 248u <= (*p) )
				goto st11;
		} else if ( (*p) >= 128u )
			goto tr98;
	} else
		goto tr96;
	goto tr349;
st220:
	if ( ++p == pe )
		goto _test_eof220;
case 220:
	switch( (*p) ) {
		case 4u: goto tr393;
		case 5u: goto tr411;
		case 68u: goto tr395;
		case 132u: goto tr397;
	}
	if ( (*p) < 64u ) {
		if ( (*p) <= 7u )
			goto tr392;
	} else if ( (*p) > 71u ) {
		if ( (*p) > 135u ) {
			if ( 192u <= (*p) && (*p) <= 199u )
				goto tr398;
		} else if ( (*p) >= 128u )
			goto tr396;
	} else
		goto tr394;
	goto tr33;
st221:
	if ( ++p == pe )
		goto _test_eof221;
case 221:
	switch( (*p) ) {
		case 4u: goto st44;
		case 5u: goto tr95;
		case 12u: goto st44;
		case 13u: goto tr95;
		case 20u: goto st44;
		case 21u: goto tr95;
		case 28u: goto st44;
		case 29u: goto tr95;
		case 36u: goto st44;
		case 37u: goto tr95;
		case 44u: goto st44;
		case 45u: goto tr95;
		case 60u: goto st44;
		case 61u: goto tr95;
		case 68u: goto st50;
		case 76u: goto st50;
		case 84u: goto st50;
		case 92u: goto st50;
		case 100u: goto st50;
		case 108u: goto st50;
		case 124u: goto st50;
		case 132u: goto st51;
		case 140u: goto st51;
		case 148u: goto st51;
		case 156u: goto st51;
		case 164u: goto st51;
		case 172u: goto st51;
		case 188u: goto st51;
	}
	if ( (*p) < 112u ) {
		if ( (*p) < 48u ) {
			if ( (*p) <= 47u )
				goto tr93;
		} else if ( (*p) > 55u ) {
			if ( (*p) > 63u ) {
				if ( 64u <= (*p) && (*p) <= 111u )
					goto tr96;
			} else if ( (*p) >= 56u )
				goto tr93;
		} else
			goto tr33;
	} else if ( (*p) > 119u ) {
		if ( (*p) < 176u ) {
			if ( (*p) > 127u ) {
				if ( 128u <= (*p) && (*p) <= 175u )
					goto tr98;
			} else if ( (*p) >= 120u )
				goto tr96;
		} else if ( (*p) > 183u ) {
			if ( (*p) > 191u ) {
				if ( 240u <= (*p) && (*p) <= 247u )
					goto tr33;
			} else if ( (*p) >= 184u )
				goto tr98;
		} else
			goto tr33;
	} else
		goto tr33;
	goto tr349;
st222:
	if ( ++p == pe )
		goto _test_eof222;
case 222:
	switch( (*p) ) {
		case 4u: goto st192;
		case 5u: goto tr410;
		case 68u: goto st198;
		case 132u: goto st199;
	}
	if ( (*p) < 64u ) {
		if ( (*p) <= 7u )
			goto tr385;
	} else if ( (*p) > 71u ) {
		if ( (*p) > 135u ) {
			if ( 192u <= (*p) && (*p) <= 199u )
				goto tr391;
		} else if ( (*p) >= 128u )
			goto tr389;
	} else
		goto tr387;
	goto tr33;
st223:
	if ( ++p == pe )
		goto _test_eof223;
case 223:
	switch( (*p) ) {
		case 4u: goto st2;
		case 5u: goto tr2;
		case 12u: goto st2;
		case 13u: goto tr2;
		case 20u: goto st2;
		case 21u: goto tr2;
		case 28u: goto st2;
		case 29u: goto tr2;
		case 36u: goto st2;
		case 37u: goto tr2;
		case 44u: goto st2;
		case 45u: goto tr2;
		case 60u: goto st2;
		case 61u: goto tr2;
		case 68u: goto st8;
		case 76u: goto st8;
		case 84u: goto st8;
		case 92u: goto st8;
		case 100u: goto st8;
		case 108u: goto st8;
		case 124u: goto st8;
		case 132u: goto st9;
		case 140u: goto st9;
		case 148u: goto st9;
		case 156u: goto st9;
		case 164u: goto st9;
		case 172u: goto st9;
		case 188u: goto st9;
	}
	if ( (*p) < 112u ) {
		if ( (*p) < 48u ) {
			if ( (*p) <= 47u )
				goto tr0;
		} else if ( (*p) > 55u ) {
			if ( (*p) > 63u ) {
				if ( 64u <= (*p) && (*p) <= 111u )
					goto tr3;
			} else if ( (*p) >= 56u )
				goto tr0;
		} else
			goto tr33;
	} else if ( (*p) > 119u ) {
		if ( (*p) < 176u ) {
			if ( (*p) > 127u ) {
				if ( 128u <= (*p) && (*p) <= 175u )
					goto tr5;
			} else if ( (*p) >= 120u )
				goto tr3;
		} else if ( (*p) > 183u ) {
			if ( (*p) > 191u ) {
				if ( 240u <= (*p) && (*p) <= 247u )
					goto tr33;
			} else if ( (*p) >= 184u )
				goto tr5;
		} else
			goto tr33;
	} else
		goto tr33;
	goto tr57;
tr314:
#line 13 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_LOCK_PREFIX(TRUE);
  }
	goto st224;
tr894:
#line 10 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_DATA16_PREFIX(TRUE);
  }
	goto st224;
st224:
	if ( ++p == pe )
		goto _test_eof224;
case 224:
#line 15479 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 1u: goto st39;
		case 3u: goto tr334;
		case 9u: goto st39;
		case 11u: goto tr334;
		case 15u: goto st225;
		case 17u: goto st39;
		case 19u: goto tr334;
		case 25u: goto st39;
		case 27u: goto tr334;
		case 33u: goto st39;
		case 35u: goto tr334;
		case 41u: goto st39;
		case 43u: goto tr334;
		case 49u: goto st39;
		case 51u: goto tr334;
		case 129u: goto st235;
		case 131u: goto st236;
		case 135u: goto tr416;
		case 247u: goto st237;
		case 255u: goto st238;
	}
	if ( 64u <= (*p) && (*p) <= 71u )
		goto tr413;
	goto tr33;
st225:
	if ( ++p == pe )
		goto _test_eof225;
case 225:
	switch( (*p) ) {
		case 177u: goto st39;
		case 186u: goto st226;
		case 193u: goto st39;
	}
	goto tr33;
st226:
	if ( ++p == pe )
		goto _test_eof226;
case 226:
	switch( (*p) ) {
		case 44u: goto st44;
		case 45u: goto tr95;
		case 52u: goto st44;
		case 53u: goto tr95;
		case 60u: goto st44;
		case 61u: goto tr95;
		case 108u: goto st50;
		case 116u: goto st50;
		case 124u: goto st50;
		case 172u: goto st51;
		case 180u: goto st51;
		case 188u: goto st51;
	}
	if ( (*p) < 104u ) {
		if ( 40u <= (*p) && (*p) <= 63u )
			goto tr93;
	} else if ( (*p) > 127u ) {
		if ( 168u <= (*p) && (*p) <= 191u )
			goto tr98;
	} else
		goto tr96;
	goto tr33;
tr413:
#line 190 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_REX_PREFIX(*p);
  }
	goto st227;
st227:
	if ( ++p == pe )
		goto _test_eof227;
case 227:
#line 15552 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 1u: goto st39;
		case 3u: goto tr334;
		case 9u: goto st39;
		case 11u: goto tr334;
		case 15u: goto st228;
		case 17u: goto st39;
		case 19u: goto tr334;
		case 25u: goto st39;
		case 27u: goto tr334;
		case 33u: goto st39;
		case 35u: goto tr334;
		case 41u: goto st39;
		case 43u: goto tr334;
		case 49u: goto st39;
		case 51u: goto tr334;
		case 129u: goto st230;
		case 131u: goto st231;
		case 135u: goto tr416;
		case 247u: goto st233;
		case 255u: goto st234;
	}
	goto tr33;
st228:
	if ( ++p == pe )
		goto _test_eof228;
case 228:
	switch( (*p) ) {
		case 177u: goto st39;
		case 186u: goto st229;
		case 193u: goto st39;
	}
	goto tr33;
st229:
	if ( ++p == pe )
		goto _test_eof229;
case 229:
	switch( (*p) ) {
		case 44u: goto st44;
		case 52u: goto st44;
		case 60u: goto st44;
		case 108u: goto st50;
		case 116u: goto st50;
		case 124u: goto st50;
		case 172u: goto st51;
		case 180u: goto st51;
		case 188u: goto st51;
	}
	if ( (*p) < 54u ) {
		if ( (*p) > 43u ) {
			if ( 46u <= (*p) && (*p) <= 51u )
				goto tr93;
		} else if ( (*p) >= 40u )
			goto tr93;
	} else if ( (*p) > 59u ) {
		if ( (*p) < 104u ) {
			if ( 62u <= (*p) && (*p) <= 63u )
				goto tr93;
		} else if ( (*p) > 127u ) {
			if ( 168u <= (*p) && (*p) <= 191u )
				goto tr98;
		} else
			goto tr96;
	} else
		goto tr93;
	goto tr33;
st230:
	if ( ++p == pe )
		goto _test_eof230;
case 230:
	switch( (*p) ) {
		case 4u: goto st192;
		case 12u: goto st192;
		case 20u: goto st192;
		case 28u: goto st192;
		case 36u: goto st192;
		case 44u: goto st192;
		case 52u: goto st192;
		case 68u: goto st198;
		case 76u: goto st198;
		case 84u: goto st198;
		case 92u: goto st198;
		case 100u: goto st198;
		case 108u: goto st198;
		case 116u: goto st198;
		case 132u: goto st199;
		case 140u: goto st199;
		case 148u: goto st199;
		case 156u: goto st199;
		case 164u: goto st199;
		case 172u: goto st199;
		case 180u: goto st199;
	}
	if ( (*p) < 30u ) {
		if ( (*p) < 6u ) {
			if ( (*p) <= 3u )
				goto tr385;
		} else if ( (*p) > 11u ) {
			if ( (*p) > 19u ) {
				if ( 22u <= (*p) && (*p) <= 27u )
					goto tr385;
			} else if ( (*p) >= 14u )
				goto tr385;
		} else
			goto tr385;
	} else if ( (*p) > 35u ) {
		if ( (*p) < 54u ) {
			if ( (*p) > 43u ) {
				if ( 46u <= (*p) && (*p) <= 51u )
					goto tr385;
			} else if ( (*p) >= 38u )
				goto tr385;
		} else if ( (*p) > 55u ) {
			if ( (*p) > 119u ) {
				if ( 128u <= (*p) && (*p) <= 183u )
					goto tr389;
			} else if ( (*p) >= 64u )
				goto tr387;
		} else
			goto tr385;
	} else
		goto tr385;
	goto tr33;
st231:
	if ( ++p == pe )
		goto _test_eof231;
case 231:
	switch( (*p) ) {
		case 4u: goto st44;
		case 12u: goto st44;
		case 20u: goto st44;
		case 28u: goto st44;
		case 36u: goto st44;
		case 44u: goto st44;
		case 52u: goto st44;
		case 68u: goto st50;
		case 76u: goto st50;
		case 84u: goto st50;
		case 92u: goto st50;
		case 100u: goto st50;
		case 108u: goto st50;
		case 116u: goto st50;
		case 132u: goto st51;
		case 140u: goto st51;
		case 148u: goto st51;
		case 156u: goto st51;
		case 164u: goto st51;
		case 172u: goto st51;
		case 180u: goto st51;
	}
	if ( (*p) < 30u ) {
		if ( (*p) < 6u ) {
			if ( (*p) <= 3u )
				goto tr93;
		} else if ( (*p) > 11u ) {
			if ( (*p) > 19u ) {
				if ( 22u <= (*p) && (*p) <= 27u )
					goto tr93;
			} else if ( (*p) >= 14u )
				goto tr93;
		} else
			goto tr93;
	} else if ( (*p) > 35u ) {
		if ( (*p) < 54u ) {
			if ( (*p) > 43u ) {
				if ( 46u <= (*p) && (*p) <= 51u )
					goto tr93;
			} else if ( (*p) >= 38u )
				goto tr93;
		} else if ( (*p) > 55u ) {
			if ( (*p) > 119u ) {
				if ( 128u <= (*p) && (*p) <= 183u )
					goto tr98;
			} else if ( (*p) >= 64u )
				goto tr96;
		} else
			goto tr93;
	} else
		goto tr93;
	goto tr33;
tr416:
#line 439 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(1, OperandSize16bit);
  }
	goto st232;
tr896:
#line 436 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(1, OperandSize8bit);
  }
	goto st232;
tr897:
#line 442 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(1, OperandSize32bit);
  }
	goto st232;
tr901:
#line 445 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(1, OperandSize64bit);
  }
	goto st232;
st232:
	if ( ++p == pe )
		goto _test_eof232;
case 232:
#line 15761 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 4u: goto tr194;
		case 5u: goto tr195;
		case 12u: goto tr194;
		case 13u: goto tr195;
		case 20u: goto tr194;
		case 21u: goto tr195;
		case 28u: goto tr194;
		case 29u: goto tr195;
		case 36u: goto tr194;
		case 37u: goto tr195;
		case 44u: goto tr194;
		case 45u: goto tr195;
		case 52u: goto tr194;
		case 53u: goto tr195;
		case 60u: goto tr194;
		case 61u: goto tr195;
		case 68u: goto tr197;
		case 76u: goto tr197;
		case 84u: goto tr197;
		case 92u: goto tr197;
		case 100u: goto tr197;
		case 108u: goto tr197;
		case 116u: goto tr197;
		case 124u: goto tr197;
		case 132u: goto tr199;
		case 140u: goto tr199;
		case 148u: goto tr199;
		case 156u: goto tr199;
		case 164u: goto tr199;
		case 172u: goto tr199;
		case 180u: goto tr199;
		case 188u: goto tr199;
	}
	if ( (*p) < 64u ) {
		if ( (*p) <= 63u )
			goto tr193;
	} else if ( (*p) > 127u ) {
		if ( 128u <= (*p) && (*p) <= 191u )
			goto tr198;
	} else
		goto tr196;
	goto tr33;
st233:
	if ( ++p == pe )
		goto _test_eof233;
case 233:
	switch( (*p) ) {
		case 20u: goto st2;
		case 28u: goto st2;
		case 84u: goto st8;
		case 92u: goto st8;
		case 148u: goto st9;
		case 156u: goto st9;
	}
	if ( (*p) < 30u ) {
		if ( (*p) > 19u ) {
			if ( 22u <= (*p) && (*p) <= 27u )
				goto tr0;
		} else if ( (*p) >= 16u )
			goto tr0;
	} else if ( (*p) > 31u ) {
		if ( (*p) > 95u ) {
			if ( 144u <= (*p) && (*p) <= 159u )
				goto tr5;
		} else if ( (*p) >= 80u )
			goto tr3;
	} else
		goto tr0;
	goto tr33;
st234:
	if ( ++p == pe )
		goto _test_eof234;
case 234:
	switch( (*p) ) {
		case 4u: goto st2;
		case 12u: goto st2;
		case 68u: goto st8;
		case 76u: goto st8;
		case 132u: goto st9;
		case 140u: goto st9;
	}
	if ( (*p) < 14u ) {
		if ( (*p) > 3u ) {
			if ( 6u <= (*p) && (*p) <= 11u )
				goto tr0;
		} else
			goto tr0;
	} else if ( (*p) > 15u ) {
		if ( (*p) > 79u ) {
			if ( 128u <= (*p) && (*p) <= 143u )
				goto tr5;
		} else if ( (*p) >= 64u )
			goto tr3;
	} else
		goto tr0;
	goto tr33;
st235:
	if ( ++p == pe )
		goto _test_eof235;
case 235:
	switch( (*p) ) {
		case 4u: goto st192;
		case 5u: goto tr410;
		case 12u: goto st192;
		case 13u: goto tr410;
		case 20u: goto st192;
		case 21u: goto tr410;
		case 28u: goto st192;
		case 29u: goto tr410;
		case 36u: goto st192;
		case 37u: goto tr410;
		case 44u: goto st192;
		case 45u: goto tr410;
		case 52u: goto st192;
		case 53u: goto tr410;
		case 68u: goto st198;
		case 76u: goto st198;
		case 84u: goto st198;
		case 92u: goto st198;
		case 100u: goto st198;
		case 108u: goto st198;
		case 116u: goto st198;
		case 132u: goto st199;
		case 140u: goto st199;
		case 148u: goto st199;
		case 156u: goto st199;
		case 164u: goto st199;
		case 172u: goto st199;
		case 180u: goto st199;
	}
	if ( (*p) < 64u ) {
		if ( (*p) <= 55u )
			goto tr385;
	} else if ( (*p) > 119u ) {
		if ( 128u <= (*p) && (*p) <= 183u )
			goto tr389;
	} else
		goto tr387;
	goto tr33;
st236:
	if ( ++p == pe )
		goto _test_eof236;
case 236:
	switch( (*p) ) {
		case 4u: goto st44;
		case 5u: goto tr95;
		case 12u: goto st44;
		case 13u: goto tr95;
		case 20u: goto st44;
		case 21u: goto tr95;
		case 28u: goto st44;
		case 29u: goto tr95;
		case 36u: goto st44;
		case 37u: goto tr95;
		case 44u: goto st44;
		case 45u: goto tr95;
		case 52u: goto st44;
		case 53u: goto tr95;
		case 68u: goto st50;
		case 76u: goto st50;
		case 84u: goto st50;
		case 92u: goto st50;
		case 100u: goto st50;
		case 108u: goto st50;
		case 116u: goto st50;
		case 132u: goto st51;
		case 140u: goto st51;
		case 148u: goto st51;
		case 156u: goto st51;
		case 164u: goto st51;
		case 172u: goto st51;
		case 180u: goto st51;
	}
	if ( (*p) < 64u ) {
		if ( (*p) <= 55u )
			goto tr93;
	} else if ( (*p) > 119u ) {
		if ( 128u <= (*p) && (*p) <= 183u )
			goto tr98;
	} else
		goto tr96;
	goto tr33;
st237:
	if ( ++p == pe )
		goto _test_eof237;
case 237:
	switch( (*p) ) {
		case 20u: goto st2;
		case 21u: goto tr2;
		case 28u: goto st2;
		case 29u: goto tr2;
		case 84u: goto st8;
		case 92u: goto st8;
		case 148u: goto st9;
		case 156u: goto st9;
	}
	if ( (*p) < 80u ) {
		if ( 16u <= (*p) && (*p) <= 31u )
			goto tr0;
	} else if ( (*p) > 95u ) {
		if ( 144u <= (*p) && (*p) <= 159u )
			goto tr5;
	} else
		goto tr3;
	goto tr33;
st238:
	if ( ++p == pe )
		goto _test_eof238;
case 238:
	switch( (*p) ) {
		case 4u: goto st2;
		case 5u: goto tr2;
		case 12u: goto st2;
		case 13u: goto tr2;
		case 68u: goto st8;
		case 76u: goto st8;
		case 132u: goto st9;
		case 140u: goto st9;
	}
	if ( (*p) < 64u ) {
		if ( (*p) <= 15u )
			goto tr0;
	} else if ( (*p) > 79u ) {
		if ( 128u <= (*p) && (*p) <= 143u )
			goto tr5;
	} else
		goto tr3;
	goto tr33;
tr315:
#line 22 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_REPNZ_PREFIX(TRUE);
  }
	goto st239;
tr907:
#line 10 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_DATA16_PREFIX(TRUE);
  }
	goto st239;
st239:
	if ( ++p == pe )
		goto _test_eof239;
case 239:
#line 16007 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 15u: goto st240;
		case 167u: goto tr232;
		case 175u: goto tr233;
	}
	if ( 64u <= (*p) && (*p) <= 71u )
		goto tr427;
	goto tr33;
st240:
	if ( ++p == pe )
		goto _test_eof240;
case 240:
	if ( (*p) == 56u )
		goto st241;
	goto tr33;
st241:
	if ( ++p == pe )
		goto _test_eof241;
case 241:
	if ( (*p) == 241u )
		goto tr429;
	goto tr33;
tr427:
#line 190 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_REX_PREFIX(*p);
  }
	goto st242;
st242:
	if ( ++p == pe )
		goto _test_eof242;
case 242:
#line 16040 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	if ( (*p) == 15u )
		goto st240;
	goto tr33;
tr316:
#line 16 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_REPZ_PREFIX(TRUE);
  }
#line 19 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_REPZ_PREFIX(TRUE);
  }
	goto st243;
tr923:
#line 10 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_DATA16_PREFIX(TRUE);
  }
	goto st243;
st243:
	if ( ++p == pe )
		goto _test_eof243;
case 243:
#line 16064 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 15u: goto st244;
		case 165u: goto tr232;
		case 167u: goto tr232;
		case 171u: goto tr233;
		case 173u: goto tr234;
		case 175u: goto tr233;
	}
	if ( 64u <= (*p) && (*p) <= 71u )
		goto tr431;
	goto tr33;
st244:
	if ( ++p == pe )
		goto _test_eof244;
case 244:
	if ( (*p) == 184u )
		goto tr432;
	if ( 188u <= (*p) && (*p) <= 189u )
		goto tr432;
	goto tr33;
tr431:
#line 190 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_REX_PREFIX(*p);
  }
	goto st245;
st245:
	if ( ++p == pe )
		goto _test_eof245;
case 245:
#line 16095 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	if ( (*p) == 15u )
		goto st244;
	goto tr33;
st246:
	if ( ++p == pe )
		goto _test_eof246;
case 246:
	switch( (*p) ) {
		case 4u: goto st192;
		case 5u: goto tr410;
		case 20u: goto st2;
		case 21u: goto tr2;
		case 28u: goto st2;
		case 29u: goto tr2;
		case 36u: goto st2;
		case 37u: goto tr2;
		case 44u: goto st2;
		case 45u: goto tr2;
		case 52u: goto st2;
		case 53u: goto tr2;
		case 60u: goto st2;
		case 61u: goto tr2;
		case 68u: goto st198;
		case 84u: goto st8;
		case 92u: goto st8;
		case 100u: goto st8;
		case 108u: goto st8;
		case 116u: goto st8;
		case 124u: goto st8;
		case 132u: goto st199;
		case 148u: goto st9;
		case 156u: goto st9;
		case 164u: goto st9;
		case 172u: goto st9;
		case 180u: goto st9;
		case 188u: goto st9;
	}
	if ( (*p) < 80u ) {
		if ( (*p) < 16u ) {
			if ( (*p) > 7u ) {
				if ( 8u <= (*p) && (*p) <= 15u )
					goto tr33;
			} else
				goto tr385;
		} else if ( (*p) > 63u ) {
			if ( (*p) > 71u ) {
				if ( 72u <= (*p) && (*p) <= 79u )
					goto tr33;
			} else if ( (*p) >= 64u )
				goto tr387;
		} else
			goto tr0;
	} else if ( (*p) > 127u ) {
		if ( (*p) < 144u ) {
			if ( (*p) > 135u ) {
				if ( 136u <= (*p) && (*p) <= 143u )
					goto tr33;
			} else if ( (*p) >= 128u )
				goto tr389;
		} else if ( (*p) > 191u ) {
			if ( (*p) > 199u ) {
				if ( 200u <= (*p) && (*p) <= 207u )
					goto tr33;
			} else if ( (*p) >= 192u )
				goto tr391;
		} else
			goto tr5;
	} else
		goto tr3;
	goto tr57;
st247:
	if ( ++p == pe )
		goto _test_eof247;
case 247:
	switch( (*p) ) {
		case 4u: goto st2;
		case 5u: goto tr2;
		case 12u: goto st2;
		case 13u: goto tr2;
		case 68u: goto st8;
		case 76u: goto st8;
		case 132u: goto st9;
		case 140u: goto st9;
	}
	if ( (*p) < 64u ) {
		if ( (*p) <= 15u )
			goto tr0;
	} else if ( (*p) > 79u ) {
		if ( (*p) > 143u ) {
			if ( 192u <= (*p) && (*p) <= 207u )
				goto tr57;
		} else if ( (*p) >= 128u )
			goto tr5;
	} else
		goto tr3;
	goto tr33;
tr1003:
#line 329 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
        begin = p;
        BitmapSetBit(valid_targets, p - data);
        SET_REX_PREFIX(FALSE);
        SET_VEX_PREFIX2(0xe0);
        SET_VEX_PREFIX3(0x00);
        operand_states = 0;
     }
	goto st248;
st248:
	if ( ++p == pe )
		goto _test_eof248;
case 248:
#line 16207 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 4u: goto st44;
		case 5u: goto tr95;
		case 12u: goto st44;
		case 13u: goto tr95;
		case 20u: goto st44;
		case 21u: goto tr95;
		case 28u: goto st44;
		case 29u: goto tr95;
		case 36u: goto st44;
		case 37u: goto tr95;
		case 44u: goto st44;
		case 45u: goto tr95;
		case 52u: goto st44;
		case 53u: goto tr95;
		case 60u: goto st44;
		case 61u: goto tr95;
		case 68u: goto st50;
		case 76u: goto st50;
		case 84u: goto st50;
		case 92u: goto st50;
		case 100u: goto st50;
		case 108u: goto st50;
		case 116u: goto st50;
		case 124u: goto st50;
		case 132u: goto st51;
		case 140u: goto st51;
		case 148u: goto st51;
		case 156u: goto st51;
		case 164u: goto st51;
		case 172u: goto st51;
		case 180u: goto st51;
		case 188u: goto st51;
	}
	if ( (*p) < 64u ) {
		if ( (*p) <= 63u )
			goto tr93;
	} else if ( (*p) > 127u ) {
		if ( (*p) > 191u ) {
			if ( 248u <= (*p) )
				goto st11;
		} else if ( (*p) >= 128u )
			goto tr98;
	} else
		goto tr96;
	goto tr184;
tr1004:
#line 329 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
        begin = p;
        BitmapSetBit(valid_targets, p - data);
        SET_REX_PREFIX(FALSE);
        SET_VEX_PREFIX2(0xe0);
        SET_VEX_PREFIX3(0x00);
        operand_states = 0;
     }
	goto st249;
st249:
	if ( ++p == pe )
		goto _test_eof249;
case 249:
#line 16269 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 4u: goto st80;
		case 5u: goto tr248;
		case 12u: goto st80;
		case 13u: goto tr248;
		case 20u: goto st80;
		case 21u: goto tr248;
		case 28u: goto st80;
		case 29u: goto tr248;
		case 36u: goto st80;
		case 37u: goto tr248;
		case 44u: goto st80;
		case 45u: goto tr248;
		case 52u: goto st80;
		case 53u: goto tr248;
		case 60u: goto st80;
		case 61u: goto tr248;
		case 68u: goto st86;
		case 76u: goto st86;
		case 84u: goto st86;
		case 92u: goto st86;
		case 100u: goto st86;
		case 108u: goto st86;
		case 116u: goto st86;
		case 124u: goto st86;
		case 132u: goto st87;
		case 140u: goto st87;
		case 148u: goto st87;
		case 156u: goto st87;
		case 164u: goto st87;
		case 172u: goto st87;
		case 180u: goto st87;
		case 188u: goto st87;
	}
	if ( (*p) < 64u ) {
		if ( (*p) <= 63u )
			goto tr185;
	} else if ( (*p) > 127u ) {
		if ( (*p) > 191u ) {
			if ( 248u <= (*p) )
				goto st12;
		} else if ( (*p) >= 128u )
			goto tr189;
	} else
		goto tr187;
	goto tr191;
tr1005:
#line 329 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
        begin = p;
        BitmapSetBit(valid_targets, p - data);
        SET_REX_PREFIX(FALSE);
        SET_VEX_PREFIX2(0xe0);
        SET_VEX_PREFIX3(0x00);
        operand_states = 0;
     }
	goto st250;
st250:
	if ( ++p == pe )
		goto _test_eof250;
case 250:
#line 16331 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 4u: goto st44;
		case 5u: goto tr95;
		case 12u: goto st44;
		case 13u: goto tr95;
		case 20u: goto st44;
		case 21u: goto tr95;
		case 28u: goto st44;
		case 29u: goto tr95;
		case 36u: goto st44;
		case 37u: goto tr95;
		case 44u: goto st44;
		case 45u: goto tr95;
		case 52u: goto st44;
		case 53u: goto tr95;
		case 60u: goto st44;
		case 61u: goto tr95;
		case 68u: goto st50;
		case 76u: goto st50;
		case 84u: goto st50;
		case 92u: goto st50;
		case 100u: goto st50;
		case 108u: goto st50;
		case 116u: goto st50;
		case 124u: goto st50;
		case 132u: goto st51;
		case 140u: goto st51;
		case 148u: goto st51;
		case 156u: goto st51;
		case 164u: goto st51;
		case 172u: goto st51;
		case 180u: goto st51;
		case 188u: goto st51;
		case 224u: goto tr433;
		case 225u: goto tr434;
		case 226u: goto tr435;
		case 227u: goto tr436;
		case 228u: goto tr437;
		case 229u: goto tr438;
		case 230u: goto tr439;
		case 231u: goto tr440;
	}
	if ( (*p) < 64u ) {
		if ( (*p) <= 63u )
			goto tr93;
	} else if ( (*p) > 127u ) {
		if ( (*p) > 247u ) {
			if ( 248u <= (*p) )
				goto st11;
		} else if ( (*p) >= 192u )
			goto tr115;
	} else
		goto tr96;
	goto tr98;
tr433:
#line 295 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(0, OperandSize32bit);
  }
#line 384 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_NAME(0, ((*p) & 0x07) |
                           ((GET_REX_PREFIX() & 0x01) << 3) |
                           (((~GET_VEX_PREFIX2()) & 0x20) >> 2));
  }
	goto st251;
st251:
	if ( ++p == pe )
		goto _test_eof251;
case 251:
#line 16402 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	if ( (*p) == 224u )
		goto tr441;
	goto tr25;
tr441:
#line 58 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_IMM_TYPE(IMM8);
    SET_IMM_PTR(p);
  }
#line 93 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    /* Restricted %rsp or %rbp must be processed by appropriate nacl-special
       instruction, not with regular instruction.  */
    if (restricted_register == REG_RSP) {
      PrintError("Incorrectly modified register %%rsp\n", begin - data);
      result = 1;
      goto error_detected;
    } else if (restricted_register == REG_RBP) {
      PrintError("Incorrectly modified register %%rbp\n", begin - data);
      result = 1;
      goto error_detected;
    }
    /* If Sandboxed Rsi is destroyed then we must note that.  */
    if (restricted_register == kSandboxedRsi) {
      if (CHECK_OPERAND(0, REG_RSI, OperandSandboxRestricted) ||
          CHECK_OPERAND(0, REG_RSI, OperandSandboxUnrestricted) ||
          CHECK_OPERAND(1, REG_RSI, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_RSI, OperandSandboxUnrestricted)) {
        restricted_register = kNoRestrictedReg;
      }
    }
    if (restricted_register == kSandboxedRsi) {
      if (CHECK_OPERAND(0, REG_RDI, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_RDI, OperandSandboxRestricted)) {
        sandboxed_rsi_restricted_rdi = begin;
        restricted_register = kSandboxedRsiRestrictedRdi;
      }
    }
    if (restricted_register != kSandboxedRsiRestrictedRdi) {
      restricted_register = kNoRestrictedReg;
      if (CHECK_OPERAND(0, REG_R15, OperandSandbox8bit) ||
          CHECK_OPERAND(0, REG_R15, OperandSandboxRestricted) ||
          CHECK_OPERAND(0, REG_R15, OperandSandboxUnrestricted) ||
          CHECK_OPERAND(1, REG_R15, OperandSandbox8bit) ||
          CHECK_OPERAND(1, REG_R15, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_R15, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%r15\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((CHECK_OPERAND(0, REG_RBP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(0, REG_RBP, OperandSandboxUnrestricted) ||
                 (CHECK_OPERAND(1, REG_RBP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(1, REG_RBP, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%rbp\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((CHECK_OPERAND(0, REG_RSP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(0, REG_RSP, OperandSandboxUnrestricted) ||
                 (CHECK_OPERAND(1, REG_RSP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(1, REG_RSP, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%rsp\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((operand_states & 0x70) == (OperandSandboxRestricted << 5)) {
        restricted_register = operand_states & 0x0f;
      } else if ((operand_states & 0x7000) ==
                                        (OperandSandboxRestricted << (5 + 8))) {
        restricted_register = (operand_states & 0x0f00) >> 8;
      }
    }
  }
#line 337 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
       /* On successful match the instruction start must point to the next byte
        * to be able to report the new offset as the start of instruction
        * causing error.  */
       begin = p + 1;
     }
	goto st724;
st724:
	if ( ++p == pe )
		goto _test_eof724;
case 724:
#line 16490 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 0u: goto tr978;
		case 1u: goto tr979;
		case 2u: goto tr980;
		case 3u: goto tr981;
		case 4u: goto tr982;
		case 5u: goto tr983;
		case 8u: goto tr978;
		case 9u: goto tr979;
		case 10u: goto tr980;
		case 11u: goto tr981;
		case 12u: goto tr982;
		case 13u: goto tr983;
		case 15u: goto tr984;
		case 16u: goto tr978;
		case 17u: goto tr979;
		case 18u: goto tr980;
		case 19u: goto tr981;
		case 20u: goto tr982;
		case 21u: goto tr983;
		case 24u: goto tr978;
		case 25u: goto tr979;
		case 26u: goto tr980;
		case 27u: goto tr981;
		case 28u: goto tr982;
		case 29u: goto tr983;
		case 32u: goto tr978;
		case 33u: goto tr979;
		case 34u: goto tr980;
		case 35u: goto tr981;
		case 36u: goto tr982;
		case 37u: goto tr983;
		case 40u: goto tr978;
		case 41u: goto tr979;
		case 42u: goto tr980;
		case 43u: goto tr981;
		case 44u: goto tr982;
		case 45u: goto tr983;
		case 46u: goto tr985;
		case 48u: goto tr978;
		case 49u: goto tr979;
		case 50u: goto tr980;
		case 51u: goto tr981;
		case 52u: goto tr982;
		case 53u: goto tr983;
		case 60u: goto tr987;
		case 61u: goto tr988;
		case 62u: goto tr989;
		case 65u: goto tr991;
		case 72u: goto tr992;
		case 73u: goto tr993;
		case 74u: goto tr994;
		case 76u: goto tr1044;
		case 99u: goto tr981;
		case 102u: goto tr999;
		case 104u: goto tr988;
		case 105u: goto tr1000;
		case 106u: goto tr987;
		case 107u: goto tr1001;
		case 128u: goto tr1003;
		case 129u: goto tr1004;
		case 131u: goto tr1005;
		case 133u: goto tr979;
		case 134u: goto tr1006;
		case 135u: goto tr1007;
		case 137u: goto tr979;
		case 138u: goto tr980;
		case 139u: goto tr981;
		case 141u: goto tr1008;
		case 143u: goto tr1009;
		case 144u: goto tr1010;
		case 155u: goto tr1010;
		case 168u: goto tr982;
		case 169u: goto tr983;
		case 192u: goto tr1017;
		case 193u: goto tr1018;
		case 196u: goto tr1019;
		case 197u: goto tr1020;
		case 198u: goto tr1021;
		case 199u: goto tr1022;
		case 200u: goto tr1023;
		case 202u: goto tr1024;
		case 203u: goto tr1010;
		case 209u: goto tr1026;
		case 211u: goto tr1026;
		case 216u: goto tr986;
		case 217u: goto tr1027;
		case 218u: goto tr1028;
		case 219u: goto tr1029;
		case 220u: goto tr1030;
		case 221u: goto tr1031;
		case 222u: goto tr1032;
		case 223u: goto tr1033;
		case 235u: goto tr1002;
		case 240u: goto tr1035;
		case 242u: goto tr1036;
		case 243u: goto tr1037;
		case 246u: goto tr1038;
		case 247u: goto tr1039;
		case 254u: goto tr1040;
		case 255u: goto tr1041;
	}
	if ( (*p) < 164u ) {
		if ( (*p) < 88u ) {
			if ( (*p) < 64u ) {
				if ( 56u <= (*p) && (*p) <= 59u )
					goto tr986;
			} else if ( (*p) > 71u ) {
				if ( (*p) > 79u ) {
					if ( 80u <= (*p) && (*p) <= 87u )
						goto tr997;
				} else if ( (*p) >= 75u )
					goto tr995;
			} else
				goto tr990;
		} else if ( (*p) > 95u ) {
			if ( (*p) < 132u ) {
				if ( 112u <= (*p) && (*p) <= 127u )
					goto tr1002;
			} else if ( (*p) > 136u ) {
				if ( (*p) > 151u ) {
					if ( 152u <= (*p) && (*p) <= 153u )
						goto tr1010;
				} else if ( (*p) >= 145u )
					goto tr1011;
			} else
				goto tr978;
		} else
			goto tr998;
	} else if ( (*p) > 167u ) {
		if ( (*p) < 184u ) {
			if ( (*p) < 172u ) {
				if ( 170u <= (*p) && (*p) <= 171u )
					goto tr1013;
			} else if ( (*p) > 173u ) {
				if ( (*p) > 175u ) {
					if ( 176u <= (*p) && (*p) <= 183u )
						goto tr1015;
				} else if ( (*p) >= 174u )
					goto tr1013;
			} else
				goto tr1014;
		} else if ( (*p) > 191u ) {
			if ( (*p) < 232u ) {
				if ( 208u <= (*p) && (*p) <= 210u )
					goto tr1025;
			} else if ( (*p) > 233u ) {
				if ( (*p) > 249u ) {
					if ( 252u <= (*p) && (*p) <= 253u )
						goto tr1010;
				} else if ( (*p) >= 244u )
					goto tr1010;
			} else
				goto tr1034;
		} else
			goto tr1016;
	} else
		goto tr1012;
	goto tr33;
tr1044:
#line 329 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
        begin = p;
        BitmapSetBit(valid_targets, p - data);
        SET_REX_PREFIX(FALSE);
        SET_VEX_PREFIX2(0xe0);
        SET_VEX_PREFIX3(0x00);
        operand_states = 0;
     }
#line 190 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_REX_PREFIX(*p);
  }
	goto st252;
st252:
	if ( ++p == pe )
		goto _test_eof252;
case 252:
#line 16669 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 1u: goto tr442;
		case 3u: goto tr221;
		case 9u: goto tr220;
		case 11u: goto tr221;
		case 15u: goto st142;
		case 17u: goto tr220;
		case 19u: goto tr221;
		case 25u: goto tr220;
		case 27u: goto tr221;
		case 33u: goto tr220;
		case 35u: goto tr221;
		case 41u: goto tr220;
		case 43u: goto tr221;
		case 49u: goto tr220;
		case 51u: goto tr221;
		case 57u: goto st38;
		case 59u: goto st38;
		case 99u: goto tr221;
		case 105u: goto tr224;
		case 107u: goto tr225;
		case 129u: goto st144;
		case 131u: goto st145;
		case 133u: goto tr220;
		case 135u: goto tr228;
		case 137u: goto tr220;
		case 139u: goto tr221;
		case 141u: goto tr230;
		case 193u: goto st150;
		case 199u: goto st151;
		case 209u: goto st152;
		case 211u: goto st152;
		case 247u: goto st153;
		case 255u: goto st154;
	}
	if ( (*p) > 151u ) {
		if ( 184u <= (*p) && (*p) <= 191u )
			goto tr235;
	} else if ( (*p) >= 145u )
		goto tr231;
	goto tr33;
tr442:
#line 298 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(0, OperandSize64bit);
  }
	goto st253;
st253:
	if ( ++p == pe )
		goto _test_eof253;
case 253:
#line 16721 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 4u: goto st2;
		case 5u: goto tr2;
		case 12u: goto st2;
		case 13u: goto tr2;
		case 20u: goto st2;
		case 21u: goto tr2;
		case 28u: goto st2;
		case 29u: goto tr2;
		case 36u: goto st2;
		case 37u: goto tr2;
		case 44u: goto st2;
		case 45u: goto tr2;
		case 52u: goto st2;
		case 53u: goto tr2;
		case 60u: goto st2;
		case 61u: goto tr2;
		case 68u: goto st8;
		case 76u: goto st8;
		case 84u: goto st8;
		case 92u: goto st8;
		case 100u: goto st8;
		case 108u: goto st8;
		case 116u: goto st8;
		case 124u: goto st8;
		case 132u: goto st9;
		case 140u: goto st9;
		case 148u: goto st9;
		case 156u: goto st9;
		case 164u: goto st9;
		case 172u: goto st9;
		case 180u: goto st9;
		case 188u: goto st9;
		case 248u: goto tr443;
		case 252u: goto tr286;
		case 253u: goto tr280;
	}
	if ( (*p) < 64u ) {
		if ( (*p) <= 63u )
			goto tr0;
	} else if ( (*p) > 127u ) {
		if ( 128u <= (*p) && (*p) <= 191u )
			goto tr5;
	} else
		goto tr3;
	goto tr7;
tr443:
#line 384 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_NAME(0, ((*p) & 0x07) |
                           ((GET_REX_PREFIX() & 0x01) << 3) |
                           (((~GET_VEX_PREFIX2()) & 0x20) >> 2));
  }
#line 93 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    /* Restricted %rsp or %rbp must be processed by appropriate nacl-special
       instruction, not with regular instruction.  */
    if (restricted_register == REG_RSP) {
      PrintError("Incorrectly modified register %%rsp\n", begin - data);
      result = 1;
      goto error_detected;
    } else if (restricted_register == REG_RBP) {
      PrintError("Incorrectly modified register %%rbp\n", begin - data);
      result = 1;
      goto error_detected;
    }
    /* If Sandboxed Rsi is destroyed then we must note that.  */
    if (restricted_register == kSandboxedRsi) {
      if (CHECK_OPERAND(0, REG_RSI, OperandSandboxRestricted) ||
          CHECK_OPERAND(0, REG_RSI, OperandSandboxUnrestricted) ||
          CHECK_OPERAND(1, REG_RSI, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_RSI, OperandSandboxUnrestricted)) {
        restricted_register = kNoRestrictedReg;
      }
    }
    if (restricted_register == kSandboxedRsi) {
      if (CHECK_OPERAND(0, REG_RDI, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_RDI, OperandSandboxRestricted)) {
        sandboxed_rsi_restricted_rdi = begin;
        restricted_register = kSandboxedRsiRestrictedRdi;
      }
    }
    if (restricted_register != kSandboxedRsiRestrictedRdi) {
      restricted_register = kNoRestrictedReg;
      if (CHECK_OPERAND(0, REG_R15, OperandSandbox8bit) ||
          CHECK_OPERAND(0, REG_R15, OperandSandboxRestricted) ||
          CHECK_OPERAND(0, REG_R15, OperandSandboxUnrestricted) ||
          CHECK_OPERAND(1, REG_R15, OperandSandbox8bit) ||
          CHECK_OPERAND(1, REG_R15, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_R15, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%r15\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((CHECK_OPERAND(0, REG_RBP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(0, REG_RBP, OperandSandboxUnrestricted) ||
                 (CHECK_OPERAND(1, REG_RBP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(1, REG_RBP, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%rbp\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((CHECK_OPERAND(0, REG_RSP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(0, REG_RSP, OperandSandboxUnrestricted) ||
                 (CHECK_OPERAND(1, REG_RSP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(1, REG_RSP, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%rsp\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((operand_states & 0x70) == (OperandSandboxRestricted << 5)) {
        restricted_register = operand_states & 0x0f;
      } else if ((operand_states & 0x7000) ==
                                        (OperandSandboxRestricted << (5 + 8))) {
        restricted_register = (operand_states & 0x0f00) >> 8;
      }
    }
  }
#line 337 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
       /* On successful match the instruction start must point to the next byte
        * to be able to report the new offset as the start of instruction
        * causing error.  */
       begin = p + 1;
     }
	goto st725;
st725:
	if ( ++p == pe )
		goto _test_eof725;
case 725:
#line 16853 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 0u: goto tr978;
		case 1u: goto tr979;
		case 2u: goto tr980;
		case 3u: goto tr981;
		case 4u: goto tr982;
		case 5u: goto tr983;
		case 8u: goto tr978;
		case 9u: goto tr979;
		case 10u: goto tr980;
		case 11u: goto tr981;
		case 12u: goto tr982;
		case 13u: goto tr983;
		case 15u: goto tr984;
		case 16u: goto tr978;
		case 17u: goto tr979;
		case 18u: goto tr980;
		case 19u: goto tr981;
		case 20u: goto tr982;
		case 21u: goto tr983;
		case 24u: goto tr978;
		case 25u: goto tr979;
		case 26u: goto tr980;
		case 27u: goto tr981;
		case 28u: goto tr982;
		case 29u: goto tr983;
		case 32u: goto tr978;
		case 33u: goto tr979;
		case 34u: goto tr980;
		case 35u: goto tr981;
		case 36u: goto tr982;
		case 37u: goto tr983;
		case 40u: goto tr978;
		case 41u: goto tr979;
		case 42u: goto tr980;
		case 43u: goto tr981;
		case 44u: goto tr982;
		case 45u: goto tr983;
		case 46u: goto tr985;
		case 48u: goto tr978;
		case 49u: goto tr979;
		case 50u: goto tr980;
		case 51u: goto tr981;
		case 52u: goto tr982;
		case 53u: goto tr983;
		case 60u: goto tr987;
		case 61u: goto tr988;
		case 62u: goto tr989;
		case 65u: goto tr991;
		case 72u: goto tr992;
		case 73u: goto tr993;
		case 74u: goto tr994;
		case 76u: goto tr996;
		case 99u: goto tr981;
		case 102u: goto tr999;
		case 104u: goto tr988;
		case 105u: goto tr1000;
		case 106u: goto tr987;
		case 107u: goto tr1001;
		case 128u: goto tr1003;
		case 129u: goto tr1004;
		case 131u: goto tr1005;
		case 133u: goto tr979;
		case 134u: goto tr1006;
		case 135u: goto tr1007;
		case 137u: goto tr979;
		case 138u: goto tr980;
		case 139u: goto tr981;
		case 141u: goto tr1008;
		case 143u: goto tr1009;
		case 144u: goto tr1010;
		case 155u: goto tr1010;
		case 168u: goto tr982;
		case 169u: goto tr983;
		case 192u: goto tr1017;
		case 193u: goto tr1018;
		case 196u: goto tr1019;
		case 197u: goto tr1020;
		case 198u: goto tr1021;
		case 199u: goto tr1022;
		case 200u: goto tr1023;
		case 202u: goto tr1024;
		case 203u: goto tr1010;
		case 209u: goto tr1026;
		case 211u: goto tr1026;
		case 216u: goto tr986;
		case 217u: goto tr1027;
		case 218u: goto tr1028;
		case 219u: goto tr1029;
		case 220u: goto tr1030;
		case 221u: goto tr1031;
		case 222u: goto tr1032;
		case 223u: goto tr1033;
		case 235u: goto tr1002;
		case 240u: goto tr1035;
		case 242u: goto tr1036;
		case 243u: goto tr1037;
		case 246u: goto tr1038;
		case 247u: goto tr1039;
		case 254u: goto tr1040;
		case 255u: goto tr1045;
	}
	if ( (*p) < 164u ) {
		if ( (*p) < 88u ) {
			if ( (*p) < 64u ) {
				if ( 56u <= (*p) && (*p) <= 59u )
					goto tr986;
			} else if ( (*p) > 71u ) {
				if ( (*p) > 79u ) {
					if ( 80u <= (*p) && (*p) <= 87u )
						goto tr997;
				} else if ( (*p) >= 75u )
					goto tr995;
			} else
				goto tr990;
		} else if ( (*p) > 95u ) {
			if ( (*p) < 132u ) {
				if ( 112u <= (*p) && (*p) <= 127u )
					goto tr1002;
			} else if ( (*p) > 136u ) {
				if ( (*p) > 151u ) {
					if ( 152u <= (*p) && (*p) <= 153u )
						goto tr1010;
				} else if ( (*p) >= 145u )
					goto tr1011;
			} else
				goto tr978;
		} else
			goto tr998;
	} else if ( (*p) > 167u ) {
		if ( (*p) < 184u ) {
			if ( (*p) < 172u ) {
				if ( 170u <= (*p) && (*p) <= 171u )
					goto tr1013;
			} else if ( (*p) > 173u ) {
				if ( (*p) > 175u ) {
					if ( 176u <= (*p) && (*p) <= 183u )
						goto tr1015;
				} else if ( (*p) >= 174u )
					goto tr1013;
			} else
				goto tr1014;
		} else if ( (*p) > 191u ) {
			if ( (*p) < 232u ) {
				if ( 208u <= (*p) && (*p) <= 210u )
					goto tr1025;
			} else if ( (*p) > 233u ) {
				if ( (*p) > 249u ) {
					if ( 252u <= (*p) && (*p) <= 253u )
						goto tr1010;
				} else if ( (*p) >= 244u )
					goto tr1010;
			} else
				goto tr1034;
		} else
			goto tr1016;
	} else
		goto tr1012;
	goto tr33;
tr1009:
#line 329 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
        begin = p;
        BitmapSetBit(valid_targets, p - data);
        SET_REX_PREFIX(FALSE);
        SET_VEX_PREFIX2(0xe0);
        SET_VEX_PREFIX3(0x00);
        operand_states = 0;
     }
	goto st254;
st254:
	if ( ++p == pe )
		goto _test_eof254;
case 254:
#line 17028 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 4u: goto st2;
		case 5u: goto tr2;
		case 8u: goto tr444;
		case 9u: goto tr445;
		case 10u: goto tr446;
		case 40u: goto tr447;
		case 41u: goto tr448;
		case 42u: goto tr449;
		case 68u: goto st8;
		case 72u: goto tr450;
		case 73u: goto tr451;
		case 74u: goto tr452;
		case 104u: goto tr453;
		case 105u: goto tr454;
		case 106u: goto tr455;
		case 132u: goto st9;
		case 136u: goto tr444;
		case 137u: goto tr456;
		case 138u: goto tr457;
		case 168u: goto tr447;
		case 169u: goto tr458;
		case 170u: goto tr459;
		case 200u: goto tr450;
		case 201u: goto tr460;
		case 202u: goto tr461;
		case 232u: goto tr453;
		case 233u: goto tr462;
		case 234u: goto tr463;
	}
	if ( (*p) < 64u ) {
		if ( (*p) <= 7u )
			goto tr0;
	} else if ( (*p) > 71u ) {
		if ( (*p) > 135u ) {
			if ( 192u <= (*p) && (*p) <= 199u )
				goto tr208;
		} else if ( (*p) >= 128u )
			goto tr5;
	} else
		goto tr3;
	goto tr33;
tr444:
#line 235 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX2(*p);
  }
	goto st255;
st255:
	if ( ++p == pe )
		goto _test_eof255;
case 255:
#line 17081 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 0u: goto tr464;
		case 4u: goto tr465;
		case 8u: goto tr464;
		case 12u: goto tr465;
		case 16u: goto tr464;
		case 20u: goto tr465;
		case 24u: goto tr464;
		case 28u: goto tr465;
		case 32u: goto tr464;
		case 36u: goto tr465;
		case 40u: goto tr464;
		case 44u: goto tr465;
		case 48u: goto tr464;
		case 52u: goto tr465;
		case 56u: goto tr464;
		case 60u: goto tr465;
		case 64u: goto tr464;
		case 68u: goto tr465;
		case 72u: goto tr464;
		case 76u: goto tr465;
		case 80u: goto tr464;
		case 84u: goto tr465;
		case 88u: goto tr464;
		case 92u: goto tr465;
		case 96u: goto tr464;
		case 100u: goto tr465;
		case 104u: goto tr464;
		case 108u: goto tr465;
		case 112u: goto tr464;
		case 116u: goto tr465;
		case 120u: goto tr466;
		case 124u: goto tr465;
		case 128u: goto tr467;
		case 132u: goto tr465;
		case 136u: goto tr467;
		case 140u: goto tr465;
		case 144u: goto tr467;
		case 148u: goto tr465;
		case 152u: goto tr467;
		case 156u: goto tr465;
		case 160u: goto tr467;
		case 164u: goto tr465;
		case 168u: goto tr467;
		case 172u: goto tr465;
		case 176u: goto tr467;
		case 180u: goto tr465;
		case 184u: goto tr467;
		case 188u: goto tr465;
		case 192u: goto tr467;
		case 196u: goto tr465;
		case 200u: goto tr467;
		case 204u: goto tr465;
		case 208u: goto tr467;
		case 212u: goto tr465;
		case 216u: goto tr467;
		case 220u: goto tr465;
		case 224u: goto tr467;
		case 228u: goto tr465;
		case 232u: goto tr467;
		case 236u: goto tr465;
		case 240u: goto tr467;
		case 244u: goto tr465;
		case 248u: goto tr467;
		case 252u: goto tr465;
	}
	goto tr33;
tr464:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st256;
st256:
	if ( ++p == pe )
		goto _test_eof256;
case 256:
#line 17159 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 166u: goto st257;
		case 182u: goto st257;
	}
	if ( (*p) < 158u ) {
		if ( (*p) < 142u ) {
			if ( 133u <= (*p) && (*p) <= 135u )
				goto st257;
		} else if ( (*p) > 143u ) {
			if ( 149u <= (*p) && (*p) <= 151u )
				goto st257;
		} else
			goto st257;
	} else if ( (*p) > 159u ) {
		if ( (*p) < 204u ) {
			if ( 162u <= (*p) && (*p) <= 163u )
				goto st257;
		} else if ( (*p) > 207u ) {
			if ( 236u <= (*p) && (*p) <= 239u )
				goto st267;
		} else
			goto st267;
	} else
		goto st257;
	goto tr33;
st257:
	if ( ++p == pe )
		goto _test_eof257;
case 257:
	switch( (*p) ) {
		case 4u: goto st258;
		case 12u: goto st258;
		case 20u: goto st258;
		case 28u: goto st258;
		case 36u: goto st258;
		case 44u: goto st258;
		case 52u: goto st258;
		case 60u: goto st258;
		case 68u: goto st260;
		case 76u: goto st260;
		case 84u: goto st260;
		case 92u: goto st260;
		case 100u: goto st260;
		case 108u: goto st260;
		case 116u: goto st260;
		case 124u: goto st260;
		case 132u: goto st262;
		case 140u: goto st262;
		case 148u: goto st262;
		case 156u: goto st262;
		case 164u: goto st262;
		case 172u: goto st262;
		case 180u: goto st262;
		case 188u: goto st262;
	}
	if ( 192u <= (*p) )
		goto st259;
	goto tr33;
st258:
	if ( ++p == pe )
		goto _test_eof258;
case 258:
	switch( (*p) ) {
		case 5u: goto tr33;
		case 13u: goto tr33;
		case 21u: goto tr33;
		case 29u: goto tr33;
		case 37u: goto tr33;
		case 45u: goto tr33;
		case 53u: goto tr33;
		case 61u: goto tr33;
		case 69u: goto tr33;
		case 77u: goto tr33;
		case 85u: goto tr33;
		case 93u: goto tr33;
		case 101u: goto tr33;
		case 109u: goto tr33;
		case 117u: goto tr33;
		case 125u: goto tr33;
		case 133u: goto tr33;
		case 141u: goto tr33;
		case 149u: goto tr33;
		case 157u: goto tr33;
		case 165u: goto tr33;
		case 173u: goto tr33;
		case 181u: goto tr33;
		case 189u: goto tr33;
		case 197u: goto tr33;
		case 205u: goto tr33;
		case 213u: goto tr33;
		case 221u: goto tr33;
		case 229u: goto tr33;
		case 237u: goto tr33;
		case 245u: goto tr33;
		case 253u: goto tr33;
	}
	goto tr474;
tr515:
#line 90 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_DISP_TYPE(DISPNONE);
    SET_MODRM_BASE(((*p) & 0x07) |
                   ((GET_REX_PREFIX() & 0x01) << 3) |
                   (((~GET_VEX_PREFIX2()) & 0x20) >> 2));
    SET_MODRM_INDEX(NO_REG);
    SET_MODRM_SCALE(0);
  }
#line 44 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    if ((base == REG_RIP) || (base == REG_R15) ||
        ((base == REG_RSP) && (restricted_register != REG_RSP)) ||
        ((base == REG_RBP) && (restricted_register != REG_RBP))) {
      if ((index == restricted_register) ||
          ((index == REG_RDI) &&
           (restricted_register == kSandboxedRsiRestrictedRdi))) {
        BitmapClearBit(valid_targets, begin - data);
      } else if ((index != NO_REG) && (index != REG_RIZ)) {
        PrintError("Improper sandboxing in instruction\n", begin - data);
        result = 1;
        goto error_detected;
      }
    } else if ((index == REG_RIP) || (index == REG_R15) ||
               ((index == REG_RSP) && (restricted_register != REG_RSP)) ||
               ((index == REG_RBP) && (restricted_register != REG_RBP))) {
      if ((base == restricted_register) ||
          ((base == REG_RDI) &&
           (restricted_register == kSandboxedRsiRestrictedRdi))) {
        BitmapClearBit(valid_targets, begin - data);
      } else if ((base != NO_REG) && (base != REG_RIZ)) {
        PrintError("Improper sandboxing in instruction\n", begin - data);
        result = 1;
        goto error_detected;
      }
    } else {
      PrintError("Improper sandboxing in instruction\n", begin - data);
      result = 1;
      goto error_detected;
    }
  }
	goto st259;
tr474:
#line 118 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_DISP_TYPE(DISPNONE);
    SET_MODRM_BASE(((*p) & 0x7) |
                   ((GET_REX_PREFIX() & 0x01) << 3) |
                   (((~GET_VEX_PREFIX2()) & 0x20) >> 2));
    SET_MODRM_INDEX(index_registers[(((*p) & 0x38) >> 3) |
                                    ((GET_REX_PREFIX() & 0x02) << 2) |
                                    (((~GET_VEX_PREFIX2()) & 0x40) >> 3)]);
    SET_MODRM_SCALE(((*p) & 0xc0) >> 6);
  }
#line 44 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    if ((base == REG_RIP) || (base == REG_R15) ||
        ((base == REG_RSP) && (restricted_register != REG_RSP)) ||
        ((base == REG_RBP) && (restricted_register != REG_RBP))) {
      if ((index == restricted_register) ||
          ((index == REG_RDI) &&
           (restricted_register == kSandboxedRsiRestrictedRdi))) {
        BitmapClearBit(valid_targets, begin - data);
      } else if ((index != NO_REG) && (index != REG_RIZ)) {
        PrintError("Improper sandboxing in instruction\n", begin - data);
        result = 1;
        goto error_detected;
      }
    } else if ((index == REG_RIP) || (index == REG_R15) ||
               ((index == REG_RSP) && (restricted_register != REG_RSP)) ||
               ((index == REG_RBP) && (restricted_register != REG_RBP))) {
      if ((base == restricted_register) ||
          ((base == REG_RDI) &&
           (restricted_register == kSandboxedRsiRestrictedRdi))) {
        BitmapClearBit(valid_targets, begin - data);
      } else if ((base != NO_REG) && (base != REG_RIZ)) {
        PrintError("Improper sandboxing in instruction\n", begin - data);
        result = 1;
        goto error_detected;
      }
    } else {
      PrintError("Improper sandboxing in instruction\n", begin - data);
      result = 1;
      goto error_detected;
    }
  }
	goto st259;
tr481:
#line 46 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_DISP_TYPE(DISP32);
    SET_DISP_PTR(p - 3);
  }
#line 44 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    if ((base == REG_RIP) || (base == REG_R15) ||
        ((base == REG_RSP) && (restricted_register != REG_RSP)) ||
        ((base == REG_RBP) && (restricted_register != REG_RBP))) {
      if ((index == restricted_register) ||
          ((index == REG_RDI) &&
           (restricted_register == kSandboxedRsiRestrictedRdi))) {
        BitmapClearBit(valid_targets, begin - data);
      } else if ((index != NO_REG) && (index != REG_RIZ)) {
        PrintError("Improper sandboxing in instruction\n", begin - data);
        result = 1;
        goto error_detected;
      }
    } else if ((index == REG_RIP) || (index == REG_R15) ||
               ((index == REG_RSP) && (restricted_register != REG_RSP)) ||
               ((index == REG_RBP) && (restricted_register != REG_RBP))) {
      if ((base == restricted_register) ||
          ((base == REG_RDI) &&
           (restricted_register == kSandboxedRsiRestrictedRdi))) {
        BitmapClearBit(valid_targets, begin - data);
      } else if ((base != NO_REG) && (base != REG_RIZ)) {
        PrintError("Improper sandboxing in instruction\n", begin - data);
        result = 1;
        goto error_detected;
      }
    } else {
      PrintError("Improper sandboxing in instruction\n", begin - data);
      result = 1;
      goto error_detected;
    }
  }
	goto st259;
tr476:
#line 42 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_DISP_TYPE(DISP8);
    SET_DISP_PTR(p);
  }
#line 44 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    if ((base == REG_RIP) || (base == REG_R15) ||
        ((base == REG_RSP) && (restricted_register != REG_RSP)) ||
        ((base == REG_RBP) && (restricted_register != REG_RBP))) {
      if ((index == restricted_register) ||
          ((index == REG_RDI) &&
           (restricted_register == kSandboxedRsiRestrictedRdi))) {
        BitmapClearBit(valid_targets, begin - data);
      } else if ((index != NO_REG) && (index != REG_RIZ)) {
        PrintError("Improper sandboxing in instruction\n", begin - data);
        result = 1;
        goto error_detected;
      }
    } else if ((index == REG_RIP) || (index == REG_R15) ||
               ((index == REG_RSP) && (restricted_register != REG_RSP)) ||
               ((index == REG_RBP) && (restricted_register != REG_RBP))) {
      if ((base == restricted_register) ||
          ((base == REG_RDI) &&
           (restricted_register == kSandboxedRsiRestrictedRdi))) {
        BitmapClearBit(valid_targets, begin - data);
      } else if ((base != NO_REG) && (base != REG_RIZ)) {
        PrintError("Improper sandboxing in instruction\n", begin - data);
        result = 1;
        goto error_detected;
      }
    } else {
      PrintError("Improper sandboxing in instruction\n", begin - data);
      result = 1;
      goto error_detected;
    }
  }
	goto st259;
st259:
	if ( ++p == pe )
		goto _test_eof259;
case 259:
#line 17427 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 0u: goto tr34;
		case 16u: goto tr34;
		case 32u: goto tr34;
		case 48u: goto tr34;
		case 64u: goto tr34;
		case 80u: goto tr34;
		case 96u: goto tr34;
		case 112u: goto tr34;
		case 128u: goto tr34;
		case 144u: goto tr34;
		case 160u: goto tr34;
		case 176u: goto tr34;
		case 192u: goto tr34;
		case 208u: goto tr34;
		case 224u: goto tr34;
		case 240u: goto tr34;
	}
	goto tr33;
st260:
	if ( ++p == pe )
		goto _test_eof260;
case 260:
	goto tr475;
tr516:
#line 98 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_MODRM_BASE(((*p) & 0x07) |
                   ((GET_REX_PREFIX() & 0x01) << 3) |
                   (((~GET_VEX_PREFIX2()) & 0x20) >> 2));
    SET_MODRM_INDEX(NO_REG);
    SET_MODRM_SCALE(0);
  }
	goto st261;
tr475:
#line 118 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_DISP_TYPE(DISPNONE);
    SET_MODRM_BASE(((*p) & 0x7) |
                   ((GET_REX_PREFIX() & 0x01) << 3) |
                   (((~GET_VEX_PREFIX2()) & 0x20) >> 2));
    SET_MODRM_INDEX(index_registers[(((*p) & 0x38) >> 3) |
                                    ((GET_REX_PREFIX() & 0x02) << 2) |
                                    (((~GET_VEX_PREFIX2()) & 0x40) >> 3)]);
    SET_MODRM_SCALE(((*p) & 0xc0) >> 6);
  }
	goto st261;
st261:
	if ( ++p == pe )
		goto _test_eof261;
case 261:
#line 17479 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	goto tr476;
st262:
	if ( ++p == pe )
		goto _test_eof262;
case 262:
	goto tr477;
tr531:
#line 105 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_MODRM_BASE(REG_RIP);
    SET_MODRM_INDEX(NO_REG);
    SET_MODRM_SCALE(0);
  }
	goto st263;
tr517:
#line 98 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_MODRM_BASE(((*p) & 0x07) |
                   ((GET_REX_PREFIX() & 0x01) << 3) |
                   (((~GET_VEX_PREFIX2()) & 0x20) >> 2));
    SET_MODRM_INDEX(NO_REG);
    SET_MODRM_SCALE(0);
  }
	goto st263;
tr500:
#line 110 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_DISP_TYPE(DISPNONE);
    SET_MODRM_BASE(NO_REG);
    SET_MODRM_INDEX(index_registers[(((*p) & 0x38) >> 3) |
                                    ((GET_REX_PREFIX() & 0x02) << 2) |
                                    (((~GET_VEX_PREFIX2()) & 0x40) >> 3)]);
    SET_MODRM_SCALE(((*p) & 0xc0) >> 6);
  }
	goto st263;
tr477:
#line 118 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_DISP_TYPE(DISPNONE);
    SET_MODRM_BASE(((*p) & 0x7) |
                   ((GET_REX_PREFIX() & 0x01) << 3) |
                   (((~GET_VEX_PREFIX2()) & 0x20) >> 2));
    SET_MODRM_INDEX(index_registers[(((*p) & 0x38) >> 3) |
                                    ((GET_REX_PREFIX() & 0x02) << 2) |
                                    (((~GET_VEX_PREFIX2()) & 0x40) >> 3)]);
    SET_MODRM_SCALE(((*p) & 0xc0) >> 6);
  }
	goto st263;
st263:
	if ( ++p == pe )
		goto _test_eof263;
case 263:
#line 17532 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	goto st264;
st264:
	if ( ++p == pe )
		goto _test_eof264;
case 264:
	goto st265;
st265:
	if ( ++p == pe )
		goto _test_eof265;
case 265:
	goto st266;
st266:
	if ( ++p == pe )
		goto _test_eof266;
case 266:
	goto tr481;
st267:
	if ( ++p == pe )
		goto _test_eof267;
case 267:
	switch( (*p) ) {
		case 4u: goto st268;
		case 12u: goto st268;
		case 20u: goto st268;
		case 28u: goto st268;
		case 36u: goto st268;
		case 44u: goto st268;
		case 52u: goto st268;
		case 60u: goto st268;
		case 68u: goto st50;
		case 76u: goto st50;
		case 84u: goto st50;
		case 92u: goto st50;
		case 100u: goto st50;
		case 108u: goto st50;
		case 116u: goto st50;
		case 124u: goto st50;
		case 132u: goto st51;
		case 140u: goto st51;
		case 148u: goto st51;
		case 156u: goto st51;
		case 164u: goto st51;
		case 172u: goto st51;
		case 180u: goto st51;
		case 188u: goto st51;
	}
	if ( 192u <= (*p) )
		goto st11;
	goto tr33;
st268:
	if ( ++p == pe )
		goto _test_eof268;
case 268:
	switch( (*p) ) {
		case 5u: goto tr33;
		case 13u: goto tr33;
		case 21u: goto tr33;
		case 29u: goto tr33;
		case 37u: goto tr33;
		case 45u: goto tr33;
		case 53u: goto tr33;
		case 61u: goto tr33;
		case 69u: goto tr33;
		case 77u: goto tr33;
		case 85u: goto tr33;
		case 93u: goto tr33;
		case 101u: goto tr33;
		case 109u: goto tr33;
		case 117u: goto tr33;
		case 125u: goto tr33;
		case 133u: goto tr33;
		case 141u: goto tr33;
		case 149u: goto tr33;
		case 157u: goto tr33;
		case 165u: goto tr33;
		case 173u: goto tr33;
		case 181u: goto tr33;
		case 189u: goto tr33;
		case 197u: goto tr33;
		case 205u: goto tr33;
		case 213u: goto tr33;
		case 221u: goto tr33;
		case 229u: goto tr33;
		case 237u: goto tr33;
		case 245u: goto tr33;
		case 253u: goto tr33;
	}
	goto tr101;
tr465:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st269;
st269:
	if ( ++p == pe )
		goto _test_eof269;
case 269:
#line 17631 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	if ( (*p) == 162u )
		goto st257;
	goto tr33;
tr466:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st270;
st270:
	if ( ++p == pe )
		goto _test_eof270;
case 270:
#line 17645 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 166u: goto st257;
		case 182u: goto st257;
	}
	if ( (*p) < 158u ) {
		if ( (*p) < 142u ) {
			if ( 133u <= (*p) && (*p) <= 135u )
				goto st257;
		} else if ( (*p) > 143u ) {
			if ( 149u <= (*p) && (*p) <= 151u )
				goto st257;
		} else
			goto st257;
	} else if ( (*p) > 159u ) {
		if ( (*p) < 192u ) {
			if ( 162u <= (*p) && (*p) <= 163u )
				goto st257;
		} else if ( (*p) > 195u ) {
			if ( (*p) > 207u ) {
				if ( 236u <= (*p) && (*p) <= 239u )
					goto st267;
			} else if ( (*p) >= 204u )
				goto st267;
		} else
			goto st267;
	} else
		goto st257;
	goto tr33;
tr467:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st271;
st271:
	if ( ++p == pe )
		goto _test_eof271;
case 271:
#line 17684 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	if ( 162u <= (*p) && (*p) <= 163u )
		goto st257;
	goto tr33;
tr445:
#line 235 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX2(*p);
  }
	goto st272;
st272:
	if ( ++p == pe )
		goto _test_eof272;
case 272:
#line 17698 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 0u: goto tr483;
		case 8u: goto tr483;
		case 16u: goto tr483;
		case 24u: goto tr483;
		case 32u: goto tr483;
		case 40u: goto tr483;
		case 48u: goto tr483;
		case 56u: goto tr483;
		case 64u: goto tr483;
		case 72u: goto tr483;
		case 80u: goto tr483;
		case 88u: goto tr483;
		case 96u: goto tr483;
		case 104u: goto tr483;
		case 112u: goto tr483;
		case 120u: goto tr484;
		case 124u: goto tr485;
		case 128u: goto tr483;
		case 136u: goto tr483;
		case 144u: goto tr483;
		case 152u: goto tr483;
		case 160u: goto tr483;
		case 168u: goto tr483;
		case 176u: goto tr483;
		case 184u: goto tr483;
		case 192u: goto tr483;
		case 200u: goto tr483;
		case 208u: goto tr483;
		case 216u: goto tr483;
		case 224u: goto tr483;
		case 232u: goto tr483;
		case 240u: goto tr483;
		case 248u: goto tr483;
	}
	goto tr33;
tr483:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st273;
st273:
	if ( ++p == pe )
		goto _test_eof273;
case 273:
#line 17745 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	if ( 144u <= (*p) && (*p) <= 155u )
		goto st274;
	goto tr33;
st274:
	if ( ++p == pe )
		goto _test_eof274;
case 274:
	switch( (*p) ) {
		case 4u: goto st275;
		case 12u: goto st275;
		case 20u: goto st275;
		case 28u: goto st275;
		case 36u: goto st275;
		case 44u: goto st275;
		case 52u: goto st275;
		case 60u: goto st275;
		case 68u: goto st8;
		case 76u: goto st8;
		case 84u: goto st8;
		case 92u: goto st8;
		case 100u: goto st8;
		case 108u: goto st8;
		case 116u: goto st8;
		case 124u: goto st8;
		case 132u: goto st9;
		case 140u: goto st9;
		case 148u: goto st9;
		case 156u: goto st9;
		case 164u: goto st9;
		case 172u: goto st9;
		case 180u: goto st9;
		case 188u: goto st9;
	}
	if ( 192u <= (*p) )
		goto tr34;
	goto tr33;
tr671:
#line 389 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_NAME(0, (((*p) & 0x38) >> 3) |
                           ((GET_REX_PREFIX() & 0x04) << 1) |
                           (((~GET_VEX_PREFIX2()) & 0x80) >> 4));
  }
	goto st275;
tr542:
#line 295 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(0, OperandSize32bit);
  }
#line 397 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_NAME(0, ((~GET_VEX_PREFIX3()) & 0x78) >> 3);
  }
	goto st275;
tr548:
#line 298 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(0, OperandSize64bit);
  }
#line 397 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_NAME(0, ((~GET_VEX_PREFIX3()) & 0x78) >> 3);
  }
	goto st275;
st275:
	if ( ++p == pe )
		goto _test_eof275;
case 275:
#line 17814 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 5u: goto tr33;
		case 13u: goto tr33;
		case 21u: goto tr33;
		case 29u: goto tr33;
		case 37u: goto tr33;
		case 45u: goto tr33;
		case 53u: goto tr33;
		case 61u: goto tr33;
		case 69u: goto tr33;
		case 77u: goto tr33;
		case 85u: goto tr33;
		case 93u: goto tr33;
		case 101u: goto tr33;
		case 109u: goto tr33;
		case 117u: goto tr33;
		case 125u: goto tr33;
		case 133u: goto tr33;
		case 141u: goto tr33;
		case 149u: goto tr33;
		case 157u: goto tr33;
		case 165u: goto tr33;
		case 173u: goto tr33;
		case 181u: goto tr33;
		case 189u: goto tr33;
		case 197u: goto tr33;
		case 205u: goto tr33;
		case 213u: goto tr33;
		case 221u: goto tr33;
		case 229u: goto tr33;
		case 237u: goto tr33;
		case 245u: goto tr33;
		case 253u: goto tr33;
	}
	goto tr8;
tr484:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st276;
st276:
	if ( ++p == pe )
		goto _test_eof276;
case 276:
#line 17860 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 203u: goto st274;
		case 219u: goto st274;
	}
	if ( (*p) < 198u ) {
		if ( (*p) < 144u ) {
			if ( 128u <= (*p) && (*p) <= 131u )
				goto st274;
		} else if ( (*p) > 155u ) {
			if ( 193u <= (*p) && (*p) <= 195u )
				goto st274;
		} else
			goto st274;
	} else if ( (*p) > 199u ) {
		if ( (*p) < 214u ) {
			if ( 209u <= (*p) && (*p) <= 211u )
				goto st274;
		} else if ( (*p) > 215u ) {
			if ( 225u <= (*p) && (*p) <= 227u )
				goto st274;
		} else
			goto st274;
	} else
		goto st274;
	goto tr33;
tr485:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st277;
st277:
	if ( ++p == pe )
		goto _test_eof277;
case 277:
#line 17896 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	if ( 128u <= (*p) && (*p) <= 129u )
		goto st274;
	goto tr33;
tr446:
#line 235 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX2(*p);
  }
	goto st278;
st278:
	if ( ++p == pe )
		goto _test_eof278;
case 278:
#line 17910 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 120u: goto tr488;
		case 248u: goto tr489;
	}
	goto tr33;
tr488:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st279;
st279:
	if ( ++p == pe )
		goto _test_eof279;
case 279:
#line 17926 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	if ( (*p) == 16u )
		goto tr490;
	goto tr33;
tr490:
#line 295 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(0, OperandSize32bit);
  }
	goto st280;
tr492:
#line 298 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(0, OperandSize64bit);
  }
	goto st280;
st280:
	if ( ++p == pe )
		goto _test_eof280;
case 280:
#line 17946 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 4u: goto tr491;
		case 12u: goto tr491;
		case 20u: goto tr491;
		case 28u: goto tr491;
		case 36u: goto tr491;
		case 44u: goto tr491;
		case 52u: goto tr491;
		case 60u: goto tr491;
		case 68u: goto tr164;
		case 76u: goto tr164;
		case 84u: goto tr164;
		case 92u: goto tr164;
		case 100u: goto tr164;
		case 108u: goto tr164;
		case 116u: goto tr164;
		case 124u: goto tr164;
		case 132u: goto tr166;
		case 140u: goto tr166;
		case 148u: goto tr166;
		case 156u: goto tr166;
		case 164u: goto tr166;
		case 172u: goto tr166;
		case 180u: goto tr166;
		case 188u: goto tr166;
	}
	if ( 192u <= (*p) )
		goto tr167;
	goto tr33;
tr491:
#line 389 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_NAME(0, (((*p) & 0x38) >> 3) |
                           ((GET_REX_PREFIX() & 0x04) << 1) |
                           (((~GET_VEX_PREFIX2()) & 0x80) >> 4));
  }
	goto st281;
tr557:
#line 295 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(0, OperandSize32bit);
  }
#line 397 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_NAME(0, ((~GET_VEX_PREFIX3()) & 0x78) >> 3);
  }
	goto st281;
tr562:
#line 298 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(0, OperandSize64bit);
  }
#line 397 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_NAME(0, ((~GET_VEX_PREFIX3()) & 0x78) >> 3);
  }
	goto st281;
st281:
	if ( ++p == pe )
		goto _test_eof281;
case 281:
#line 18008 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 5u: goto tr33;
		case 13u: goto tr33;
		case 21u: goto tr33;
		case 29u: goto tr33;
		case 37u: goto tr33;
		case 45u: goto tr33;
		case 53u: goto tr33;
		case 61u: goto tr33;
		case 69u: goto tr33;
		case 77u: goto tr33;
		case 85u: goto tr33;
		case 93u: goto tr33;
		case 101u: goto tr33;
		case 109u: goto tr33;
		case 117u: goto tr33;
		case 125u: goto tr33;
		case 133u: goto tr33;
		case 141u: goto tr33;
		case 149u: goto tr33;
		case 157u: goto tr33;
		case 165u: goto tr33;
		case 173u: goto tr33;
		case 181u: goto tr33;
		case 189u: goto tr33;
		case 197u: goto tr33;
		case 205u: goto tr33;
		case 213u: goto tr33;
		case 221u: goto tr33;
		case 229u: goto tr33;
		case 237u: goto tr33;
		case 245u: goto tr33;
		case 253u: goto tr33;
	}
	goto tr168;
tr489:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st282;
st282:
	if ( ++p == pe )
		goto _test_eof282;
case 282:
#line 18054 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	if ( (*p) == 16u )
		goto tr492;
	goto tr33;
tr447:
#line 235 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX2(*p);
  }
	goto st283;
st283:
	if ( ++p == pe )
		goto _test_eof283;
case 283:
#line 18068 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 0u: goto tr493;
		case 4u: goto tr494;
		case 8u: goto tr493;
		case 12u: goto tr494;
		case 16u: goto tr493;
		case 20u: goto tr494;
		case 24u: goto tr493;
		case 28u: goto tr494;
		case 32u: goto tr493;
		case 36u: goto tr494;
		case 40u: goto tr493;
		case 44u: goto tr494;
		case 48u: goto tr493;
		case 52u: goto tr494;
		case 56u: goto tr493;
		case 60u: goto tr494;
		case 64u: goto tr493;
		case 68u: goto tr494;
		case 72u: goto tr493;
		case 76u: goto tr494;
		case 80u: goto tr493;
		case 84u: goto tr494;
		case 88u: goto tr493;
		case 92u: goto tr494;
		case 96u: goto tr493;
		case 100u: goto tr494;
		case 104u: goto tr493;
		case 108u: goto tr494;
		case 112u: goto tr493;
		case 116u: goto tr494;
		case 120u: goto tr495;
		case 124u: goto tr494;
		case 128u: goto tr496;
		case 132u: goto tr494;
		case 136u: goto tr496;
		case 140u: goto tr494;
		case 144u: goto tr496;
		case 148u: goto tr494;
		case 152u: goto tr496;
		case 156u: goto tr494;
		case 160u: goto tr496;
		case 164u: goto tr494;
		case 168u: goto tr496;
		case 172u: goto tr494;
		case 176u: goto tr496;
		case 180u: goto tr494;
		case 184u: goto tr496;
		case 188u: goto tr494;
		case 192u: goto tr496;
		case 196u: goto tr494;
		case 200u: goto tr496;
		case 204u: goto tr494;
		case 208u: goto tr496;
		case 212u: goto tr494;
		case 216u: goto tr496;
		case 220u: goto tr494;
		case 224u: goto tr496;
		case 228u: goto tr494;
		case 232u: goto tr496;
		case 236u: goto tr494;
		case 240u: goto tr496;
		case 244u: goto tr494;
		case 248u: goto tr496;
		case 252u: goto tr494;
	}
	goto tr33;
tr493:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st284;
st284:
	if ( ++p == pe )
		goto _test_eof284;
case 284:
#line 18146 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 166u: goto st285;
		case 182u: goto st285;
	}
	if ( (*p) < 158u ) {
		if ( (*p) < 142u ) {
			if ( 133u <= (*p) && (*p) <= 135u )
				goto st285;
		} else if ( (*p) > 143u ) {
			if ( 149u <= (*p) && (*p) <= 151u )
				goto st285;
		} else
			goto st285;
	} else if ( (*p) > 159u ) {
		if ( (*p) < 204u ) {
			if ( 162u <= (*p) && (*p) <= 163u )
				goto st285;
		} else if ( (*p) > 207u ) {
			if ( 236u <= (*p) && (*p) <= 239u )
				goto st287;
		} else
			goto st287;
	} else
		goto st285;
	goto tr33;
st285:
	if ( ++p == pe )
		goto _test_eof285;
case 285:
	switch( (*p) ) {
		case 4u: goto st286;
		case 12u: goto st286;
		case 20u: goto st286;
		case 28u: goto st286;
		case 36u: goto st286;
		case 44u: goto st286;
		case 52u: goto st286;
		case 60u: goto st286;
		case 68u: goto st260;
		case 76u: goto st260;
		case 84u: goto st260;
		case 92u: goto st260;
		case 100u: goto st260;
		case 108u: goto st260;
		case 116u: goto st260;
		case 124u: goto st260;
		case 132u: goto st262;
		case 140u: goto st262;
		case 148u: goto st262;
		case 156u: goto st262;
		case 164u: goto st262;
		case 172u: goto st262;
		case 180u: goto st262;
		case 188u: goto st262;
	}
	if ( 192u <= (*p) )
		goto st259;
	goto tr33;
st286:
	if ( ++p == pe )
		goto _test_eof286;
case 286:
	switch( (*p) ) {
		case 5u: goto tr500;
		case 13u: goto tr500;
		case 21u: goto tr500;
		case 29u: goto tr500;
		case 37u: goto tr500;
		case 45u: goto tr500;
		case 53u: goto tr500;
		case 61u: goto tr500;
		case 69u: goto tr500;
		case 77u: goto tr500;
		case 85u: goto tr500;
		case 93u: goto tr500;
		case 101u: goto tr500;
		case 109u: goto tr500;
		case 117u: goto tr500;
		case 125u: goto tr500;
		case 133u: goto tr500;
		case 141u: goto tr500;
		case 149u: goto tr500;
		case 157u: goto tr500;
		case 165u: goto tr500;
		case 173u: goto tr500;
		case 181u: goto tr500;
		case 189u: goto tr500;
		case 197u: goto tr500;
		case 205u: goto tr500;
		case 213u: goto tr500;
		case 221u: goto tr500;
		case 229u: goto tr500;
		case 237u: goto tr500;
		case 245u: goto tr500;
		case 253u: goto tr500;
	}
	goto tr474;
st287:
	if ( ++p == pe )
		goto _test_eof287;
case 287:
	switch( (*p) ) {
		case 4u: goto st44;
		case 12u: goto st44;
		case 20u: goto st44;
		case 28u: goto st44;
		case 36u: goto st44;
		case 44u: goto st44;
		case 52u: goto st44;
		case 60u: goto st44;
		case 68u: goto st50;
		case 76u: goto st50;
		case 84u: goto st50;
		case 92u: goto st50;
		case 100u: goto st50;
		case 108u: goto st50;
		case 116u: goto st50;
		case 124u: goto st50;
		case 132u: goto st51;
		case 140u: goto st51;
		case 148u: goto st51;
		case 156u: goto st51;
		case 164u: goto st51;
		case 172u: goto st51;
		case 180u: goto st51;
		case 188u: goto st51;
	}
	if ( 192u <= (*p) )
		goto st11;
	goto tr33;
tr494:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st288;
st288:
	if ( ++p == pe )
		goto _test_eof288;
case 288:
#line 18287 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	if ( (*p) == 162u )
		goto st285;
	goto tr33;
tr495:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st289;
st289:
	if ( ++p == pe )
		goto _test_eof289;
case 289:
#line 18301 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 166u: goto st285;
		case 182u: goto st285;
	}
	if ( (*p) < 158u ) {
		if ( (*p) < 142u ) {
			if ( 133u <= (*p) && (*p) <= 135u )
				goto st285;
		} else if ( (*p) > 143u ) {
			if ( 149u <= (*p) && (*p) <= 151u )
				goto st285;
		} else
			goto st285;
	} else if ( (*p) > 159u ) {
		if ( (*p) < 192u ) {
			if ( 162u <= (*p) && (*p) <= 163u )
				goto st285;
		} else if ( (*p) > 195u ) {
			if ( (*p) > 207u ) {
				if ( 236u <= (*p) && (*p) <= 239u )
					goto st287;
			} else if ( (*p) >= 204u )
				goto st287;
		} else
			goto st287;
	} else
		goto st285;
	goto tr33;
tr496:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st290;
st290:
	if ( ++p == pe )
		goto _test_eof290;
case 290:
#line 18340 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	if ( 162u <= (*p) && (*p) <= 163u )
		goto st285;
	goto tr33;
tr448:
#line 235 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX2(*p);
  }
	goto st291;
st291:
	if ( ++p == pe )
		goto _test_eof291;
case 291:
#line 18354 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 0u: goto tr501;
		case 8u: goto tr501;
		case 16u: goto tr501;
		case 24u: goto tr501;
		case 32u: goto tr501;
		case 40u: goto tr501;
		case 48u: goto tr501;
		case 56u: goto tr501;
		case 64u: goto tr501;
		case 72u: goto tr501;
		case 80u: goto tr501;
		case 88u: goto tr501;
		case 96u: goto tr501;
		case 104u: goto tr501;
		case 112u: goto tr501;
		case 120u: goto tr502;
		case 124u: goto tr503;
		case 128u: goto tr501;
		case 136u: goto tr501;
		case 144u: goto tr501;
		case 152u: goto tr501;
		case 160u: goto tr501;
		case 168u: goto tr501;
		case 176u: goto tr501;
		case 184u: goto tr501;
		case 192u: goto tr501;
		case 200u: goto tr501;
		case 208u: goto tr501;
		case 216u: goto tr501;
		case 224u: goto tr501;
		case 232u: goto tr501;
		case 240u: goto tr501;
		case 248u: goto tr501;
	}
	goto tr33;
tr501:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st292;
st292:
	if ( ++p == pe )
		goto _test_eof292;
case 292:
#line 18401 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	if ( 144u <= (*p) && (*p) <= 155u )
		goto st293;
	goto tr33;
st293:
	if ( ++p == pe )
		goto _test_eof293;
case 293:
	switch( (*p) ) {
		case 4u: goto st2;
		case 12u: goto st2;
		case 20u: goto st2;
		case 28u: goto st2;
		case 36u: goto st2;
		case 44u: goto st2;
		case 52u: goto st2;
		case 60u: goto st2;
		case 68u: goto st8;
		case 76u: goto st8;
		case 84u: goto st8;
		case 92u: goto st8;
		case 100u: goto st8;
		case 108u: goto st8;
		case 116u: goto st8;
		case 124u: goto st8;
		case 132u: goto st9;
		case 140u: goto st9;
		case 148u: goto st9;
		case 156u: goto st9;
		case 164u: goto st9;
		case 172u: goto st9;
		case 180u: goto st9;
		case 188u: goto st9;
	}
	if ( 192u <= (*p) )
		goto tr34;
	goto tr33;
tr502:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st294;
st294:
	if ( ++p == pe )
		goto _test_eof294;
case 294:
#line 18448 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 203u: goto st293;
		case 219u: goto st293;
	}
	if ( (*p) < 198u ) {
		if ( (*p) < 144u ) {
			if ( 128u <= (*p) && (*p) <= 131u )
				goto st293;
		} else if ( (*p) > 155u ) {
			if ( 193u <= (*p) && (*p) <= 195u )
				goto st293;
		} else
			goto st293;
	} else if ( (*p) > 199u ) {
		if ( (*p) < 214u ) {
			if ( 209u <= (*p) && (*p) <= 211u )
				goto st293;
		} else if ( (*p) > 215u ) {
			if ( 225u <= (*p) && (*p) <= 227u )
				goto st293;
		} else
			goto st293;
	} else
		goto st293;
	goto tr33;
tr503:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st295;
st295:
	if ( ++p == pe )
		goto _test_eof295;
case 295:
#line 18484 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	if ( 128u <= (*p) && (*p) <= 129u )
		goto st293;
	goto tr33;
tr449:
#line 235 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX2(*p);
  }
	goto st296;
st296:
	if ( ++p == pe )
		goto _test_eof296;
case 296:
#line 18498 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 120u: goto tr505;
		case 248u: goto tr506;
	}
	goto tr33;
tr505:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st297;
st297:
	if ( ++p == pe )
		goto _test_eof297;
case 297:
#line 18514 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	if ( (*p) == 16u )
		goto tr507;
	goto tr33;
tr507:
#line 295 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(0, OperandSize32bit);
  }
	goto st298;
tr508:
#line 298 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(0, OperandSize64bit);
  }
	goto st298;
st298:
	if ( ++p == pe )
		goto _test_eof298;
case 298:
#line 18534 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 4u: goto tr161;
		case 12u: goto tr161;
		case 20u: goto tr161;
		case 28u: goto tr161;
		case 36u: goto tr161;
		case 44u: goto tr161;
		case 52u: goto tr161;
		case 60u: goto tr161;
		case 68u: goto tr164;
		case 76u: goto tr164;
		case 84u: goto tr164;
		case 92u: goto tr164;
		case 100u: goto tr164;
		case 108u: goto tr164;
		case 116u: goto tr164;
		case 124u: goto tr164;
		case 132u: goto tr166;
		case 140u: goto tr166;
		case 148u: goto tr166;
		case 156u: goto tr166;
		case 164u: goto tr166;
		case 172u: goto tr166;
		case 180u: goto tr166;
		case 188u: goto tr166;
	}
	if ( 192u <= (*p) )
		goto tr167;
	goto tr33;
tr506:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st299;
st299:
	if ( ++p == pe )
		goto _test_eof299;
case 299:
#line 18574 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	if ( (*p) == 16u )
		goto tr508;
	goto tr33;
tr450:
#line 235 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX2(*p);
  }
	goto st300;
st300:
	if ( ++p == pe )
		goto _test_eof300;
case 300:
#line 18588 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 0u: goto tr509;
		case 4u: goto tr510;
		case 8u: goto tr509;
		case 12u: goto tr510;
		case 16u: goto tr509;
		case 20u: goto tr510;
		case 24u: goto tr509;
		case 28u: goto tr510;
		case 32u: goto tr509;
		case 36u: goto tr510;
		case 40u: goto tr509;
		case 44u: goto tr510;
		case 48u: goto tr509;
		case 52u: goto tr510;
		case 56u: goto tr509;
		case 60u: goto tr510;
		case 64u: goto tr509;
		case 68u: goto tr510;
		case 72u: goto tr509;
		case 76u: goto tr510;
		case 80u: goto tr509;
		case 84u: goto tr510;
		case 88u: goto tr509;
		case 92u: goto tr510;
		case 96u: goto tr509;
		case 100u: goto tr510;
		case 104u: goto tr509;
		case 108u: goto tr510;
		case 112u: goto tr509;
		case 116u: goto tr510;
		case 120u: goto tr511;
		case 124u: goto tr510;
		case 128u: goto tr512;
		case 132u: goto tr510;
		case 136u: goto tr512;
		case 140u: goto tr510;
		case 144u: goto tr512;
		case 148u: goto tr510;
		case 152u: goto tr512;
		case 156u: goto tr510;
		case 160u: goto tr512;
		case 164u: goto tr510;
		case 168u: goto tr512;
		case 172u: goto tr510;
		case 176u: goto tr512;
		case 180u: goto tr510;
		case 184u: goto tr512;
		case 188u: goto tr510;
		case 192u: goto tr512;
		case 196u: goto tr510;
		case 200u: goto tr512;
		case 204u: goto tr510;
		case 208u: goto tr512;
		case 212u: goto tr510;
		case 216u: goto tr512;
		case 220u: goto tr510;
		case 224u: goto tr512;
		case 228u: goto tr510;
		case 232u: goto tr512;
		case 236u: goto tr510;
		case 240u: goto tr512;
		case 244u: goto tr510;
		case 248u: goto tr512;
		case 252u: goto tr510;
	}
	goto tr33;
tr509:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st301;
st301:
	if ( ++p == pe )
		goto _test_eof301;
case 301:
#line 18666 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 166u: goto st302;
		case 182u: goto st302;
	}
	if ( (*p) < 158u ) {
		if ( (*p) < 142u ) {
			if ( 133u <= (*p) && (*p) <= 135u )
				goto st302;
		} else if ( (*p) > 143u ) {
			if ( 149u <= (*p) && (*p) <= 151u )
				goto st302;
		} else
			goto st302;
	} else if ( (*p) > 159u ) {
		if ( (*p) < 204u ) {
			if ( 162u <= (*p) && (*p) <= 163u )
				goto st302;
		} else if ( (*p) > 207u ) {
			if ( 236u <= (*p) && (*p) <= 239u )
				goto st303;
		} else
			goto st303;
	} else
		goto st302;
	goto tr33;
st302:
	if ( ++p == pe )
		goto _test_eof302;
case 302:
	switch( (*p) ) {
		case 4u: goto st258;
		case 5u: goto tr33;
		case 12u: goto st258;
		case 13u: goto tr33;
		case 20u: goto st258;
		case 21u: goto tr33;
		case 28u: goto st258;
		case 29u: goto tr33;
		case 36u: goto st258;
		case 37u: goto tr33;
		case 44u: goto st258;
		case 45u: goto tr33;
		case 52u: goto st258;
		case 53u: goto tr33;
		case 60u: goto st258;
		case 61u: goto tr33;
		case 68u: goto st260;
		case 76u: goto st260;
		case 84u: goto st260;
		case 92u: goto st260;
		case 100u: goto st260;
		case 108u: goto st260;
		case 116u: goto st260;
		case 124u: goto st260;
		case 132u: goto st262;
		case 140u: goto st262;
		case 148u: goto st262;
		case 156u: goto st262;
		case 164u: goto st262;
		case 172u: goto st262;
		case 180u: goto st262;
		case 188u: goto st262;
	}
	if ( (*p) < 64u ) {
		if ( (*p) <= 63u )
			goto tr515;
	} else if ( (*p) > 127u ) {
		if ( 128u <= (*p) && (*p) <= 191u )
			goto tr517;
	} else
		goto tr516;
	goto st259;
st303:
	if ( ++p == pe )
		goto _test_eof303;
case 303:
	switch( (*p) ) {
		case 4u: goto st268;
		case 5u: goto tr33;
		case 12u: goto st268;
		case 13u: goto tr33;
		case 20u: goto st268;
		case 21u: goto tr33;
		case 28u: goto st268;
		case 29u: goto tr33;
		case 36u: goto st268;
		case 37u: goto tr33;
		case 44u: goto st268;
		case 45u: goto tr33;
		case 52u: goto st268;
		case 53u: goto tr33;
		case 60u: goto st268;
		case 61u: goto tr33;
		case 68u: goto st50;
		case 76u: goto st50;
		case 84u: goto st50;
		case 92u: goto st50;
		case 100u: goto st50;
		case 108u: goto st50;
		case 116u: goto st50;
		case 124u: goto st50;
		case 132u: goto st51;
		case 140u: goto st51;
		case 148u: goto st51;
		case 156u: goto st51;
		case 164u: goto st51;
		case 172u: goto st51;
		case 180u: goto st51;
		case 188u: goto st51;
	}
	if ( (*p) < 64u ) {
		if ( (*p) <= 63u )
			goto tr93;
	} else if ( (*p) > 127u ) {
		if ( 128u <= (*p) && (*p) <= 191u )
			goto tr98;
	} else
		goto tr96;
	goto st11;
tr510:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st304;
st304:
	if ( ++p == pe )
		goto _test_eof304;
case 304:
#line 18796 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	if ( (*p) == 162u )
		goto st302;
	goto tr33;
tr511:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st305;
st305:
	if ( ++p == pe )
		goto _test_eof305;
case 305:
#line 18810 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 166u: goto st302;
		case 182u: goto st302;
	}
	if ( (*p) < 158u ) {
		if ( (*p) < 142u ) {
			if ( 133u <= (*p) && (*p) <= 135u )
				goto st302;
		} else if ( (*p) > 143u ) {
			if ( 149u <= (*p) && (*p) <= 151u )
				goto st302;
		} else
			goto st302;
	} else if ( (*p) > 159u ) {
		if ( (*p) < 192u ) {
			if ( 162u <= (*p) && (*p) <= 163u )
				goto st302;
		} else if ( (*p) > 195u ) {
			if ( (*p) > 207u ) {
				if ( 236u <= (*p) && (*p) <= 239u )
					goto st303;
			} else if ( (*p) >= 204u )
				goto st303;
		} else
			goto st303;
	} else
		goto st302;
	goto tr33;
tr512:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st306;
st306:
	if ( ++p == pe )
		goto _test_eof306;
case 306:
#line 18849 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	if ( 162u <= (*p) && (*p) <= 163u )
		goto st302;
	goto tr33;
tr451:
#line 235 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX2(*p);
  }
	goto st307;
st307:
	if ( ++p == pe )
		goto _test_eof307;
case 307:
#line 18863 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 0u: goto tr518;
		case 8u: goto tr518;
		case 16u: goto tr518;
		case 24u: goto tr518;
		case 32u: goto tr518;
		case 40u: goto tr518;
		case 48u: goto tr518;
		case 56u: goto tr518;
		case 64u: goto tr518;
		case 72u: goto tr518;
		case 80u: goto tr518;
		case 88u: goto tr518;
		case 96u: goto tr518;
		case 104u: goto tr518;
		case 112u: goto tr518;
		case 120u: goto tr519;
		case 124u: goto tr520;
		case 128u: goto tr518;
		case 136u: goto tr518;
		case 144u: goto tr518;
		case 152u: goto tr518;
		case 160u: goto tr518;
		case 168u: goto tr518;
		case 176u: goto tr518;
		case 184u: goto tr518;
		case 192u: goto tr518;
		case 200u: goto tr518;
		case 208u: goto tr518;
		case 216u: goto tr518;
		case 224u: goto tr518;
		case 232u: goto tr518;
		case 240u: goto tr518;
		case 248u: goto tr518;
	}
	goto tr33;
tr518:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st308;
st308:
	if ( ++p == pe )
		goto _test_eof308;
case 308:
#line 18910 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	if ( 144u <= (*p) && (*p) <= 155u )
		goto st309;
	goto tr33;
st309:
	if ( ++p == pe )
		goto _test_eof309;
case 309:
	switch( (*p) ) {
		case 4u: goto st275;
		case 5u: goto tr33;
		case 12u: goto st275;
		case 13u: goto tr33;
		case 20u: goto st275;
		case 21u: goto tr33;
		case 28u: goto st275;
		case 29u: goto tr33;
		case 36u: goto st275;
		case 37u: goto tr33;
		case 44u: goto st275;
		case 45u: goto tr33;
		case 52u: goto st275;
		case 53u: goto tr33;
		case 60u: goto st275;
		case 61u: goto tr33;
		case 68u: goto st8;
		case 76u: goto st8;
		case 84u: goto st8;
		case 92u: goto st8;
		case 100u: goto st8;
		case 108u: goto st8;
		case 116u: goto st8;
		case 124u: goto st8;
		case 132u: goto st9;
		case 140u: goto st9;
		case 148u: goto st9;
		case 156u: goto st9;
		case 164u: goto st9;
		case 172u: goto st9;
		case 180u: goto st9;
		case 188u: goto st9;
	}
	if ( (*p) < 64u ) {
		if ( (*p) <= 63u )
			goto tr0;
	} else if ( (*p) > 127u ) {
		if ( 128u <= (*p) && (*p) <= 191u )
			goto tr5;
	} else
		goto tr3;
	goto tr34;
tr519:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st310;
st310:
	if ( ++p == pe )
		goto _test_eof310;
case 310:
#line 18971 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 203u: goto st309;
		case 219u: goto st309;
	}
	if ( (*p) < 198u ) {
		if ( (*p) < 144u ) {
			if ( 128u <= (*p) && (*p) <= 131u )
				goto st309;
		} else if ( (*p) > 155u ) {
			if ( 193u <= (*p) && (*p) <= 195u )
				goto st309;
		} else
			goto st309;
	} else if ( (*p) > 199u ) {
		if ( (*p) < 214u ) {
			if ( 209u <= (*p) && (*p) <= 211u )
				goto st309;
		} else if ( (*p) > 215u ) {
			if ( 225u <= (*p) && (*p) <= 227u )
				goto st309;
		} else
			goto st309;
	} else
		goto st309;
	goto tr33;
tr520:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st311;
st311:
	if ( ++p == pe )
		goto _test_eof311;
case 311:
#line 19007 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	if ( 128u <= (*p) && (*p) <= 129u )
		goto st309;
	goto tr33;
tr452:
#line 235 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX2(*p);
  }
	goto st312;
st312:
	if ( ++p == pe )
		goto _test_eof312;
case 312:
#line 19021 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 120u: goto tr522;
		case 248u: goto tr523;
	}
	goto tr33;
tr522:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st313;
st313:
	if ( ++p == pe )
		goto _test_eof313;
case 313:
#line 19037 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	if ( (*p) == 16u )
		goto tr524;
	goto tr33;
tr524:
#line 295 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(0, OperandSize32bit);
  }
	goto st314;
tr525:
#line 298 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(0, OperandSize64bit);
  }
	goto st314;
st314:
	if ( ++p == pe )
		goto _test_eof314;
case 314:
#line 19057 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 4u: goto tr491;
		case 5u: goto tr33;
		case 12u: goto tr491;
		case 13u: goto tr33;
		case 20u: goto tr491;
		case 21u: goto tr33;
		case 28u: goto tr491;
		case 29u: goto tr33;
		case 36u: goto tr491;
		case 37u: goto tr33;
		case 44u: goto tr491;
		case 45u: goto tr33;
		case 52u: goto tr491;
		case 53u: goto tr33;
		case 60u: goto tr491;
		case 61u: goto tr33;
		case 68u: goto tr164;
		case 76u: goto tr164;
		case 84u: goto tr164;
		case 92u: goto tr164;
		case 100u: goto tr164;
		case 108u: goto tr164;
		case 116u: goto tr164;
		case 124u: goto tr164;
		case 132u: goto tr166;
		case 140u: goto tr166;
		case 148u: goto tr166;
		case 156u: goto tr166;
		case 164u: goto tr166;
		case 172u: goto tr166;
		case 180u: goto tr166;
		case 188u: goto tr166;
	}
	if ( (*p) < 64u ) {
		if ( (*p) <= 63u )
			goto tr160;
	} else if ( (*p) > 127u ) {
		if ( 128u <= (*p) && (*p) <= 191u )
			goto tr165;
	} else
		goto tr163;
	goto tr167;
tr523:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st315;
st315:
	if ( ++p == pe )
		goto _test_eof315;
case 315:
#line 19111 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	if ( (*p) == 16u )
		goto tr525;
	goto tr33;
tr453:
#line 235 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX2(*p);
  }
	goto st316;
st316:
	if ( ++p == pe )
		goto _test_eof316;
case 316:
#line 19125 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 0u: goto tr526;
		case 4u: goto tr527;
		case 8u: goto tr526;
		case 12u: goto tr527;
		case 16u: goto tr526;
		case 20u: goto tr527;
		case 24u: goto tr526;
		case 28u: goto tr527;
		case 32u: goto tr526;
		case 36u: goto tr527;
		case 40u: goto tr526;
		case 44u: goto tr527;
		case 48u: goto tr526;
		case 52u: goto tr527;
		case 56u: goto tr526;
		case 60u: goto tr527;
		case 64u: goto tr526;
		case 68u: goto tr527;
		case 72u: goto tr526;
		case 76u: goto tr527;
		case 80u: goto tr526;
		case 84u: goto tr527;
		case 88u: goto tr526;
		case 92u: goto tr527;
		case 96u: goto tr526;
		case 100u: goto tr527;
		case 104u: goto tr526;
		case 108u: goto tr527;
		case 112u: goto tr526;
		case 116u: goto tr527;
		case 120u: goto tr528;
		case 124u: goto tr527;
		case 128u: goto tr529;
		case 132u: goto tr527;
		case 136u: goto tr529;
		case 140u: goto tr527;
		case 144u: goto tr529;
		case 148u: goto tr527;
		case 152u: goto tr529;
		case 156u: goto tr527;
		case 160u: goto tr529;
		case 164u: goto tr527;
		case 168u: goto tr529;
		case 172u: goto tr527;
		case 176u: goto tr529;
		case 180u: goto tr527;
		case 184u: goto tr529;
		case 188u: goto tr527;
		case 192u: goto tr529;
		case 196u: goto tr527;
		case 200u: goto tr529;
		case 204u: goto tr527;
		case 208u: goto tr529;
		case 212u: goto tr527;
		case 216u: goto tr529;
		case 220u: goto tr527;
		case 224u: goto tr529;
		case 228u: goto tr527;
		case 232u: goto tr529;
		case 236u: goto tr527;
		case 240u: goto tr529;
		case 244u: goto tr527;
		case 248u: goto tr529;
		case 252u: goto tr527;
	}
	goto tr33;
tr526:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st317;
st317:
	if ( ++p == pe )
		goto _test_eof317;
case 317:
#line 19203 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 166u: goto st318;
		case 182u: goto st318;
	}
	if ( (*p) < 158u ) {
		if ( (*p) < 142u ) {
			if ( 133u <= (*p) && (*p) <= 135u )
				goto st318;
		} else if ( (*p) > 143u ) {
			if ( 149u <= (*p) && (*p) <= 151u )
				goto st318;
		} else
			goto st318;
	} else if ( (*p) > 159u ) {
		if ( (*p) < 204u ) {
			if ( 162u <= (*p) && (*p) <= 163u )
				goto st318;
		} else if ( (*p) > 207u ) {
			if ( 236u <= (*p) && (*p) <= 239u )
				goto st43;
		} else
			goto st43;
	} else
		goto st318;
	goto tr33;
st318:
	if ( ++p == pe )
		goto _test_eof318;
case 318:
	switch( (*p) ) {
		case 4u: goto st286;
		case 5u: goto tr531;
		case 12u: goto st286;
		case 13u: goto tr531;
		case 20u: goto st286;
		case 21u: goto tr531;
		case 28u: goto st286;
		case 29u: goto tr531;
		case 36u: goto st286;
		case 37u: goto tr531;
		case 44u: goto st286;
		case 45u: goto tr531;
		case 52u: goto st286;
		case 53u: goto tr531;
		case 60u: goto st286;
		case 61u: goto tr531;
		case 68u: goto st260;
		case 76u: goto st260;
		case 84u: goto st260;
		case 92u: goto st260;
		case 100u: goto st260;
		case 108u: goto st260;
		case 116u: goto st260;
		case 124u: goto st260;
		case 132u: goto st262;
		case 140u: goto st262;
		case 148u: goto st262;
		case 156u: goto st262;
		case 164u: goto st262;
		case 172u: goto st262;
		case 180u: goto st262;
		case 188u: goto st262;
	}
	if ( (*p) < 64u ) {
		if ( (*p) <= 63u )
			goto tr515;
	} else if ( (*p) > 127u ) {
		if ( 128u <= (*p) && (*p) <= 191u )
			goto tr517;
	} else
		goto tr516;
	goto st259;
tr527:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st319;
st319:
	if ( ++p == pe )
		goto _test_eof319;
case 319:
#line 19286 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	if ( (*p) == 162u )
		goto st318;
	goto tr33;
tr528:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st320;
st320:
	if ( ++p == pe )
		goto _test_eof320;
case 320:
#line 19300 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 166u: goto st318;
		case 182u: goto st318;
	}
	if ( (*p) < 158u ) {
		if ( (*p) < 142u ) {
			if ( 133u <= (*p) && (*p) <= 135u )
				goto st318;
		} else if ( (*p) > 143u ) {
			if ( 149u <= (*p) && (*p) <= 151u )
				goto st318;
		} else
			goto st318;
	} else if ( (*p) > 159u ) {
		if ( (*p) < 192u ) {
			if ( 162u <= (*p) && (*p) <= 163u )
				goto st318;
		} else if ( (*p) > 195u ) {
			if ( (*p) > 207u ) {
				if ( 236u <= (*p) && (*p) <= 239u )
					goto st43;
			} else if ( (*p) >= 204u )
				goto st43;
		} else
			goto st43;
	} else
		goto st318;
	goto tr33;
tr529:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st321;
st321:
	if ( ++p == pe )
		goto _test_eof321;
case 321:
#line 19339 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	if ( 162u <= (*p) && (*p) <= 163u )
		goto st318;
	goto tr33;
tr454:
#line 235 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX2(*p);
  }
	goto st322;
st322:
	if ( ++p == pe )
		goto _test_eof322;
case 322:
#line 19353 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 0u: goto tr532;
		case 8u: goto tr532;
		case 16u: goto tr532;
		case 24u: goto tr532;
		case 32u: goto tr532;
		case 40u: goto tr532;
		case 48u: goto tr532;
		case 56u: goto tr532;
		case 64u: goto tr532;
		case 72u: goto tr532;
		case 80u: goto tr532;
		case 88u: goto tr532;
		case 96u: goto tr532;
		case 104u: goto tr532;
		case 112u: goto tr532;
		case 120u: goto tr533;
		case 124u: goto tr534;
		case 128u: goto tr532;
		case 136u: goto tr532;
		case 144u: goto tr532;
		case 152u: goto tr532;
		case 160u: goto tr532;
		case 168u: goto tr532;
		case 176u: goto tr532;
		case 184u: goto tr532;
		case 192u: goto tr532;
		case 200u: goto tr532;
		case 208u: goto tr532;
		case 216u: goto tr532;
		case 224u: goto tr532;
		case 232u: goto tr532;
		case 240u: goto tr532;
		case 248u: goto tr532;
	}
	goto tr33;
tr532:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st323;
st323:
	if ( ++p == pe )
		goto _test_eof323;
case 323:
#line 19400 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	if ( 144u <= (*p) && (*p) <= 155u )
		goto st38;
	goto tr33;
tr533:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st324;
st324:
	if ( ++p == pe )
		goto _test_eof324;
case 324:
#line 19414 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 203u: goto st38;
		case 219u: goto st38;
	}
	if ( (*p) < 198u ) {
		if ( (*p) < 144u ) {
			if ( 128u <= (*p) && (*p) <= 131u )
				goto st38;
		} else if ( (*p) > 155u ) {
			if ( 193u <= (*p) && (*p) <= 195u )
				goto st38;
		} else
			goto st38;
	} else if ( (*p) > 199u ) {
		if ( (*p) < 214u ) {
			if ( 209u <= (*p) && (*p) <= 211u )
				goto st38;
		} else if ( (*p) > 215u ) {
			if ( 225u <= (*p) && (*p) <= 227u )
				goto st38;
		} else
			goto st38;
	} else
		goto st38;
	goto tr33;
tr534:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st325;
st325:
	if ( ++p == pe )
		goto _test_eof325;
case 325:
#line 19450 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	if ( 128u <= (*p) && (*p) <= 129u )
		goto st38;
	goto tr33;
tr455:
#line 235 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX2(*p);
  }
	goto st326;
st326:
	if ( ++p == pe )
		goto _test_eof326;
case 326:
#line 19464 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 120u: goto tr535;
		case 248u: goto tr536;
	}
	goto tr33;
tr535:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st327;
st327:
	if ( ++p == pe )
		goto _test_eof327;
case 327:
#line 19480 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	if ( (*p) == 16u )
		goto tr124;
	goto tr33;
tr536:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st328;
st328:
	if ( ++p == pe )
		goto _test_eof328;
case 328:
#line 19494 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	if ( (*p) == 16u )
		goto tr224;
	goto tr33;
tr456:
#line 235 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX2(*p);
  }
	goto st329;
st329:
	if ( ++p == pe )
		goto _test_eof329;
case 329:
#line 19508 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 0u: goto tr537;
		case 8u: goto tr537;
		case 16u: goto tr537;
		case 24u: goto tr537;
		case 32u: goto tr537;
		case 40u: goto tr537;
		case 48u: goto tr537;
		case 56u: goto tr537;
		case 64u: goto tr537;
		case 72u: goto tr537;
		case 80u: goto tr537;
		case 88u: goto tr537;
		case 96u: goto tr537;
		case 104u: goto tr537;
		case 112u: goto tr537;
		case 120u: goto tr538;
		case 124u: goto tr485;
		case 128u: goto tr539;
		case 136u: goto tr539;
		case 144u: goto tr539;
		case 152u: goto tr539;
		case 160u: goto tr539;
		case 168u: goto tr539;
		case 176u: goto tr539;
		case 184u: goto tr539;
		case 192u: goto tr539;
		case 200u: goto tr539;
		case 208u: goto tr539;
		case 216u: goto tr539;
		case 224u: goto tr539;
		case 232u: goto tr539;
		case 240u: goto tr539;
		case 248u: goto tr539;
	}
	goto tr33;
tr537:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st330;
st330:
	if ( ++p == pe )
		goto _test_eof330;
case 330:
#line 19555 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 1u: goto st331;
		case 2u: goto st332;
	}
	if ( 144u <= (*p) && (*p) <= 155u )
		goto st274;
	goto tr33;
st331:
	if ( ++p == pe )
		goto _test_eof331;
case 331:
	switch( (*p) ) {
		case 12u: goto tr542;
		case 20u: goto tr542;
		case 28u: goto tr542;
		case 36u: goto tr542;
		case 44u: goto tr542;
		case 52u: goto tr542;
		case 60u: goto tr542;
		case 76u: goto tr543;
		case 84u: goto tr543;
		case 92u: goto tr543;
		case 100u: goto tr543;
		case 108u: goto tr543;
		case 116u: goto tr543;
		case 124u: goto tr543;
		case 140u: goto tr544;
		case 148u: goto tr544;
		case 156u: goto tr544;
		case 164u: goto tr544;
		case 172u: goto tr544;
		case 180u: goto tr544;
		case 188u: goto tr544;
	}
	if ( 200u <= (*p) )
		goto tr545;
	goto tr33;
st332:
	if ( ++p == pe )
		goto _test_eof332;
case 332:
	switch( (*p) ) {
		case 12u: goto tr542;
		case 52u: goto tr542;
		case 76u: goto tr543;
		case 116u: goto tr543;
		case 140u: goto tr544;
		case 180u: goto tr544;
	}
	if ( (*p) > 207u ) {
		if ( 240u <= (*p) && (*p) <= 247u )
			goto tr545;
	} else if ( (*p) >= 200u )
		goto tr545;
	goto tr33;
tr538:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st333;
st333:
	if ( ++p == pe )
		goto _test_eof333;
case 333:
#line 19621 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 1u: goto st331;
		case 2u: goto st332;
		case 203u: goto st274;
		case 219u: goto st274;
	}
	if ( (*p) < 198u ) {
		if ( (*p) < 144u ) {
			if ( 128u <= (*p) && (*p) <= 131u )
				goto st274;
		} else if ( (*p) > 155u ) {
			if ( 193u <= (*p) && (*p) <= 195u )
				goto st274;
		} else
			goto st274;
	} else if ( (*p) > 199u ) {
		if ( (*p) < 214u ) {
			if ( 209u <= (*p) && (*p) <= 211u )
				goto st274;
		} else if ( (*p) > 215u ) {
			if ( 225u <= (*p) && (*p) <= 227u )
				goto st274;
		} else
			goto st274;
	} else
		goto st274;
	goto tr33;
tr539:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st334;
st334:
	if ( ++p == pe )
		goto _test_eof334;
case 334:
#line 19659 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 1u: goto st335;
		case 2u: goto st336;
	}
	if ( 144u <= (*p) && (*p) <= 155u )
		goto st274;
	goto tr33;
st335:
	if ( ++p == pe )
		goto _test_eof335;
case 335:
	switch( (*p) ) {
		case 12u: goto tr548;
		case 20u: goto tr548;
		case 28u: goto tr548;
		case 36u: goto tr548;
		case 44u: goto tr548;
		case 52u: goto tr548;
		case 60u: goto tr548;
		case 76u: goto tr549;
		case 84u: goto tr549;
		case 92u: goto tr549;
		case 100u: goto tr549;
		case 108u: goto tr549;
		case 116u: goto tr549;
		case 124u: goto tr549;
		case 140u: goto tr550;
		case 148u: goto tr550;
		case 156u: goto tr550;
		case 164u: goto tr550;
		case 172u: goto tr550;
		case 180u: goto tr550;
		case 188u: goto tr550;
	}
	if ( 200u <= (*p) )
		goto tr551;
	goto tr33;
st336:
	if ( ++p == pe )
		goto _test_eof336;
case 336:
	switch( (*p) ) {
		case 12u: goto tr548;
		case 52u: goto tr548;
		case 76u: goto tr549;
		case 116u: goto tr549;
		case 140u: goto tr550;
		case 180u: goto tr550;
	}
	if ( (*p) > 207u ) {
		if ( 240u <= (*p) && (*p) <= 247u )
			goto tr551;
	} else if ( (*p) >= 200u )
		goto tr551;
	goto tr33;
tr457:
#line 235 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX2(*p);
  }
	goto st337;
st337:
	if ( ++p == pe )
		goto _test_eof337;
case 337:
#line 19725 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 0u: goto tr552;
		case 8u: goto tr552;
		case 16u: goto tr552;
		case 24u: goto tr552;
		case 32u: goto tr552;
		case 40u: goto tr552;
		case 48u: goto tr552;
		case 56u: goto tr552;
		case 64u: goto tr552;
		case 72u: goto tr552;
		case 80u: goto tr552;
		case 88u: goto tr552;
		case 96u: goto tr552;
		case 104u: goto tr552;
		case 112u: goto tr552;
		case 120u: goto tr553;
		case 128u: goto tr554;
		case 136u: goto tr554;
		case 144u: goto tr554;
		case 152u: goto tr554;
		case 160u: goto tr554;
		case 168u: goto tr554;
		case 176u: goto tr554;
		case 184u: goto tr554;
		case 192u: goto tr554;
		case 200u: goto tr554;
		case 208u: goto tr554;
		case 216u: goto tr554;
		case 224u: goto tr554;
		case 232u: goto tr554;
		case 240u: goto tr554;
		case 248u: goto tr555;
	}
	goto tr33;
tr552:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st338;
st338:
	if ( ++p == pe )
		goto _test_eof338;
case 338:
#line 19771 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	if ( (*p) == 18u )
		goto st339;
	goto tr33;
st339:
	if ( ++p == pe )
		goto _test_eof339;
case 339:
	switch( (*p) ) {
		case 4u: goto tr557;
		case 12u: goto tr557;
		case 68u: goto tr558;
		case 76u: goto tr558;
		case 132u: goto tr559;
		case 140u: goto tr559;
	}
	if ( 192u <= (*p) && (*p) <= 207u )
		goto tr560;
	goto tr33;
tr553:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st340;
st340:
	if ( ++p == pe )
		goto _test_eof340;
case 340:
#line 19800 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 16u: goto tr490;
		case 18u: goto st339;
	}
	goto tr33;
tr554:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st341;
st341:
	if ( ++p == pe )
		goto _test_eof341;
case 341:
#line 19816 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	if ( (*p) == 18u )
		goto st342;
	goto tr33;
st342:
	if ( ++p == pe )
		goto _test_eof342;
case 342:
	switch( (*p) ) {
		case 4u: goto tr562;
		case 12u: goto tr562;
		case 68u: goto tr563;
		case 76u: goto tr563;
		case 132u: goto tr564;
		case 140u: goto tr564;
	}
	if ( 192u <= (*p) && (*p) <= 207u )
		goto tr565;
	goto tr33;
tr555:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st343;
st343:
	if ( ++p == pe )
		goto _test_eof343;
case 343:
#line 19845 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 16u: goto tr492;
		case 18u: goto st342;
	}
	goto tr33;
tr458:
#line 235 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX2(*p);
  }
	goto st344;
st344:
	if ( ++p == pe )
		goto _test_eof344;
case 344:
#line 19861 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 0u: goto tr566;
		case 8u: goto tr566;
		case 16u: goto tr566;
		case 24u: goto tr566;
		case 32u: goto tr566;
		case 40u: goto tr566;
		case 48u: goto tr566;
		case 56u: goto tr566;
		case 64u: goto tr566;
		case 72u: goto tr566;
		case 80u: goto tr566;
		case 88u: goto tr566;
		case 96u: goto tr566;
		case 104u: goto tr566;
		case 112u: goto tr566;
		case 120u: goto tr567;
		case 124u: goto tr503;
		case 128u: goto tr568;
		case 136u: goto tr568;
		case 144u: goto tr568;
		case 152u: goto tr568;
		case 160u: goto tr568;
		case 168u: goto tr568;
		case 176u: goto tr568;
		case 184u: goto tr568;
		case 192u: goto tr568;
		case 200u: goto tr568;
		case 208u: goto tr568;
		case 216u: goto tr568;
		case 224u: goto tr568;
		case 232u: goto tr568;
		case 240u: goto tr568;
		case 248u: goto tr568;
	}
	goto tr33;
tr566:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st345;
st345:
	if ( ++p == pe )
		goto _test_eof345;
case 345:
#line 19908 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 1u: goto st346;
		case 2u: goto st347;
	}
	if ( 144u <= (*p) && (*p) <= 155u )
		goto st293;
	goto tr33;
st346:
	if ( ++p == pe )
		goto _test_eof346;
case 346:
	switch( (*p) ) {
		case 12u: goto tr571;
		case 20u: goto tr571;
		case 28u: goto tr571;
		case 36u: goto tr571;
		case 44u: goto tr571;
		case 52u: goto tr571;
		case 60u: goto tr571;
		case 76u: goto tr543;
		case 84u: goto tr543;
		case 92u: goto tr543;
		case 100u: goto tr543;
		case 108u: goto tr543;
		case 116u: goto tr543;
		case 124u: goto tr543;
		case 140u: goto tr544;
		case 148u: goto tr544;
		case 156u: goto tr544;
		case 164u: goto tr544;
		case 172u: goto tr544;
		case 180u: goto tr544;
		case 188u: goto tr544;
	}
	if ( 200u <= (*p) )
		goto tr545;
	goto tr33;
st347:
	if ( ++p == pe )
		goto _test_eof347;
case 347:
	switch( (*p) ) {
		case 12u: goto tr571;
		case 52u: goto tr571;
		case 76u: goto tr543;
		case 116u: goto tr543;
		case 140u: goto tr544;
		case 180u: goto tr544;
	}
	if ( (*p) > 207u ) {
		if ( 240u <= (*p) && (*p) <= 247u )
			goto tr545;
	} else if ( (*p) >= 200u )
		goto tr545;
	goto tr33;
tr567:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st348;
st348:
	if ( ++p == pe )
		goto _test_eof348;
case 348:
#line 19974 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 1u: goto st346;
		case 2u: goto st347;
		case 203u: goto st293;
		case 219u: goto st293;
	}
	if ( (*p) < 198u ) {
		if ( (*p) < 144u ) {
			if ( 128u <= (*p) && (*p) <= 131u )
				goto st293;
		} else if ( (*p) > 155u ) {
			if ( 193u <= (*p) && (*p) <= 195u )
				goto st293;
		} else
			goto st293;
	} else if ( (*p) > 199u ) {
		if ( (*p) < 214u ) {
			if ( 209u <= (*p) && (*p) <= 211u )
				goto st293;
		} else if ( (*p) > 215u ) {
			if ( 225u <= (*p) && (*p) <= 227u )
				goto st293;
		} else
			goto st293;
	} else
		goto st293;
	goto tr33;
tr568:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st349;
st349:
	if ( ++p == pe )
		goto _test_eof349;
case 349:
#line 20012 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 1u: goto st350;
		case 2u: goto st351;
	}
	if ( 144u <= (*p) && (*p) <= 155u )
		goto st293;
	goto tr33;
st350:
	if ( ++p == pe )
		goto _test_eof350;
case 350:
	switch( (*p) ) {
		case 12u: goto tr574;
		case 20u: goto tr574;
		case 28u: goto tr574;
		case 36u: goto tr574;
		case 44u: goto tr574;
		case 52u: goto tr574;
		case 60u: goto tr574;
		case 76u: goto tr549;
		case 84u: goto tr549;
		case 92u: goto tr549;
		case 100u: goto tr549;
		case 108u: goto tr549;
		case 116u: goto tr549;
		case 124u: goto tr549;
		case 140u: goto tr550;
		case 148u: goto tr550;
		case 156u: goto tr550;
		case 164u: goto tr550;
		case 172u: goto tr550;
		case 180u: goto tr550;
		case 188u: goto tr550;
	}
	if ( 200u <= (*p) )
		goto tr551;
	goto tr33;
st351:
	if ( ++p == pe )
		goto _test_eof351;
case 351:
	switch( (*p) ) {
		case 12u: goto tr574;
		case 52u: goto tr574;
		case 76u: goto tr549;
		case 116u: goto tr549;
		case 140u: goto tr550;
		case 180u: goto tr550;
	}
	if ( (*p) > 207u ) {
		if ( 240u <= (*p) && (*p) <= 247u )
			goto tr551;
	} else if ( (*p) >= 200u )
		goto tr551;
	goto tr33;
tr459:
#line 235 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX2(*p);
  }
	goto st352;
st352:
	if ( ++p == pe )
		goto _test_eof352;
case 352:
#line 20078 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 0u: goto tr575;
		case 8u: goto tr575;
		case 16u: goto tr575;
		case 24u: goto tr575;
		case 32u: goto tr575;
		case 40u: goto tr575;
		case 48u: goto tr575;
		case 56u: goto tr575;
		case 64u: goto tr575;
		case 72u: goto tr575;
		case 80u: goto tr575;
		case 88u: goto tr575;
		case 96u: goto tr575;
		case 104u: goto tr575;
		case 112u: goto tr575;
		case 120u: goto tr576;
		case 128u: goto tr577;
		case 136u: goto tr577;
		case 144u: goto tr577;
		case 152u: goto tr577;
		case 160u: goto tr577;
		case 168u: goto tr577;
		case 176u: goto tr577;
		case 184u: goto tr577;
		case 192u: goto tr577;
		case 200u: goto tr577;
		case 208u: goto tr577;
		case 216u: goto tr577;
		case 224u: goto tr577;
		case 232u: goto tr577;
		case 240u: goto tr577;
		case 248u: goto tr578;
	}
	goto tr33;
tr575:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st353;
st353:
	if ( ++p == pe )
		goto _test_eof353;
case 353:
#line 20124 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	if ( (*p) == 18u )
		goto st354;
	goto tr33;
st354:
	if ( ++p == pe )
		goto _test_eof354;
case 354:
	switch( (*p) ) {
		case 4u: goto tr580;
		case 12u: goto tr580;
		case 68u: goto tr558;
		case 76u: goto tr558;
		case 132u: goto tr559;
		case 140u: goto tr559;
	}
	if ( 192u <= (*p) && (*p) <= 207u )
		goto tr560;
	goto tr33;
tr576:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st355;
st355:
	if ( ++p == pe )
		goto _test_eof355;
case 355:
#line 20153 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 16u: goto tr507;
		case 18u: goto st354;
	}
	goto tr33;
tr577:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st356;
st356:
	if ( ++p == pe )
		goto _test_eof356;
case 356:
#line 20169 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	if ( (*p) == 18u )
		goto st357;
	goto tr33;
st357:
	if ( ++p == pe )
		goto _test_eof357;
case 357:
	switch( (*p) ) {
		case 4u: goto tr582;
		case 12u: goto tr582;
		case 68u: goto tr563;
		case 76u: goto tr563;
		case 132u: goto tr564;
		case 140u: goto tr564;
	}
	if ( 192u <= (*p) && (*p) <= 207u )
		goto tr565;
	goto tr33;
tr578:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st358;
st358:
	if ( ++p == pe )
		goto _test_eof358;
case 358:
#line 20198 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 16u: goto tr508;
		case 18u: goto st357;
	}
	goto tr33;
tr460:
#line 235 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX2(*p);
  }
	goto st359;
st359:
	if ( ++p == pe )
		goto _test_eof359;
case 359:
#line 20214 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 0u: goto tr583;
		case 8u: goto tr583;
		case 16u: goto tr583;
		case 24u: goto tr583;
		case 32u: goto tr583;
		case 40u: goto tr583;
		case 48u: goto tr583;
		case 56u: goto tr583;
		case 64u: goto tr583;
		case 72u: goto tr583;
		case 80u: goto tr583;
		case 88u: goto tr583;
		case 96u: goto tr583;
		case 104u: goto tr583;
		case 112u: goto tr583;
		case 120u: goto tr584;
		case 124u: goto tr520;
		case 128u: goto tr585;
		case 136u: goto tr585;
		case 144u: goto tr585;
		case 152u: goto tr585;
		case 160u: goto tr585;
		case 168u: goto tr585;
		case 176u: goto tr585;
		case 184u: goto tr585;
		case 192u: goto tr585;
		case 200u: goto tr585;
		case 208u: goto tr585;
		case 216u: goto tr585;
		case 224u: goto tr585;
		case 232u: goto tr585;
		case 240u: goto tr585;
		case 248u: goto tr586;
	}
	goto tr33;
tr583:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st360;
st360:
	if ( ++p == pe )
		goto _test_eof360;
case 360:
#line 20261 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 1u: goto st361;
		case 2u: goto st362;
	}
	if ( 144u <= (*p) && (*p) <= 155u )
		goto st309;
	goto tr33;
st361:
	if ( ++p == pe )
		goto _test_eof361;
case 361:
	switch( (*p) ) {
		case 12u: goto tr542;
		case 13u: goto tr33;
		case 20u: goto tr542;
		case 21u: goto tr33;
		case 28u: goto tr542;
		case 29u: goto tr33;
		case 36u: goto tr542;
		case 37u: goto tr33;
		case 44u: goto tr542;
		case 45u: goto tr33;
		case 52u: goto tr542;
		case 53u: goto tr33;
		case 60u: goto tr542;
		case 61u: goto tr33;
		case 76u: goto tr543;
		case 84u: goto tr543;
		case 92u: goto tr543;
		case 100u: goto tr543;
		case 108u: goto tr543;
		case 116u: goto tr543;
		case 124u: goto tr543;
		case 140u: goto tr544;
		case 148u: goto tr544;
		case 156u: goto tr544;
		case 164u: goto tr544;
		case 172u: goto tr544;
		case 180u: goto tr544;
		case 188u: goto tr544;
	}
	if ( (*p) < 72u ) {
		if ( (*p) < 8u ) {
			if ( (*p) <= 7u )
				goto tr33;
		} else if ( (*p) > 63u ) {
			if ( 64u <= (*p) && (*p) <= 71u )
				goto tr33;
		} else
			goto tr589;
	} else if ( (*p) > 127u ) {
		if ( (*p) < 136u ) {
			if ( 128u <= (*p) && (*p) <= 135u )
				goto tr33;
		} else if ( (*p) > 191u ) {
			if ( 192u <= (*p) && (*p) <= 199u )
				goto tr33;
		} else
			goto tr591;
	} else
		goto tr590;
	goto tr545;
st362:
	if ( ++p == pe )
		goto _test_eof362;
case 362:
	switch( (*p) ) {
		case 12u: goto tr542;
		case 52u: goto tr542;
		case 76u: goto tr543;
		case 116u: goto tr543;
		case 140u: goto tr544;
		case 180u: goto tr544;
	}
	if ( (*p) < 72u ) {
		if ( (*p) < 14u ) {
			if ( 8u <= (*p) && (*p) <= 11u )
				goto tr589;
		} else if ( (*p) > 15u ) {
			if ( (*p) > 51u ) {
				if ( 54u <= (*p) && (*p) <= 55u )
					goto tr589;
			} else if ( (*p) >= 48u )
				goto tr589;
		} else
			goto tr589;
	} else if ( (*p) > 79u ) {
		if ( (*p) < 176u ) {
			if ( (*p) > 119u ) {
				if ( 136u <= (*p) && (*p) <= 143u )
					goto tr591;
			} else if ( (*p) >= 112u )
				goto tr590;
		} else if ( (*p) > 183u ) {
			if ( (*p) > 207u ) {
				if ( 240u <= (*p) && (*p) <= 247u )
					goto tr545;
			} else if ( (*p) >= 200u )
				goto tr545;
		} else
			goto tr591;
	} else
		goto tr590;
	goto tr33;
tr584:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st363;
st363:
	if ( ++p == pe )
		goto _test_eof363;
case 363:
#line 20376 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 1u: goto st361;
		case 2u: goto st362;
		case 18u: goto st364;
		case 203u: goto st309;
		case 219u: goto st309;
	}
	if ( (*p) < 198u ) {
		if ( (*p) < 144u ) {
			if ( 128u <= (*p) && (*p) <= 131u )
				goto st309;
		} else if ( (*p) > 155u ) {
			if ( 193u <= (*p) && (*p) <= 195u )
				goto st309;
		} else
			goto st309;
	} else if ( (*p) > 199u ) {
		if ( (*p) < 214u ) {
			if ( 209u <= (*p) && (*p) <= 211u )
				goto st309;
		} else if ( (*p) > 215u ) {
			if ( 225u <= (*p) && (*p) <= 227u )
				goto st309;
		} else
			goto st309;
	} else
		goto st309;
	goto tr33;
st364:
	if ( ++p == pe )
		goto _test_eof364;
case 364:
	if ( 192u <= (*p) && (*p) <= 207u )
		goto tr56;
	goto tr33;
tr585:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st365;
st365:
	if ( ++p == pe )
		goto _test_eof365;
case 365:
#line 20422 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 1u: goto st366;
		case 2u: goto st367;
	}
	if ( 144u <= (*p) && (*p) <= 155u )
		goto st309;
	goto tr33;
st366:
	if ( ++p == pe )
		goto _test_eof366;
case 366:
	switch( (*p) ) {
		case 12u: goto tr548;
		case 13u: goto tr33;
		case 20u: goto tr548;
		case 21u: goto tr33;
		case 28u: goto tr548;
		case 29u: goto tr33;
		case 36u: goto tr548;
		case 37u: goto tr33;
		case 44u: goto tr548;
		case 45u: goto tr33;
		case 52u: goto tr548;
		case 53u: goto tr33;
		case 60u: goto tr548;
		case 61u: goto tr33;
		case 76u: goto tr549;
		case 84u: goto tr549;
		case 92u: goto tr549;
		case 100u: goto tr549;
		case 108u: goto tr549;
		case 116u: goto tr549;
		case 124u: goto tr549;
		case 140u: goto tr550;
		case 148u: goto tr550;
		case 156u: goto tr550;
		case 164u: goto tr550;
		case 172u: goto tr550;
		case 180u: goto tr550;
		case 188u: goto tr550;
	}
	if ( (*p) < 72u ) {
		if ( (*p) < 8u ) {
			if ( (*p) <= 7u )
				goto tr33;
		} else if ( (*p) > 63u ) {
			if ( 64u <= (*p) && (*p) <= 71u )
				goto tr33;
		} else
			goto tr595;
	} else if ( (*p) > 127u ) {
		if ( (*p) < 136u ) {
			if ( 128u <= (*p) && (*p) <= 135u )
				goto tr33;
		} else if ( (*p) > 191u ) {
			if ( 192u <= (*p) && (*p) <= 199u )
				goto tr33;
		} else
			goto tr597;
	} else
		goto tr596;
	goto tr551;
st367:
	if ( ++p == pe )
		goto _test_eof367;
case 367:
	switch( (*p) ) {
		case 12u: goto tr548;
		case 52u: goto tr548;
		case 76u: goto tr549;
		case 116u: goto tr549;
		case 140u: goto tr550;
		case 180u: goto tr550;
	}
	if ( (*p) < 72u ) {
		if ( (*p) < 14u ) {
			if ( 8u <= (*p) && (*p) <= 11u )
				goto tr595;
		} else if ( (*p) > 15u ) {
			if ( (*p) > 51u ) {
				if ( 54u <= (*p) && (*p) <= 55u )
					goto tr595;
			} else if ( (*p) >= 48u )
				goto tr595;
		} else
			goto tr595;
	} else if ( (*p) > 79u ) {
		if ( (*p) < 176u ) {
			if ( (*p) > 119u ) {
				if ( 136u <= (*p) && (*p) <= 143u )
					goto tr597;
			} else if ( (*p) >= 112u )
				goto tr596;
		} else if ( (*p) > 183u ) {
			if ( (*p) > 207u ) {
				if ( 240u <= (*p) && (*p) <= 247u )
					goto tr551;
			} else if ( (*p) >= 200u )
				goto tr551;
		} else
			goto tr597;
	} else
		goto tr596;
	goto tr33;
tr586:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st368;
st368:
	if ( ++p == pe )
		goto _test_eof368;
case 368:
#line 20537 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 1u: goto st366;
		case 2u: goto st367;
		case 18u: goto st369;
	}
	if ( 144u <= (*p) && (*p) <= 155u )
		goto st309;
	goto tr33;
st369:
	if ( ++p == pe )
		goto _test_eof369;
case 369:
	if ( 192u <= (*p) && (*p) <= 207u )
		goto tr208;
	goto tr33;
tr461:
#line 235 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX2(*p);
  }
	goto st370;
st370:
	if ( ++p == pe )
		goto _test_eof370;
case 370:
#line 20563 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 0u: goto tr599;
		case 8u: goto tr599;
		case 16u: goto tr599;
		case 24u: goto tr599;
		case 32u: goto tr599;
		case 40u: goto tr599;
		case 48u: goto tr599;
		case 56u: goto tr599;
		case 64u: goto tr599;
		case 72u: goto tr599;
		case 80u: goto tr599;
		case 88u: goto tr599;
		case 96u: goto tr599;
		case 104u: goto tr599;
		case 112u: goto tr599;
		case 120u: goto tr600;
		case 128u: goto tr601;
		case 136u: goto tr601;
		case 144u: goto tr601;
		case 152u: goto tr601;
		case 160u: goto tr601;
		case 168u: goto tr601;
		case 176u: goto tr601;
		case 184u: goto tr601;
		case 192u: goto tr601;
		case 200u: goto tr601;
		case 208u: goto tr601;
		case 216u: goto tr601;
		case 224u: goto tr601;
		case 232u: goto tr601;
		case 240u: goto tr601;
		case 248u: goto tr602;
	}
	goto tr33;
tr599:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st371;
st371:
	if ( ++p == pe )
		goto _test_eof371;
case 371:
#line 20609 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	if ( (*p) == 18u )
		goto st372;
	goto tr33;
st372:
	if ( ++p == pe )
		goto _test_eof372;
case 372:
	switch( (*p) ) {
		case 4u: goto tr557;
		case 12u: goto tr557;
		case 68u: goto tr558;
		case 76u: goto tr558;
		case 132u: goto tr559;
		case 140u: goto tr559;
	}
	if ( (*p) < 14u ) {
		if ( (*p) > 3u ) {
			if ( 6u <= (*p) && (*p) <= 11u )
				goto tr604;
		} else
			goto tr604;
	} else if ( (*p) > 15u ) {
		if ( (*p) < 128u ) {
			if ( 64u <= (*p) && (*p) <= 79u )
				goto tr605;
		} else if ( (*p) > 143u ) {
			if ( 192u <= (*p) && (*p) <= 207u )
				goto tr560;
		} else
			goto tr606;
	} else
		goto tr604;
	goto tr33;
tr600:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st373;
st373:
	if ( ++p == pe )
		goto _test_eof373;
case 373:
#line 20653 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 16u: goto tr524;
		case 18u: goto st372;
	}
	goto tr33;
tr601:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st374;
st374:
	if ( ++p == pe )
		goto _test_eof374;
case 374:
#line 20669 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	if ( (*p) == 18u )
		goto st375;
	goto tr33;
st375:
	if ( ++p == pe )
		goto _test_eof375;
case 375:
	switch( (*p) ) {
		case 4u: goto tr562;
		case 12u: goto tr562;
		case 68u: goto tr563;
		case 76u: goto tr563;
		case 132u: goto tr564;
		case 140u: goto tr564;
	}
	if ( (*p) < 14u ) {
		if ( (*p) > 3u ) {
			if ( 6u <= (*p) && (*p) <= 11u )
				goto tr608;
		} else
			goto tr608;
	} else if ( (*p) > 15u ) {
		if ( (*p) < 128u ) {
			if ( 64u <= (*p) && (*p) <= 79u )
				goto tr609;
		} else if ( (*p) > 143u ) {
			if ( 192u <= (*p) && (*p) <= 207u )
				goto tr565;
		} else
			goto tr610;
	} else
		goto tr608;
	goto tr33;
tr602:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st376;
st376:
	if ( ++p == pe )
		goto _test_eof376;
case 376:
#line 20713 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 16u: goto tr525;
		case 18u: goto st375;
	}
	goto tr33;
tr462:
#line 235 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX2(*p);
  }
	goto st377;
st377:
	if ( ++p == pe )
		goto _test_eof377;
case 377:
#line 20729 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 0u: goto tr611;
		case 8u: goto tr611;
		case 16u: goto tr611;
		case 24u: goto tr611;
		case 32u: goto tr611;
		case 40u: goto tr611;
		case 48u: goto tr611;
		case 56u: goto tr611;
		case 64u: goto tr611;
		case 72u: goto tr611;
		case 80u: goto tr611;
		case 88u: goto tr611;
		case 96u: goto tr611;
		case 104u: goto tr611;
		case 112u: goto tr611;
		case 120u: goto tr612;
		case 124u: goto tr534;
		case 128u: goto tr613;
		case 136u: goto tr613;
		case 144u: goto tr613;
		case 152u: goto tr613;
		case 160u: goto tr613;
		case 168u: goto tr613;
		case 176u: goto tr613;
		case 184u: goto tr613;
		case 192u: goto tr613;
		case 200u: goto tr613;
		case 208u: goto tr613;
		case 216u: goto tr613;
		case 224u: goto tr613;
		case 232u: goto tr613;
		case 240u: goto tr613;
		case 248u: goto tr614;
	}
	goto tr33;
tr611:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st378;
st378:
	if ( ++p == pe )
		goto _test_eof378;
case 378:
#line 20776 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 1u: goto st379;
		case 2u: goto st380;
	}
	if ( 144u <= (*p) && (*p) <= 155u )
		goto st38;
	goto tr33;
st379:
	if ( ++p == pe )
		goto _test_eof379;
case 379:
	switch( (*p) ) {
		case 12u: goto tr571;
		case 13u: goto tr617;
		case 20u: goto tr571;
		case 21u: goto tr617;
		case 28u: goto tr571;
		case 29u: goto tr617;
		case 36u: goto tr571;
		case 37u: goto tr617;
		case 44u: goto tr571;
		case 45u: goto tr617;
		case 52u: goto tr571;
		case 53u: goto tr617;
		case 60u: goto tr571;
		case 61u: goto tr617;
		case 76u: goto tr543;
		case 84u: goto tr543;
		case 92u: goto tr543;
		case 100u: goto tr543;
		case 108u: goto tr543;
		case 116u: goto tr543;
		case 124u: goto tr543;
		case 140u: goto tr544;
		case 148u: goto tr544;
		case 156u: goto tr544;
		case 164u: goto tr544;
		case 172u: goto tr544;
		case 180u: goto tr544;
		case 188u: goto tr544;
	}
	if ( (*p) < 72u ) {
		if ( (*p) < 8u ) {
			if ( (*p) <= 7u )
				goto tr33;
		} else if ( (*p) > 63u ) {
			if ( 64u <= (*p) && (*p) <= 71u )
				goto tr33;
		} else
			goto tr589;
	} else if ( (*p) > 127u ) {
		if ( (*p) < 136u ) {
			if ( 128u <= (*p) && (*p) <= 135u )
				goto tr33;
		} else if ( (*p) > 191u ) {
			if ( 192u <= (*p) && (*p) <= 199u )
				goto tr33;
		} else
			goto tr591;
	} else
		goto tr590;
	goto tr545;
st380:
	if ( ++p == pe )
		goto _test_eof380;
case 380:
	switch( (*p) ) {
		case 12u: goto tr571;
		case 13u: goto tr617;
		case 52u: goto tr571;
		case 53u: goto tr617;
		case 76u: goto tr543;
		case 116u: goto tr543;
		case 140u: goto tr544;
		case 180u: goto tr544;
	}
	if ( (*p) < 112u ) {
		if ( (*p) < 48u ) {
			if ( 8u <= (*p) && (*p) <= 15u )
				goto tr589;
		} else if ( (*p) > 55u ) {
			if ( 72u <= (*p) && (*p) <= 79u )
				goto tr590;
		} else
			goto tr589;
	} else if ( (*p) > 119u ) {
		if ( (*p) < 176u ) {
			if ( 136u <= (*p) && (*p) <= 143u )
				goto tr591;
		} else if ( (*p) > 183u ) {
			if ( (*p) > 207u ) {
				if ( 240u <= (*p) && (*p) <= 247u )
					goto tr545;
			} else if ( (*p) >= 200u )
				goto tr545;
		} else
			goto tr591;
	} else
		goto tr590;
	goto tr33;
tr612:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st381;
st381:
	if ( ++p == pe )
		goto _test_eof381;
case 381:
#line 20887 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 1u: goto st379;
		case 2u: goto st380;
		case 18u: goto st364;
		case 203u: goto st38;
		case 219u: goto st38;
	}
	if ( (*p) < 198u ) {
		if ( (*p) < 144u ) {
			if ( 128u <= (*p) && (*p) <= 131u )
				goto st38;
		} else if ( (*p) > 155u ) {
			if ( 193u <= (*p) && (*p) <= 195u )
				goto st38;
		} else
			goto st38;
	} else if ( (*p) > 199u ) {
		if ( (*p) < 214u ) {
			if ( 209u <= (*p) && (*p) <= 211u )
				goto st38;
		} else if ( (*p) > 215u ) {
			if ( 225u <= (*p) && (*p) <= 227u )
				goto st38;
		} else
			goto st38;
	} else
		goto st38;
	goto tr33;
tr613:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st382;
st382:
	if ( ++p == pe )
		goto _test_eof382;
case 382:
#line 20926 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 1u: goto st383;
		case 2u: goto st384;
	}
	if ( 144u <= (*p) && (*p) <= 155u )
		goto st38;
	goto tr33;
st383:
	if ( ++p == pe )
		goto _test_eof383;
case 383:
	switch( (*p) ) {
		case 12u: goto tr574;
		case 13u: goto tr620;
		case 20u: goto tr574;
		case 21u: goto tr620;
		case 28u: goto tr574;
		case 29u: goto tr620;
		case 36u: goto tr574;
		case 37u: goto tr620;
		case 44u: goto tr574;
		case 45u: goto tr620;
		case 52u: goto tr574;
		case 53u: goto tr620;
		case 60u: goto tr574;
		case 61u: goto tr620;
		case 76u: goto tr549;
		case 84u: goto tr549;
		case 92u: goto tr549;
		case 100u: goto tr549;
		case 108u: goto tr549;
		case 116u: goto tr549;
		case 124u: goto tr549;
		case 140u: goto tr550;
		case 148u: goto tr550;
		case 156u: goto tr550;
		case 164u: goto tr550;
		case 172u: goto tr550;
		case 180u: goto tr550;
		case 188u: goto tr550;
	}
	if ( (*p) < 72u ) {
		if ( (*p) < 8u ) {
			if ( (*p) <= 7u )
				goto tr33;
		} else if ( (*p) > 63u ) {
			if ( 64u <= (*p) && (*p) <= 71u )
				goto tr33;
		} else
			goto tr595;
	} else if ( (*p) > 127u ) {
		if ( (*p) < 136u ) {
			if ( 128u <= (*p) && (*p) <= 135u )
				goto tr33;
		} else if ( (*p) > 191u ) {
			if ( 192u <= (*p) && (*p) <= 199u )
				goto tr33;
		} else
			goto tr597;
	} else
		goto tr596;
	goto tr551;
st384:
	if ( ++p == pe )
		goto _test_eof384;
case 384:
	switch( (*p) ) {
		case 12u: goto tr574;
		case 13u: goto tr620;
		case 52u: goto tr574;
		case 53u: goto tr620;
		case 76u: goto tr549;
		case 116u: goto tr549;
		case 140u: goto tr550;
		case 180u: goto tr550;
	}
	if ( (*p) < 112u ) {
		if ( (*p) < 48u ) {
			if ( 8u <= (*p) && (*p) <= 15u )
				goto tr595;
		} else if ( (*p) > 55u ) {
			if ( 72u <= (*p) && (*p) <= 79u )
				goto tr596;
		} else
			goto tr595;
	} else if ( (*p) > 119u ) {
		if ( (*p) < 176u ) {
			if ( 136u <= (*p) && (*p) <= 143u )
				goto tr597;
		} else if ( (*p) > 183u ) {
			if ( (*p) > 207u ) {
				if ( 240u <= (*p) && (*p) <= 247u )
					goto tr551;
			} else if ( (*p) >= 200u )
				goto tr551;
		} else
			goto tr597;
	} else
		goto tr596;
	goto tr33;
tr614:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st385;
st385:
	if ( ++p == pe )
		goto _test_eof385;
case 385:
#line 21037 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 1u: goto st383;
		case 2u: goto st384;
		case 18u: goto st369;
	}
	if ( 144u <= (*p) && (*p) <= 155u )
		goto st38;
	goto tr33;
tr463:
#line 235 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX2(*p);
  }
	goto st386;
st386:
	if ( ++p == pe )
		goto _test_eof386;
case 386:
#line 21056 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 0u: goto tr621;
		case 8u: goto tr621;
		case 16u: goto tr621;
		case 24u: goto tr621;
		case 32u: goto tr621;
		case 40u: goto tr621;
		case 48u: goto tr621;
		case 56u: goto tr621;
		case 64u: goto tr621;
		case 72u: goto tr621;
		case 80u: goto tr621;
		case 88u: goto tr621;
		case 96u: goto tr621;
		case 104u: goto tr621;
		case 112u: goto tr621;
		case 120u: goto tr622;
		case 128u: goto tr623;
		case 136u: goto tr623;
		case 144u: goto tr623;
		case 152u: goto tr623;
		case 160u: goto tr623;
		case 168u: goto tr623;
		case 176u: goto tr623;
		case 184u: goto tr623;
		case 192u: goto tr623;
		case 200u: goto tr623;
		case 208u: goto tr623;
		case 216u: goto tr623;
		case 224u: goto tr623;
		case 232u: goto tr623;
		case 240u: goto tr623;
		case 248u: goto tr624;
	}
	goto tr33;
tr621:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st387;
st387:
	if ( ++p == pe )
		goto _test_eof387;
case 387:
#line 21102 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	if ( (*p) == 18u )
		goto st388;
	goto tr33;
st388:
	if ( ++p == pe )
		goto _test_eof388;
case 388:
	switch( (*p) ) {
		case 4u: goto tr580;
		case 5u: goto tr626;
		case 12u: goto tr580;
		case 13u: goto tr626;
		case 68u: goto tr558;
		case 76u: goto tr558;
		case 132u: goto tr559;
		case 140u: goto tr559;
	}
	if ( (*p) < 64u ) {
		if ( (*p) <= 15u )
			goto tr604;
	} else if ( (*p) > 79u ) {
		if ( (*p) > 143u ) {
			if ( 192u <= (*p) && (*p) <= 207u )
				goto tr560;
		} else if ( (*p) >= 128u )
			goto tr606;
	} else
		goto tr605;
	goto tr33;
tr622:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st389;
st389:
	if ( ++p == pe )
		goto _test_eof389;
case 389:
#line 21142 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 16u: goto tr124;
		case 18u: goto st388;
	}
	goto tr33;
tr623:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st390;
st390:
	if ( ++p == pe )
		goto _test_eof390;
case 390:
#line 21158 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	if ( (*p) == 18u )
		goto st391;
	goto tr33;
st391:
	if ( ++p == pe )
		goto _test_eof391;
case 391:
	switch( (*p) ) {
		case 4u: goto tr582;
		case 5u: goto tr628;
		case 12u: goto tr582;
		case 13u: goto tr628;
		case 68u: goto tr563;
		case 76u: goto tr563;
		case 132u: goto tr564;
		case 140u: goto tr564;
	}
	if ( (*p) < 64u ) {
		if ( (*p) <= 15u )
			goto tr608;
	} else if ( (*p) > 79u ) {
		if ( (*p) > 143u ) {
			if ( 192u <= (*p) && (*p) <= 207u )
				goto tr565;
		} else if ( (*p) >= 128u )
			goto tr610;
	} else
		goto tr609;
	goto tr33;
tr624:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st392;
st392:
	if ( ++p == pe )
		goto _test_eof392;
case 392:
#line 21198 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 16u: goto tr224;
		case 18u: goto st391;
	}
	goto tr33;
tr1017:
#line 329 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
        begin = p;
        BitmapSetBit(valid_targets, p - data);
        SET_REX_PREFIX(FALSE);
        SET_VEX_PREFIX2(0xe0);
        SET_VEX_PREFIX3(0x00);
        operand_states = 0;
     }
	goto st393;
st393:
	if ( ++p == pe )
		goto _test_eof393;
case 393:
#line 21219 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 4u: goto st44;
		case 5u: goto tr95;
		case 12u: goto st44;
		case 13u: goto tr95;
		case 20u: goto st44;
		case 21u: goto tr95;
		case 28u: goto st44;
		case 29u: goto tr95;
		case 36u: goto st44;
		case 37u: goto tr95;
		case 44u: goto st44;
		case 45u: goto tr95;
		case 60u: goto st44;
		case 61u: goto tr95;
		case 68u: goto st50;
		case 76u: goto st50;
		case 84u: goto st50;
		case 92u: goto st50;
		case 100u: goto st50;
		case 108u: goto st50;
		case 124u: goto st50;
		case 132u: goto st51;
		case 140u: goto st51;
		case 148u: goto st51;
		case 156u: goto st51;
		case 164u: goto st51;
		case 172u: goto st51;
		case 188u: goto st51;
	}
	if ( (*p) < 112u ) {
		if ( (*p) < 48u ) {
			if ( (*p) <= 47u )
				goto tr93;
		} else if ( (*p) > 55u ) {
			if ( (*p) > 63u ) {
				if ( 64u <= (*p) && (*p) <= 111u )
					goto tr96;
			} else if ( (*p) >= 56u )
				goto tr93;
		} else
			goto tr33;
	} else if ( (*p) > 119u ) {
		if ( (*p) < 176u ) {
			if ( (*p) > 127u ) {
				if ( 128u <= (*p) && (*p) <= 175u )
					goto tr98;
			} else if ( (*p) >= 120u )
				goto tr96;
		} else if ( (*p) > 183u ) {
			if ( (*p) > 191u ) {
				if ( 240u <= (*p) && (*p) <= 247u )
					goto tr33;
			} else if ( (*p) >= 184u )
				goto tr98;
		} else
			goto tr33;
	} else
		goto tr33;
	goto tr184;
tr1018:
#line 329 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
        begin = p;
        BitmapSetBit(valid_targets, p - data);
        SET_REX_PREFIX(FALSE);
        SET_VEX_PREFIX2(0xe0);
        SET_VEX_PREFIX3(0x00);
        operand_states = 0;
     }
	goto st394;
st394:
	if ( ++p == pe )
		goto _test_eof394;
case 394:
#line 21295 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 4u: goto st44;
		case 5u: goto tr95;
		case 12u: goto st44;
		case 13u: goto tr95;
		case 20u: goto st44;
		case 21u: goto tr95;
		case 28u: goto st44;
		case 29u: goto tr95;
		case 36u: goto st44;
		case 37u: goto tr95;
		case 44u: goto st44;
		case 45u: goto tr95;
		case 60u: goto st44;
		case 61u: goto tr95;
		case 68u: goto st50;
		case 76u: goto st50;
		case 84u: goto st50;
		case 92u: goto st50;
		case 100u: goto st50;
		case 108u: goto st50;
		case 124u: goto st50;
		case 132u: goto st51;
		case 140u: goto st51;
		case 148u: goto st51;
		case 156u: goto st51;
		case 164u: goto st51;
		case 172u: goto st51;
		case 188u: goto st51;
	}
	if ( (*p) < 112u ) {
		if ( (*p) < 48u ) {
			if ( (*p) <= 47u )
				goto tr93;
		} else if ( (*p) > 55u ) {
			if ( (*p) > 63u ) {
				if ( 64u <= (*p) && (*p) <= 111u )
					goto tr96;
			} else if ( (*p) >= 56u )
				goto tr93;
		} else
			goto tr33;
	} else if ( (*p) > 119u ) {
		if ( (*p) < 176u ) {
			if ( (*p) > 127u ) {
				if ( 128u <= (*p) && (*p) <= 175u )
					goto tr98;
			} else if ( (*p) >= 120u )
				goto tr96;
		} else if ( (*p) > 183u ) {
			if ( (*p) > 191u ) {
				if ( 240u <= (*p) && (*p) <= 247u )
					goto tr33;
			} else if ( (*p) >= 184u )
				goto tr98;
		} else
			goto tr33;
	} else
		goto tr33;
	goto tr115;
tr1019:
#line 329 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
        begin = p;
        BitmapSetBit(valid_targets, p - data);
        SET_REX_PREFIX(FALSE);
        SET_VEX_PREFIX2(0xe0);
        SET_VEX_PREFIX3(0x00);
        operand_states = 0;
     }
	goto st395;
st395:
	if ( ++p == pe )
		goto _test_eof395;
case 395:
#line 21371 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 1u: goto tr629;
		case 2u: goto tr630;
		case 3u: goto tr631;
		case 33u: goto tr632;
		case 34u: goto tr633;
		case 35u: goto tr634;
		case 65u: goto tr635;
		case 66u: goto tr636;
		case 67u: goto tr637;
		case 97u: goto tr638;
		case 98u: goto tr639;
		case 99u: goto tr640;
		case 129u: goto tr641;
		case 130u: goto tr642;
		case 131u: goto tr631;
		case 161u: goto tr643;
		case 162u: goto tr644;
		case 163u: goto tr634;
		case 193u: goto tr645;
		case 194u: goto tr646;
		case 195u: goto tr637;
		case 225u: goto tr647;
		case 226u: goto tr648;
		case 227u: goto tr640;
	}
	goto tr33;
tr629:
#line 235 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX2(*p);
  }
	goto st396;
st396:
	if ( ++p == pe )
		goto _test_eof396;
case 396:
#line 21409 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 0u: goto tr649;
		case 1u: goto tr650;
		case 2u: goto tr651;
		case 3u: goto tr652;
		case 4u: goto tr653;
		case 5u: goto tr654;
		case 7u: goto tr655;
		case 8u: goto tr649;
		case 9u: goto tr650;
		case 10u: goto tr651;
		case 11u: goto tr652;
		case 12u: goto tr653;
		case 13u: goto tr654;
		case 15u: goto tr655;
		case 16u: goto tr649;
		case 17u: goto tr650;
		case 18u: goto tr651;
		case 19u: goto tr652;
		case 20u: goto tr653;
		case 21u: goto tr654;
		case 23u: goto tr655;
		case 24u: goto tr649;
		case 25u: goto tr650;
		case 26u: goto tr651;
		case 27u: goto tr652;
		case 28u: goto tr653;
		case 29u: goto tr654;
		case 31u: goto tr655;
		case 32u: goto tr649;
		case 33u: goto tr650;
		case 34u: goto tr651;
		case 35u: goto tr652;
		case 36u: goto tr653;
		case 37u: goto tr654;
		case 39u: goto tr655;
		case 40u: goto tr649;
		case 41u: goto tr650;
		case 42u: goto tr651;
		case 43u: goto tr652;
		case 44u: goto tr653;
		case 45u: goto tr654;
		case 47u: goto tr655;
		case 48u: goto tr649;
		case 49u: goto tr650;
		case 50u: goto tr651;
		case 51u: goto tr652;
		case 52u: goto tr653;
		case 53u: goto tr654;
		case 55u: goto tr655;
		case 56u: goto tr649;
		case 57u: goto tr650;
		case 58u: goto tr651;
		case 59u: goto tr652;
		case 60u: goto tr653;
		case 61u: goto tr654;
		case 63u: goto tr655;
		case 64u: goto tr649;
		case 65u: goto tr650;
		case 66u: goto tr651;
		case 67u: goto tr652;
		case 68u: goto tr653;
		case 69u: goto tr654;
		case 71u: goto tr655;
		case 72u: goto tr649;
		case 73u: goto tr650;
		case 74u: goto tr651;
		case 75u: goto tr652;
		case 76u: goto tr653;
		case 77u: goto tr654;
		case 79u: goto tr655;
		case 80u: goto tr649;
		case 81u: goto tr650;
		case 82u: goto tr651;
		case 83u: goto tr652;
		case 84u: goto tr653;
		case 85u: goto tr654;
		case 87u: goto tr655;
		case 88u: goto tr649;
		case 89u: goto tr650;
		case 90u: goto tr651;
		case 91u: goto tr652;
		case 92u: goto tr653;
		case 93u: goto tr654;
		case 95u: goto tr655;
		case 96u: goto tr649;
		case 97u: goto tr650;
		case 98u: goto tr651;
		case 99u: goto tr652;
		case 100u: goto tr653;
		case 101u: goto tr654;
		case 103u: goto tr655;
		case 104u: goto tr649;
		case 105u: goto tr650;
		case 106u: goto tr651;
		case 107u: goto tr652;
		case 108u: goto tr653;
		case 109u: goto tr654;
		case 111u: goto tr655;
		case 112u: goto tr649;
		case 113u: goto tr650;
		case 114u: goto tr651;
		case 115u: goto tr652;
		case 116u: goto tr653;
		case 117u: goto tr654;
		case 119u: goto tr655;
		case 120u: goto tr656;
		case 121u: goto tr657;
		case 122u: goto tr658;
		case 123u: goto tr659;
		case 124u: goto tr660;
		case 125u: goto tr661;
		case 126u: goto tr662;
		case 127u: goto tr663;
		case 249u: goto tr665;
		case 253u: goto tr667;
	}
	if ( (*p) < 186u ) {
		if ( (*p) < 154u ) {
			if ( (*p) < 138u ) {
				if ( 130u <= (*p) && (*p) <= 131u )
					goto tr664;
			} else if ( (*p) > 139u ) {
				if ( 146u <= (*p) && (*p) <= 147u )
					goto tr664;
			} else
				goto tr664;
		} else if ( (*p) > 155u ) {
			if ( (*p) < 170u ) {
				if ( 162u <= (*p) && (*p) <= 163u )
					goto tr664;
			} else if ( (*p) > 171u ) {
				if ( 178u <= (*p) && (*p) <= 179u )
					goto tr664;
			} else
				goto tr664;
		} else
			goto tr664;
	} else if ( (*p) > 187u ) {
		if ( (*p) < 218u ) {
			if ( (*p) < 202u ) {
				if ( 194u <= (*p) && (*p) <= 195u )
					goto tr664;
			} else if ( (*p) > 203u ) {
				if ( 210u <= (*p) && (*p) <= 211u )
					goto tr664;
			} else
				goto tr664;
		} else if ( (*p) > 219u ) {
			if ( (*p) < 234u ) {
				if ( 226u <= (*p) && (*p) <= 227u )
					goto tr664;
			} else if ( (*p) > 235u ) {
				if ( (*p) > 243u ) {
					if ( 250u <= (*p) && (*p) <= 251u )
						goto tr666;
				} else if ( (*p) >= 242u )
					goto tr664;
			} else
				goto tr664;
		} else
			goto tr664;
	} else
		goto tr664;
	goto tr33;
tr649:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st397;
st397:
	if ( ++p == pe )
		goto _test_eof397;
case 397:
#line 21585 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 18u: goto st398;
		case 81u: goto st274;
		case 194u: goto st267;
		case 198u: goto st267;
	}
	if ( (*p) < 46u ) {
		if ( (*p) > 21u ) {
			if ( 22u <= (*p) && (*p) <= 23u )
				goto st398;
		} else if ( (*p) >= 20u )
			goto st274;
	} else if ( (*p) > 47u ) {
		if ( (*p) > 89u ) {
			if ( 92u <= (*p) && (*p) <= 95u )
				goto st274;
		} else if ( (*p) >= 84u )
			goto st274;
	} else
		goto st274;
	goto tr33;
st398:
	if ( ++p == pe )
		goto _test_eof398;
case 398:
	switch( (*p) ) {
		case 4u: goto st275;
		case 12u: goto st275;
		case 20u: goto st275;
		case 28u: goto st275;
		case 36u: goto st275;
		case 44u: goto st275;
		case 52u: goto st275;
		case 60u: goto st275;
		case 68u: goto st8;
		case 76u: goto st8;
		case 84u: goto st8;
		case 92u: goto st8;
		case 100u: goto st8;
		case 108u: goto st8;
		case 116u: goto st8;
		case 124u: goto st8;
		case 132u: goto st9;
		case 140u: goto st9;
		case 148u: goto st9;
		case 156u: goto st9;
		case 164u: goto st9;
		case 172u: goto st9;
		case 180u: goto st9;
		case 188u: goto st9;
	}
	goto tr33;
tr650:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st399;
st399:
	if ( ++p == pe )
		goto _test_eof399;
case 399:
#line 21648 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 18u: goto st398;
		case 81u: goto st274;
		case 194u: goto st267;
		case 198u: goto st267;
	}
	if ( (*p) < 116u ) {
		if ( (*p) < 46u ) {
			if ( (*p) > 21u ) {
				if ( 22u <= (*p) && (*p) <= 23u )
					goto st398;
			} else if ( (*p) >= 20u )
				goto st274;
		} else if ( (*p) > 47u ) {
			if ( (*p) > 89u ) {
				if ( 92u <= (*p) && (*p) <= 109u )
					goto st274;
			} else if ( (*p) >= 84u )
				goto st274;
		} else
			goto st274;
	} else if ( (*p) > 118u ) {
		if ( (*p) < 216u ) {
			if ( (*p) > 125u ) {
				if ( 208u <= (*p) && (*p) <= 213u )
					goto st274;
			} else if ( (*p) >= 124u )
				goto st274;
		} else if ( (*p) > 229u ) {
			if ( (*p) < 241u ) {
				if ( 232u <= (*p) && (*p) <= 239u )
					goto st274;
			} else if ( (*p) > 246u ) {
				if ( 248u <= (*p) && (*p) <= 254u )
					goto st274;
			} else
				goto st274;
		} else
			goto st274;
	} else
		goto st274;
	goto tr33;
tr651:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st400;
st400:
	if ( ++p == pe )
		goto _test_eof400;
case 400:
#line 21701 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 42u: goto st274;
		case 81u: goto st274;
		case 83u: goto st274;
		case 194u: goto st267;
	}
	if ( (*p) > 90u ) {
		if ( 92u <= (*p) && (*p) <= 95u )
			goto st274;
	} else if ( (*p) >= 88u )
		goto st274;
	goto tr33;
tr652:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st401;
st401:
	if ( ++p == pe )
		goto _test_eof401;
case 401:
#line 21724 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 42u: goto st274;
		case 81u: goto st274;
		case 194u: goto st267;
		case 208u: goto st274;
	}
	if ( (*p) < 92u ) {
		if ( 88u <= (*p) && (*p) <= 90u )
			goto st274;
	} else if ( (*p) > 95u ) {
		if ( 124u <= (*p) && (*p) <= 125u )
			goto st274;
	} else
		goto st274;
	goto tr33;
tr653:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st402;
st402:
	if ( ++p == pe )
		goto _test_eof402;
case 402:
#line 21750 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 81u: goto st274;
		case 194u: goto st267;
		case 198u: goto st267;
	}
	if ( (*p) < 84u ) {
		if ( 20u <= (*p) && (*p) <= 21u )
			goto st274;
	} else if ( (*p) > 89u ) {
		if ( 92u <= (*p) && (*p) <= 95u )
			goto st274;
	} else
		goto st274;
	goto tr33;
tr654:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st403;
st403:
	if ( ++p == pe )
		goto _test_eof403;
case 403:
#line 21775 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 81u: goto st274;
		case 194u: goto st267;
		case 198u: goto st267;
		case 208u: goto st274;
	}
	if ( (*p) < 84u ) {
		if ( 20u <= (*p) && (*p) <= 21u )
			goto st274;
	} else if ( (*p) > 89u ) {
		if ( (*p) > 95u ) {
			if ( 124u <= (*p) && (*p) <= 125u )
				goto st274;
		} else if ( (*p) >= 92u )
			goto st274;
	} else
		goto st274;
	goto tr33;
tr655:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st404;
st404:
	if ( ++p == pe )
		goto _test_eof404;
case 404:
#line 21804 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	if ( (*p) == 208u )
		goto st274;
	if ( 124u <= (*p) && (*p) <= 125u )
		goto st274;
	goto tr33;
tr656:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st405;
st405:
	if ( ++p == pe )
		goto _test_eof405;
case 405:
#line 21820 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 43u: goto st398;
		case 194u: goto st267;
		case 198u: goto st267;
	}
	if ( (*p) < 22u ) {
		if ( (*p) < 18u ) {
			if ( 16u <= (*p) && (*p) <= 17u )
				goto st274;
		} else if ( (*p) > 19u ) {
			if ( 20u <= (*p) && (*p) <= 21u )
				goto st274;
		} else
			goto st398;
	} else if ( (*p) > 23u ) {
		if ( (*p) < 46u ) {
			if ( 40u <= (*p) && (*p) <= 41u )
				goto st274;
		} else if ( (*p) > 47u ) {
			if ( 81u <= (*p) && (*p) <= 95u )
				goto st274;
		} else
			goto st274;
	} else
		goto st398;
	goto tr33;
tr657:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st406;
st406:
	if ( ++p == pe )
		goto _test_eof406;
case 406:
#line 21857 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 43u: goto st398;
		case 81u: goto st274;
		case 112u: goto st267;
		case 127u: goto st274;
		case 194u: goto st267;
		case 196u: goto st407;
		case 198u: goto st267;
		case 231u: goto st398;
	}
	if ( (*p) < 84u ) {
		if ( (*p) < 20u ) {
			if ( (*p) > 17u ) {
				if ( 18u <= (*p) && (*p) <= 19u )
					goto st398;
			} else if ( (*p) >= 16u )
				goto st274;
		} else if ( (*p) > 21u ) {
			if ( (*p) < 40u ) {
				if ( 22u <= (*p) && (*p) <= 23u )
					goto st398;
			} else if ( (*p) > 41u ) {
				if ( 46u <= (*p) && (*p) <= 47u )
					goto st274;
			} else
				goto st274;
		} else
			goto st274;
	} else if ( (*p) > 111u ) {
		if ( (*p) < 208u ) {
			if ( (*p) > 118u ) {
				if ( 124u <= (*p) && (*p) <= 125u )
					goto st274;
			} else if ( (*p) >= 116u )
				goto st274;
		} else if ( (*p) > 213u ) {
			if ( (*p) < 241u ) {
				if ( 216u <= (*p) && (*p) <= 239u )
					goto st274;
			} else if ( (*p) > 246u ) {
				if ( 248u <= (*p) && (*p) <= 254u )
					goto st274;
			} else
				goto st274;
		} else
			goto st274;
	} else
		goto st274;
	goto tr33;
st407:
	if ( ++p == pe )
		goto _test_eof407;
case 407:
	switch( (*p) ) {
		case 4u: goto st268;
		case 12u: goto st268;
		case 20u: goto st268;
		case 28u: goto st268;
		case 36u: goto st268;
		case 44u: goto st268;
		case 52u: goto st268;
		case 60u: goto st268;
		case 68u: goto st50;
		case 76u: goto st50;
		case 84u: goto st50;
		case 92u: goto st50;
		case 100u: goto st50;
		case 108u: goto st50;
		case 116u: goto st50;
		case 124u: goto st50;
		case 132u: goto st51;
		case 140u: goto st51;
		case 148u: goto st51;
		case 156u: goto st51;
		case 164u: goto st51;
		case 172u: goto st51;
		case 180u: goto st51;
		case 188u: goto st51;
	}
	goto tr33;
tr658:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st408;
st408:
	if ( ++p == pe )
		goto _test_eof408;
case 408:
#line 21948 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 18u: goto st274;
		case 22u: goto st274;
		case 42u: goto st274;
		case 111u: goto st274;
		case 112u: goto st267;
		case 126u: goto st398;
		case 127u: goto st274;
		case 194u: goto st267;
		case 230u: goto st274;
	}
	if ( (*p) < 44u ) {
		if ( 16u <= (*p) && (*p) <= 17u )
			goto st398;
	} else if ( (*p) > 45u ) {
		if ( (*p) > 83u ) {
			if ( 88u <= (*p) && (*p) <= 95u )
				goto st274;
		} else if ( (*p) >= 81u )
			goto st274;
	} else
		goto tr670;
	goto tr33;
tr670:
#line 295 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(0, OperandSize32bit);
  }
	goto st409;
tr673:
#line 298 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(0, OperandSize64bit);
  }
	goto st409;
st409:
	if ( ++p == pe )
		goto _test_eof409;
case 409:
#line 21988 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 4u: goto tr671;
		case 12u: goto tr671;
		case 20u: goto tr671;
		case 28u: goto tr671;
		case 36u: goto tr671;
		case 44u: goto tr671;
		case 52u: goto tr671;
		case 60u: goto tr671;
		case 68u: goto tr21;
		case 76u: goto tr21;
		case 84u: goto tr21;
		case 92u: goto tr21;
		case 100u: goto tr21;
		case 108u: goto tr21;
		case 116u: goto tr21;
		case 124u: goto tr21;
		case 132u: goto tr23;
		case 140u: goto tr23;
		case 148u: goto tr23;
		case 156u: goto tr23;
		case 164u: goto tr23;
		case 172u: goto tr23;
		case 180u: goto tr23;
		case 188u: goto tr23;
	}
	if ( 192u <= (*p) )
		goto tr24;
	goto tr33;
tr659:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st410;
st410:
	if ( ++p == pe )
		goto _test_eof410;
case 410:
#line 22028 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 18u: goto st274;
		case 42u: goto st274;
		case 81u: goto st274;
		case 112u: goto st267;
		case 194u: goto st267;
		case 208u: goto st274;
		case 230u: goto st274;
		case 240u: goto st398;
	}
	if ( (*p) < 88u ) {
		if ( (*p) > 17u ) {
			if ( 44u <= (*p) && (*p) <= 45u )
				goto tr670;
		} else if ( (*p) >= 16u )
			goto st398;
	} else if ( (*p) > 90u ) {
		if ( (*p) > 95u ) {
			if ( 124u <= (*p) && (*p) <= 125u )
				goto st274;
		} else if ( (*p) >= 92u )
			goto st274;
	} else
		goto st274;
	goto tr33;
tr660:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st411;
st411:
	if ( ++p == pe )
		goto _test_eof411;
case 411:
#line 22064 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 43u: goto st398;
		case 194u: goto st267;
		case 198u: goto st267;
	}
	if ( (*p) < 20u ) {
		if ( 16u <= (*p) && (*p) <= 17u )
			goto st274;
	} else if ( (*p) > 21u ) {
		if ( (*p) > 41u ) {
			if ( 81u <= (*p) && (*p) <= 95u )
				goto st274;
		} else if ( (*p) >= 40u )
			goto st274;
	} else
		goto st274;
	goto tr33;
tr661:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st412;
st412:
	if ( ++p == pe )
		goto _test_eof412;
case 412:
#line 22092 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 43u: goto st398;
		case 81u: goto st274;
		case 126u: goto tr672;
		case 194u: goto st267;
		case 198u: goto st267;
		case 208u: goto st274;
		case 214u: goto st274;
		case 230u: goto st274;
		case 231u: goto st398;
	}
	if ( (*p) < 40u ) {
		if ( (*p) > 17u ) {
			if ( 20u <= (*p) && (*p) <= 21u )
				goto st274;
		} else if ( (*p) >= 16u )
			goto st274;
	} else if ( (*p) > 41u ) {
		if ( (*p) > 95u ) {
			if ( 124u <= (*p) && (*p) <= 127u )
				goto st274;
		} else if ( (*p) >= 84u )
			goto st274;
	} else
		goto st274;
	goto tr33;
tr672:
#line 295 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(0, OperandSize32bit);
  }
	goto st413;
tr674:
#line 298 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(0, OperandSize64bit);
  }
	goto st413;
st413:
	if ( ++p == pe )
		goto _test_eof413;
case 413:
#line 22135 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 4u: goto st275;
		case 12u: goto st275;
		case 20u: goto st275;
		case 28u: goto st275;
		case 36u: goto st275;
		case 44u: goto st275;
		case 52u: goto st275;
		case 60u: goto st275;
		case 68u: goto st8;
		case 76u: goto st8;
		case 84u: goto st8;
		case 92u: goto st8;
		case 100u: goto st8;
		case 108u: goto st8;
		case 116u: goto st8;
		case 124u: goto st8;
		case 132u: goto st9;
		case 140u: goto st9;
		case 148u: goto st9;
		case 156u: goto st9;
		case 164u: goto st9;
		case 172u: goto st9;
		case 180u: goto st9;
		case 188u: goto st9;
	}
	if ( 192u <= (*p) )
		goto tr7;
	goto tr33;
tr662:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st414;
st414:
	if ( ++p == pe )
		goto _test_eof414;
case 414:
#line 22175 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 18u: goto st274;
		case 22u: goto st274;
		case 91u: goto st274;
		case 127u: goto st274;
		case 230u: goto st274;
	}
	goto tr33;
tr663:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st415;
st415:
	if ( ++p == pe )
		goto _test_eof415;
case 415:
#line 22194 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 18u: goto st274;
		case 208u: goto st274;
		case 230u: goto st274;
		case 240u: goto st398;
	}
	if ( 124u <= (*p) && (*p) <= 125u )
		goto st274;
	goto tr33;
tr664:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st416;
st416:
	if ( ++p == pe )
		goto _test_eof416;
case 416:
#line 22214 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	if ( (*p) == 42u )
		goto st274;
	goto tr33;
tr665:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st417;
st417:
	if ( ++p == pe )
		goto _test_eof417;
case 417:
#line 22228 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	if ( (*p) == 110u )
		goto st274;
	goto tr33;
tr666:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st418;
st418:
	if ( ++p == pe )
		goto _test_eof418;
case 418:
#line 22242 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	if ( (*p) == 42u )
		goto st274;
	if ( 44u <= (*p) && (*p) <= 45u )
		goto tr673;
	goto tr33;
tr667:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st419;
st419:
	if ( ++p == pe )
		goto _test_eof419;
case 419:
#line 22258 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	if ( (*p) == 126u )
		goto tr674;
	goto tr33;
tr630:
#line 235 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX2(*p);
  }
	goto st420;
st420:
	if ( ++p == pe )
		goto _test_eof420;
case 420:
#line 22272 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 0u: goto tr675;
		case 1u: goto tr676;
		case 5u: goto tr677;
		case 8u: goto tr675;
		case 9u: goto tr676;
		case 13u: goto tr677;
		case 16u: goto tr675;
		case 17u: goto tr676;
		case 21u: goto tr677;
		case 24u: goto tr675;
		case 25u: goto tr676;
		case 29u: goto tr677;
		case 32u: goto tr675;
		case 33u: goto tr676;
		case 37u: goto tr677;
		case 40u: goto tr675;
		case 41u: goto tr676;
		case 45u: goto tr677;
		case 48u: goto tr675;
		case 49u: goto tr676;
		case 53u: goto tr677;
		case 56u: goto tr675;
		case 57u: goto tr676;
		case 61u: goto tr677;
		case 64u: goto tr675;
		case 65u: goto tr676;
		case 69u: goto tr677;
		case 72u: goto tr675;
		case 73u: goto tr676;
		case 77u: goto tr677;
		case 80u: goto tr675;
		case 81u: goto tr676;
		case 85u: goto tr677;
		case 88u: goto tr675;
		case 89u: goto tr676;
		case 93u: goto tr677;
		case 96u: goto tr675;
		case 97u: goto tr676;
		case 101u: goto tr677;
		case 104u: goto tr675;
		case 105u: goto tr676;
		case 109u: goto tr677;
		case 112u: goto tr675;
		case 113u: goto tr676;
		case 117u: goto tr677;
		case 120u: goto tr675;
		case 121u: goto tr678;
		case 125u: goto tr679;
		case 128u: goto tr680;
		case 129u: goto tr681;
		case 133u: goto tr682;
		case 136u: goto tr680;
		case 137u: goto tr681;
		case 141u: goto tr682;
		case 144u: goto tr680;
		case 145u: goto tr681;
		case 149u: goto tr682;
		case 152u: goto tr680;
		case 153u: goto tr681;
		case 157u: goto tr682;
		case 160u: goto tr680;
		case 161u: goto tr681;
		case 165u: goto tr682;
		case 168u: goto tr680;
		case 169u: goto tr681;
		case 173u: goto tr682;
		case 176u: goto tr680;
		case 177u: goto tr681;
		case 181u: goto tr682;
		case 184u: goto tr680;
		case 185u: goto tr681;
		case 189u: goto tr682;
		case 192u: goto tr680;
		case 193u: goto tr681;
		case 197u: goto tr682;
		case 200u: goto tr680;
		case 201u: goto tr681;
		case 205u: goto tr682;
		case 208u: goto tr680;
		case 209u: goto tr681;
		case 213u: goto tr682;
		case 216u: goto tr680;
		case 217u: goto tr681;
		case 221u: goto tr682;
		case 224u: goto tr680;
		case 225u: goto tr681;
		case 229u: goto tr682;
		case 232u: goto tr680;
		case 233u: goto tr681;
		case 237u: goto tr682;
		case 240u: goto tr680;
		case 241u: goto tr681;
		case 245u: goto tr682;
		case 248u: goto tr680;
		case 249u: goto tr681;
		case 253u: goto tr682;
	}
	goto tr33;
tr675:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st421;
st421:
	if ( ++p == pe )
		goto _test_eof421;
case 421:
#line 22382 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 242u: goto tr670;
		case 247u: goto tr670;
	}
	goto tr33;
tr676:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st422;
st422:
	if ( ++p == pe )
		goto _test_eof422;
case 422:
#line 22398 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	if ( (*p) == 43u )
		goto st274;
	if ( (*p) < 55u ) {
		if ( (*p) < 40u ) {
			if ( (*p) <= 13u )
				goto st274;
		} else if ( (*p) > 41u ) {
			if ( 44u <= (*p) && (*p) <= 47u )
				goto st398;
		} else
			goto st274;
	} else if ( (*p) > 64u ) {
		if ( (*p) < 166u ) {
			if ( 150u <= (*p) && (*p) <= 159u )
				goto st274;
		} else if ( (*p) > 175u ) {
			if ( (*p) > 191u ) {
				if ( 219u <= (*p) && (*p) <= 223u )
					goto st274;
			} else if ( (*p) >= 182u )
				goto st274;
		} else
			goto st274;
	} else
		goto st274;
	goto tr33;
tr677:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st423;
st423:
	if ( ++p == pe )
		goto _test_eof423;
case 423:
#line 22435 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 154u: goto st274;
		case 156u: goto st274;
		case 158u: goto st274;
		case 170u: goto st274;
		case 172u: goto st274;
		case 174u: goto st274;
		case 186u: goto st274;
		case 188u: goto st274;
		case 190u: goto st274;
	}
	if ( (*p) < 150u ) {
		if ( (*p) > 13u ) {
			if ( 44u <= (*p) && (*p) <= 47u )
				goto st398;
		} else if ( (*p) >= 12u )
			goto st274;
	} else if ( (*p) > 152u ) {
		if ( (*p) > 168u ) {
			if ( 182u <= (*p) && (*p) <= 184u )
				goto st274;
		} else if ( (*p) >= 166u )
			goto st274;
	} else
		goto st274;
	goto tr33;
tr678:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st424;
st424:
	if ( ++p == pe )
		goto _test_eof424;
case 424:
#line 22472 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 19u: goto st274;
		case 23u: goto st274;
		case 24u: goto st398;
		case 42u: goto st398;
	}
	if ( (*p) < 48u ) {
		if ( (*p) < 32u ) {
			if ( (*p) > 15u ) {
				if ( 28u <= (*p) && (*p) <= 30u )
					goto st274;
			} else
				goto st274;
		} else if ( (*p) > 37u ) {
			if ( (*p) > 43u ) {
				if ( 44u <= (*p) && (*p) <= 47u )
					goto st398;
			} else if ( (*p) >= 40u )
				goto st274;
		} else
			goto st274;
	} else if ( (*p) > 53u ) {
		if ( (*p) < 166u ) {
			if ( (*p) > 65u ) {
				if ( 150u <= (*p) && (*p) <= 159u )
					goto st274;
			} else if ( (*p) >= 55u )
				goto st274;
		} else if ( (*p) > 175u ) {
			if ( (*p) > 191u ) {
				if ( 219u <= (*p) && (*p) <= 223u )
					goto st274;
			} else if ( (*p) >= 182u )
				goto st274;
		} else
			goto st274;
	} else
		goto st274;
	goto tr33;
tr679:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st425;
st425:
	if ( ++p == pe )
		goto _test_eof425;
case 425:
#line 22522 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 19u: goto st274;
		case 23u: goto st274;
		case 154u: goto st274;
		case 156u: goto st274;
		case 158u: goto st274;
		case 170u: goto st274;
		case 172u: goto st274;
		case 174u: goto st274;
		case 186u: goto st274;
		case 188u: goto st274;
		case 190u: goto st274;
	}
	if ( (*p) < 44u ) {
		if ( (*p) > 15u ) {
			if ( 24u <= (*p) && (*p) <= 26u )
				goto st398;
		} else if ( (*p) >= 12u )
			goto st274;
	} else if ( (*p) > 47u ) {
		if ( (*p) < 166u ) {
			if ( 150u <= (*p) && (*p) <= 152u )
				goto st274;
		} else if ( (*p) > 168u ) {
			if ( 182u <= (*p) && (*p) <= 184u )
				goto st274;
		} else
			goto st274;
	} else
		goto st398;
	goto tr33;
tr680:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st426;
st426:
	if ( ++p == pe )
		goto _test_eof426;
case 426:
#line 22564 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 242u: goto tr673;
		case 247u: goto tr673;
	}
	goto tr33;
tr681:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st427;
st427:
	if ( ++p == pe )
		goto _test_eof427;
case 427:
#line 22580 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	if ( (*p) < 166u ) {
		if ( 150u <= (*p) && (*p) <= 159u )
			goto st274;
	} else if ( (*p) > 175u ) {
		if ( 182u <= (*p) && (*p) <= 191u )
			goto st274;
	} else
		goto st274;
	goto tr33;
tr682:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st428;
st428:
	if ( ++p == pe )
		goto _test_eof428;
case 428:
#line 22600 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 154u: goto st274;
		case 156u: goto st274;
		case 158u: goto st274;
		case 170u: goto st274;
		case 172u: goto st274;
		case 174u: goto st274;
		case 186u: goto st274;
		case 188u: goto st274;
		case 190u: goto st274;
	}
	if ( (*p) < 166u ) {
		if ( 150u <= (*p) && (*p) <= 152u )
			goto st274;
	} else if ( (*p) > 168u ) {
		if ( 182u <= (*p) && (*p) <= 184u )
			goto st274;
	} else
		goto st274;
	goto tr33;
tr631:
#line 235 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX2(*p);
  }
	goto st429;
st429:
	if ( ++p == pe )
		goto _test_eof429;
case 429:
#line 22631 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 1u: goto tr683;
		case 5u: goto tr684;
		case 9u: goto tr683;
		case 13u: goto tr684;
		case 17u: goto tr683;
		case 21u: goto tr684;
		case 25u: goto tr683;
		case 29u: goto tr684;
		case 33u: goto tr683;
		case 37u: goto tr684;
		case 41u: goto tr683;
		case 45u: goto tr684;
		case 49u: goto tr683;
		case 53u: goto tr684;
		case 57u: goto tr683;
		case 61u: goto tr684;
		case 65u: goto tr683;
		case 69u: goto tr684;
		case 73u: goto tr683;
		case 77u: goto tr684;
		case 81u: goto tr683;
		case 85u: goto tr684;
		case 89u: goto tr683;
		case 93u: goto tr684;
		case 97u: goto tr683;
		case 101u: goto tr684;
		case 105u: goto tr683;
		case 109u: goto tr684;
		case 113u: goto tr683;
		case 117u: goto tr684;
		case 121u: goto tr685;
		case 125u: goto tr686;
		case 129u: goto tr687;
		case 133u: goto tr688;
		case 137u: goto tr687;
		case 141u: goto tr688;
		case 145u: goto tr687;
		case 149u: goto tr688;
		case 153u: goto tr687;
		case 157u: goto tr688;
		case 161u: goto tr687;
		case 165u: goto tr688;
		case 169u: goto tr687;
		case 173u: goto tr688;
		case 177u: goto tr687;
		case 181u: goto tr688;
		case 185u: goto tr687;
		case 189u: goto tr688;
		case 193u: goto tr687;
		case 197u: goto tr688;
		case 201u: goto tr687;
		case 205u: goto tr688;
		case 209u: goto tr687;
		case 213u: goto tr688;
		case 217u: goto tr687;
		case 221u: goto tr688;
		case 225u: goto tr687;
		case 229u: goto tr688;
		case 233u: goto tr687;
		case 237u: goto tr688;
		case 241u: goto tr687;
		case 245u: goto tr688;
		case 249u: goto tr689;
		case 253u: goto tr688;
	}
	goto tr33;
tr683:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st430;
st430:
	if ( ++p == pe )
		goto _test_eof430;
case 430:
#line 22709 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 33u: goto st407;
		case 68u: goto st267;
		case 223u: goto st267;
	}
	if ( (*p) < 74u ) {
		if ( (*p) < 64u ) {
			if ( 8u <= (*p) && (*p) <= 15u )
				goto st267;
		} else if ( (*p) > 66u ) {
			if ( 72u <= (*p) && (*p) <= 73u )
				goto st431;
		} else
			goto st267;
	} else if ( (*p) > 76u ) {
		if ( (*p) < 104u ) {
			if ( 92u <= (*p) && (*p) <= 95u )
				goto st257;
		} else if ( (*p) > 111u ) {
			if ( 120u <= (*p) && (*p) <= 127u )
				goto st257;
		} else
			goto st257;
	} else
		goto st257;
	goto tr33;
st431:
	if ( ++p == pe )
		goto _test_eof431;
case 431:
	switch( (*p) ) {
		case 4u: goto st432;
		case 12u: goto st432;
		case 20u: goto st432;
		case 28u: goto st432;
		case 36u: goto st432;
		case 44u: goto st432;
		case 52u: goto st432;
		case 60u: goto st432;
		case 68u: goto st434;
		case 76u: goto st434;
		case 84u: goto st434;
		case 92u: goto st434;
		case 100u: goto st434;
		case 108u: goto st434;
		case 116u: goto st434;
		case 124u: goto st434;
		case 132u: goto st436;
		case 140u: goto st436;
		case 148u: goto st436;
		case 156u: goto st436;
		case 164u: goto st436;
		case 172u: goto st436;
		case 180u: goto st436;
		case 188u: goto st436;
	}
	if ( 192u <= (*p) )
		goto st433;
	goto tr33;
st432:
	if ( ++p == pe )
		goto _test_eof432;
case 432:
	switch( (*p) ) {
		case 5u: goto tr33;
		case 13u: goto tr33;
		case 21u: goto tr33;
		case 29u: goto tr33;
		case 37u: goto tr33;
		case 45u: goto tr33;
		case 53u: goto tr33;
		case 61u: goto tr33;
		case 69u: goto tr33;
		case 77u: goto tr33;
		case 85u: goto tr33;
		case 93u: goto tr33;
		case 101u: goto tr33;
		case 109u: goto tr33;
		case 117u: goto tr33;
		case 125u: goto tr33;
		case 133u: goto tr33;
		case 141u: goto tr33;
		case 149u: goto tr33;
		case 157u: goto tr33;
		case 165u: goto tr33;
		case 173u: goto tr33;
		case 181u: goto tr33;
		case 189u: goto tr33;
		case 197u: goto tr33;
		case 205u: goto tr33;
		case 213u: goto tr33;
		case 221u: goto tr33;
		case 229u: goto tr33;
		case 237u: goto tr33;
		case 245u: goto tr33;
		case 253u: goto tr33;
	}
	goto tr695;
tr792:
#line 90 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_DISP_TYPE(DISPNONE);
    SET_MODRM_BASE(((*p) & 0x07) |
                   ((GET_REX_PREFIX() & 0x01) << 3) |
                   (((~GET_VEX_PREFIX2()) & 0x20) >> 2));
    SET_MODRM_INDEX(NO_REG);
    SET_MODRM_SCALE(0);
  }
#line 44 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    if ((base == REG_RIP) || (base == REG_R15) ||
        ((base == REG_RSP) && (restricted_register != REG_RSP)) ||
        ((base == REG_RBP) && (restricted_register != REG_RBP))) {
      if ((index == restricted_register) ||
          ((index == REG_RDI) &&
           (restricted_register == kSandboxedRsiRestrictedRdi))) {
        BitmapClearBit(valid_targets, begin - data);
      } else if ((index != NO_REG) && (index != REG_RIZ)) {
        PrintError("Improper sandboxing in instruction\n", begin - data);
        result = 1;
        goto error_detected;
      }
    } else if ((index == REG_RIP) || (index == REG_R15) ||
               ((index == REG_RSP) && (restricted_register != REG_RSP)) ||
               ((index == REG_RBP) && (restricted_register != REG_RBP))) {
      if ((base == restricted_register) ||
          ((base == REG_RDI) &&
           (restricted_register == kSandboxedRsiRestrictedRdi))) {
        BitmapClearBit(valid_targets, begin - data);
      } else if ((base != NO_REG) && (base != REG_RIZ)) {
        PrintError("Improper sandboxing in instruction\n", begin - data);
        result = 1;
        goto error_detected;
      }
    } else {
      PrintError("Improper sandboxing in instruction\n", begin - data);
      result = 1;
      goto error_detected;
    }
  }
	goto st433;
tr695:
#line 118 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_DISP_TYPE(DISPNONE);
    SET_MODRM_BASE(((*p) & 0x7) |
                   ((GET_REX_PREFIX() & 0x01) << 3) |
                   (((~GET_VEX_PREFIX2()) & 0x20) >> 2));
    SET_MODRM_INDEX(index_registers[(((*p) & 0x38) >> 3) |
                                    ((GET_REX_PREFIX() & 0x02) << 2) |
                                    (((~GET_VEX_PREFIX2()) & 0x40) >> 3)]);
    SET_MODRM_SCALE(((*p) & 0xc0) >> 6);
  }
#line 44 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    if ((base == REG_RIP) || (base == REG_R15) ||
        ((base == REG_RSP) && (restricted_register != REG_RSP)) ||
        ((base == REG_RBP) && (restricted_register != REG_RBP))) {
      if ((index == restricted_register) ||
          ((index == REG_RDI) &&
           (restricted_register == kSandboxedRsiRestrictedRdi))) {
        BitmapClearBit(valid_targets, begin - data);
      } else if ((index != NO_REG) && (index != REG_RIZ)) {
        PrintError("Improper sandboxing in instruction\n", begin - data);
        result = 1;
        goto error_detected;
      }
    } else if ((index == REG_RIP) || (index == REG_R15) ||
               ((index == REG_RSP) && (restricted_register != REG_RSP)) ||
               ((index == REG_RBP) && (restricted_register != REG_RBP))) {
      if ((base == restricted_register) ||
          ((base == REG_RDI) &&
           (restricted_register == kSandboxedRsiRestrictedRdi))) {
        BitmapClearBit(valid_targets, begin - data);
      } else if ((base != NO_REG) && (base != REG_RIZ)) {
        PrintError("Improper sandboxing in instruction\n", begin - data);
        result = 1;
        goto error_detected;
      }
    } else {
      PrintError("Improper sandboxing in instruction\n", begin - data);
      result = 1;
      goto error_detected;
    }
  }
	goto st433;
tr703:
#line 46 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_DISP_TYPE(DISP32);
    SET_DISP_PTR(p - 3);
  }
#line 44 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    if ((base == REG_RIP) || (base == REG_R15) ||
        ((base == REG_RSP) && (restricted_register != REG_RSP)) ||
        ((base == REG_RBP) && (restricted_register != REG_RBP))) {
      if ((index == restricted_register) ||
          ((index == REG_RDI) &&
           (restricted_register == kSandboxedRsiRestrictedRdi))) {
        BitmapClearBit(valid_targets, begin - data);
      } else if ((index != NO_REG) && (index != REG_RIZ)) {
        PrintError("Improper sandboxing in instruction\n", begin - data);
        result = 1;
        goto error_detected;
      }
    } else if ((index == REG_RIP) || (index == REG_R15) ||
               ((index == REG_RSP) && (restricted_register != REG_RSP)) ||
               ((index == REG_RBP) && (restricted_register != REG_RBP))) {
      if ((base == restricted_register) ||
          ((base == REG_RDI) &&
           (restricted_register == kSandboxedRsiRestrictedRdi))) {
        BitmapClearBit(valid_targets, begin - data);
      } else if ((base != NO_REG) && (base != REG_RIZ)) {
        PrintError("Improper sandboxing in instruction\n", begin - data);
        result = 1;
        goto error_detected;
      }
    } else {
      PrintError("Improper sandboxing in instruction\n", begin - data);
      result = 1;
      goto error_detected;
    }
  }
	goto st433;
tr698:
#line 42 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_DISP_TYPE(DISP8);
    SET_DISP_PTR(p);
  }
#line 44 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    if ((base == REG_RIP) || (base == REG_R15) ||
        ((base == REG_RSP) && (restricted_register != REG_RSP)) ||
        ((base == REG_RBP) && (restricted_register != REG_RBP))) {
      if ((index == restricted_register) ||
          ((index == REG_RDI) &&
           (restricted_register == kSandboxedRsiRestrictedRdi))) {
        BitmapClearBit(valid_targets, begin - data);
      } else if ((index != NO_REG) && (index != REG_RIZ)) {
        PrintError("Improper sandboxing in instruction\n", begin - data);
        result = 1;
        goto error_detected;
      }
    } else if ((index == REG_RIP) || (index == REG_R15) ||
               ((index == REG_RSP) && (restricted_register != REG_RSP)) ||
               ((index == REG_RBP) && (restricted_register != REG_RBP))) {
      if ((base == restricted_register) ||
          ((base == REG_RDI) &&
           (restricted_register == kSandboxedRsiRestrictedRdi))) {
        BitmapClearBit(valid_targets, begin - data);
      } else if ((base != NO_REG) && (base != REG_RIZ)) {
        PrintError("Improper sandboxing in instruction\n", begin - data);
        result = 1;
        goto error_detected;
      }
    } else {
      PrintError("Improper sandboxing in instruction\n", begin - data);
      result = 1;
      goto error_detected;
    }
  }
	goto st433;
st433:
	if ( ++p == pe )
		goto _test_eof433;
case 433:
#line 22978 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	if ( (*p) < 112u ) {
		if ( (*p) < 48u ) {
			if ( (*p) < 16u ) {
				if ( (*p) <= 3u )
					goto tr696;
			} else if ( (*p) > 19u ) {
				if ( 32u <= (*p) && (*p) <= 35u )
					goto tr696;
			} else
				goto tr696;
		} else if ( (*p) > 51u ) {
			if ( (*p) < 80u ) {
				if ( 64u <= (*p) && (*p) <= 67u )
					goto tr696;
			} else if ( (*p) > 83u ) {
				if ( 96u <= (*p) && (*p) <= 99u )
					goto tr696;
			} else
				goto tr696;
		} else
			goto tr696;
	} else if ( (*p) > 115u ) {
		if ( (*p) < 176u ) {
			if ( (*p) < 144u ) {
				if ( 128u <= (*p) && (*p) <= 131u )
					goto tr696;
			} else if ( (*p) > 147u ) {
				if ( 160u <= (*p) && (*p) <= 163u )
					goto tr696;
			} else
				goto tr696;
		} else if ( (*p) > 179u ) {
			if ( (*p) < 208u ) {
				if ( 192u <= (*p) && (*p) <= 195u )
					goto tr696;
			} else if ( (*p) > 211u ) {
				if ( (*p) > 227u ) {
					if ( 240u <= (*p) && (*p) <= 243u )
						goto tr696;
				} else if ( (*p) >= 224u )
					goto tr696;
			} else
				goto tr696;
		} else
			goto tr696;
	} else
		goto tr696;
	goto tr33;
st434:
	if ( ++p == pe )
		goto _test_eof434;
case 434:
	goto tr697;
tr793:
#line 98 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_MODRM_BASE(((*p) & 0x07) |
                   ((GET_REX_PREFIX() & 0x01) << 3) |
                   (((~GET_VEX_PREFIX2()) & 0x20) >> 2));
    SET_MODRM_INDEX(NO_REG);
    SET_MODRM_SCALE(0);
  }
	goto st435;
tr697:
#line 118 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_DISP_TYPE(DISPNONE);
    SET_MODRM_BASE(((*p) & 0x7) |
                   ((GET_REX_PREFIX() & 0x01) << 3) |
                   (((~GET_VEX_PREFIX2()) & 0x20) >> 2));
    SET_MODRM_INDEX(index_registers[(((*p) & 0x38) >> 3) |
                                    ((GET_REX_PREFIX() & 0x02) << 2) |
                                    (((~GET_VEX_PREFIX2()) & 0x40) >> 3)]);
    SET_MODRM_SCALE(((*p) & 0xc0) >> 6);
  }
	goto st435;
st435:
	if ( ++p == pe )
		goto _test_eof435;
case 435:
#line 23059 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	goto tr698;
st436:
	if ( ++p == pe )
		goto _test_eof436;
case 436:
	goto tr699;
tr834:
#line 105 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_MODRM_BASE(REG_RIP);
    SET_MODRM_INDEX(NO_REG);
    SET_MODRM_SCALE(0);
  }
	goto st437;
tr794:
#line 98 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_MODRM_BASE(((*p) & 0x07) |
                   ((GET_REX_PREFIX() & 0x01) << 3) |
                   (((~GET_VEX_PREFIX2()) & 0x20) >> 2));
    SET_MODRM_INDEX(NO_REG);
    SET_MODRM_SCALE(0);
  }
	goto st437;
tr748:
#line 110 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_DISP_TYPE(DISPNONE);
    SET_MODRM_BASE(NO_REG);
    SET_MODRM_INDEX(index_registers[(((*p) & 0x38) >> 3) |
                                    ((GET_REX_PREFIX() & 0x02) << 2) |
                                    (((~GET_VEX_PREFIX2()) & 0x40) >> 3)]);
    SET_MODRM_SCALE(((*p) & 0xc0) >> 6);
  }
	goto st437;
tr699:
#line 118 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_DISP_TYPE(DISPNONE);
    SET_MODRM_BASE(((*p) & 0x7) |
                   ((GET_REX_PREFIX() & 0x01) << 3) |
                   (((~GET_VEX_PREFIX2()) & 0x20) >> 2));
    SET_MODRM_INDEX(index_registers[(((*p) & 0x38) >> 3) |
                                    ((GET_REX_PREFIX() & 0x02) << 2) |
                                    (((~GET_VEX_PREFIX2()) & 0x40) >> 3)]);
    SET_MODRM_SCALE(((*p) & 0xc0) >> 6);
  }
	goto st437;
st437:
	if ( ++p == pe )
		goto _test_eof437;
case 437:
#line 23112 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	goto st438;
st438:
	if ( ++p == pe )
		goto _test_eof438;
case 438:
	goto st439;
st439:
	if ( ++p == pe )
		goto _test_eof439;
case 439:
	goto st440;
st440:
	if ( ++p == pe )
		goto _test_eof440;
case 440:
	goto tr703;
tr684:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st441;
st441:
	if ( ++p == pe )
		goto _test_eof441;
case 441:
#line 23139 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 6u: goto st267;
		case 64u: goto st267;
	}
	if ( (*p) < 92u ) {
		if ( (*p) < 12u ) {
			if ( 8u <= (*p) && (*p) <= 9u )
				goto st267;
		} else if ( (*p) > 13u ) {
			if ( (*p) > 73u ) {
				if ( 74u <= (*p) && (*p) <= 75u )
					goto st257;
			} else if ( (*p) >= 72u )
				goto st431;
		} else
			goto st267;
	} else if ( (*p) > 95u ) {
		if ( (*p) < 108u ) {
			if ( 104u <= (*p) && (*p) <= 105u )
				goto st257;
		} else if ( (*p) > 109u ) {
			if ( (*p) > 121u ) {
				if ( 124u <= (*p) && (*p) <= 125u )
					goto st257;
			} else if ( (*p) >= 120u )
				goto st257;
		} else
			goto st257;
	} else
		goto st257;
	goto tr33;
tr685:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st442;
st442:
	if ( ++p == pe )
		goto _test_eof442;
case 442:
#line 23181 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 22u: goto tr704;
		case 29u: goto st267;
		case 34u: goto st267;
		case 68u: goto st267;
		case 223u: goto st267;
	}
	if ( (*p) < 72u ) {
		if ( (*p) < 20u ) {
			if ( (*p) > 5u ) {
				if ( 8u <= (*p) && (*p) <= 15u )
					goto st267;
			} else if ( (*p) >= 4u )
				goto st267;
		} else if ( (*p) > 23u ) {
			if ( (*p) > 33u ) {
				if ( 64u <= (*p) && (*p) <= 66u )
					goto st267;
			} else if ( (*p) >= 32u )
				goto st407;
		} else
			goto st407;
	} else if ( (*p) > 73u ) {
		if ( (*p) < 96u ) {
			if ( (*p) > 76u ) {
				if ( 92u <= (*p) && (*p) <= 95u )
					goto st257;
			} else if ( (*p) >= 74u )
				goto st257;
		} else if ( (*p) > 99u ) {
			if ( (*p) > 111u ) {
				if ( 120u <= (*p) && (*p) <= 127u )
					goto st257;
			} else if ( (*p) >= 104u )
				goto st257;
		} else
			goto st267;
	} else
		goto st431;
	goto tr33;
tr704:
#line 295 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(0, OperandSize32bit);
  }
	goto st443;
tr705:
#line 298 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(0, OperandSize64bit);
  }
	goto st443;
st443:
	if ( ++p == pe )
		goto _test_eof443;
case 443:
#line 23238 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 4u: goto st268;
		case 12u: goto st268;
		case 20u: goto st268;
		case 28u: goto st268;
		case 36u: goto st268;
		case 44u: goto st268;
		case 52u: goto st268;
		case 60u: goto st268;
		case 68u: goto st50;
		case 76u: goto st50;
		case 84u: goto st50;
		case 92u: goto st50;
		case 100u: goto st50;
		case 108u: goto st50;
		case 116u: goto st50;
		case 124u: goto st50;
		case 132u: goto st51;
		case 140u: goto st51;
		case 148u: goto st51;
		case 156u: goto st51;
		case 164u: goto st51;
		case 172u: goto st51;
		case 180u: goto st51;
		case 188u: goto st51;
	}
	if ( 192u <= (*p) )
		goto tr114;
	goto tr33;
tr686:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st444;
st444:
	if ( ++p == pe )
		goto _test_eof444;
case 444:
#line 23278 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 29u: goto st267;
		case 64u: goto st267;
	}
	if ( (*p) < 74u ) {
		if ( (*p) < 12u ) {
			if ( (*p) > 6u ) {
				if ( 8u <= (*p) && (*p) <= 9u )
					goto st267;
			} else if ( (*p) >= 4u )
				goto st267;
		} else if ( (*p) > 13u ) {
			if ( (*p) > 25u ) {
				if ( 72u <= (*p) && (*p) <= 73u )
					goto st431;
			} else if ( (*p) >= 24u )
				goto st267;
		} else
			goto st267;
	} else if ( (*p) > 75u ) {
		if ( (*p) < 108u ) {
			if ( (*p) > 95u ) {
				if ( 104u <= (*p) && (*p) <= 105u )
					goto st257;
			} else if ( (*p) >= 92u )
				goto st257;
		} else if ( (*p) > 109u ) {
			if ( (*p) > 121u ) {
				if ( 124u <= (*p) && (*p) <= 125u )
					goto st257;
			} else if ( (*p) >= 120u )
				goto st257;
		} else
			goto st257;
	} else
		goto st257;
	goto tr33;
tr687:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st445;
st445:
	if ( ++p == pe )
		goto _test_eof445;
case 445:
#line 23326 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	if ( (*p) < 92u ) {
		if ( 72u <= (*p) && (*p) <= 73u )
			goto st431;
	} else if ( (*p) > 95u ) {
		if ( (*p) > 111u ) {
			if ( 120u <= (*p) && (*p) <= 127u )
				goto st257;
		} else if ( (*p) >= 104u )
			goto st257;
	} else
		goto st257;
	goto tr33;
tr688:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st446;
st446:
	if ( ++p == pe )
		goto _test_eof446;
case 446:
#line 23349 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	if ( (*p) < 104u ) {
		if ( (*p) > 73u ) {
			if ( 92u <= (*p) && (*p) <= 95u )
				goto st257;
		} else if ( (*p) >= 72u )
			goto st431;
	} else if ( (*p) > 105u ) {
		if ( (*p) < 120u ) {
			if ( 108u <= (*p) && (*p) <= 109u )
				goto st257;
		} else if ( (*p) > 121u ) {
			if ( 124u <= (*p) && (*p) <= 125u )
				goto st257;
		} else
			goto st257;
	} else
		goto st257;
	goto tr33;
tr689:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st447;
st447:
	if ( ++p == pe )
		goto _test_eof447;
case 447:
#line 23378 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 22u: goto tr705;
		case 34u: goto st267;
	}
	if ( (*p) < 92u ) {
		if ( 72u <= (*p) && (*p) <= 73u )
			goto st431;
	} else if ( (*p) > 95u ) {
		if ( (*p) > 111u ) {
			if ( 120u <= (*p) && (*p) <= 127u )
				goto st257;
		} else if ( (*p) >= 104u )
			goto st257;
	} else
		goto st257;
	goto tr33;
tr632:
#line 235 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX2(*p);
  }
	goto st448;
st448:
	if ( ++p == pe )
		goto _test_eof448;
case 448:
#line 23405 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 0u: goto tr706;
		case 1u: goto tr707;
		case 2u: goto tr708;
		case 3u: goto tr709;
		case 4u: goto tr710;
		case 5u: goto tr711;
		case 7u: goto tr712;
		case 8u: goto tr706;
		case 9u: goto tr707;
		case 10u: goto tr708;
		case 11u: goto tr709;
		case 12u: goto tr710;
		case 13u: goto tr711;
		case 15u: goto tr712;
		case 16u: goto tr706;
		case 17u: goto tr707;
		case 18u: goto tr708;
		case 19u: goto tr709;
		case 20u: goto tr710;
		case 21u: goto tr711;
		case 23u: goto tr712;
		case 24u: goto tr706;
		case 25u: goto tr707;
		case 26u: goto tr708;
		case 27u: goto tr709;
		case 28u: goto tr710;
		case 29u: goto tr711;
		case 31u: goto tr712;
		case 32u: goto tr706;
		case 33u: goto tr707;
		case 34u: goto tr708;
		case 35u: goto tr709;
		case 36u: goto tr710;
		case 37u: goto tr711;
		case 39u: goto tr712;
		case 40u: goto tr706;
		case 41u: goto tr707;
		case 42u: goto tr708;
		case 43u: goto tr709;
		case 44u: goto tr710;
		case 45u: goto tr711;
		case 47u: goto tr712;
		case 48u: goto tr706;
		case 49u: goto tr707;
		case 50u: goto tr708;
		case 51u: goto tr709;
		case 52u: goto tr710;
		case 53u: goto tr711;
		case 55u: goto tr712;
		case 56u: goto tr706;
		case 57u: goto tr707;
		case 58u: goto tr708;
		case 59u: goto tr709;
		case 60u: goto tr710;
		case 61u: goto tr711;
		case 63u: goto tr712;
		case 64u: goto tr706;
		case 65u: goto tr707;
		case 66u: goto tr708;
		case 67u: goto tr709;
		case 68u: goto tr710;
		case 69u: goto tr711;
		case 71u: goto tr712;
		case 72u: goto tr706;
		case 73u: goto tr707;
		case 74u: goto tr708;
		case 75u: goto tr709;
		case 76u: goto tr710;
		case 77u: goto tr711;
		case 79u: goto tr712;
		case 80u: goto tr706;
		case 81u: goto tr707;
		case 82u: goto tr708;
		case 83u: goto tr709;
		case 84u: goto tr710;
		case 85u: goto tr711;
		case 87u: goto tr712;
		case 88u: goto tr706;
		case 89u: goto tr707;
		case 90u: goto tr708;
		case 91u: goto tr709;
		case 92u: goto tr710;
		case 93u: goto tr711;
		case 95u: goto tr712;
		case 96u: goto tr706;
		case 97u: goto tr707;
		case 98u: goto tr708;
		case 99u: goto tr709;
		case 100u: goto tr710;
		case 101u: goto tr711;
		case 103u: goto tr712;
		case 104u: goto tr706;
		case 105u: goto tr707;
		case 106u: goto tr708;
		case 107u: goto tr709;
		case 108u: goto tr710;
		case 109u: goto tr711;
		case 111u: goto tr712;
		case 112u: goto tr706;
		case 113u: goto tr707;
		case 114u: goto tr708;
		case 115u: goto tr709;
		case 116u: goto tr710;
		case 117u: goto tr711;
		case 119u: goto tr712;
		case 120u: goto tr713;
		case 121u: goto tr714;
		case 122u: goto tr715;
		case 123u: goto tr716;
		case 124u: goto tr717;
		case 125u: goto tr718;
		case 126u: goto tr719;
		case 127u: goto tr720;
		case 249u: goto tr722;
		case 253u: goto tr724;
	}
	if ( (*p) < 186u ) {
		if ( (*p) < 154u ) {
			if ( (*p) < 138u ) {
				if ( 130u <= (*p) && (*p) <= 131u )
					goto tr721;
			} else if ( (*p) > 139u ) {
				if ( 146u <= (*p) && (*p) <= 147u )
					goto tr721;
			} else
				goto tr721;
		} else if ( (*p) > 155u ) {
			if ( (*p) < 170u ) {
				if ( 162u <= (*p) && (*p) <= 163u )
					goto tr721;
			} else if ( (*p) > 171u ) {
				if ( 178u <= (*p) && (*p) <= 179u )
					goto tr721;
			} else
				goto tr721;
		} else
			goto tr721;
	} else if ( (*p) > 187u ) {
		if ( (*p) < 218u ) {
			if ( (*p) < 202u ) {
				if ( 194u <= (*p) && (*p) <= 195u )
					goto tr721;
			} else if ( (*p) > 203u ) {
				if ( 210u <= (*p) && (*p) <= 211u )
					goto tr721;
			} else
				goto tr721;
		} else if ( (*p) > 219u ) {
			if ( (*p) < 234u ) {
				if ( 226u <= (*p) && (*p) <= 227u )
					goto tr721;
			} else if ( (*p) > 235u ) {
				if ( (*p) > 243u ) {
					if ( 250u <= (*p) && (*p) <= 251u )
						goto tr723;
				} else if ( (*p) >= 242u )
					goto tr721;
			} else
				goto tr721;
		} else
			goto tr721;
	} else
		goto tr721;
	goto tr33;
tr706:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st449;
st449:
	if ( ++p == pe )
		goto _test_eof449;
case 449:
#line 23581 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 18u: goto st450;
		case 81u: goto st293;
		case 194u: goto st287;
		case 198u: goto st287;
	}
	if ( (*p) < 46u ) {
		if ( (*p) > 21u ) {
			if ( 22u <= (*p) && (*p) <= 23u )
				goto st450;
		} else if ( (*p) >= 20u )
			goto st293;
	} else if ( (*p) > 47u ) {
		if ( (*p) > 89u ) {
			if ( 92u <= (*p) && (*p) <= 95u )
				goto st293;
		} else if ( (*p) >= 84u )
			goto st293;
	} else
		goto st293;
	goto tr33;
st450:
	if ( ++p == pe )
		goto _test_eof450;
case 450:
	switch( (*p) ) {
		case 4u: goto st2;
		case 12u: goto st2;
		case 20u: goto st2;
		case 28u: goto st2;
		case 36u: goto st2;
		case 44u: goto st2;
		case 52u: goto st2;
		case 60u: goto st2;
		case 68u: goto st8;
		case 76u: goto st8;
		case 84u: goto st8;
		case 92u: goto st8;
		case 100u: goto st8;
		case 108u: goto st8;
		case 116u: goto st8;
		case 124u: goto st8;
		case 132u: goto st9;
		case 140u: goto st9;
		case 148u: goto st9;
		case 156u: goto st9;
		case 164u: goto st9;
		case 172u: goto st9;
		case 180u: goto st9;
		case 188u: goto st9;
	}
	goto tr33;
tr707:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st451;
st451:
	if ( ++p == pe )
		goto _test_eof451;
case 451:
#line 23644 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 18u: goto st450;
		case 81u: goto st293;
		case 194u: goto st287;
		case 198u: goto st287;
	}
	if ( (*p) < 116u ) {
		if ( (*p) < 46u ) {
			if ( (*p) > 21u ) {
				if ( 22u <= (*p) && (*p) <= 23u )
					goto st450;
			} else if ( (*p) >= 20u )
				goto st293;
		} else if ( (*p) > 47u ) {
			if ( (*p) > 89u ) {
				if ( 92u <= (*p) && (*p) <= 109u )
					goto st293;
			} else if ( (*p) >= 84u )
				goto st293;
		} else
			goto st293;
	} else if ( (*p) > 118u ) {
		if ( (*p) < 216u ) {
			if ( (*p) > 125u ) {
				if ( 208u <= (*p) && (*p) <= 213u )
					goto st293;
			} else if ( (*p) >= 124u )
				goto st293;
		} else if ( (*p) > 229u ) {
			if ( (*p) < 241u ) {
				if ( 232u <= (*p) && (*p) <= 239u )
					goto st293;
			} else if ( (*p) > 246u ) {
				if ( 248u <= (*p) && (*p) <= 254u )
					goto st293;
			} else
				goto st293;
		} else
			goto st293;
	} else
		goto st293;
	goto tr33;
tr708:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st452;
st452:
	if ( ++p == pe )
		goto _test_eof452;
case 452:
#line 23697 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 42u: goto st293;
		case 81u: goto st293;
		case 83u: goto st293;
		case 194u: goto st287;
	}
	if ( (*p) > 90u ) {
		if ( 92u <= (*p) && (*p) <= 95u )
			goto st293;
	} else if ( (*p) >= 88u )
		goto st293;
	goto tr33;
tr709:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st453;
st453:
	if ( ++p == pe )
		goto _test_eof453;
case 453:
#line 23720 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 42u: goto st293;
		case 81u: goto st293;
		case 194u: goto st287;
		case 208u: goto st293;
	}
	if ( (*p) < 92u ) {
		if ( 88u <= (*p) && (*p) <= 90u )
			goto st293;
	} else if ( (*p) > 95u ) {
		if ( 124u <= (*p) && (*p) <= 125u )
			goto st293;
	} else
		goto st293;
	goto tr33;
tr710:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st454;
st454:
	if ( ++p == pe )
		goto _test_eof454;
case 454:
#line 23746 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 81u: goto st293;
		case 194u: goto st287;
		case 198u: goto st287;
	}
	if ( (*p) < 84u ) {
		if ( 20u <= (*p) && (*p) <= 21u )
			goto st293;
	} else if ( (*p) > 89u ) {
		if ( 92u <= (*p) && (*p) <= 95u )
			goto st293;
	} else
		goto st293;
	goto tr33;
tr711:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st455;
st455:
	if ( ++p == pe )
		goto _test_eof455;
case 455:
#line 23771 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 81u: goto st293;
		case 194u: goto st287;
		case 198u: goto st287;
		case 208u: goto st293;
	}
	if ( (*p) < 84u ) {
		if ( 20u <= (*p) && (*p) <= 21u )
			goto st293;
	} else if ( (*p) > 89u ) {
		if ( (*p) > 95u ) {
			if ( 124u <= (*p) && (*p) <= 125u )
				goto st293;
		} else if ( (*p) >= 92u )
			goto st293;
	} else
		goto st293;
	goto tr33;
tr712:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st456;
st456:
	if ( ++p == pe )
		goto _test_eof456;
case 456:
#line 23800 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	if ( (*p) == 208u )
		goto st293;
	if ( 124u <= (*p) && (*p) <= 125u )
		goto st293;
	goto tr33;
tr713:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st457;
st457:
	if ( ++p == pe )
		goto _test_eof457;
case 457:
#line 23816 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 43u: goto st450;
		case 194u: goto st287;
		case 198u: goto st287;
	}
	if ( (*p) < 22u ) {
		if ( (*p) < 18u ) {
			if ( 16u <= (*p) && (*p) <= 17u )
				goto st293;
		} else if ( (*p) > 19u ) {
			if ( 20u <= (*p) && (*p) <= 21u )
				goto st293;
		} else
			goto st450;
	} else if ( (*p) > 23u ) {
		if ( (*p) < 46u ) {
			if ( 40u <= (*p) && (*p) <= 41u )
				goto st293;
		} else if ( (*p) > 47u ) {
			if ( 81u <= (*p) && (*p) <= 95u )
				goto st293;
		} else
			goto st293;
	} else
		goto st450;
	goto tr33;
tr714:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st458;
st458:
	if ( ++p == pe )
		goto _test_eof458;
case 458:
#line 23853 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 43u: goto st450;
		case 81u: goto st293;
		case 112u: goto st287;
		case 127u: goto st293;
		case 194u: goto st287;
		case 196u: goto st459;
		case 198u: goto st287;
		case 231u: goto st450;
	}
	if ( (*p) < 84u ) {
		if ( (*p) < 20u ) {
			if ( (*p) > 17u ) {
				if ( 18u <= (*p) && (*p) <= 19u )
					goto st450;
			} else if ( (*p) >= 16u )
				goto st293;
		} else if ( (*p) > 21u ) {
			if ( (*p) < 40u ) {
				if ( 22u <= (*p) && (*p) <= 23u )
					goto st450;
			} else if ( (*p) > 41u ) {
				if ( 46u <= (*p) && (*p) <= 47u )
					goto st293;
			} else
				goto st293;
		} else
			goto st293;
	} else if ( (*p) > 111u ) {
		if ( (*p) < 208u ) {
			if ( (*p) > 118u ) {
				if ( 124u <= (*p) && (*p) <= 125u )
					goto st293;
			} else if ( (*p) >= 116u )
				goto st293;
		} else if ( (*p) > 213u ) {
			if ( (*p) < 241u ) {
				if ( 216u <= (*p) && (*p) <= 239u )
					goto st293;
			} else if ( (*p) > 246u ) {
				if ( 248u <= (*p) && (*p) <= 254u )
					goto st293;
			} else
				goto st293;
		} else
			goto st293;
	} else
		goto st293;
	goto tr33;
st459:
	if ( ++p == pe )
		goto _test_eof459;
case 459:
	switch( (*p) ) {
		case 4u: goto st44;
		case 12u: goto st44;
		case 20u: goto st44;
		case 28u: goto st44;
		case 36u: goto st44;
		case 44u: goto st44;
		case 52u: goto st44;
		case 60u: goto st44;
		case 68u: goto st50;
		case 76u: goto st50;
		case 84u: goto st50;
		case 92u: goto st50;
		case 100u: goto st50;
		case 108u: goto st50;
		case 116u: goto st50;
		case 124u: goto st50;
		case 132u: goto st51;
		case 140u: goto st51;
		case 148u: goto st51;
		case 156u: goto st51;
		case 164u: goto st51;
		case 172u: goto st51;
		case 180u: goto st51;
		case 188u: goto st51;
	}
	goto tr33;
tr715:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st460;
st460:
	if ( ++p == pe )
		goto _test_eof460;
case 460:
#line 23944 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 18u: goto st293;
		case 22u: goto st293;
		case 42u: goto st293;
		case 111u: goto st293;
		case 112u: goto st287;
		case 126u: goto st450;
		case 127u: goto st293;
		case 194u: goto st287;
		case 230u: goto st293;
	}
	if ( (*p) < 44u ) {
		if ( 16u <= (*p) && (*p) <= 17u )
			goto st450;
	} else if ( (*p) > 45u ) {
		if ( (*p) > 83u ) {
			if ( 88u <= (*p) && (*p) <= 95u )
				goto st293;
		} else if ( (*p) >= 81u )
			goto st293;
	} else
		goto tr727;
	goto tr33;
tr727:
#line 295 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(0, OperandSize32bit);
  }
	goto st461;
tr729:
#line 298 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(0, OperandSize64bit);
  }
	goto st461;
st461:
	if ( ++p == pe )
		goto _test_eof461;
case 461:
#line 23984 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 4u: goto tr18;
		case 12u: goto tr18;
		case 20u: goto tr18;
		case 28u: goto tr18;
		case 36u: goto tr18;
		case 44u: goto tr18;
		case 52u: goto tr18;
		case 60u: goto tr18;
		case 68u: goto tr21;
		case 76u: goto tr21;
		case 84u: goto tr21;
		case 92u: goto tr21;
		case 100u: goto tr21;
		case 108u: goto tr21;
		case 116u: goto tr21;
		case 124u: goto tr21;
		case 132u: goto tr23;
		case 140u: goto tr23;
		case 148u: goto tr23;
		case 156u: goto tr23;
		case 164u: goto tr23;
		case 172u: goto tr23;
		case 180u: goto tr23;
		case 188u: goto tr23;
	}
	if ( 192u <= (*p) )
		goto tr24;
	goto tr33;
tr716:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st462;
st462:
	if ( ++p == pe )
		goto _test_eof462;
case 462:
#line 24024 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 18u: goto st293;
		case 42u: goto st293;
		case 81u: goto st293;
		case 112u: goto st287;
		case 194u: goto st287;
		case 208u: goto st293;
		case 230u: goto st293;
		case 240u: goto st450;
	}
	if ( (*p) < 88u ) {
		if ( (*p) > 17u ) {
			if ( 44u <= (*p) && (*p) <= 45u )
				goto tr727;
		} else if ( (*p) >= 16u )
			goto st450;
	} else if ( (*p) > 90u ) {
		if ( (*p) > 95u ) {
			if ( 124u <= (*p) && (*p) <= 125u )
				goto st293;
		} else if ( (*p) >= 92u )
			goto st293;
	} else
		goto st293;
	goto tr33;
tr717:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st463;
st463:
	if ( ++p == pe )
		goto _test_eof463;
case 463:
#line 24060 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 43u: goto st450;
		case 194u: goto st287;
		case 198u: goto st287;
	}
	if ( (*p) < 20u ) {
		if ( 16u <= (*p) && (*p) <= 17u )
			goto st293;
	} else if ( (*p) > 21u ) {
		if ( (*p) > 41u ) {
			if ( 81u <= (*p) && (*p) <= 95u )
				goto st293;
		} else if ( (*p) >= 40u )
			goto st293;
	} else
		goto st293;
	goto tr33;
tr718:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st464;
st464:
	if ( ++p == pe )
		goto _test_eof464;
case 464:
#line 24088 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 43u: goto st450;
		case 81u: goto st293;
		case 126u: goto tr728;
		case 194u: goto st287;
		case 198u: goto st287;
		case 208u: goto st293;
		case 214u: goto st293;
		case 230u: goto st293;
		case 231u: goto st450;
	}
	if ( (*p) < 40u ) {
		if ( (*p) > 17u ) {
			if ( 20u <= (*p) && (*p) <= 21u )
				goto st293;
		} else if ( (*p) >= 16u )
			goto st293;
	} else if ( (*p) > 41u ) {
		if ( (*p) > 95u ) {
			if ( 124u <= (*p) && (*p) <= 127u )
				goto st293;
		} else if ( (*p) >= 84u )
			goto st293;
	} else
		goto st293;
	goto tr33;
tr728:
#line 295 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(0, OperandSize32bit);
  }
	goto st465;
tr730:
#line 298 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(0, OperandSize64bit);
  }
	goto st465;
st465:
	if ( ++p == pe )
		goto _test_eof465;
case 465:
#line 24131 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 4u: goto st2;
		case 12u: goto st2;
		case 20u: goto st2;
		case 28u: goto st2;
		case 36u: goto st2;
		case 44u: goto st2;
		case 52u: goto st2;
		case 60u: goto st2;
		case 68u: goto st8;
		case 76u: goto st8;
		case 84u: goto st8;
		case 92u: goto st8;
		case 100u: goto st8;
		case 108u: goto st8;
		case 116u: goto st8;
		case 124u: goto st8;
		case 132u: goto st9;
		case 140u: goto st9;
		case 148u: goto st9;
		case 156u: goto st9;
		case 164u: goto st9;
		case 172u: goto st9;
		case 180u: goto st9;
		case 188u: goto st9;
	}
	if ( 192u <= (*p) )
		goto tr7;
	goto tr33;
tr719:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st466;
st466:
	if ( ++p == pe )
		goto _test_eof466;
case 466:
#line 24171 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 18u: goto st293;
		case 22u: goto st293;
		case 91u: goto st293;
		case 127u: goto st293;
		case 230u: goto st293;
	}
	goto tr33;
tr720:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st467;
st467:
	if ( ++p == pe )
		goto _test_eof467;
case 467:
#line 24190 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 18u: goto st293;
		case 208u: goto st293;
		case 230u: goto st293;
		case 240u: goto st450;
	}
	if ( 124u <= (*p) && (*p) <= 125u )
		goto st293;
	goto tr33;
tr721:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st468;
st468:
	if ( ++p == pe )
		goto _test_eof468;
case 468:
#line 24210 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	if ( (*p) == 42u )
		goto st293;
	goto tr33;
tr722:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st469;
st469:
	if ( ++p == pe )
		goto _test_eof469;
case 469:
#line 24224 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	if ( (*p) == 110u )
		goto st293;
	goto tr33;
tr723:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st470;
st470:
	if ( ++p == pe )
		goto _test_eof470;
case 470:
#line 24238 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	if ( (*p) == 42u )
		goto st293;
	if ( 44u <= (*p) && (*p) <= 45u )
		goto tr729;
	goto tr33;
tr724:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st471;
st471:
	if ( ++p == pe )
		goto _test_eof471;
case 471:
#line 24254 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	if ( (*p) == 126u )
		goto tr730;
	goto tr33;
tr633:
#line 235 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX2(*p);
  }
	goto st472;
st472:
	if ( ++p == pe )
		goto _test_eof472;
case 472:
#line 24268 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 0u: goto tr731;
		case 1u: goto tr732;
		case 5u: goto tr733;
		case 8u: goto tr731;
		case 9u: goto tr732;
		case 13u: goto tr733;
		case 16u: goto tr731;
		case 17u: goto tr732;
		case 21u: goto tr733;
		case 24u: goto tr731;
		case 25u: goto tr732;
		case 29u: goto tr733;
		case 32u: goto tr731;
		case 33u: goto tr732;
		case 37u: goto tr733;
		case 40u: goto tr731;
		case 41u: goto tr732;
		case 45u: goto tr733;
		case 48u: goto tr731;
		case 49u: goto tr732;
		case 53u: goto tr733;
		case 56u: goto tr731;
		case 57u: goto tr732;
		case 61u: goto tr733;
		case 64u: goto tr731;
		case 65u: goto tr732;
		case 69u: goto tr733;
		case 72u: goto tr731;
		case 73u: goto tr732;
		case 77u: goto tr733;
		case 80u: goto tr731;
		case 81u: goto tr732;
		case 85u: goto tr733;
		case 88u: goto tr731;
		case 89u: goto tr732;
		case 93u: goto tr733;
		case 96u: goto tr731;
		case 97u: goto tr732;
		case 101u: goto tr733;
		case 104u: goto tr731;
		case 105u: goto tr732;
		case 109u: goto tr733;
		case 112u: goto tr731;
		case 113u: goto tr732;
		case 117u: goto tr733;
		case 120u: goto tr731;
		case 121u: goto tr734;
		case 125u: goto tr735;
		case 128u: goto tr736;
		case 129u: goto tr737;
		case 133u: goto tr738;
		case 136u: goto tr736;
		case 137u: goto tr737;
		case 141u: goto tr738;
		case 144u: goto tr736;
		case 145u: goto tr737;
		case 149u: goto tr738;
		case 152u: goto tr736;
		case 153u: goto tr737;
		case 157u: goto tr738;
		case 160u: goto tr736;
		case 161u: goto tr737;
		case 165u: goto tr738;
		case 168u: goto tr736;
		case 169u: goto tr737;
		case 173u: goto tr738;
		case 176u: goto tr736;
		case 177u: goto tr737;
		case 181u: goto tr738;
		case 184u: goto tr736;
		case 185u: goto tr737;
		case 189u: goto tr738;
		case 192u: goto tr736;
		case 193u: goto tr737;
		case 197u: goto tr738;
		case 200u: goto tr736;
		case 201u: goto tr737;
		case 205u: goto tr738;
		case 208u: goto tr736;
		case 209u: goto tr737;
		case 213u: goto tr738;
		case 216u: goto tr736;
		case 217u: goto tr737;
		case 221u: goto tr738;
		case 224u: goto tr736;
		case 225u: goto tr737;
		case 229u: goto tr738;
		case 232u: goto tr736;
		case 233u: goto tr737;
		case 237u: goto tr738;
		case 240u: goto tr736;
		case 241u: goto tr737;
		case 245u: goto tr738;
		case 248u: goto tr736;
		case 249u: goto tr737;
		case 253u: goto tr738;
	}
	goto tr33;
tr731:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st473;
st473:
	if ( ++p == pe )
		goto _test_eof473;
case 473:
#line 24378 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 242u: goto tr727;
		case 247u: goto tr727;
	}
	goto tr33;
tr732:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st474;
st474:
	if ( ++p == pe )
		goto _test_eof474;
case 474:
#line 24394 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	if ( (*p) == 43u )
		goto st293;
	if ( (*p) < 55u ) {
		if ( (*p) < 40u ) {
			if ( (*p) <= 13u )
				goto st293;
		} else if ( (*p) > 41u ) {
			if ( 44u <= (*p) && (*p) <= 47u )
				goto st450;
		} else
			goto st293;
	} else if ( (*p) > 64u ) {
		if ( (*p) < 166u ) {
			if ( 150u <= (*p) && (*p) <= 159u )
				goto st293;
		} else if ( (*p) > 175u ) {
			if ( (*p) > 191u ) {
				if ( 219u <= (*p) && (*p) <= 223u )
					goto st293;
			} else if ( (*p) >= 182u )
				goto st293;
		} else
			goto st293;
	} else
		goto st293;
	goto tr33;
tr733:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st475;
st475:
	if ( ++p == pe )
		goto _test_eof475;
case 475:
#line 24431 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 154u: goto st293;
		case 156u: goto st293;
		case 158u: goto st293;
		case 170u: goto st293;
		case 172u: goto st293;
		case 174u: goto st293;
		case 186u: goto st293;
		case 188u: goto st293;
		case 190u: goto st293;
	}
	if ( (*p) < 150u ) {
		if ( (*p) > 13u ) {
			if ( 44u <= (*p) && (*p) <= 47u )
				goto st450;
		} else if ( (*p) >= 12u )
			goto st293;
	} else if ( (*p) > 152u ) {
		if ( (*p) > 168u ) {
			if ( 182u <= (*p) && (*p) <= 184u )
				goto st293;
		} else if ( (*p) >= 166u )
			goto st293;
	} else
		goto st293;
	goto tr33;
tr734:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st476;
st476:
	if ( ++p == pe )
		goto _test_eof476;
case 476:
#line 24468 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 19u: goto st293;
		case 23u: goto st293;
		case 24u: goto st450;
		case 42u: goto st450;
	}
	if ( (*p) < 48u ) {
		if ( (*p) < 32u ) {
			if ( (*p) > 15u ) {
				if ( 28u <= (*p) && (*p) <= 30u )
					goto st293;
			} else
				goto st293;
		} else if ( (*p) > 37u ) {
			if ( (*p) > 43u ) {
				if ( 44u <= (*p) && (*p) <= 47u )
					goto st450;
			} else if ( (*p) >= 40u )
				goto st293;
		} else
			goto st293;
	} else if ( (*p) > 53u ) {
		if ( (*p) < 166u ) {
			if ( (*p) > 65u ) {
				if ( 150u <= (*p) && (*p) <= 159u )
					goto st293;
			} else if ( (*p) >= 55u )
				goto st293;
		} else if ( (*p) > 175u ) {
			if ( (*p) > 191u ) {
				if ( 219u <= (*p) && (*p) <= 223u )
					goto st293;
			} else if ( (*p) >= 182u )
				goto st293;
		} else
			goto st293;
	} else
		goto st293;
	goto tr33;
tr735:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st477;
st477:
	if ( ++p == pe )
		goto _test_eof477;
case 477:
#line 24518 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 19u: goto st293;
		case 23u: goto st293;
		case 154u: goto st293;
		case 156u: goto st293;
		case 158u: goto st293;
		case 170u: goto st293;
		case 172u: goto st293;
		case 174u: goto st293;
		case 186u: goto st293;
		case 188u: goto st293;
		case 190u: goto st293;
	}
	if ( (*p) < 44u ) {
		if ( (*p) > 15u ) {
			if ( 24u <= (*p) && (*p) <= 26u )
				goto st450;
		} else if ( (*p) >= 12u )
			goto st293;
	} else if ( (*p) > 47u ) {
		if ( (*p) < 166u ) {
			if ( 150u <= (*p) && (*p) <= 152u )
				goto st293;
		} else if ( (*p) > 168u ) {
			if ( 182u <= (*p) && (*p) <= 184u )
				goto st293;
		} else
			goto st293;
	} else
		goto st450;
	goto tr33;
tr736:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st478;
st478:
	if ( ++p == pe )
		goto _test_eof478;
case 478:
#line 24560 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 242u: goto tr729;
		case 247u: goto tr729;
	}
	goto tr33;
tr737:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st479;
st479:
	if ( ++p == pe )
		goto _test_eof479;
case 479:
#line 24576 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	if ( (*p) < 166u ) {
		if ( 150u <= (*p) && (*p) <= 159u )
			goto st293;
	} else if ( (*p) > 175u ) {
		if ( 182u <= (*p) && (*p) <= 191u )
			goto st293;
	} else
		goto st293;
	goto tr33;
tr738:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st480;
st480:
	if ( ++p == pe )
		goto _test_eof480;
case 480:
#line 24596 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 154u: goto st293;
		case 156u: goto st293;
		case 158u: goto st293;
		case 170u: goto st293;
		case 172u: goto st293;
		case 174u: goto st293;
		case 186u: goto st293;
		case 188u: goto st293;
		case 190u: goto st293;
	}
	if ( (*p) < 166u ) {
		if ( 150u <= (*p) && (*p) <= 152u )
			goto st293;
	} else if ( (*p) > 168u ) {
		if ( 182u <= (*p) && (*p) <= 184u )
			goto st293;
	} else
		goto st293;
	goto tr33;
tr634:
#line 235 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX2(*p);
  }
	goto st481;
st481:
	if ( ++p == pe )
		goto _test_eof481;
case 481:
#line 24627 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 1u: goto tr739;
		case 5u: goto tr740;
		case 9u: goto tr739;
		case 13u: goto tr740;
		case 17u: goto tr739;
		case 21u: goto tr740;
		case 25u: goto tr739;
		case 29u: goto tr740;
		case 33u: goto tr739;
		case 37u: goto tr740;
		case 41u: goto tr739;
		case 45u: goto tr740;
		case 49u: goto tr739;
		case 53u: goto tr740;
		case 57u: goto tr739;
		case 61u: goto tr740;
		case 65u: goto tr739;
		case 69u: goto tr740;
		case 73u: goto tr739;
		case 77u: goto tr740;
		case 81u: goto tr739;
		case 85u: goto tr740;
		case 89u: goto tr739;
		case 93u: goto tr740;
		case 97u: goto tr739;
		case 101u: goto tr740;
		case 105u: goto tr739;
		case 109u: goto tr740;
		case 113u: goto tr739;
		case 117u: goto tr740;
		case 121u: goto tr741;
		case 125u: goto tr742;
		case 129u: goto tr743;
		case 133u: goto tr744;
		case 137u: goto tr743;
		case 141u: goto tr744;
		case 145u: goto tr743;
		case 149u: goto tr744;
		case 153u: goto tr743;
		case 157u: goto tr744;
		case 161u: goto tr743;
		case 165u: goto tr744;
		case 169u: goto tr743;
		case 173u: goto tr744;
		case 177u: goto tr743;
		case 181u: goto tr744;
		case 185u: goto tr743;
		case 189u: goto tr744;
		case 193u: goto tr743;
		case 197u: goto tr744;
		case 201u: goto tr743;
		case 205u: goto tr744;
		case 209u: goto tr743;
		case 213u: goto tr744;
		case 217u: goto tr743;
		case 221u: goto tr744;
		case 225u: goto tr743;
		case 229u: goto tr744;
		case 233u: goto tr743;
		case 237u: goto tr744;
		case 241u: goto tr743;
		case 245u: goto tr744;
		case 249u: goto tr745;
		case 253u: goto tr744;
	}
	goto tr33;
tr739:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st482;
st482:
	if ( ++p == pe )
		goto _test_eof482;
case 482:
#line 24705 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 33u: goto st459;
		case 68u: goto st287;
		case 223u: goto st287;
	}
	if ( (*p) < 74u ) {
		if ( (*p) < 64u ) {
			if ( 8u <= (*p) && (*p) <= 15u )
				goto st287;
		} else if ( (*p) > 66u ) {
			if ( 72u <= (*p) && (*p) <= 73u )
				goto st483;
		} else
			goto st287;
	} else if ( (*p) > 76u ) {
		if ( (*p) < 104u ) {
			if ( 92u <= (*p) && (*p) <= 95u )
				goto st285;
		} else if ( (*p) > 111u ) {
			if ( 120u <= (*p) && (*p) <= 127u )
				goto st285;
		} else
			goto st285;
	} else
		goto st285;
	goto tr33;
st483:
	if ( ++p == pe )
		goto _test_eof483;
case 483:
	switch( (*p) ) {
		case 4u: goto st484;
		case 12u: goto st484;
		case 20u: goto st484;
		case 28u: goto st484;
		case 36u: goto st484;
		case 44u: goto st484;
		case 52u: goto st484;
		case 60u: goto st484;
		case 68u: goto st434;
		case 76u: goto st434;
		case 84u: goto st434;
		case 92u: goto st434;
		case 100u: goto st434;
		case 108u: goto st434;
		case 116u: goto st434;
		case 124u: goto st434;
		case 132u: goto st436;
		case 140u: goto st436;
		case 148u: goto st436;
		case 156u: goto st436;
		case 164u: goto st436;
		case 172u: goto st436;
		case 180u: goto st436;
		case 188u: goto st436;
	}
	if ( 192u <= (*p) )
		goto st433;
	goto tr33;
st484:
	if ( ++p == pe )
		goto _test_eof484;
case 484:
	switch( (*p) ) {
		case 5u: goto tr748;
		case 13u: goto tr748;
		case 21u: goto tr748;
		case 29u: goto tr748;
		case 37u: goto tr748;
		case 45u: goto tr748;
		case 53u: goto tr748;
		case 61u: goto tr748;
		case 69u: goto tr748;
		case 77u: goto tr748;
		case 85u: goto tr748;
		case 93u: goto tr748;
		case 101u: goto tr748;
		case 109u: goto tr748;
		case 117u: goto tr748;
		case 125u: goto tr748;
		case 133u: goto tr748;
		case 141u: goto tr748;
		case 149u: goto tr748;
		case 157u: goto tr748;
		case 165u: goto tr748;
		case 173u: goto tr748;
		case 181u: goto tr748;
		case 189u: goto tr748;
		case 197u: goto tr748;
		case 205u: goto tr748;
		case 213u: goto tr748;
		case 221u: goto tr748;
		case 229u: goto tr748;
		case 237u: goto tr748;
		case 245u: goto tr748;
		case 253u: goto tr748;
	}
	goto tr695;
tr740:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st485;
st485:
	if ( ++p == pe )
		goto _test_eof485;
case 485:
#line 24814 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 6u: goto st287;
		case 64u: goto st287;
	}
	if ( (*p) < 92u ) {
		if ( (*p) < 12u ) {
			if ( 8u <= (*p) && (*p) <= 9u )
				goto st287;
		} else if ( (*p) > 13u ) {
			if ( (*p) > 73u ) {
				if ( 74u <= (*p) && (*p) <= 75u )
					goto st285;
			} else if ( (*p) >= 72u )
				goto st483;
		} else
			goto st287;
	} else if ( (*p) > 95u ) {
		if ( (*p) < 108u ) {
			if ( 104u <= (*p) && (*p) <= 105u )
				goto st285;
		} else if ( (*p) > 109u ) {
			if ( (*p) > 121u ) {
				if ( 124u <= (*p) && (*p) <= 125u )
					goto st285;
			} else if ( (*p) >= 120u )
				goto st285;
		} else
			goto st285;
	} else
		goto st285;
	goto tr33;
tr741:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st486;
st486:
	if ( ++p == pe )
		goto _test_eof486;
case 486:
#line 24856 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 22u: goto tr749;
		case 29u: goto st287;
		case 34u: goto st287;
		case 68u: goto st287;
		case 223u: goto st287;
	}
	if ( (*p) < 72u ) {
		if ( (*p) < 20u ) {
			if ( (*p) > 5u ) {
				if ( 8u <= (*p) && (*p) <= 15u )
					goto st287;
			} else if ( (*p) >= 4u )
				goto st287;
		} else if ( (*p) > 23u ) {
			if ( (*p) > 33u ) {
				if ( 64u <= (*p) && (*p) <= 66u )
					goto st287;
			} else if ( (*p) >= 32u )
				goto st459;
		} else
			goto st459;
	} else if ( (*p) > 73u ) {
		if ( (*p) < 96u ) {
			if ( (*p) > 76u ) {
				if ( 92u <= (*p) && (*p) <= 95u )
					goto st285;
			} else if ( (*p) >= 74u )
				goto st285;
		} else if ( (*p) > 99u ) {
			if ( (*p) > 111u ) {
				if ( 120u <= (*p) && (*p) <= 127u )
					goto st285;
			} else if ( (*p) >= 104u )
				goto st285;
		} else
			goto st287;
	} else
		goto st483;
	goto tr33;
tr749:
#line 295 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(0, OperandSize32bit);
  }
	goto st487;
tr750:
#line 298 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(0, OperandSize64bit);
  }
	goto st487;
st487:
	if ( ++p == pe )
		goto _test_eof487;
case 487:
#line 24913 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 4u: goto st44;
		case 12u: goto st44;
		case 20u: goto st44;
		case 28u: goto st44;
		case 36u: goto st44;
		case 44u: goto st44;
		case 52u: goto st44;
		case 60u: goto st44;
		case 68u: goto st50;
		case 76u: goto st50;
		case 84u: goto st50;
		case 92u: goto st50;
		case 100u: goto st50;
		case 108u: goto st50;
		case 116u: goto st50;
		case 124u: goto st50;
		case 132u: goto st51;
		case 140u: goto st51;
		case 148u: goto st51;
		case 156u: goto st51;
		case 164u: goto st51;
		case 172u: goto st51;
		case 180u: goto st51;
		case 188u: goto st51;
	}
	if ( 192u <= (*p) )
		goto tr114;
	goto tr33;
tr742:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st488;
st488:
	if ( ++p == pe )
		goto _test_eof488;
case 488:
#line 24953 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 29u: goto st287;
		case 64u: goto st287;
	}
	if ( (*p) < 74u ) {
		if ( (*p) < 12u ) {
			if ( (*p) > 6u ) {
				if ( 8u <= (*p) && (*p) <= 9u )
					goto st287;
			} else if ( (*p) >= 4u )
				goto st287;
		} else if ( (*p) > 13u ) {
			if ( (*p) > 25u ) {
				if ( 72u <= (*p) && (*p) <= 73u )
					goto st483;
			} else if ( (*p) >= 24u )
				goto st287;
		} else
			goto st287;
	} else if ( (*p) > 75u ) {
		if ( (*p) < 108u ) {
			if ( (*p) > 95u ) {
				if ( 104u <= (*p) && (*p) <= 105u )
					goto st285;
			} else if ( (*p) >= 92u )
				goto st285;
		} else if ( (*p) > 109u ) {
			if ( (*p) > 121u ) {
				if ( 124u <= (*p) && (*p) <= 125u )
					goto st285;
			} else if ( (*p) >= 120u )
				goto st285;
		} else
			goto st285;
	} else
		goto st285;
	goto tr33;
tr743:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st489;
st489:
	if ( ++p == pe )
		goto _test_eof489;
case 489:
#line 25001 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	if ( (*p) < 92u ) {
		if ( 72u <= (*p) && (*p) <= 73u )
			goto st483;
	} else if ( (*p) > 95u ) {
		if ( (*p) > 111u ) {
			if ( 120u <= (*p) && (*p) <= 127u )
				goto st285;
		} else if ( (*p) >= 104u )
			goto st285;
	} else
		goto st285;
	goto tr33;
tr744:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st490;
st490:
	if ( ++p == pe )
		goto _test_eof490;
case 490:
#line 25024 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	if ( (*p) < 104u ) {
		if ( (*p) > 73u ) {
			if ( 92u <= (*p) && (*p) <= 95u )
				goto st285;
		} else if ( (*p) >= 72u )
			goto st483;
	} else if ( (*p) > 105u ) {
		if ( (*p) < 120u ) {
			if ( 108u <= (*p) && (*p) <= 109u )
				goto st285;
		} else if ( (*p) > 121u ) {
			if ( 124u <= (*p) && (*p) <= 125u )
				goto st285;
		} else
			goto st285;
	} else
		goto st285;
	goto tr33;
tr745:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st491;
st491:
	if ( ++p == pe )
		goto _test_eof491;
case 491:
#line 25053 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 22u: goto tr750;
		case 34u: goto st287;
	}
	if ( (*p) < 92u ) {
		if ( 72u <= (*p) && (*p) <= 73u )
			goto st483;
	} else if ( (*p) > 95u ) {
		if ( (*p) > 111u ) {
			if ( 120u <= (*p) && (*p) <= 127u )
				goto st285;
		} else if ( (*p) >= 104u )
			goto st285;
	} else
		goto st285;
	goto tr33;
tr635:
#line 235 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX2(*p);
  }
	goto st492;
st492:
	if ( ++p == pe )
		goto _test_eof492;
case 492:
#line 25080 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 1u: goto tr752;
		case 2u: goto tr753;
		case 3u: goto tr754;
		case 4u: goto tr755;
		case 5u: goto tr756;
		case 6u: goto tr757;
		case 7u: goto tr758;
		case 9u: goto tr752;
		case 10u: goto tr753;
		case 11u: goto tr754;
		case 12u: goto tr755;
		case 13u: goto tr756;
		case 14u: goto tr757;
		case 15u: goto tr758;
		case 17u: goto tr752;
		case 18u: goto tr753;
		case 19u: goto tr754;
		case 20u: goto tr755;
		case 21u: goto tr756;
		case 22u: goto tr757;
		case 23u: goto tr758;
		case 25u: goto tr752;
		case 26u: goto tr753;
		case 27u: goto tr754;
		case 28u: goto tr755;
		case 29u: goto tr756;
		case 30u: goto tr757;
		case 31u: goto tr758;
		case 33u: goto tr752;
		case 34u: goto tr753;
		case 35u: goto tr754;
		case 36u: goto tr755;
		case 37u: goto tr756;
		case 38u: goto tr757;
		case 39u: goto tr758;
		case 41u: goto tr752;
		case 42u: goto tr753;
		case 43u: goto tr754;
		case 44u: goto tr755;
		case 45u: goto tr756;
		case 46u: goto tr757;
		case 47u: goto tr758;
		case 49u: goto tr752;
		case 50u: goto tr753;
		case 51u: goto tr754;
		case 52u: goto tr755;
		case 53u: goto tr756;
		case 54u: goto tr757;
		case 55u: goto tr758;
		case 57u: goto tr752;
		case 58u: goto tr753;
		case 59u: goto tr754;
		case 60u: goto tr755;
		case 61u: goto tr756;
		case 62u: goto tr757;
		case 63u: goto tr758;
		case 65u: goto tr752;
		case 66u: goto tr753;
		case 67u: goto tr754;
		case 68u: goto tr755;
		case 69u: goto tr756;
		case 70u: goto tr757;
		case 71u: goto tr758;
		case 73u: goto tr752;
		case 74u: goto tr753;
		case 75u: goto tr754;
		case 76u: goto tr755;
		case 77u: goto tr756;
		case 78u: goto tr757;
		case 79u: goto tr758;
		case 81u: goto tr752;
		case 82u: goto tr753;
		case 83u: goto tr754;
		case 84u: goto tr755;
		case 85u: goto tr756;
		case 86u: goto tr757;
		case 87u: goto tr758;
		case 89u: goto tr752;
		case 90u: goto tr753;
		case 91u: goto tr754;
		case 92u: goto tr755;
		case 93u: goto tr756;
		case 94u: goto tr757;
		case 95u: goto tr758;
		case 97u: goto tr752;
		case 98u: goto tr753;
		case 99u: goto tr754;
		case 100u: goto tr755;
		case 101u: goto tr756;
		case 102u: goto tr757;
		case 103u: goto tr758;
		case 105u: goto tr752;
		case 106u: goto tr753;
		case 107u: goto tr754;
		case 108u: goto tr755;
		case 109u: goto tr756;
		case 110u: goto tr757;
		case 111u: goto tr758;
		case 113u: goto tr752;
		case 114u: goto tr753;
		case 115u: goto tr754;
		case 116u: goto tr755;
		case 117u: goto tr756;
		case 118u: goto tr757;
		case 119u: goto tr758;
		case 120u: goto tr759;
		case 121u: goto tr760;
		case 122u: goto tr761;
		case 123u: goto tr762;
		case 124u: goto tr763;
		case 125u: goto tr764;
		case 126u: goto tr765;
		case 127u: goto tr766;
		case 249u: goto tr768;
		case 253u: goto tr770;
	}
	if ( (*p) < 186u ) {
		if ( (*p) < 146u ) {
			if ( (*p) < 130u ) {
				if ( (*p) <= 112u )
					goto tr751;
			} else if ( (*p) > 131u ) {
				if ( 138u <= (*p) && (*p) <= 139u )
					goto tr767;
			} else
				goto tr767;
		} else if ( (*p) > 147u ) {
			if ( (*p) < 162u ) {
				if ( 154u <= (*p) && (*p) <= 155u )
					goto tr767;
			} else if ( (*p) > 163u ) {
				if ( (*p) > 171u ) {
					if ( 178u <= (*p) && (*p) <= 179u )
						goto tr767;
				} else if ( (*p) >= 170u )
					goto tr767;
			} else
				goto tr767;
		} else
			goto tr767;
	} else if ( (*p) > 187u ) {
		if ( (*p) < 218u ) {
			if ( (*p) < 202u ) {
				if ( 194u <= (*p) && (*p) <= 195u )
					goto tr767;
			} else if ( (*p) > 203u ) {
				if ( 210u <= (*p) && (*p) <= 211u )
					goto tr767;
			} else
				goto tr767;
		} else if ( (*p) > 219u ) {
			if ( (*p) < 234u ) {
				if ( 226u <= (*p) && (*p) <= 227u )
					goto tr767;
			} else if ( (*p) > 235u ) {
				if ( (*p) > 243u ) {
					if ( 250u <= (*p) && (*p) <= 251u )
						goto tr769;
				} else if ( (*p) >= 242u )
					goto tr767;
			} else
				goto tr767;
		} else
			goto tr767;
	} else
		goto tr767;
	goto tr33;
tr751:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st493;
st493:
	if ( ++p == pe )
		goto _test_eof493;
case 493:
#line 25259 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 18u: goto st309;
		case 23u: goto st494;
		case 81u: goto st309;
		case 194u: goto st303;
		case 198u: goto st303;
	}
	if ( (*p) < 46u ) {
		if ( 20u <= (*p) && (*p) <= 22u )
			goto st309;
	} else if ( (*p) > 47u ) {
		if ( (*p) > 89u ) {
			if ( 92u <= (*p) && (*p) <= 95u )
				goto st309;
		} else if ( (*p) >= 84u )
			goto st309;
	} else
		goto st309;
	goto tr33;
st494:
	if ( ++p == pe )
		goto _test_eof494;
case 494:
	switch( (*p) ) {
		case 4u: goto st275;
		case 12u: goto st275;
		case 20u: goto st275;
		case 28u: goto st275;
		case 36u: goto st275;
		case 44u: goto st275;
		case 52u: goto st275;
		case 60u: goto st275;
		case 68u: goto st8;
		case 76u: goto st8;
		case 84u: goto st8;
		case 92u: goto st8;
		case 100u: goto st8;
		case 108u: goto st8;
		case 116u: goto st8;
		case 124u: goto st8;
		case 132u: goto st9;
		case 140u: goto st9;
		case 148u: goto st9;
		case 156u: goto st9;
		case 164u: goto st9;
		case 172u: goto st9;
		case 180u: goto st9;
		case 188u: goto st9;
	}
	if ( (*p) < 38u ) {
		if ( (*p) < 14u ) {
			if ( (*p) > 3u ) {
				if ( 6u <= (*p) && (*p) <= 11u )
					goto tr0;
			} else
				goto tr0;
		} else if ( (*p) > 19u ) {
			if ( (*p) > 27u ) {
				if ( 30u <= (*p) && (*p) <= 35u )
					goto tr0;
			} else if ( (*p) >= 22u )
				goto tr0;
		} else
			goto tr0;
	} else if ( (*p) > 43u ) {
		if ( (*p) < 62u ) {
			if ( (*p) > 51u ) {
				if ( 54u <= (*p) && (*p) <= 59u )
					goto tr0;
			} else if ( (*p) >= 46u )
				goto tr0;
		} else if ( (*p) > 63u ) {
			if ( (*p) > 127u ) {
				if ( 128u <= (*p) && (*p) <= 191u )
					goto tr5;
			} else if ( (*p) >= 64u )
				goto tr3;
		} else
			goto tr0;
	} else
		goto tr0;
	goto tr33;
tr752:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st495;
st495:
	if ( ++p == pe )
		goto _test_eof495;
case 495:
#line 25352 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 18u: goto st494;
		case 81u: goto st309;
		case 194u: goto st303;
		case 198u: goto st303;
	}
	if ( (*p) < 116u ) {
		if ( (*p) < 46u ) {
			if ( (*p) > 21u ) {
				if ( 22u <= (*p) && (*p) <= 23u )
					goto st494;
			} else if ( (*p) >= 20u )
				goto st309;
		} else if ( (*p) > 47u ) {
			if ( (*p) > 89u ) {
				if ( 92u <= (*p) && (*p) <= 109u )
					goto st309;
			} else if ( (*p) >= 84u )
				goto st309;
		} else
			goto st309;
	} else if ( (*p) > 118u ) {
		if ( (*p) < 216u ) {
			if ( (*p) > 125u ) {
				if ( 208u <= (*p) && (*p) <= 213u )
					goto st309;
			} else if ( (*p) >= 124u )
				goto st309;
		} else if ( (*p) > 229u ) {
			if ( (*p) < 241u ) {
				if ( 232u <= (*p) && (*p) <= 239u )
					goto st309;
			} else if ( (*p) > 246u ) {
				if ( 248u <= (*p) && (*p) <= 254u )
					goto st309;
			} else
				goto st309;
		} else
			goto st309;
	} else
		goto st309;
	goto tr33;
tr753:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st496;
st496:
	if ( ++p == pe )
		goto _test_eof496;
case 496:
#line 25405 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 42u: goto st309;
		case 81u: goto st309;
		case 83u: goto st309;
		case 194u: goto st303;
	}
	if ( (*p) > 90u ) {
		if ( 92u <= (*p) && (*p) <= 95u )
			goto st309;
	} else if ( (*p) >= 88u )
		goto st309;
	goto tr33;
tr754:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st497;
st497:
	if ( ++p == pe )
		goto _test_eof497;
case 497:
#line 25428 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 42u: goto st309;
		case 81u: goto st309;
		case 194u: goto st303;
		case 208u: goto st309;
	}
	if ( (*p) < 92u ) {
		if ( 88u <= (*p) && (*p) <= 90u )
			goto st309;
	} else if ( (*p) > 95u ) {
		if ( 124u <= (*p) && (*p) <= 125u )
			goto st309;
	} else
		goto st309;
	goto tr33;
tr755:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st498;
st498:
	if ( ++p == pe )
		goto _test_eof498;
case 498:
#line 25454 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 81u: goto st309;
		case 194u: goto st303;
		case 198u: goto st303;
	}
	if ( (*p) < 84u ) {
		if ( 20u <= (*p) && (*p) <= 21u )
			goto st309;
	} else if ( (*p) > 89u ) {
		if ( 92u <= (*p) && (*p) <= 95u )
			goto st309;
	} else
		goto st309;
	goto tr33;
tr756:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st499;
st499:
	if ( ++p == pe )
		goto _test_eof499;
case 499:
#line 25479 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 81u: goto st309;
		case 194u: goto st303;
		case 198u: goto st303;
		case 208u: goto st309;
	}
	if ( (*p) < 84u ) {
		if ( 20u <= (*p) && (*p) <= 21u )
			goto st309;
	} else if ( (*p) > 89u ) {
		if ( (*p) > 95u ) {
			if ( 124u <= (*p) && (*p) <= 125u )
				goto st309;
		} else if ( (*p) >= 92u )
			goto st309;
	} else
		goto st309;
	goto tr33;
tr757:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st500;
tr872:
#line 243 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    /* This emulates two prefixes case. */
    SET_VEX_PREFIX2((p[0] & 0x80) | 0x61);
    SET_VEX_PREFIX3(p[0] & 0x7f);
  }
	goto st500;
st500:
	if ( ++p == pe )
		goto _test_eof500;
case 500:
#line 25516 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	if ( 16u <= (*p) && (*p) <= 17u )
		goto st64;
	goto tr33;
tr758:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st501;
st501:
	if ( ++p == pe )
		goto _test_eof501;
case 501:
#line 25530 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	if ( (*p) == 208u )
		goto st309;
	if ( (*p) > 17u ) {
		if ( 124u <= (*p) && (*p) <= 125u )
			goto st309;
	} else if ( (*p) >= 16u )
		goto st64;
	goto tr33;
tr759:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st502;
st502:
	if ( ++p == pe )
		goto _test_eof502;
case 502:
#line 25549 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 19u: goto st494;
		case 23u: goto st494;
		case 43u: goto st494;
		case 80u: goto tr41;
		case 194u: goto st303;
		case 198u: goto st303;
	}
	if ( (*p) < 40u ) {
		if ( 16u <= (*p) && (*p) <= 22u )
			goto st309;
	} else if ( (*p) > 41u ) {
		if ( (*p) > 47u ) {
			if ( 81u <= (*p) && (*p) <= 95u )
				goto st309;
		} else if ( (*p) >= 46u )
			goto st309;
	} else
		goto st309;
	goto tr33;
tr760:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st503;
st503:
	if ( ++p == pe )
		goto _test_eof503;
case 503:
#line 25580 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 43u: goto st494;
		case 80u: goto tr41;
		case 81u: goto st309;
		case 112u: goto st303;
		case 127u: goto st309;
		case 194u: goto st303;
		case 197u: goto tr52;
		case 215u: goto tr41;
		case 231u: goto st494;
		case 247u: goto st64;
	}
	if ( (*p) < 84u ) {
		if ( (*p) < 20u ) {
			if ( (*p) > 17u ) {
				if ( 18u <= (*p) && (*p) <= 19u )
					goto st494;
			} else if ( (*p) >= 16u )
				goto st309;
		} else if ( (*p) > 21u ) {
			if ( (*p) < 40u ) {
				if ( 22u <= (*p) && (*p) <= 23u )
					goto st494;
			} else if ( (*p) > 41u ) {
				if ( 46u <= (*p) && (*p) <= 47u )
					goto st309;
			} else
				goto st309;
		} else
			goto st309;
	} else if ( (*p) > 111u ) {
		if ( (*p) < 196u ) {
			if ( (*p) > 118u ) {
				if ( 124u <= (*p) && (*p) <= 125u )
					goto st309;
			} else if ( (*p) >= 116u )
				goto st309;
		} else if ( (*p) > 198u ) {
			if ( (*p) < 216u ) {
				if ( 208u <= (*p) && (*p) <= 213u )
					goto st309;
			} else if ( (*p) > 239u ) {
				if ( 241u <= (*p) && (*p) <= 254u )
					goto st309;
			} else
				goto st309;
		} else
			goto st303;
	} else
		goto st309;
	goto tr33;
tr761:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st504;
st504:
	if ( ++p == pe )
		goto _test_eof504;
case 504:
#line 25642 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 18u: goto st309;
		case 22u: goto st309;
		case 42u: goto st309;
		case 111u: goto st309;
		case 112u: goto st303;
		case 194u: goto st303;
		case 230u: goto st309;
	}
	if ( (*p) < 81u ) {
		if ( (*p) > 17u ) {
			if ( 44u <= (*p) && (*p) <= 45u )
				goto tr772;
		} else if ( (*p) >= 16u )
			goto st494;
	} else if ( (*p) > 83u ) {
		if ( (*p) > 95u ) {
			if ( 126u <= (*p) && (*p) <= 127u )
				goto st309;
		} else if ( (*p) >= 88u )
			goto st309;
	} else
		goto st309;
	goto tr33;
tr772:
#line 295 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(0, OperandSize32bit);
  }
	goto st505;
tr774:
#line 298 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(0, OperandSize64bit);
  }
	goto st505;
st505:
	if ( ++p == pe )
		goto _test_eof505;
case 505:
#line 25683 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 4u: goto tr671;
		case 5u: goto tr33;
		case 12u: goto tr671;
		case 13u: goto tr33;
		case 20u: goto tr671;
		case 21u: goto tr33;
		case 28u: goto tr671;
		case 29u: goto tr33;
		case 36u: goto tr671;
		case 37u: goto tr33;
		case 44u: goto tr671;
		case 45u: goto tr33;
		case 52u: goto tr671;
		case 53u: goto tr33;
		case 60u: goto tr671;
		case 61u: goto tr33;
		case 68u: goto tr21;
		case 76u: goto tr21;
		case 84u: goto tr21;
		case 92u: goto tr21;
		case 100u: goto tr21;
		case 108u: goto tr21;
		case 116u: goto tr21;
		case 124u: goto tr21;
		case 132u: goto tr23;
		case 140u: goto tr23;
		case 148u: goto tr23;
		case 156u: goto tr23;
		case 164u: goto tr23;
		case 172u: goto tr23;
		case 180u: goto tr23;
		case 188u: goto tr23;
	}
	if ( (*p) < 64u ) {
		if ( (*p) <= 63u )
			goto tr17;
	} else if ( (*p) > 127u ) {
		if ( 128u <= (*p) && (*p) <= 191u )
			goto tr22;
	} else
		goto tr20;
	goto tr24;
tr762:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st506;
st506:
	if ( ++p == pe )
		goto _test_eof506;
case 506:
#line 25737 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 18u: goto st309;
		case 42u: goto st309;
		case 81u: goto st309;
		case 112u: goto st303;
		case 194u: goto st303;
		case 208u: goto st309;
		case 230u: goto st309;
		case 240u: goto st494;
	}
	if ( (*p) < 88u ) {
		if ( (*p) > 17u ) {
			if ( 44u <= (*p) && (*p) <= 45u )
				goto tr772;
		} else if ( (*p) >= 16u )
			goto st494;
	} else if ( (*p) > 90u ) {
		if ( (*p) > 95u ) {
			if ( 124u <= (*p) && (*p) <= 125u )
				goto st309;
		} else if ( (*p) >= 92u )
			goto st309;
	} else
		goto st309;
	goto tr33;
tr763:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st507;
st507:
	if ( ++p == pe )
		goto _test_eof507;
case 507:
#line 25773 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 43u: goto st494;
		case 80u: goto tr41;
		case 194u: goto st303;
		case 198u: goto st303;
	}
	if ( (*p) < 20u ) {
		if ( 16u <= (*p) && (*p) <= 17u )
			goto st309;
	} else if ( (*p) > 21u ) {
		if ( (*p) > 41u ) {
			if ( 81u <= (*p) && (*p) <= 95u )
				goto st309;
		} else if ( (*p) >= 40u )
			goto st309;
	} else
		goto st309;
	goto tr33;
tr764:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st508;
st508:
	if ( ++p == pe )
		goto _test_eof508;
case 508:
#line 25802 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 43u: goto st494;
		case 80u: goto tr41;
		case 81u: goto st309;
		case 126u: goto tr773;
		case 194u: goto st303;
		case 198u: goto st303;
		case 208u: goto st309;
		case 214u: goto st309;
		case 230u: goto st309;
		case 231u: goto st494;
	}
	if ( (*p) < 40u ) {
		if ( (*p) > 17u ) {
			if ( 20u <= (*p) && (*p) <= 21u )
				goto st309;
		} else if ( (*p) >= 16u )
			goto st309;
	} else if ( (*p) > 41u ) {
		if ( (*p) > 95u ) {
			if ( 124u <= (*p) && (*p) <= 127u )
				goto st309;
		} else if ( (*p) >= 84u )
			goto st309;
	} else
		goto st309;
	goto tr33;
tr773:
#line 295 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(0, OperandSize32bit);
  }
	goto st509;
tr775:
#line 298 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(0, OperandSize64bit);
  }
	goto st509;
st509:
	if ( ++p == pe )
		goto _test_eof509;
case 509:
#line 25846 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 4u: goto st275;
		case 5u: goto tr33;
		case 12u: goto st275;
		case 13u: goto tr33;
		case 20u: goto st275;
		case 21u: goto tr33;
		case 28u: goto st275;
		case 29u: goto tr33;
		case 36u: goto st275;
		case 37u: goto tr33;
		case 44u: goto st275;
		case 45u: goto tr33;
		case 52u: goto st275;
		case 53u: goto tr33;
		case 60u: goto st275;
		case 61u: goto tr33;
		case 68u: goto st8;
		case 76u: goto st8;
		case 84u: goto st8;
		case 92u: goto st8;
		case 100u: goto st8;
		case 108u: goto st8;
		case 116u: goto st8;
		case 124u: goto st8;
		case 132u: goto st9;
		case 140u: goto st9;
		case 148u: goto st9;
		case 156u: goto st9;
		case 164u: goto st9;
		case 172u: goto st9;
		case 180u: goto st9;
		case 188u: goto st9;
	}
	if ( (*p) < 64u ) {
		if ( (*p) <= 63u )
			goto tr0;
	} else if ( (*p) > 127u ) {
		if ( 128u <= (*p) && (*p) <= 191u )
			goto tr5;
	} else
		goto tr3;
	goto tr7;
tr765:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st510;
st510:
	if ( ++p == pe )
		goto _test_eof510;
case 510:
#line 25900 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 18u: goto st309;
		case 22u: goto st309;
		case 91u: goto st309;
		case 127u: goto st309;
		case 230u: goto st309;
	}
	if ( 16u <= (*p) && (*p) <= 17u )
		goto st64;
	goto tr33;
tr766:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st511;
st511:
	if ( ++p == pe )
		goto _test_eof511;
case 511:
#line 25921 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 18u: goto st309;
		case 208u: goto st309;
		case 230u: goto st309;
		case 240u: goto st494;
	}
	if ( (*p) > 17u ) {
		if ( 124u <= (*p) && (*p) <= 125u )
			goto st309;
	} else if ( (*p) >= 16u )
		goto st64;
	goto tr33;
tr767:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st512;
st512:
	if ( ++p == pe )
		goto _test_eof512;
case 512:
#line 25944 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	if ( (*p) == 42u )
		goto st309;
	goto tr33;
tr768:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st513;
st513:
	if ( ++p == pe )
		goto _test_eof513;
case 513:
#line 25958 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	if ( (*p) == 110u )
		goto st309;
	goto tr33;
tr769:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st514;
st514:
	if ( ++p == pe )
		goto _test_eof514;
case 514:
#line 25972 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	if ( (*p) == 42u )
		goto st309;
	if ( 44u <= (*p) && (*p) <= 45u )
		goto tr774;
	goto tr33;
tr770:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st515;
st515:
	if ( ++p == pe )
		goto _test_eof515;
case 515:
#line 25988 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	if ( (*p) == 126u )
		goto tr775;
	goto tr33;
tr636:
#line 235 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX2(*p);
  }
	goto st516;
st516:
	if ( ++p == pe )
		goto _test_eof516;
case 516:
#line 26002 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 0u: goto tr776;
		case 1u: goto tr777;
		case 5u: goto tr778;
		case 8u: goto tr776;
		case 9u: goto tr777;
		case 13u: goto tr778;
		case 16u: goto tr776;
		case 17u: goto tr777;
		case 21u: goto tr778;
		case 24u: goto tr776;
		case 25u: goto tr777;
		case 29u: goto tr778;
		case 32u: goto tr776;
		case 33u: goto tr777;
		case 37u: goto tr778;
		case 40u: goto tr776;
		case 41u: goto tr777;
		case 45u: goto tr778;
		case 48u: goto tr776;
		case 49u: goto tr777;
		case 53u: goto tr778;
		case 56u: goto tr776;
		case 57u: goto tr777;
		case 61u: goto tr778;
		case 64u: goto tr776;
		case 65u: goto tr777;
		case 69u: goto tr778;
		case 72u: goto tr776;
		case 73u: goto tr777;
		case 77u: goto tr778;
		case 80u: goto tr776;
		case 81u: goto tr777;
		case 85u: goto tr778;
		case 88u: goto tr776;
		case 89u: goto tr777;
		case 93u: goto tr778;
		case 96u: goto tr776;
		case 97u: goto tr777;
		case 101u: goto tr778;
		case 104u: goto tr776;
		case 105u: goto tr777;
		case 109u: goto tr778;
		case 112u: goto tr776;
		case 113u: goto tr777;
		case 117u: goto tr778;
		case 120u: goto tr776;
		case 121u: goto tr779;
		case 125u: goto tr780;
		case 128u: goto tr781;
		case 129u: goto tr782;
		case 133u: goto tr783;
		case 136u: goto tr781;
		case 137u: goto tr782;
		case 141u: goto tr783;
		case 144u: goto tr781;
		case 145u: goto tr782;
		case 149u: goto tr783;
		case 152u: goto tr781;
		case 153u: goto tr782;
		case 157u: goto tr783;
		case 160u: goto tr781;
		case 161u: goto tr782;
		case 165u: goto tr783;
		case 168u: goto tr781;
		case 169u: goto tr782;
		case 173u: goto tr783;
		case 176u: goto tr781;
		case 177u: goto tr782;
		case 181u: goto tr783;
		case 184u: goto tr781;
		case 185u: goto tr782;
		case 189u: goto tr783;
		case 192u: goto tr781;
		case 193u: goto tr782;
		case 197u: goto tr783;
		case 200u: goto tr781;
		case 201u: goto tr782;
		case 205u: goto tr783;
		case 208u: goto tr781;
		case 209u: goto tr782;
		case 213u: goto tr783;
		case 216u: goto tr781;
		case 217u: goto tr782;
		case 221u: goto tr783;
		case 224u: goto tr781;
		case 225u: goto tr782;
		case 229u: goto tr783;
		case 232u: goto tr781;
		case 233u: goto tr782;
		case 237u: goto tr783;
		case 240u: goto tr781;
		case 241u: goto tr782;
		case 245u: goto tr783;
		case 248u: goto tr781;
		case 249u: goto tr782;
		case 253u: goto tr783;
	}
	goto tr33;
tr776:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st517;
st517:
	if ( ++p == pe )
		goto _test_eof517;
case 517:
#line 26112 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 242u: goto tr772;
		case 247u: goto tr772;
	}
	goto tr33;
tr777:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st518;
st518:
	if ( ++p == pe )
		goto _test_eof518;
case 518:
#line 26128 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	if ( (*p) == 43u )
		goto st309;
	if ( (*p) < 55u ) {
		if ( (*p) < 40u ) {
			if ( (*p) <= 13u )
				goto st309;
		} else if ( (*p) > 41u ) {
			if ( 44u <= (*p) && (*p) <= 47u )
				goto st494;
		} else
			goto st309;
	} else if ( (*p) > 64u ) {
		if ( (*p) < 166u ) {
			if ( 150u <= (*p) && (*p) <= 159u )
				goto st309;
		} else if ( (*p) > 175u ) {
			if ( (*p) > 191u ) {
				if ( 219u <= (*p) && (*p) <= 223u )
					goto st309;
			} else if ( (*p) >= 182u )
				goto st309;
		} else
			goto st309;
	} else
		goto st309;
	goto tr33;
tr778:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st519;
st519:
	if ( ++p == pe )
		goto _test_eof519;
case 519:
#line 26165 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 154u: goto st309;
		case 156u: goto st309;
		case 158u: goto st309;
		case 170u: goto st309;
		case 172u: goto st309;
		case 174u: goto st309;
		case 186u: goto st309;
		case 188u: goto st309;
		case 190u: goto st309;
	}
	if ( (*p) < 150u ) {
		if ( (*p) > 13u ) {
			if ( 44u <= (*p) && (*p) <= 47u )
				goto st494;
		} else if ( (*p) >= 12u )
			goto st309;
	} else if ( (*p) > 152u ) {
		if ( (*p) > 168u ) {
			if ( 182u <= (*p) && (*p) <= 184u )
				goto st309;
		} else if ( (*p) >= 166u )
			goto st309;
	} else
		goto st309;
	goto tr33;
tr779:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st520;
st520:
	if ( ++p == pe )
		goto _test_eof520;
case 520:
#line 26202 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 19u: goto st309;
		case 23u: goto st309;
		case 24u: goto st494;
		case 42u: goto st494;
	}
	if ( (*p) < 48u ) {
		if ( (*p) < 32u ) {
			if ( (*p) > 15u ) {
				if ( 28u <= (*p) && (*p) <= 30u )
					goto st309;
			} else
				goto st309;
		} else if ( (*p) > 37u ) {
			if ( (*p) > 43u ) {
				if ( 44u <= (*p) && (*p) <= 47u )
					goto st494;
			} else if ( (*p) >= 40u )
				goto st309;
		} else
			goto st309;
	} else if ( (*p) > 53u ) {
		if ( (*p) < 166u ) {
			if ( (*p) > 65u ) {
				if ( 150u <= (*p) && (*p) <= 159u )
					goto st309;
			} else if ( (*p) >= 55u )
				goto st309;
		} else if ( (*p) > 175u ) {
			if ( (*p) > 191u ) {
				if ( 219u <= (*p) && (*p) <= 223u )
					goto st309;
			} else if ( (*p) >= 182u )
				goto st309;
		} else
			goto st309;
	} else
		goto st309;
	goto tr33;
tr780:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st521;
st521:
	if ( ++p == pe )
		goto _test_eof521;
case 521:
#line 26252 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 19u: goto st309;
		case 23u: goto st309;
		case 154u: goto st309;
		case 156u: goto st309;
		case 158u: goto st309;
		case 170u: goto st309;
		case 172u: goto st309;
		case 174u: goto st309;
		case 186u: goto st309;
		case 188u: goto st309;
		case 190u: goto st309;
	}
	if ( (*p) < 44u ) {
		if ( (*p) > 15u ) {
			if ( 24u <= (*p) && (*p) <= 26u )
				goto st494;
		} else if ( (*p) >= 12u )
			goto st309;
	} else if ( (*p) > 47u ) {
		if ( (*p) < 166u ) {
			if ( 150u <= (*p) && (*p) <= 152u )
				goto st309;
		} else if ( (*p) > 168u ) {
			if ( 182u <= (*p) && (*p) <= 184u )
				goto st309;
		} else
			goto st309;
	} else
		goto st494;
	goto tr33;
tr781:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st522;
st522:
	if ( ++p == pe )
		goto _test_eof522;
case 522:
#line 26294 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 242u: goto tr774;
		case 247u: goto tr774;
	}
	goto tr33;
tr782:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st523;
st523:
	if ( ++p == pe )
		goto _test_eof523;
case 523:
#line 26310 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	if ( (*p) < 166u ) {
		if ( 150u <= (*p) && (*p) <= 159u )
			goto st309;
	} else if ( (*p) > 175u ) {
		if ( 182u <= (*p) && (*p) <= 191u )
			goto st309;
	} else
		goto st309;
	goto tr33;
tr783:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st524;
st524:
	if ( ++p == pe )
		goto _test_eof524;
case 524:
#line 26330 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 154u: goto st309;
		case 156u: goto st309;
		case 158u: goto st309;
		case 170u: goto st309;
		case 172u: goto st309;
		case 174u: goto st309;
		case 186u: goto st309;
		case 188u: goto st309;
		case 190u: goto st309;
	}
	if ( (*p) < 166u ) {
		if ( 150u <= (*p) && (*p) <= 152u )
			goto st309;
	} else if ( (*p) > 168u ) {
		if ( 182u <= (*p) && (*p) <= 184u )
			goto st309;
	} else
		goto st309;
	goto tr33;
tr637:
#line 235 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX2(*p);
  }
	goto st525;
st525:
	if ( ++p == pe )
		goto _test_eof525;
case 525:
#line 26361 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 1u: goto tr784;
		case 5u: goto tr785;
		case 9u: goto tr784;
		case 13u: goto tr785;
		case 17u: goto tr784;
		case 21u: goto tr785;
		case 25u: goto tr784;
		case 29u: goto tr785;
		case 33u: goto tr784;
		case 37u: goto tr785;
		case 41u: goto tr784;
		case 45u: goto tr785;
		case 49u: goto tr784;
		case 53u: goto tr785;
		case 57u: goto tr784;
		case 61u: goto tr785;
		case 65u: goto tr784;
		case 69u: goto tr785;
		case 73u: goto tr784;
		case 77u: goto tr785;
		case 81u: goto tr784;
		case 85u: goto tr785;
		case 89u: goto tr784;
		case 93u: goto tr785;
		case 97u: goto tr784;
		case 101u: goto tr785;
		case 105u: goto tr784;
		case 109u: goto tr785;
		case 113u: goto tr784;
		case 117u: goto tr785;
		case 121u: goto tr786;
		case 125u: goto tr787;
		case 129u: goto tr788;
		case 133u: goto tr789;
		case 137u: goto tr788;
		case 141u: goto tr789;
		case 145u: goto tr788;
		case 149u: goto tr789;
		case 153u: goto tr788;
		case 157u: goto tr789;
		case 161u: goto tr788;
		case 165u: goto tr789;
		case 169u: goto tr788;
		case 173u: goto tr789;
		case 177u: goto tr788;
		case 181u: goto tr789;
		case 185u: goto tr788;
		case 189u: goto tr789;
		case 193u: goto tr788;
		case 197u: goto tr789;
		case 201u: goto tr788;
		case 205u: goto tr789;
		case 209u: goto tr788;
		case 213u: goto tr789;
		case 217u: goto tr788;
		case 221u: goto tr789;
		case 225u: goto tr788;
		case 229u: goto tr789;
		case 233u: goto tr788;
		case 237u: goto tr789;
		case 241u: goto tr788;
		case 245u: goto tr789;
		case 249u: goto tr790;
		case 253u: goto tr789;
	}
	goto tr33;
tr784:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st526;
st526:
	if ( ++p == pe )
		goto _test_eof526;
case 526:
#line 26439 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 33u: goto st303;
		case 68u: goto st303;
		case 223u: goto st303;
	}
	if ( (*p) < 74u ) {
		if ( (*p) < 64u ) {
			if ( 8u <= (*p) && (*p) <= 15u )
				goto st303;
		} else if ( (*p) > 66u ) {
			if ( 72u <= (*p) && (*p) <= 73u )
				goto st527;
		} else
			goto st303;
	} else if ( (*p) > 76u ) {
		if ( (*p) < 104u ) {
			if ( 92u <= (*p) && (*p) <= 95u )
				goto st302;
		} else if ( (*p) > 111u ) {
			if ( 120u <= (*p) && (*p) <= 127u )
				goto st302;
		} else
			goto st302;
	} else
		goto st302;
	goto tr33;
st527:
	if ( ++p == pe )
		goto _test_eof527;
case 527:
	switch( (*p) ) {
		case 4u: goto st432;
		case 5u: goto tr33;
		case 12u: goto st432;
		case 13u: goto tr33;
		case 20u: goto st432;
		case 21u: goto tr33;
		case 28u: goto st432;
		case 29u: goto tr33;
		case 36u: goto st432;
		case 37u: goto tr33;
		case 44u: goto st432;
		case 45u: goto tr33;
		case 52u: goto st432;
		case 53u: goto tr33;
		case 60u: goto st432;
		case 61u: goto tr33;
		case 68u: goto st434;
		case 76u: goto st434;
		case 84u: goto st434;
		case 92u: goto st434;
		case 100u: goto st434;
		case 108u: goto st434;
		case 116u: goto st434;
		case 124u: goto st434;
		case 132u: goto st436;
		case 140u: goto st436;
		case 148u: goto st436;
		case 156u: goto st436;
		case 164u: goto st436;
		case 172u: goto st436;
		case 180u: goto st436;
		case 188u: goto st436;
	}
	if ( (*p) < 64u ) {
		if ( (*p) <= 63u )
			goto tr792;
	} else if ( (*p) > 127u ) {
		if ( 128u <= (*p) && (*p) <= 191u )
			goto tr794;
	} else
		goto tr793;
	goto st433;
tr785:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st528;
st528:
	if ( ++p == pe )
		goto _test_eof528;
case 528:
#line 26523 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 6u: goto st303;
		case 64u: goto st303;
	}
	if ( (*p) < 92u ) {
		if ( (*p) < 12u ) {
			if ( 8u <= (*p) && (*p) <= 9u )
				goto st303;
		} else if ( (*p) > 13u ) {
			if ( (*p) > 73u ) {
				if ( 74u <= (*p) && (*p) <= 75u )
					goto st302;
			} else if ( (*p) >= 72u )
				goto st527;
		} else
			goto st303;
	} else if ( (*p) > 95u ) {
		if ( (*p) < 108u ) {
			if ( 104u <= (*p) && (*p) <= 105u )
				goto st302;
		} else if ( (*p) > 109u ) {
			if ( (*p) > 121u ) {
				if ( 124u <= (*p) && (*p) <= 125u )
					goto st302;
			} else if ( (*p) >= 120u )
				goto st302;
		} else
			goto st302;
	} else
		goto st302;
	goto tr33;
tr786:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st529;
st529:
	if ( ++p == pe )
		goto _test_eof529;
case 529:
#line 26565 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 22u: goto tr796;
		case 23u: goto st532;
		case 29u: goto st303;
		case 68u: goto st303;
		case 223u: goto st303;
	}
	if ( (*p) < 72u ) {
		if ( (*p) < 20u ) {
			if ( (*p) > 5u ) {
				if ( 8u <= (*p) && (*p) <= 15u )
					goto st303;
			} else if ( (*p) >= 4u )
				goto st303;
		} else if ( (*p) > 21u ) {
			if ( (*p) > 34u ) {
				if ( 64u <= (*p) && (*p) <= 66u )
					goto st303;
			} else if ( (*p) >= 32u )
				goto st303;
		} else
			goto st530;
	} else if ( (*p) > 73u ) {
		if ( (*p) < 96u ) {
			if ( (*p) > 76u ) {
				if ( 92u <= (*p) && (*p) <= 95u )
					goto st302;
			} else if ( (*p) >= 74u )
				goto st302;
		} else if ( (*p) > 99u ) {
			if ( (*p) > 111u ) {
				if ( 120u <= (*p) && (*p) <= 127u )
					goto st302;
			} else if ( (*p) >= 104u )
				goto st302;
		} else
			goto st303;
	} else
		goto st527;
	goto tr33;
st530:
	if ( ++p == pe )
		goto _test_eof530;
case 530:
	switch( (*p) ) {
		case 4u: goto st268;
		case 5u: goto tr33;
		case 12u: goto st268;
		case 13u: goto tr33;
		case 20u: goto st268;
		case 21u: goto tr33;
		case 28u: goto st268;
		case 29u: goto tr33;
		case 36u: goto st268;
		case 37u: goto tr33;
		case 44u: goto st268;
		case 45u: goto tr33;
		case 52u: goto st268;
		case 53u: goto tr33;
		case 60u: goto st268;
		case 61u: goto tr33;
		case 68u: goto st50;
		case 76u: goto st50;
		case 84u: goto st50;
		case 92u: goto st50;
		case 100u: goto st50;
		case 108u: goto st50;
		case 116u: goto st50;
		case 124u: goto st50;
		case 132u: goto st51;
		case 140u: goto st51;
		case 148u: goto st51;
		case 156u: goto st51;
		case 164u: goto st51;
		case 172u: goto st51;
		case 180u: goto st51;
		case 188u: goto st51;
	}
	if ( (*p) < 64u ) {
		if ( (*p) <= 63u )
			goto tr93;
	} else if ( (*p) > 127u ) {
		if ( 128u <= (*p) && (*p) <= 191u )
			goto tr98;
	} else
		goto tr96;
	goto tr115;
tr796:
#line 295 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(0, OperandSize32bit);
  }
	goto st531;
tr798:
#line 298 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(0, OperandSize64bit);
  }
	goto st531;
st531:
	if ( ++p == pe )
		goto _test_eof531;
case 531:
#line 26669 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 4u: goto st268;
		case 5u: goto tr33;
		case 12u: goto st268;
		case 13u: goto tr33;
		case 20u: goto st268;
		case 21u: goto tr33;
		case 28u: goto st268;
		case 29u: goto tr33;
		case 36u: goto st268;
		case 37u: goto tr33;
		case 44u: goto st268;
		case 45u: goto tr33;
		case 52u: goto st268;
		case 53u: goto tr33;
		case 60u: goto st268;
		case 61u: goto tr33;
		case 68u: goto st50;
		case 76u: goto st50;
		case 84u: goto st50;
		case 92u: goto st50;
		case 100u: goto st50;
		case 108u: goto st50;
		case 116u: goto st50;
		case 124u: goto st50;
		case 132u: goto st51;
		case 140u: goto st51;
		case 148u: goto st51;
		case 156u: goto st51;
		case 164u: goto st51;
		case 172u: goto st51;
		case 180u: goto st51;
		case 188u: goto st51;
	}
	if ( (*p) < 64u ) {
		if ( (*p) <= 63u )
			goto tr93;
	} else if ( (*p) > 127u ) {
		if ( 128u <= (*p) && (*p) <= 191u )
			goto tr98;
	} else
		goto tr96;
	goto tr114;
st532:
	if ( ++p == pe )
		goto _test_eof532;
case 532:
	switch( (*p) ) {
		case 4u: goto st268;
		case 12u: goto st268;
		case 20u: goto st268;
		case 28u: goto st268;
		case 36u: goto st268;
		case 44u: goto st268;
		case 52u: goto st268;
		case 60u: goto st268;
		case 68u: goto st50;
		case 76u: goto st50;
		case 84u: goto st50;
		case 92u: goto st50;
		case 100u: goto st50;
		case 108u: goto st50;
		case 116u: goto st50;
		case 124u: goto st50;
		case 132u: goto st51;
		case 140u: goto st51;
		case 148u: goto st51;
		case 156u: goto st51;
		case 164u: goto st51;
		case 172u: goto st51;
		case 180u: goto st51;
		case 188u: goto st51;
	}
	if ( (*p) < 38u ) {
		if ( (*p) < 14u ) {
			if ( (*p) > 3u ) {
				if ( 6u <= (*p) && (*p) <= 11u )
					goto tr93;
			} else
				goto tr93;
		} else if ( (*p) > 19u ) {
			if ( (*p) > 27u ) {
				if ( 30u <= (*p) && (*p) <= 35u )
					goto tr93;
			} else if ( (*p) >= 22u )
				goto tr93;
		} else
			goto tr93;
	} else if ( (*p) > 43u ) {
		if ( (*p) < 62u ) {
			if ( (*p) > 51u ) {
				if ( 54u <= (*p) && (*p) <= 59u )
					goto tr93;
			} else if ( (*p) >= 46u )
				goto tr93;
		} else if ( (*p) > 63u ) {
			if ( (*p) > 127u ) {
				if ( 128u <= (*p) && (*p) <= 191u )
					goto tr98;
			} else if ( (*p) >= 64u )
				goto tr96;
		} else
			goto tr93;
	} else
		goto tr93;
	goto tr33;
tr787:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st533;
st533:
	if ( ++p == pe )
		goto _test_eof533;
case 533:
#line 26786 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 29u: goto st303;
		case 64u: goto st303;
	}
	if ( (*p) < 74u ) {
		if ( (*p) < 12u ) {
			if ( (*p) > 6u ) {
				if ( 8u <= (*p) && (*p) <= 9u )
					goto st303;
			} else if ( (*p) >= 4u )
				goto st303;
		} else if ( (*p) > 13u ) {
			if ( (*p) > 25u ) {
				if ( 72u <= (*p) && (*p) <= 73u )
					goto st527;
			} else if ( (*p) >= 24u )
				goto st303;
		} else
			goto st303;
	} else if ( (*p) > 75u ) {
		if ( (*p) < 108u ) {
			if ( (*p) > 95u ) {
				if ( 104u <= (*p) && (*p) <= 105u )
					goto st302;
			} else if ( (*p) >= 92u )
				goto st302;
		} else if ( (*p) > 109u ) {
			if ( (*p) > 121u ) {
				if ( 124u <= (*p) && (*p) <= 125u )
					goto st302;
			} else if ( (*p) >= 120u )
				goto st302;
		} else
			goto st302;
	} else
		goto st302;
	goto tr33;
tr788:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st534;
st534:
	if ( ++p == pe )
		goto _test_eof534;
case 534:
#line 26834 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	if ( (*p) < 92u ) {
		if ( 72u <= (*p) && (*p) <= 73u )
			goto st527;
	} else if ( (*p) > 95u ) {
		if ( (*p) > 111u ) {
			if ( 120u <= (*p) && (*p) <= 127u )
				goto st302;
		} else if ( (*p) >= 104u )
			goto st302;
	} else
		goto st302;
	goto tr33;
tr789:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st535;
st535:
	if ( ++p == pe )
		goto _test_eof535;
case 535:
#line 26857 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	if ( (*p) < 104u ) {
		if ( (*p) > 73u ) {
			if ( 92u <= (*p) && (*p) <= 95u )
				goto st302;
		} else if ( (*p) >= 72u )
			goto st527;
	} else if ( (*p) > 105u ) {
		if ( (*p) < 120u ) {
			if ( 108u <= (*p) && (*p) <= 109u )
				goto st302;
		} else if ( (*p) > 121u ) {
			if ( 124u <= (*p) && (*p) <= 125u )
				goto st302;
		} else
			goto st302;
	} else
		goto st302;
	goto tr33;
tr790:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st536;
st536:
	if ( ++p == pe )
		goto _test_eof536;
case 536:
#line 26886 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 22u: goto tr798;
		case 34u: goto st303;
	}
	if ( (*p) < 92u ) {
		if ( 72u <= (*p) && (*p) <= 73u )
			goto st527;
	} else if ( (*p) > 95u ) {
		if ( (*p) > 111u ) {
			if ( 120u <= (*p) && (*p) <= 127u )
				goto st302;
		} else if ( (*p) >= 104u )
			goto st302;
	} else
		goto st302;
	goto tr33;
tr638:
#line 235 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX2(*p);
  }
	goto st537;
st537:
	if ( ++p == pe )
		goto _test_eof537;
case 537:
#line 26913 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 1u: goto tr800;
		case 2u: goto tr801;
		case 3u: goto tr802;
		case 4u: goto tr803;
		case 5u: goto tr804;
		case 6u: goto tr757;
		case 7u: goto tr805;
		case 9u: goto tr800;
		case 10u: goto tr801;
		case 11u: goto tr802;
		case 12u: goto tr803;
		case 13u: goto tr804;
		case 14u: goto tr757;
		case 15u: goto tr805;
		case 17u: goto tr800;
		case 18u: goto tr801;
		case 19u: goto tr802;
		case 20u: goto tr803;
		case 21u: goto tr804;
		case 22u: goto tr757;
		case 23u: goto tr805;
		case 25u: goto tr800;
		case 26u: goto tr801;
		case 27u: goto tr802;
		case 28u: goto tr803;
		case 29u: goto tr804;
		case 30u: goto tr757;
		case 31u: goto tr805;
		case 33u: goto tr800;
		case 34u: goto tr801;
		case 35u: goto tr802;
		case 36u: goto tr803;
		case 37u: goto tr804;
		case 38u: goto tr757;
		case 39u: goto tr805;
		case 41u: goto tr800;
		case 42u: goto tr801;
		case 43u: goto tr802;
		case 44u: goto tr803;
		case 45u: goto tr804;
		case 46u: goto tr757;
		case 47u: goto tr805;
		case 49u: goto tr800;
		case 50u: goto tr801;
		case 51u: goto tr802;
		case 52u: goto tr803;
		case 53u: goto tr804;
		case 54u: goto tr757;
		case 55u: goto tr805;
		case 57u: goto tr800;
		case 58u: goto tr801;
		case 59u: goto tr802;
		case 60u: goto tr803;
		case 61u: goto tr804;
		case 62u: goto tr757;
		case 63u: goto tr805;
		case 65u: goto tr800;
		case 66u: goto tr801;
		case 67u: goto tr802;
		case 68u: goto tr803;
		case 69u: goto tr804;
		case 70u: goto tr757;
		case 71u: goto tr805;
		case 73u: goto tr800;
		case 74u: goto tr801;
		case 75u: goto tr802;
		case 76u: goto tr803;
		case 77u: goto tr804;
		case 78u: goto tr757;
		case 79u: goto tr805;
		case 81u: goto tr800;
		case 82u: goto tr801;
		case 83u: goto tr802;
		case 84u: goto tr803;
		case 85u: goto tr804;
		case 86u: goto tr757;
		case 87u: goto tr805;
		case 89u: goto tr800;
		case 90u: goto tr801;
		case 91u: goto tr802;
		case 92u: goto tr803;
		case 93u: goto tr804;
		case 94u: goto tr757;
		case 95u: goto tr805;
		case 97u: goto tr800;
		case 98u: goto tr801;
		case 99u: goto tr802;
		case 100u: goto tr803;
		case 101u: goto tr804;
		case 102u: goto tr757;
		case 103u: goto tr805;
		case 105u: goto tr800;
		case 106u: goto tr801;
		case 107u: goto tr802;
		case 108u: goto tr803;
		case 109u: goto tr804;
		case 110u: goto tr757;
		case 111u: goto tr805;
		case 113u: goto tr800;
		case 114u: goto tr801;
		case 115u: goto tr802;
		case 116u: goto tr803;
		case 117u: goto tr804;
		case 118u: goto tr757;
		case 119u: goto tr805;
		case 120u: goto tr806;
		case 121u: goto tr807;
		case 122u: goto tr808;
		case 123u: goto tr809;
		case 124u: goto tr810;
		case 125u: goto tr811;
		case 126u: goto tr812;
		case 127u: goto tr813;
		case 249u: goto tr815;
		case 253u: goto tr817;
	}
	if ( (*p) < 186u ) {
		if ( (*p) < 146u ) {
			if ( (*p) < 130u ) {
				if ( (*p) <= 112u )
					goto tr799;
			} else if ( (*p) > 131u ) {
				if ( 138u <= (*p) && (*p) <= 139u )
					goto tr814;
			} else
				goto tr814;
		} else if ( (*p) > 147u ) {
			if ( (*p) < 162u ) {
				if ( 154u <= (*p) && (*p) <= 155u )
					goto tr814;
			} else if ( (*p) > 163u ) {
				if ( (*p) > 171u ) {
					if ( 178u <= (*p) && (*p) <= 179u )
						goto tr814;
				} else if ( (*p) >= 170u )
					goto tr814;
			} else
				goto tr814;
		} else
			goto tr814;
	} else if ( (*p) > 187u ) {
		if ( (*p) < 218u ) {
			if ( (*p) < 202u ) {
				if ( 194u <= (*p) && (*p) <= 195u )
					goto tr814;
			} else if ( (*p) > 203u ) {
				if ( 210u <= (*p) && (*p) <= 211u )
					goto tr814;
			} else
				goto tr814;
		} else if ( (*p) > 219u ) {
			if ( (*p) < 234u ) {
				if ( 226u <= (*p) && (*p) <= 227u )
					goto tr814;
			} else if ( (*p) > 235u ) {
				if ( (*p) > 243u ) {
					if ( 250u <= (*p) && (*p) <= 251u )
						goto tr816;
				} else if ( (*p) >= 242u )
					goto tr814;
			} else
				goto tr814;
		} else
			goto tr814;
	} else
		goto tr814;
	goto tr33;
tr799:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st538;
tr866:
#line 243 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    /* This emulates two prefixes case. */
    SET_VEX_PREFIX2((p[0] & 0x80) | 0x61);
    SET_VEX_PREFIX3(p[0] & 0x7f);
  }
	goto st538;
st538:
	if ( ++p == pe )
		goto _test_eof538;
case 538:
#line 27100 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 18u: goto st38;
		case 23u: goto st39;
		case 81u: goto st38;
		case 194u: goto st43;
		case 198u: goto st43;
	}
	if ( (*p) < 46u ) {
		if ( 20u <= (*p) && (*p) <= 22u )
			goto st38;
	} else if ( (*p) > 47u ) {
		if ( (*p) > 89u ) {
			if ( 92u <= (*p) && (*p) <= 95u )
				goto st38;
		} else if ( (*p) >= 84u )
			goto st38;
	} else
		goto st38;
	goto tr33;
tr800:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st539;
tr867:
#line 243 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    /* This emulates two prefixes case. */
    SET_VEX_PREFIX2((p[0] & 0x80) | 0x61);
    SET_VEX_PREFIX3(p[0] & 0x7f);
  }
	goto st539;
st539:
	if ( ++p == pe )
		goto _test_eof539;
case 539:
#line 27138 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 18u: goto st39;
		case 81u: goto st38;
		case 194u: goto st43;
		case 198u: goto st43;
	}
	if ( (*p) < 116u ) {
		if ( (*p) < 46u ) {
			if ( (*p) > 21u ) {
				if ( 22u <= (*p) && (*p) <= 23u )
					goto st39;
			} else if ( (*p) >= 20u )
				goto st38;
		} else if ( (*p) > 47u ) {
			if ( (*p) > 89u ) {
				if ( 92u <= (*p) && (*p) <= 109u )
					goto st38;
			} else if ( (*p) >= 84u )
				goto st38;
		} else
			goto st38;
	} else if ( (*p) > 118u ) {
		if ( (*p) < 216u ) {
			if ( (*p) > 125u ) {
				if ( 208u <= (*p) && (*p) <= 213u )
					goto st38;
			} else if ( (*p) >= 124u )
				goto st38;
		} else if ( (*p) > 229u ) {
			if ( (*p) < 241u ) {
				if ( 232u <= (*p) && (*p) <= 239u )
					goto st38;
			} else if ( (*p) > 246u ) {
				if ( 248u <= (*p) && (*p) <= 254u )
					goto st38;
			} else
				goto st38;
		} else
			goto st38;
	} else
		goto st38;
	goto tr33;
tr801:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st540;
st540:
	if ( ++p == pe )
		goto _test_eof540;
case 540:
#line 27191 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 42u: goto st38;
		case 81u: goto st38;
		case 83u: goto st38;
		case 194u: goto st43;
	}
	if ( (*p) > 90u ) {
		if ( 92u <= (*p) && (*p) <= 95u )
			goto st38;
	} else if ( (*p) >= 88u )
		goto st38;
	goto tr33;
tr802:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st541;
st541:
	if ( ++p == pe )
		goto _test_eof541;
case 541:
#line 27214 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 42u: goto st38;
		case 81u: goto st38;
		case 194u: goto st43;
		case 208u: goto st38;
	}
	if ( (*p) < 92u ) {
		if ( 88u <= (*p) && (*p) <= 90u )
			goto st38;
	} else if ( (*p) > 95u ) {
		if ( 124u <= (*p) && (*p) <= 125u )
			goto st38;
	} else
		goto st38;
	goto tr33;
tr803:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st542;
tr870:
#line 243 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    /* This emulates two prefixes case. */
    SET_VEX_PREFIX2((p[0] & 0x80) | 0x61);
    SET_VEX_PREFIX3(p[0] & 0x7f);
  }
	goto st542;
st542:
	if ( ++p == pe )
		goto _test_eof542;
case 542:
#line 27248 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 81u: goto st38;
		case 194u: goto st43;
		case 198u: goto st43;
	}
	if ( (*p) < 84u ) {
		if ( 20u <= (*p) && (*p) <= 21u )
			goto st38;
	} else if ( (*p) > 89u ) {
		if ( 92u <= (*p) && (*p) <= 95u )
			goto st38;
	} else
		goto st38;
	goto tr33;
tr804:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st543;
tr871:
#line 243 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    /* This emulates two prefixes case. */
    SET_VEX_PREFIX2((p[0] & 0x80) | 0x61);
    SET_VEX_PREFIX3(p[0] & 0x7f);
  }
	goto st543;
st543:
	if ( ++p == pe )
		goto _test_eof543;
case 543:
#line 27281 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 81u: goto st38;
		case 194u: goto st43;
		case 198u: goto st43;
		case 208u: goto st38;
	}
	if ( (*p) < 84u ) {
		if ( 20u <= (*p) && (*p) <= 21u )
			goto st38;
	} else if ( (*p) > 89u ) {
		if ( (*p) > 95u ) {
			if ( 124u <= (*p) && (*p) <= 125u )
				goto st38;
		} else if ( (*p) >= 92u )
			goto st38;
	} else
		goto st38;
	goto tr33;
tr805:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st544;
tr873:
#line 243 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    /* This emulates two prefixes case. */
    SET_VEX_PREFIX2((p[0] & 0x80) | 0x61);
    SET_VEX_PREFIX3(p[0] & 0x7f);
  }
	goto st544;
st544:
	if ( ++p == pe )
		goto _test_eof544;
case 544:
#line 27318 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	if ( (*p) == 208u )
		goto st38;
	if ( (*p) > 17u ) {
		if ( 124u <= (*p) && (*p) <= 125u )
			goto st38;
	} else if ( (*p) >= 16u )
		goto st64;
	goto tr33;
tr806:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st545;
tr874:
#line 243 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    /* This emulates two prefixes case. */
    SET_VEX_PREFIX2((p[0] & 0x80) | 0x61);
    SET_VEX_PREFIX3(p[0] & 0x7f);
  }
	goto st545;
st545:
	if ( ++p == pe )
		goto _test_eof545;
case 545:
#line 27345 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 19u: goto st39;
		case 23u: goto st39;
		case 43u: goto st39;
		case 80u: goto tr41;
		case 194u: goto st43;
		case 198u: goto st43;
	}
	if ( (*p) < 40u ) {
		if ( 16u <= (*p) && (*p) <= 22u )
			goto st38;
	} else if ( (*p) > 41u ) {
		if ( (*p) > 47u ) {
			if ( 81u <= (*p) && (*p) <= 95u )
				goto st38;
		} else if ( (*p) >= 46u )
			goto st38;
	} else
		goto st38;
	goto tr33;
tr807:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st546;
tr875:
#line 243 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    /* This emulates two prefixes case. */
    SET_VEX_PREFIX2((p[0] & 0x80) | 0x61);
    SET_VEX_PREFIX3(p[0] & 0x7f);
  }
	goto st546;
st546:
	if ( ++p == pe )
		goto _test_eof546;
case 546:
#line 27384 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 43u: goto st39;
		case 80u: goto tr41;
		case 81u: goto st38;
		case 112u: goto st43;
		case 127u: goto st38;
		case 194u: goto st43;
		case 197u: goto tr52;
		case 215u: goto tr41;
		case 231u: goto st39;
		case 247u: goto st64;
	}
	if ( (*p) < 84u ) {
		if ( (*p) < 20u ) {
			if ( (*p) > 17u ) {
				if ( 18u <= (*p) && (*p) <= 19u )
					goto st39;
			} else if ( (*p) >= 16u )
				goto st38;
		} else if ( (*p) > 21u ) {
			if ( (*p) < 40u ) {
				if ( 22u <= (*p) && (*p) <= 23u )
					goto st39;
			} else if ( (*p) > 41u ) {
				if ( 46u <= (*p) && (*p) <= 47u )
					goto st38;
			} else
				goto st38;
		} else
			goto st38;
	} else if ( (*p) > 111u ) {
		if ( (*p) < 196u ) {
			if ( (*p) > 118u ) {
				if ( 124u <= (*p) && (*p) <= 125u )
					goto st38;
			} else if ( (*p) >= 116u )
				goto st38;
		} else if ( (*p) > 198u ) {
			if ( (*p) < 216u ) {
				if ( 208u <= (*p) && (*p) <= 213u )
					goto st38;
			} else if ( (*p) > 239u ) {
				if ( 241u <= (*p) && (*p) <= 254u )
					goto st38;
			} else
				goto st38;
		} else
			goto st43;
	} else
		goto st38;
	goto tr33;
tr808:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st547;
st547:
	if ( ++p == pe )
		goto _test_eof547;
case 547:
#line 27446 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 18u: goto st38;
		case 22u: goto st38;
		case 42u: goto st38;
		case 111u: goto st38;
		case 112u: goto st43;
		case 194u: goto st43;
		case 230u: goto st38;
	}
	if ( (*p) < 81u ) {
		if ( (*p) > 17u ) {
			if ( 44u <= (*p) && (*p) <= 45u )
				goto tr32;
		} else if ( (*p) >= 16u )
			goto st39;
	} else if ( (*p) > 83u ) {
		if ( (*p) > 95u ) {
			if ( 126u <= (*p) && (*p) <= 127u )
				goto st38;
		} else if ( (*p) >= 88u )
			goto st38;
	} else
		goto st38;
	goto tr33;
tr809:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st548;
st548:
	if ( ++p == pe )
		goto _test_eof548;
case 548:
#line 27481 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 18u: goto st38;
		case 42u: goto st38;
		case 81u: goto st38;
		case 112u: goto st43;
		case 194u: goto st43;
		case 208u: goto st38;
		case 230u: goto st38;
		case 240u: goto st39;
	}
	if ( (*p) < 88u ) {
		if ( (*p) > 17u ) {
			if ( 44u <= (*p) && (*p) <= 45u )
				goto tr32;
		} else if ( (*p) >= 16u )
			goto st39;
	} else if ( (*p) > 90u ) {
		if ( (*p) > 95u ) {
			if ( 124u <= (*p) && (*p) <= 125u )
				goto st38;
		} else if ( (*p) >= 92u )
			goto st38;
	} else
		goto st38;
	goto tr33;
tr810:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st549;
tr878:
#line 243 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    /* This emulates two prefixes case. */
    SET_VEX_PREFIX2((p[0] & 0x80) | 0x61);
    SET_VEX_PREFIX3(p[0] & 0x7f);
  }
	goto st549;
st549:
	if ( ++p == pe )
		goto _test_eof549;
case 549:
#line 27525 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 43u: goto st39;
		case 80u: goto tr41;
		case 194u: goto st43;
		case 198u: goto st43;
	}
	if ( (*p) < 20u ) {
		if ( 16u <= (*p) && (*p) <= 17u )
			goto st38;
	} else if ( (*p) > 21u ) {
		if ( (*p) > 41u ) {
			if ( 81u <= (*p) && (*p) <= 95u )
				goto st38;
		} else if ( (*p) >= 40u )
			goto st38;
	} else
		goto st38;
	goto tr33;
tr811:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st550;
tr879:
#line 243 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    /* This emulates two prefixes case. */
    SET_VEX_PREFIX2((p[0] & 0x80) | 0x61);
    SET_VEX_PREFIX3(p[0] & 0x7f);
  }
	goto st550;
st550:
	if ( ++p == pe )
		goto _test_eof550;
case 550:
#line 27562 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 43u: goto st39;
		case 80u: goto tr41;
		case 81u: goto st38;
		case 126u: goto tr45;
		case 194u: goto st43;
		case 198u: goto st43;
		case 208u: goto st38;
		case 214u: goto st38;
		case 230u: goto st38;
		case 231u: goto st39;
	}
	if ( (*p) < 40u ) {
		if ( (*p) > 17u ) {
			if ( 20u <= (*p) && (*p) <= 21u )
				goto st38;
		} else if ( (*p) >= 16u )
			goto st38;
	} else if ( (*p) > 41u ) {
		if ( (*p) > 95u ) {
			if ( 124u <= (*p) && (*p) <= 127u )
				goto st38;
		} else if ( (*p) >= 84u )
			goto st38;
	} else
		goto st38;
	goto tr33;
tr812:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st551;
tr880:
#line 243 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    /* This emulates two prefixes case. */
    SET_VEX_PREFIX2((p[0] & 0x80) | 0x61);
    SET_VEX_PREFIX3(p[0] & 0x7f);
  }
	goto st551;
st551:
	if ( ++p == pe )
		goto _test_eof551;
case 551:
#line 27608 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 18u: goto st38;
		case 22u: goto st38;
		case 91u: goto st38;
		case 127u: goto st38;
		case 230u: goto st38;
	}
	if ( 16u <= (*p) && (*p) <= 17u )
		goto st64;
	goto tr33;
tr813:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st552;
tr881:
#line 243 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    /* This emulates two prefixes case. */
    SET_VEX_PREFIX2((p[0] & 0x80) | 0x61);
    SET_VEX_PREFIX3(p[0] & 0x7f);
  }
	goto st552;
st552:
	if ( ++p == pe )
		goto _test_eof552;
case 552:
#line 27637 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 18u: goto st38;
		case 208u: goto st38;
		case 230u: goto st38;
		case 240u: goto st39;
	}
	if ( (*p) > 17u ) {
		if ( 124u <= (*p) && (*p) <= 125u )
			goto st38;
	} else if ( (*p) >= 16u )
		goto st64;
	goto tr33;
tr814:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st553;
st553:
	if ( ++p == pe )
		goto _test_eof553;
case 553:
#line 27660 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	if ( (*p) == 42u )
		goto st38;
	goto tr33;
tr815:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st554;
st554:
	if ( ++p == pe )
		goto _test_eof554;
case 554:
#line 27674 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	if ( (*p) == 110u )
		goto st38;
	goto tr33;
tr816:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st555;
st555:
	if ( ++p == pe )
		goto _test_eof555;
case 555:
#line 27688 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	if ( (*p) == 42u )
		goto st38;
	if ( 44u <= (*p) && (*p) <= 45u )
		goto tr221;
	goto tr33;
tr817:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st556;
st556:
	if ( ++p == pe )
		goto _test_eof556;
case 556:
#line 27704 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	if ( (*p) == 126u )
		goto tr220;
	goto tr33;
tr639:
#line 235 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX2(*p);
  }
	goto st557;
st557:
	if ( ++p == pe )
		goto _test_eof557;
case 557:
#line 27718 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 0u: goto tr818;
		case 1u: goto tr819;
		case 5u: goto tr820;
		case 8u: goto tr818;
		case 9u: goto tr819;
		case 13u: goto tr820;
		case 16u: goto tr818;
		case 17u: goto tr819;
		case 21u: goto tr820;
		case 24u: goto tr818;
		case 25u: goto tr819;
		case 29u: goto tr820;
		case 32u: goto tr818;
		case 33u: goto tr819;
		case 37u: goto tr820;
		case 40u: goto tr818;
		case 41u: goto tr819;
		case 45u: goto tr820;
		case 48u: goto tr818;
		case 49u: goto tr819;
		case 53u: goto tr820;
		case 56u: goto tr818;
		case 57u: goto tr819;
		case 61u: goto tr820;
		case 64u: goto tr818;
		case 65u: goto tr819;
		case 69u: goto tr820;
		case 72u: goto tr818;
		case 73u: goto tr819;
		case 77u: goto tr820;
		case 80u: goto tr818;
		case 81u: goto tr819;
		case 85u: goto tr820;
		case 88u: goto tr818;
		case 89u: goto tr819;
		case 93u: goto tr820;
		case 96u: goto tr818;
		case 97u: goto tr819;
		case 101u: goto tr820;
		case 104u: goto tr818;
		case 105u: goto tr819;
		case 109u: goto tr820;
		case 112u: goto tr818;
		case 113u: goto tr819;
		case 117u: goto tr820;
		case 120u: goto tr818;
		case 121u: goto tr821;
		case 125u: goto tr822;
		case 128u: goto tr823;
		case 129u: goto tr824;
		case 133u: goto tr825;
		case 136u: goto tr823;
		case 137u: goto tr824;
		case 141u: goto tr825;
		case 144u: goto tr823;
		case 145u: goto tr824;
		case 149u: goto tr825;
		case 152u: goto tr823;
		case 153u: goto tr824;
		case 157u: goto tr825;
		case 160u: goto tr823;
		case 161u: goto tr824;
		case 165u: goto tr825;
		case 168u: goto tr823;
		case 169u: goto tr824;
		case 173u: goto tr825;
		case 176u: goto tr823;
		case 177u: goto tr824;
		case 181u: goto tr825;
		case 184u: goto tr823;
		case 185u: goto tr824;
		case 189u: goto tr825;
		case 192u: goto tr823;
		case 193u: goto tr824;
		case 197u: goto tr825;
		case 200u: goto tr823;
		case 201u: goto tr824;
		case 205u: goto tr825;
		case 208u: goto tr823;
		case 209u: goto tr824;
		case 213u: goto tr825;
		case 216u: goto tr823;
		case 217u: goto tr824;
		case 221u: goto tr825;
		case 224u: goto tr823;
		case 225u: goto tr824;
		case 229u: goto tr825;
		case 232u: goto tr823;
		case 233u: goto tr824;
		case 237u: goto tr825;
		case 240u: goto tr823;
		case 241u: goto tr824;
		case 245u: goto tr825;
		case 248u: goto tr823;
		case 249u: goto tr824;
		case 253u: goto tr825;
	}
	goto tr33;
tr818:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st558;
st558:
	if ( ++p == pe )
		goto _test_eof558;
case 558:
#line 27828 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 242u: goto tr32;
		case 247u: goto tr32;
	}
	goto tr33;
tr819:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st559;
st559:
	if ( ++p == pe )
		goto _test_eof559;
case 559:
#line 27844 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	if ( (*p) == 43u )
		goto st38;
	if ( (*p) < 55u ) {
		if ( (*p) < 40u ) {
			if ( (*p) <= 13u )
				goto st38;
		} else if ( (*p) > 41u ) {
			if ( 44u <= (*p) && (*p) <= 47u )
				goto st39;
		} else
			goto st38;
	} else if ( (*p) > 64u ) {
		if ( (*p) < 166u ) {
			if ( 150u <= (*p) && (*p) <= 159u )
				goto st38;
		} else if ( (*p) > 175u ) {
			if ( (*p) > 191u ) {
				if ( 219u <= (*p) && (*p) <= 223u )
					goto st38;
			} else if ( (*p) >= 182u )
				goto st38;
		} else
			goto st38;
	} else
		goto st38;
	goto tr33;
tr820:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st560;
st560:
	if ( ++p == pe )
		goto _test_eof560;
case 560:
#line 27881 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 154u: goto st38;
		case 156u: goto st38;
		case 158u: goto st38;
		case 170u: goto st38;
		case 172u: goto st38;
		case 174u: goto st38;
		case 186u: goto st38;
		case 188u: goto st38;
		case 190u: goto st38;
	}
	if ( (*p) < 150u ) {
		if ( (*p) > 13u ) {
			if ( 44u <= (*p) && (*p) <= 47u )
				goto st39;
		} else if ( (*p) >= 12u )
			goto st38;
	} else if ( (*p) > 152u ) {
		if ( (*p) > 168u ) {
			if ( 182u <= (*p) && (*p) <= 184u )
				goto st38;
		} else if ( (*p) >= 166u )
			goto st38;
	} else
		goto st38;
	goto tr33;
tr821:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st561;
st561:
	if ( ++p == pe )
		goto _test_eof561;
case 561:
#line 27918 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 19u: goto st38;
		case 23u: goto st38;
		case 24u: goto st39;
		case 42u: goto st39;
	}
	if ( (*p) < 48u ) {
		if ( (*p) < 32u ) {
			if ( (*p) > 15u ) {
				if ( 28u <= (*p) && (*p) <= 30u )
					goto st38;
			} else
				goto st38;
		} else if ( (*p) > 37u ) {
			if ( (*p) > 43u ) {
				if ( 44u <= (*p) && (*p) <= 47u )
					goto st39;
			} else if ( (*p) >= 40u )
				goto st38;
		} else
			goto st38;
	} else if ( (*p) > 53u ) {
		if ( (*p) < 166u ) {
			if ( (*p) > 65u ) {
				if ( 150u <= (*p) && (*p) <= 159u )
					goto st38;
			} else if ( (*p) >= 55u )
				goto st38;
		} else if ( (*p) > 175u ) {
			if ( (*p) > 191u ) {
				if ( 219u <= (*p) && (*p) <= 223u )
					goto st38;
			} else if ( (*p) >= 182u )
				goto st38;
		} else
			goto st38;
	} else
		goto st38;
	goto tr33;
tr822:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st562;
st562:
	if ( ++p == pe )
		goto _test_eof562;
case 562:
#line 27968 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 19u: goto st38;
		case 23u: goto st38;
		case 154u: goto st38;
		case 156u: goto st38;
		case 158u: goto st38;
		case 170u: goto st38;
		case 172u: goto st38;
		case 174u: goto st38;
		case 186u: goto st38;
		case 188u: goto st38;
		case 190u: goto st38;
	}
	if ( (*p) < 44u ) {
		if ( (*p) > 15u ) {
			if ( 24u <= (*p) && (*p) <= 26u )
				goto st39;
		} else if ( (*p) >= 12u )
			goto st38;
	} else if ( (*p) > 47u ) {
		if ( (*p) < 166u ) {
			if ( 150u <= (*p) && (*p) <= 152u )
				goto st38;
		} else if ( (*p) > 168u ) {
			if ( 182u <= (*p) && (*p) <= 184u )
				goto st38;
		} else
			goto st38;
	} else
		goto st39;
	goto tr33;
tr823:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st563;
st563:
	if ( ++p == pe )
		goto _test_eof563;
case 563:
#line 28010 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 242u: goto tr221;
		case 247u: goto tr221;
	}
	goto tr33;
tr824:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st564;
st564:
	if ( ++p == pe )
		goto _test_eof564;
case 564:
#line 28026 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	if ( (*p) < 166u ) {
		if ( 150u <= (*p) && (*p) <= 159u )
			goto st38;
	} else if ( (*p) > 175u ) {
		if ( 182u <= (*p) && (*p) <= 191u )
			goto st38;
	} else
		goto st38;
	goto tr33;
tr825:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st565;
st565:
	if ( ++p == pe )
		goto _test_eof565;
case 565:
#line 28046 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 154u: goto st38;
		case 156u: goto st38;
		case 158u: goto st38;
		case 170u: goto st38;
		case 172u: goto st38;
		case 174u: goto st38;
		case 186u: goto st38;
		case 188u: goto st38;
		case 190u: goto st38;
	}
	if ( (*p) < 166u ) {
		if ( 150u <= (*p) && (*p) <= 152u )
			goto st38;
	} else if ( (*p) > 168u ) {
		if ( 182u <= (*p) && (*p) <= 184u )
			goto st38;
	} else
		goto st38;
	goto tr33;
tr640:
#line 235 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX2(*p);
  }
	goto st566;
st566:
	if ( ++p == pe )
		goto _test_eof566;
case 566:
#line 28077 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 1u: goto tr826;
		case 5u: goto tr827;
		case 9u: goto tr826;
		case 13u: goto tr827;
		case 17u: goto tr826;
		case 21u: goto tr827;
		case 25u: goto tr826;
		case 29u: goto tr827;
		case 33u: goto tr826;
		case 37u: goto tr827;
		case 41u: goto tr826;
		case 45u: goto tr827;
		case 49u: goto tr826;
		case 53u: goto tr827;
		case 57u: goto tr826;
		case 61u: goto tr827;
		case 65u: goto tr826;
		case 69u: goto tr827;
		case 73u: goto tr826;
		case 77u: goto tr827;
		case 81u: goto tr826;
		case 85u: goto tr827;
		case 89u: goto tr826;
		case 93u: goto tr827;
		case 97u: goto tr826;
		case 101u: goto tr827;
		case 105u: goto tr826;
		case 109u: goto tr827;
		case 113u: goto tr826;
		case 117u: goto tr827;
		case 121u: goto tr828;
		case 125u: goto tr829;
		case 129u: goto tr830;
		case 133u: goto tr831;
		case 137u: goto tr830;
		case 141u: goto tr831;
		case 145u: goto tr830;
		case 149u: goto tr831;
		case 153u: goto tr830;
		case 157u: goto tr831;
		case 161u: goto tr830;
		case 165u: goto tr831;
		case 169u: goto tr830;
		case 173u: goto tr831;
		case 177u: goto tr830;
		case 181u: goto tr831;
		case 185u: goto tr830;
		case 189u: goto tr831;
		case 193u: goto tr830;
		case 197u: goto tr831;
		case 201u: goto tr830;
		case 205u: goto tr831;
		case 209u: goto tr830;
		case 213u: goto tr831;
		case 217u: goto tr830;
		case 221u: goto tr831;
		case 225u: goto tr830;
		case 229u: goto tr831;
		case 233u: goto tr830;
		case 237u: goto tr831;
		case 241u: goto tr830;
		case 245u: goto tr831;
		case 249u: goto tr832;
		case 253u: goto tr831;
	}
	goto tr33;
tr826:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st567;
st567:
	if ( ++p == pe )
		goto _test_eof567;
case 567:
#line 28155 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 33u: goto st43;
		case 68u: goto st43;
		case 223u: goto st43;
	}
	if ( (*p) < 74u ) {
		if ( (*p) < 64u ) {
			if ( 8u <= (*p) && (*p) <= 15u )
				goto st43;
		} else if ( (*p) > 66u ) {
			if ( 72u <= (*p) && (*p) <= 73u )
				goto st568;
		} else
			goto st43;
	} else if ( (*p) > 76u ) {
		if ( (*p) < 104u ) {
			if ( 92u <= (*p) && (*p) <= 95u )
				goto st318;
		} else if ( (*p) > 111u ) {
			if ( 120u <= (*p) && (*p) <= 127u )
				goto st318;
		} else
			goto st318;
	} else
		goto st318;
	goto tr33;
st568:
	if ( ++p == pe )
		goto _test_eof568;
case 568:
	switch( (*p) ) {
		case 4u: goto st484;
		case 5u: goto tr834;
		case 12u: goto st484;
		case 13u: goto tr834;
		case 20u: goto st484;
		case 21u: goto tr834;
		case 28u: goto st484;
		case 29u: goto tr834;
		case 36u: goto st484;
		case 37u: goto tr834;
		case 44u: goto st484;
		case 45u: goto tr834;
		case 52u: goto st484;
		case 53u: goto tr834;
		case 60u: goto st484;
		case 61u: goto tr834;
		case 68u: goto st434;
		case 76u: goto st434;
		case 84u: goto st434;
		case 92u: goto st434;
		case 100u: goto st434;
		case 108u: goto st434;
		case 116u: goto st434;
		case 124u: goto st434;
		case 132u: goto st436;
		case 140u: goto st436;
		case 148u: goto st436;
		case 156u: goto st436;
		case 164u: goto st436;
		case 172u: goto st436;
		case 180u: goto st436;
		case 188u: goto st436;
	}
	if ( (*p) < 64u ) {
		if ( (*p) <= 63u )
			goto tr792;
	} else if ( (*p) > 127u ) {
		if ( 128u <= (*p) && (*p) <= 191u )
			goto tr794;
	} else
		goto tr793;
	goto st433;
tr827:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st569;
st569:
	if ( ++p == pe )
		goto _test_eof569;
case 569:
#line 28239 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 6u: goto st43;
		case 64u: goto st43;
	}
	if ( (*p) < 92u ) {
		if ( (*p) < 12u ) {
			if ( 8u <= (*p) && (*p) <= 9u )
				goto st43;
		} else if ( (*p) > 13u ) {
			if ( (*p) > 73u ) {
				if ( 74u <= (*p) && (*p) <= 75u )
					goto st318;
			} else if ( (*p) >= 72u )
				goto st568;
		} else
			goto st43;
	} else if ( (*p) > 95u ) {
		if ( (*p) < 108u ) {
			if ( 104u <= (*p) && (*p) <= 105u )
				goto st318;
		} else if ( (*p) > 109u ) {
			if ( (*p) > 121u ) {
				if ( 124u <= (*p) && (*p) <= 125u )
					goto st318;
			} else if ( (*p) >= 120u )
				goto st318;
		} else
			goto st318;
	} else
		goto st318;
	goto tr33;
tr828:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st570;
st570:
	if ( ++p == pe )
		goto _test_eof570;
case 570:
#line 28281 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 22u: goto tr48;
		case 23u: goto st572;
		case 29u: goto st43;
		case 68u: goto st43;
		case 223u: goto st43;
	}
	if ( (*p) < 72u ) {
		if ( (*p) < 20u ) {
			if ( (*p) > 5u ) {
				if ( 8u <= (*p) && (*p) <= 15u )
					goto st43;
			} else if ( (*p) >= 4u )
				goto st43;
		} else if ( (*p) > 21u ) {
			if ( (*p) > 34u ) {
				if ( 64u <= (*p) && (*p) <= 66u )
					goto st43;
			} else if ( (*p) >= 32u )
				goto st43;
		} else
			goto st571;
	} else if ( (*p) > 73u ) {
		if ( (*p) < 96u ) {
			if ( (*p) > 76u ) {
				if ( 92u <= (*p) && (*p) <= 95u )
					goto st318;
			} else if ( (*p) >= 74u )
				goto st318;
		} else if ( (*p) > 99u ) {
			if ( (*p) > 111u ) {
				if ( 120u <= (*p) && (*p) <= 127u )
					goto st318;
			} else if ( (*p) >= 104u )
				goto st318;
		} else
			goto st43;
	} else
		goto st568;
	goto tr33;
st571:
	if ( ++p == pe )
		goto _test_eof571;
case 571:
	switch( (*p) ) {
		case 4u: goto st44;
		case 5u: goto tr95;
		case 12u: goto st44;
		case 13u: goto tr95;
		case 20u: goto st44;
		case 21u: goto tr95;
		case 28u: goto st44;
		case 29u: goto tr95;
		case 36u: goto st44;
		case 37u: goto tr95;
		case 44u: goto st44;
		case 45u: goto tr95;
		case 52u: goto st44;
		case 53u: goto tr95;
		case 60u: goto st44;
		case 61u: goto tr95;
		case 68u: goto st50;
		case 76u: goto st50;
		case 84u: goto st50;
		case 92u: goto st50;
		case 100u: goto st50;
		case 108u: goto st50;
		case 116u: goto st50;
		case 124u: goto st50;
		case 132u: goto st51;
		case 140u: goto st51;
		case 148u: goto st51;
		case 156u: goto st51;
		case 164u: goto st51;
		case 172u: goto st51;
		case 180u: goto st51;
		case 188u: goto st51;
	}
	if ( (*p) < 64u ) {
		if ( (*p) <= 63u )
			goto tr93;
	} else if ( (*p) > 127u ) {
		if ( 128u <= (*p) && (*p) <= 191u )
			goto tr98;
	} else
		goto tr96;
	goto tr115;
st572:
	if ( ++p == pe )
		goto _test_eof572;
case 572:
	switch( (*p) ) {
		case 4u: goto st44;
		case 5u: goto tr95;
		case 12u: goto st44;
		case 13u: goto tr95;
		case 20u: goto st44;
		case 21u: goto tr95;
		case 28u: goto st44;
		case 29u: goto tr95;
		case 36u: goto st44;
		case 37u: goto tr95;
		case 44u: goto st44;
		case 45u: goto tr95;
		case 52u: goto st44;
		case 53u: goto tr95;
		case 60u: goto st44;
		case 61u: goto tr95;
		case 68u: goto st50;
		case 76u: goto st50;
		case 84u: goto st50;
		case 92u: goto st50;
		case 100u: goto st50;
		case 108u: goto st50;
		case 116u: goto st50;
		case 124u: goto st50;
		case 132u: goto st51;
		case 140u: goto st51;
		case 148u: goto st51;
		case 156u: goto st51;
		case 164u: goto st51;
		case 172u: goto st51;
		case 180u: goto st51;
		case 188u: goto st51;
	}
	if ( (*p) < 64u ) {
		if ( (*p) <= 63u )
			goto tr93;
	} else if ( (*p) > 127u ) {
		if ( 128u <= (*p) && (*p) <= 191u )
			goto tr98;
	} else
		goto tr96;
	goto tr33;
tr829:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st573;
st573:
	if ( ++p == pe )
		goto _test_eof573;
case 573:
#line 28426 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 29u: goto st43;
		case 64u: goto st43;
	}
	if ( (*p) < 74u ) {
		if ( (*p) < 12u ) {
			if ( (*p) > 6u ) {
				if ( 8u <= (*p) && (*p) <= 9u )
					goto st43;
			} else if ( (*p) >= 4u )
				goto st43;
		} else if ( (*p) > 13u ) {
			if ( (*p) > 25u ) {
				if ( 72u <= (*p) && (*p) <= 73u )
					goto st568;
			} else if ( (*p) >= 24u )
				goto st43;
		} else
			goto st43;
	} else if ( (*p) > 75u ) {
		if ( (*p) < 108u ) {
			if ( (*p) > 95u ) {
				if ( 104u <= (*p) && (*p) <= 105u )
					goto st318;
			} else if ( (*p) >= 92u )
				goto st318;
		} else if ( (*p) > 109u ) {
			if ( (*p) > 121u ) {
				if ( 124u <= (*p) && (*p) <= 125u )
					goto st318;
			} else if ( (*p) >= 120u )
				goto st318;
		} else
			goto st318;
	} else
		goto st318;
	goto tr33;
tr830:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st574;
st574:
	if ( ++p == pe )
		goto _test_eof574;
case 574:
#line 28474 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	if ( (*p) < 92u ) {
		if ( 72u <= (*p) && (*p) <= 73u )
			goto st568;
	} else if ( (*p) > 95u ) {
		if ( (*p) > 111u ) {
			if ( 120u <= (*p) && (*p) <= 127u )
				goto st318;
		} else if ( (*p) >= 104u )
			goto st318;
	} else
		goto st318;
	goto tr33;
tr831:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st575;
st575:
	if ( ++p == pe )
		goto _test_eof575;
case 575:
#line 28497 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	if ( (*p) < 104u ) {
		if ( (*p) > 73u ) {
			if ( 92u <= (*p) && (*p) <= 95u )
				goto st318;
		} else if ( (*p) >= 72u )
			goto st568;
	} else if ( (*p) > 105u ) {
		if ( (*p) < 120u ) {
			if ( 108u <= (*p) && (*p) <= 109u )
				goto st318;
		} else if ( (*p) > 121u ) {
			if ( 124u <= (*p) && (*p) <= 125u )
				goto st318;
		} else
			goto st318;
	} else
		goto st318;
	goto tr33;
tr832:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st576;
st576:
	if ( ++p == pe )
		goto _test_eof576;
case 576:
#line 28526 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 22u: goto tr243;
		case 34u: goto st43;
	}
	if ( (*p) < 92u ) {
		if ( 72u <= (*p) && (*p) <= 73u )
			goto st568;
	} else if ( (*p) > 95u ) {
		if ( (*p) > 111u ) {
			if ( 120u <= (*p) && (*p) <= 127u )
				goto st318;
		} else if ( (*p) >= 104u )
			goto st318;
	} else
		goto st318;
	goto tr33;
tr641:
#line 235 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX2(*p);
  }
	goto st577;
st577:
	if ( ++p == pe )
		goto _test_eof577;
case 577:
#line 28553 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 0u: goto tr649;
		case 1u: goto tr650;
		case 2u: goto tr651;
		case 3u: goto tr652;
		case 4u: goto tr653;
		case 5u: goto tr654;
		case 7u: goto tr655;
		case 8u: goto tr649;
		case 9u: goto tr650;
		case 10u: goto tr651;
		case 11u: goto tr652;
		case 12u: goto tr653;
		case 13u: goto tr654;
		case 15u: goto tr655;
		case 16u: goto tr649;
		case 17u: goto tr650;
		case 18u: goto tr651;
		case 19u: goto tr652;
		case 20u: goto tr653;
		case 21u: goto tr654;
		case 23u: goto tr655;
		case 24u: goto tr649;
		case 25u: goto tr650;
		case 26u: goto tr651;
		case 27u: goto tr652;
		case 28u: goto tr653;
		case 29u: goto tr654;
		case 31u: goto tr655;
		case 32u: goto tr649;
		case 33u: goto tr650;
		case 34u: goto tr651;
		case 35u: goto tr652;
		case 36u: goto tr653;
		case 37u: goto tr654;
		case 39u: goto tr655;
		case 40u: goto tr649;
		case 41u: goto tr650;
		case 42u: goto tr651;
		case 43u: goto tr652;
		case 44u: goto tr653;
		case 45u: goto tr654;
		case 47u: goto tr655;
		case 48u: goto tr649;
		case 49u: goto tr650;
		case 50u: goto tr651;
		case 51u: goto tr652;
		case 52u: goto tr653;
		case 53u: goto tr654;
		case 55u: goto tr655;
		case 56u: goto tr649;
		case 57u: goto tr650;
		case 58u: goto tr651;
		case 59u: goto tr652;
		case 60u: goto tr653;
		case 61u: goto tr654;
		case 63u: goto tr655;
		case 64u: goto tr649;
		case 65u: goto tr650;
		case 66u: goto tr651;
		case 67u: goto tr652;
		case 68u: goto tr653;
		case 69u: goto tr654;
		case 71u: goto tr655;
		case 72u: goto tr649;
		case 73u: goto tr650;
		case 74u: goto tr651;
		case 75u: goto tr652;
		case 76u: goto tr653;
		case 77u: goto tr654;
		case 79u: goto tr655;
		case 80u: goto tr649;
		case 81u: goto tr650;
		case 82u: goto tr651;
		case 83u: goto tr652;
		case 84u: goto tr653;
		case 85u: goto tr654;
		case 87u: goto tr655;
		case 88u: goto tr649;
		case 89u: goto tr650;
		case 90u: goto tr651;
		case 91u: goto tr652;
		case 92u: goto tr653;
		case 93u: goto tr654;
		case 95u: goto tr655;
		case 96u: goto tr649;
		case 97u: goto tr650;
		case 98u: goto tr651;
		case 99u: goto tr652;
		case 100u: goto tr653;
		case 101u: goto tr654;
		case 103u: goto tr655;
		case 104u: goto tr649;
		case 105u: goto tr650;
		case 106u: goto tr651;
		case 107u: goto tr652;
		case 108u: goto tr653;
		case 109u: goto tr654;
		case 111u: goto tr655;
		case 112u: goto tr649;
		case 113u: goto tr650;
		case 114u: goto tr651;
		case 115u: goto tr652;
		case 116u: goto tr653;
		case 117u: goto tr654;
		case 119u: goto tr655;
		case 120u: goto tr837;
		case 121u: goto tr657;
		case 122u: goto tr658;
		case 123u: goto tr659;
		case 124u: goto tr660;
		case 125u: goto tr661;
		case 126u: goto tr662;
		case 127u: goto tr663;
		case 249u: goto tr665;
		case 253u: goto tr667;
	}
	if ( (*p) < 186u ) {
		if ( (*p) < 154u ) {
			if ( (*p) < 138u ) {
				if ( 130u <= (*p) && (*p) <= 131u )
					goto tr664;
			} else if ( (*p) > 139u ) {
				if ( 146u <= (*p) && (*p) <= 147u )
					goto tr664;
			} else
				goto tr664;
		} else if ( (*p) > 155u ) {
			if ( (*p) < 170u ) {
				if ( 162u <= (*p) && (*p) <= 163u )
					goto tr664;
			} else if ( (*p) > 171u ) {
				if ( 178u <= (*p) && (*p) <= 179u )
					goto tr664;
			} else
				goto tr664;
		} else
			goto tr664;
	} else if ( (*p) > 187u ) {
		if ( (*p) < 218u ) {
			if ( (*p) < 202u ) {
				if ( 194u <= (*p) && (*p) <= 195u )
					goto tr664;
			} else if ( (*p) > 203u ) {
				if ( 210u <= (*p) && (*p) <= 211u )
					goto tr664;
			} else
				goto tr664;
		} else if ( (*p) > 219u ) {
			if ( (*p) < 234u ) {
				if ( 226u <= (*p) && (*p) <= 227u )
					goto tr664;
			} else if ( (*p) > 235u ) {
				if ( (*p) > 243u ) {
					if ( 250u <= (*p) && (*p) <= 251u )
						goto tr666;
				} else if ( (*p) >= 242u )
					goto tr664;
			} else
				goto tr664;
		} else
			goto tr664;
	} else
		goto tr664;
	goto tr33;
tr837:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st578;
st578:
	if ( ++p == pe )
		goto _test_eof578;
case 578:
#line 28729 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 43u: goto st398;
		case 174u: goto st579;
		case 194u: goto st267;
		case 198u: goto st267;
	}
	if ( (*p) < 22u ) {
		if ( (*p) < 18u ) {
			if ( 16u <= (*p) && (*p) <= 17u )
				goto st274;
		} else if ( (*p) > 19u ) {
			if ( 20u <= (*p) && (*p) <= 21u )
				goto st274;
		} else
			goto st398;
	} else if ( (*p) > 23u ) {
		if ( (*p) < 46u ) {
			if ( 40u <= (*p) && (*p) <= 41u )
				goto st274;
		} else if ( (*p) > 47u ) {
			if ( 81u <= (*p) && (*p) <= 95u )
				goto st274;
		} else
			goto st274;
	} else
		goto st398;
	goto tr33;
st579:
	if ( ++p == pe )
		goto _test_eof579;
case 579:
	switch( (*p) ) {
		case 20u: goto st275;
		case 28u: goto st275;
		case 84u: goto st8;
		case 92u: goto st8;
		case 148u: goto st9;
		case 156u: goto st9;
	}
	goto tr33;
tr642:
#line 235 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX2(*p);
  }
	goto st580;
st580:
	if ( ++p == pe )
		goto _test_eof580;
case 580:
#line 28780 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 0u: goto tr839;
		case 1u: goto tr676;
		case 5u: goto tr677;
		case 8u: goto tr839;
		case 9u: goto tr676;
		case 13u: goto tr677;
		case 16u: goto tr839;
		case 17u: goto tr676;
		case 21u: goto tr677;
		case 24u: goto tr839;
		case 25u: goto tr676;
		case 29u: goto tr677;
		case 32u: goto tr839;
		case 33u: goto tr676;
		case 37u: goto tr677;
		case 40u: goto tr839;
		case 41u: goto tr676;
		case 45u: goto tr677;
		case 48u: goto tr839;
		case 49u: goto tr676;
		case 53u: goto tr677;
		case 56u: goto tr839;
		case 57u: goto tr676;
		case 61u: goto tr677;
		case 64u: goto tr839;
		case 65u: goto tr676;
		case 69u: goto tr677;
		case 72u: goto tr839;
		case 73u: goto tr676;
		case 77u: goto tr677;
		case 80u: goto tr839;
		case 81u: goto tr676;
		case 85u: goto tr677;
		case 88u: goto tr839;
		case 89u: goto tr676;
		case 93u: goto tr677;
		case 96u: goto tr839;
		case 97u: goto tr676;
		case 101u: goto tr677;
		case 104u: goto tr839;
		case 105u: goto tr676;
		case 109u: goto tr677;
		case 112u: goto tr839;
		case 113u: goto tr676;
		case 117u: goto tr677;
		case 120u: goto tr839;
		case 121u: goto tr678;
		case 125u: goto tr679;
		case 128u: goto tr840;
		case 129u: goto tr681;
		case 133u: goto tr682;
		case 136u: goto tr840;
		case 137u: goto tr681;
		case 141u: goto tr682;
		case 144u: goto tr840;
		case 145u: goto tr681;
		case 149u: goto tr682;
		case 152u: goto tr840;
		case 153u: goto tr681;
		case 157u: goto tr682;
		case 160u: goto tr840;
		case 161u: goto tr681;
		case 165u: goto tr682;
		case 168u: goto tr840;
		case 169u: goto tr681;
		case 173u: goto tr682;
		case 176u: goto tr840;
		case 177u: goto tr681;
		case 181u: goto tr682;
		case 184u: goto tr840;
		case 185u: goto tr681;
		case 189u: goto tr682;
		case 192u: goto tr840;
		case 193u: goto tr681;
		case 197u: goto tr682;
		case 200u: goto tr840;
		case 201u: goto tr681;
		case 205u: goto tr682;
		case 208u: goto tr840;
		case 209u: goto tr681;
		case 213u: goto tr682;
		case 216u: goto tr840;
		case 217u: goto tr681;
		case 221u: goto tr682;
		case 224u: goto tr840;
		case 225u: goto tr681;
		case 229u: goto tr682;
		case 232u: goto tr840;
		case 233u: goto tr681;
		case 237u: goto tr682;
		case 240u: goto tr840;
		case 241u: goto tr681;
		case 245u: goto tr682;
		case 248u: goto tr840;
		case 249u: goto tr681;
		case 253u: goto tr682;
	}
	goto tr33;
tr839:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st581;
st581:
	if ( ++p == pe )
		goto _test_eof581;
case 581:
#line 28890 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 242u: goto tr670;
		case 243u: goto st582;
		case 247u: goto tr670;
	}
	goto tr33;
st582:
	if ( ++p == pe )
		goto _test_eof582;
case 582:
	switch( (*p) ) {
		case 12u: goto tr542;
		case 20u: goto tr542;
		case 28u: goto tr542;
		case 76u: goto tr543;
		case 84u: goto tr543;
		case 92u: goto tr543;
		case 140u: goto tr544;
		case 148u: goto tr544;
		case 156u: goto tr544;
	}
	if ( 200u <= (*p) && (*p) <= 223u )
		goto tr545;
	goto tr33;
tr840:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st583;
st583:
	if ( ++p == pe )
		goto _test_eof583;
case 583:
#line 28925 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 242u: goto tr673;
		case 243u: goto st584;
		case 247u: goto tr673;
	}
	goto tr33;
st584:
	if ( ++p == pe )
		goto _test_eof584;
case 584:
	switch( (*p) ) {
		case 12u: goto tr548;
		case 20u: goto tr548;
		case 28u: goto tr548;
		case 76u: goto tr549;
		case 84u: goto tr549;
		case 92u: goto tr549;
		case 140u: goto tr550;
		case 148u: goto tr550;
		case 156u: goto tr550;
	}
	if ( 200u <= (*p) && (*p) <= 223u )
		goto tr551;
	goto tr33;
tr643:
#line 235 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX2(*p);
  }
	goto st585;
st585:
	if ( ++p == pe )
		goto _test_eof585;
case 585:
#line 28960 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 0u: goto tr706;
		case 1u: goto tr707;
		case 2u: goto tr708;
		case 3u: goto tr709;
		case 4u: goto tr710;
		case 5u: goto tr711;
		case 7u: goto tr712;
		case 8u: goto tr706;
		case 9u: goto tr707;
		case 10u: goto tr708;
		case 11u: goto tr709;
		case 12u: goto tr710;
		case 13u: goto tr711;
		case 15u: goto tr712;
		case 16u: goto tr706;
		case 17u: goto tr707;
		case 18u: goto tr708;
		case 19u: goto tr709;
		case 20u: goto tr710;
		case 21u: goto tr711;
		case 23u: goto tr712;
		case 24u: goto tr706;
		case 25u: goto tr707;
		case 26u: goto tr708;
		case 27u: goto tr709;
		case 28u: goto tr710;
		case 29u: goto tr711;
		case 31u: goto tr712;
		case 32u: goto tr706;
		case 33u: goto tr707;
		case 34u: goto tr708;
		case 35u: goto tr709;
		case 36u: goto tr710;
		case 37u: goto tr711;
		case 39u: goto tr712;
		case 40u: goto tr706;
		case 41u: goto tr707;
		case 42u: goto tr708;
		case 43u: goto tr709;
		case 44u: goto tr710;
		case 45u: goto tr711;
		case 47u: goto tr712;
		case 48u: goto tr706;
		case 49u: goto tr707;
		case 50u: goto tr708;
		case 51u: goto tr709;
		case 52u: goto tr710;
		case 53u: goto tr711;
		case 55u: goto tr712;
		case 56u: goto tr706;
		case 57u: goto tr707;
		case 58u: goto tr708;
		case 59u: goto tr709;
		case 60u: goto tr710;
		case 61u: goto tr711;
		case 63u: goto tr712;
		case 64u: goto tr706;
		case 65u: goto tr707;
		case 66u: goto tr708;
		case 67u: goto tr709;
		case 68u: goto tr710;
		case 69u: goto tr711;
		case 71u: goto tr712;
		case 72u: goto tr706;
		case 73u: goto tr707;
		case 74u: goto tr708;
		case 75u: goto tr709;
		case 76u: goto tr710;
		case 77u: goto tr711;
		case 79u: goto tr712;
		case 80u: goto tr706;
		case 81u: goto tr707;
		case 82u: goto tr708;
		case 83u: goto tr709;
		case 84u: goto tr710;
		case 85u: goto tr711;
		case 87u: goto tr712;
		case 88u: goto tr706;
		case 89u: goto tr707;
		case 90u: goto tr708;
		case 91u: goto tr709;
		case 92u: goto tr710;
		case 93u: goto tr711;
		case 95u: goto tr712;
		case 96u: goto tr706;
		case 97u: goto tr707;
		case 98u: goto tr708;
		case 99u: goto tr709;
		case 100u: goto tr710;
		case 101u: goto tr711;
		case 103u: goto tr712;
		case 104u: goto tr706;
		case 105u: goto tr707;
		case 106u: goto tr708;
		case 107u: goto tr709;
		case 108u: goto tr710;
		case 109u: goto tr711;
		case 111u: goto tr712;
		case 112u: goto tr706;
		case 113u: goto tr707;
		case 114u: goto tr708;
		case 115u: goto tr709;
		case 116u: goto tr710;
		case 117u: goto tr711;
		case 119u: goto tr712;
		case 120u: goto tr843;
		case 121u: goto tr714;
		case 122u: goto tr715;
		case 123u: goto tr716;
		case 124u: goto tr717;
		case 125u: goto tr718;
		case 126u: goto tr719;
		case 127u: goto tr720;
		case 249u: goto tr722;
		case 253u: goto tr724;
	}
	if ( (*p) < 186u ) {
		if ( (*p) < 154u ) {
			if ( (*p) < 138u ) {
				if ( 130u <= (*p) && (*p) <= 131u )
					goto tr721;
			} else if ( (*p) > 139u ) {
				if ( 146u <= (*p) && (*p) <= 147u )
					goto tr721;
			} else
				goto tr721;
		} else if ( (*p) > 155u ) {
			if ( (*p) < 170u ) {
				if ( 162u <= (*p) && (*p) <= 163u )
					goto tr721;
			} else if ( (*p) > 171u ) {
				if ( 178u <= (*p) && (*p) <= 179u )
					goto tr721;
			} else
				goto tr721;
		} else
			goto tr721;
	} else if ( (*p) > 187u ) {
		if ( (*p) < 218u ) {
			if ( (*p) < 202u ) {
				if ( 194u <= (*p) && (*p) <= 195u )
					goto tr721;
			} else if ( (*p) > 203u ) {
				if ( 210u <= (*p) && (*p) <= 211u )
					goto tr721;
			} else
				goto tr721;
		} else if ( (*p) > 219u ) {
			if ( (*p) < 234u ) {
				if ( 226u <= (*p) && (*p) <= 227u )
					goto tr721;
			} else if ( (*p) > 235u ) {
				if ( (*p) > 243u ) {
					if ( 250u <= (*p) && (*p) <= 251u )
						goto tr723;
				} else if ( (*p) >= 242u )
					goto tr721;
			} else
				goto tr721;
		} else
			goto tr721;
	} else
		goto tr721;
	goto tr33;
tr843:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st586;
st586:
	if ( ++p == pe )
		goto _test_eof586;
case 586:
#line 29136 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 43u: goto st450;
		case 174u: goto st587;
		case 194u: goto st287;
		case 198u: goto st287;
	}
	if ( (*p) < 22u ) {
		if ( (*p) < 18u ) {
			if ( 16u <= (*p) && (*p) <= 17u )
				goto st293;
		} else if ( (*p) > 19u ) {
			if ( 20u <= (*p) && (*p) <= 21u )
				goto st293;
		} else
			goto st450;
	} else if ( (*p) > 23u ) {
		if ( (*p) < 46u ) {
			if ( 40u <= (*p) && (*p) <= 41u )
				goto st293;
		} else if ( (*p) > 47u ) {
			if ( 81u <= (*p) && (*p) <= 95u )
				goto st293;
		} else
			goto st293;
	} else
		goto st450;
	goto tr33;
st587:
	if ( ++p == pe )
		goto _test_eof587;
case 587:
	switch( (*p) ) {
		case 20u: goto st2;
		case 28u: goto st2;
		case 84u: goto st8;
		case 92u: goto st8;
		case 148u: goto st9;
		case 156u: goto st9;
	}
	goto tr33;
tr644:
#line 235 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX2(*p);
  }
	goto st588;
st588:
	if ( ++p == pe )
		goto _test_eof588;
case 588:
#line 29187 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 0u: goto tr845;
		case 1u: goto tr732;
		case 5u: goto tr733;
		case 8u: goto tr845;
		case 9u: goto tr732;
		case 13u: goto tr733;
		case 16u: goto tr845;
		case 17u: goto tr732;
		case 21u: goto tr733;
		case 24u: goto tr845;
		case 25u: goto tr732;
		case 29u: goto tr733;
		case 32u: goto tr845;
		case 33u: goto tr732;
		case 37u: goto tr733;
		case 40u: goto tr845;
		case 41u: goto tr732;
		case 45u: goto tr733;
		case 48u: goto tr845;
		case 49u: goto tr732;
		case 53u: goto tr733;
		case 56u: goto tr845;
		case 57u: goto tr732;
		case 61u: goto tr733;
		case 64u: goto tr845;
		case 65u: goto tr732;
		case 69u: goto tr733;
		case 72u: goto tr845;
		case 73u: goto tr732;
		case 77u: goto tr733;
		case 80u: goto tr845;
		case 81u: goto tr732;
		case 85u: goto tr733;
		case 88u: goto tr845;
		case 89u: goto tr732;
		case 93u: goto tr733;
		case 96u: goto tr845;
		case 97u: goto tr732;
		case 101u: goto tr733;
		case 104u: goto tr845;
		case 105u: goto tr732;
		case 109u: goto tr733;
		case 112u: goto tr845;
		case 113u: goto tr732;
		case 117u: goto tr733;
		case 120u: goto tr845;
		case 121u: goto tr734;
		case 125u: goto tr735;
		case 128u: goto tr846;
		case 129u: goto tr737;
		case 133u: goto tr738;
		case 136u: goto tr846;
		case 137u: goto tr737;
		case 141u: goto tr738;
		case 144u: goto tr846;
		case 145u: goto tr737;
		case 149u: goto tr738;
		case 152u: goto tr846;
		case 153u: goto tr737;
		case 157u: goto tr738;
		case 160u: goto tr846;
		case 161u: goto tr737;
		case 165u: goto tr738;
		case 168u: goto tr846;
		case 169u: goto tr737;
		case 173u: goto tr738;
		case 176u: goto tr846;
		case 177u: goto tr737;
		case 181u: goto tr738;
		case 184u: goto tr846;
		case 185u: goto tr737;
		case 189u: goto tr738;
		case 192u: goto tr846;
		case 193u: goto tr737;
		case 197u: goto tr738;
		case 200u: goto tr846;
		case 201u: goto tr737;
		case 205u: goto tr738;
		case 208u: goto tr846;
		case 209u: goto tr737;
		case 213u: goto tr738;
		case 216u: goto tr846;
		case 217u: goto tr737;
		case 221u: goto tr738;
		case 224u: goto tr846;
		case 225u: goto tr737;
		case 229u: goto tr738;
		case 232u: goto tr846;
		case 233u: goto tr737;
		case 237u: goto tr738;
		case 240u: goto tr846;
		case 241u: goto tr737;
		case 245u: goto tr738;
		case 248u: goto tr846;
		case 249u: goto tr737;
		case 253u: goto tr738;
	}
	goto tr33;
tr845:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st589;
st589:
	if ( ++p == pe )
		goto _test_eof589;
case 589:
#line 29297 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 242u: goto tr727;
		case 243u: goto st590;
		case 247u: goto tr727;
	}
	goto tr33;
st590:
	if ( ++p == pe )
		goto _test_eof590;
case 590:
	switch( (*p) ) {
		case 12u: goto tr571;
		case 20u: goto tr571;
		case 28u: goto tr571;
		case 76u: goto tr543;
		case 84u: goto tr543;
		case 92u: goto tr543;
		case 140u: goto tr544;
		case 148u: goto tr544;
		case 156u: goto tr544;
	}
	if ( 200u <= (*p) && (*p) <= 223u )
		goto tr545;
	goto tr33;
tr846:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st591;
st591:
	if ( ++p == pe )
		goto _test_eof591;
case 591:
#line 29332 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 242u: goto tr729;
		case 243u: goto st592;
		case 247u: goto tr729;
	}
	goto tr33;
st592:
	if ( ++p == pe )
		goto _test_eof592;
case 592:
	switch( (*p) ) {
		case 12u: goto tr574;
		case 20u: goto tr574;
		case 28u: goto tr574;
		case 76u: goto tr549;
		case 84u: goto tr549;
		case 92u: goto tr549;
		case 140u: goto tr550;
		case 148u: goto tr550;
		case 156u: goto tr550;
	}
	if ( 200u <= (*p) && (*p) <= 223u )
		goto tr551;
	goto tr33;
tr645:
#line 235 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX2(*p);
  }
	goto st593;
st593:
	if ( ++p == pe )
		goto _test_eof593;
case 593:
#line 29367 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 1u: goto tr849;
		case 2u: goto tr753;
		case 3u: goto tr754;
		case 4u: goto tr755;
		case 5u: goto tr756;
		case 6u: goto tr757;
		case 7u: goto tr758;
		case 9u: goto tr849;
		case 10u: goto tr753;
		case 11u: goto tr754;
		case 12u: goto tr755;
		case 13u: goto tr756;
		case 14u: goto tr757;
		case 15u: goto tr758;
		case 17u: goto tr849;
		case 18u: goto tr753;
		case 19u: goto tr754;
		case 20u: goto tr755;
		case 21u: goto tr756;
		case 22u: goto tr757;
		case 23u: goto tr758;
		case 25u: goto tr849;
		case 26u: goto tr753;
		case 27u: goto tr754;
		case 28u: goto tr755;
		case 29u: goto tr756;
		case 30u: goto tr757;
		case 31u: goto tr758;
		case 33u: goto tr849;
		case 34u: goto tr753;
		case 35u: goto tr754;
		case 36u: goto tr755;
		case 37u: goto tr756;
		case 38u: goto tr757;
		case 39u: goto tr758;
		case 41u: goto tr849;
		case 42u: goto tr753;
		case 43u: goto tr754;
		case 44u: goto tr755;
		case 45u: goto tr756;
		case 46u: goto tr757;
		case 47u: goto tr758;
		case 49u: goto tr849;
		case 50u: goto tr753;
		case 51u: goto tr754;
		case 52u: goto tr755;
		case 53u: goto tr756;
		case 54u: goto tr757;
		case 55u: goto tr758;
		case 57u: goto tr849;
		case 58u: goto tr753;
		case 59u: goto tr754;
		case 60u: goto tr755;
		case 61u: goto tr756;
		case 62u: goto tr757;
		case 63u: goto tr758;
		case 65u: goto tr849;
		case 66u: goto tr753;
		case 67u: goto tr754;
		case 68u: goto tr755;
		case 69u: goto tr756;
		case 70u: goto tr757;
		case 71u: goto tr758;
		case 73u: goto tr849;
		case 74u: goto tr753;
		case 75u: goto tr754;
		case 76u: goto tr755;
		case 77u: goto tr756;
		case 78u: goto tr757;
		case 79u: goto tr758;
		case 81u: goto tr849;
		case 82u: goto tr753;
		case 83u: goto tr754;
		case 84u: goto tr755;
		case 85u: goto tr756;
		case 86u: goto tr757;
		case 87u: goto tr758;
		case 89u: goto tr849;
		case 90u: goto tr753;
		case 91u: goto tr754;
		case 92u: goto tr755;
		case 93u: goto tr756;
		case 94u: goto tr757;
		case 95u: goto tr758;
		case 97u: goto tr849;
		case 98u: goto tr753;
		case 99u: goto tr754;
		case 100u: goto tr755;
		case 101u: goto tr756;
		case 102u: goto tr757;
		case 103u: goto tr758;
		case 105u: goto tr849;
		case 106u: goto tr753;
		case 107u: goto tr754;
		case 108u: goto tr755;
		case 109u: goto tr756;
		case 110u: goto tr757;
		case 111u: goto tr758;
		case 113u: goto tr849;
		case 114u: goto tr753;
		case 115u: goto tr754;
		case 116u: goto tr755;
		case 117u: goto tr756;
		case 118u: goto tr757;
		case 119u: goto tr758;
		case 120u: goto tr850;
		case 121u: goto tr851;
		case 122u: goto tr761;
		case 123u: goto tr762;
		case 124u: goto tr763;
		case 125u: goto tr764;
		case 126u: goto tr765;
		case 127u: goto tr766;
		case 249u: goto tr768;
		case 253u: goto tr770;
	}
	if ( (*p) < 186u ) {
		if ( (*p) < 146u ) {
			if ( (*p) < 130u ) {
				if ( (*p) <= 112u )
					goto tr751;
			} else if ( (*p) > 131u ) {
				if ( 138u <= (*p) && (*p) <= 139u )
					goto tr767;
			} else
				goto tr767;
		} else if ( (*p) > 147u ) {
			if ( (*p) < 162u ) {
				if ( 154u <= (*p) && (*p) <= 155u )
					goto tr767;
			} else if ( (*p) > 163u ) {
				if ( (*p) > 171u ) {
					if ( 178u <= (*p) && (*p) <= 179u )
						goto tr767;
				} else if ( (*p) >= 170u )
					goto tr767;
			} else
				goto tr767;
		} else
			goto tr767;
	} else if ( (*p) > 187u ) {
		if ( (*p) < 218u ) {
			if ( (*p) < 202u ) {
				if ( 194u <= (*p) && (*p) <= 195u )
					goto tr767;
			} else if ( (*p) > 203u ) {
				if ( 210u <= (*p) && (*p) <= 211u )
					goto tr767;
			} else
				goto tr767;
		} else if ( (*p) > 219u ) {
			if ( (*p) < 234u ) {
				if ( 226u <= (*p) && (*p) <= 227u )
					goto tr767;
			} else if ( (*p) > 235u ) {
				if ( (*p) > 243u ) {
					if ( 250u <= (*p) && (*p) <= 251u )
						goto tr769;
				} else if ( (*p) >= 242u )
					goto tr767;
			} else
				goto tr767;
		} else
			goto tr767;
	} else
		goto tr767;
	goto tr33;
tr849:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st594;
st594:
	if ( ++p == pe )
		goto _test_eof594;
case 594:
#line 29546 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 18u: goto st494;
		case 81u: goto st309;
		case 115u: goto st595;
		case 194u: goto st303;
		case 198u: goto st303;
	}
	if ( (*p) < 116u ) {
		if ( (*p) < 46u ) {
			if ( (*p) > 21u ) {
				if ( 22u <= (*p) && (*p) <= 23u )
					goto st494;
			} else if ( (*p) >= 20u )
				goto st309;
		} else if ( (*p) > 47u ) {
			if ( (*p) < 92u ) {
				if ( 84u <= (*p) && (*p) <= 89u )
					goto st309;
			} else if ( (*p) > 109u ) {
				if ( 113u <= (*p) && (*p) <= 114u )
					goto st52;
			} else
				goto st309;
		} else
			goto st309;
	} else if ( (*p) > 118u ) {
		if ( (*p) < 216u ) {
			if ( (*p) > 125u ) {
				if ( 208u <= (*p) && (*p) <= 213u )
					goto st309;
			} else if ( (*p) >= 124u )
				goto st309;
		} else if ( (*p) > 229u ) {
			if ( (*p) < 241u ) {
				if ( 232u <= (*p) && (*p) <= 239u )
					goto st309;
			} else if ( (*p) > 246u ) {
				if ( 248u <= (*p) && (*p) <= 254u )
					goto st309;
			} else
				goto st309;
		} else
			goto st309;
	} else
		goto st309;
	goto tr33;
st595:
	if ( ++p == pe )
		goto _test_eof595;
case 595:
	if ( (*p) > 223u ) {
		if ( 240u <= (*p) )
			goto st11;
	} else if ( (*p) >= 208u )
		goto st11;
	goto tr33;
tr850:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st596;
st596:
	if ( ++p == pe )
		goto _test_eof596;
case 596:
#line 29613 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 19u: goto st494;
		case 23u: goto st494;
		case 43u: goto st494;
		case 80u: goto tr41;
		case 174u: goto st597;
		case 194u: goto st303;
		case 198u: goto st303;
	}
	if ( (*p) < 40u ) {
		if ( 16u <= (*p) && (*p) <= 22u )
			goto st309;
	} else if ( (*p) > 41u ) {
		if ( (*p) > 47u ) {
			if ( 81u <= (*p) && (*p) <= 95u )
				goto st309;
		} else if ( (*p) >= 46u )
			goto st309;
	} else
		goto st309;
	goto tr33;
st597:
	if ( ++p == pe )
		goto _test_eof597;
case 597:
	switch( (*p) ) {
		case 20u: goto st275;
		case 28u: goto st275;
		case 84u: goto st8;
		case 92u: goto st8;
		case 148u: goto st9;
		case 156u: goto st9;
	}
	if ( (*p) < 30u ) {
		if ( (*p) > 19u ) {
			if ( 22u <= (*p) && (*p) <= 27u )
				goto tr0;
		} else if ( (*p) >= 16u )
			goto tr0;
	} else if ( (*p) > 31u ) {
		if ( (*p) > 95u ) {
			if ( 144u <= (*p) && (*p) <= 159u )
				goto tr5;
		} else if ( (*p) >= 80u )
			goto tr3;
	} else
		goto tr0;
	goto tr33;
tr851:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st598;
st598:
	if ( ++p == pe )
		goto _test_eof598;
case 598:
#line 29672 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 43u: goto st494;
		case 80u: goto tr41;
		case 81u: goto st309;
		case 112u: goto st303;
		case 115u: goto st595;
		case 127u: goto st309;
		case 194u: goto st303;
		case 197u: goto tr52;
		case 215u: goto tr41;
		case 231u: goto st494;
		case 247u: goto st64;
	}
	if ( (*p) < 84u ) {
		if ( (*p) < 20u ) {
			if ( (*p) > 17u ) {
				if ( 18u <= (*p) && (*p) <= 19u )
					goto st494;
			} else if ( (*p) >= 16u )
				goto st309;
		} else if ( (*p) > 21u ) {
			if ( (*p) < 40u ) {
				if ( 22u <= (*p) && (*p) <= 23u )
					goto st494;
			} else if ( (*p) > 41u ) {
				if ( 46u <= (*p) && (*p) <= 47u )
					goto st309;
			} else
				goto st309;
		} else
			goto st309;
	} else if ( (*p) > 111u ) {
		if ( (*p) < 196u ) {
			if ( (*p) < 116u ) {
				if ( 113u <= (*p) && (*p) <= 114u )
					goto st52;
			} else if ( (*p) > 118u ) {
				if ( 124u <= (*p) && (*p) <= 125u )
					goto st309;
			} else
				goto st309;
		} else if ( (*p) > 198u ) {
			if ( (*p) < 216u ) {
				if ( 208u <= (*p) && (*p) <= 213u )
					goto st309;
			} else if ( (*p) > 239u ) {
				if ( 241u <= (*p) && (*p) <= 254u )
					goto st309;
			} else
				goto st309;
		} else
			goto st303;
	} else
		goto st309;
	goto tr33;
tr646:
#line 235 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX2(*p);
  }
	goto st599;
st599:
	if ( ++p == pe )
		goto _test_eof599;
case 599:
#line 29738 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 0u: goto tr854;
		case 1u: goto tr777;
		case 5u: goto tr778;
		case 8u: goto tr854;
		case 9u: goto tr777;
		case 13u: goto tr778;
		case 16u: goto tr854;
		case 17u: goto tr777;
		case 21u: goto tr778;
		case 24u: goto tr854;
		case 25u: goto tr777;
		case 29u: goto tr778;
		case 32u: goto tr854;
		case 33u: goto tr777;
		case 37u: goto tr778;
		case 40u: goto tr854;
		case 41u: goto tr777;
		case 45u: goto tr778;
		case 48u: goto tr854;
		case 49u: goto tr777;
		case 53u: goto tr778;
		case 56u: goto tr854;
		case 57u: goto tr777;
		case 61u: goto tr778;
		case 64u: goto tr854;
		case 65u: goto tr777;
		case 69u: goto tr778;
		case 72u: goto tr854;
		case 73u: goto tr777;
		case 77u: goto tr778;
		case 80u: goto tr854;
		case 81u: goto tr777;
		case 85u: goto tr778;
		case 88u: goto tr854;
		case 89u: goto tr777;
		case 93u: goto tr778;
		case 96u: goto tr854;
		case 97u: goto tr777;
		case 101u: goto tr778;
		case 104u: goto tr854;
		case 105u: goto tr777;
		case 109u: goto tr778;
		case 112u: goto tr854;
		case 113u: goto tr777;
		case 117u: goto tr778;
		case 120u: goto tr854;
		case 121u: goto tr779;
		case 125u: goto tr780;
		case 128u: goto tr855;
		case 129u: goto tr782;
		case 133u: goto tr783;
		case 136u: goto tr855;
		case 137u: goto tr782;
		case 141u: goto tr783;
		case 144u: goto tr855;
		case 145u: goto tr782;
		case 149u: goto tr783;
		case 152u: goto tr855;
		case 153u: goto tr782;
		case 157u: goto tr783;
		case 160u: goto tr855;
		case 161u: goto tr782;
		case 165u: goto tr783;
		case 168u: goto tr855;
		case 169u: goto tr782;
		case 173u: goto tr783;
		case 176u: goto tr855;
		case 177u: goto tr782;
		case 181u: goto tr783;
		case 184u: goto tr855;
		case 185u: goto tr782;
		case 189u: goto tr783;
		case 192u: goto tr855;
		case 193u: goto tr782;
		case 197u: goto tr783;
		case 200u: goto tr855;
		case 201u: goto tr782;
		case 205u: goto tr783;
		case 208u: goto tr855;
		case 209u: goto tr782;
		case 213u: goto tr783;
		case 216u: goto tr855;
		case 217u: goto tr782;
		case 221u: goto tr783;
		case 224u: goto tr855;
		case 225u: goto tr782;
		case 229u: goto tr783;
		case 232u: goto tr855;
		case 233u: goto tr782;
		case 237u: goto tr783;
		case 240u: goto tr855;
		case 241u: goto tr782;
		case 245u: goto tr783;
		case 248u: goto tr855;
		case 249u: goto tr782;
		case 253u: goto tr783;
	}
	goto tr33;
tr854:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st600;
st600:
	if ( ++p == pe )
		goto _test_eof600;
case 600:
#line 29848 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 242u: goto tr772;
		case 243u: goto st601;
		case 247u: goto tr772;
	}
	goto tr33;
st601:
	if ( ++p == pe )
		goto _test_eof601;
case 601:
	switch( (*p) ) {
		case 12u: goto tr542;
		case 20u: goto tr542;
		case 28u: goto tr542;
		case 76u: goto tr543;
		case 84u: goto tr543;
		case 92u: goto tr543;
		case 140u: goto tr544;
		case 148u: goto tr544;
		case 156u: goto tr544;
	}
	if ( (*p) < 30u ) {
		if ( (*p) < 14u ) {
			if ( 8u <= (*p) && (*p) <= 11u )
				goto tr589;
		} else if ( (*p) > 19u ) {
			if ( 22u <= (*p) && (*p) <= 27u )
				goto tr589;
		} else
			goto tr589;
	} else if ( (*p) > 31u ) {
		if ( (*p) < 136u ) {
			if ( 72u <= (*p) && (*p) <= 95u )
				goto tr590;
		} else if ( (*p) > 159u ) {
			if ( 200u <= (*p) && (*p) <= 223u )
				goto tr545;
		} else
			goto tr591;
	} else
		goto tr589;
	goto tr33;
tr855:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st602;
st602:
	if ( ++p == pe )
		goto _test_eof602;
case 602:
#line 29901 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 242u: goto tr774;
		case 243u: goto st603;
		case 247u: goto tr774;
	}
	goto tr33;
st603:
	if ( ++p == pe )
		goto _test_eof603;
case 603:
	switch( (*p) ) {
		case 12u: goto tr548;
		case 20u: goto tr548;
		case 28u: goto tr548;
		case 76u: goto tr549;
		case 84u: goto tr549;
		case 92u: goto tr549;
		case 140u: goto tr550;
		case 148u: goto tr550;
		case 156u: goto tr550;
	}
	if ( (*p) < 30u ) {
		if ( (*p) < 14u ) {
			if ( 8u <= (*p) && (*p) <= 11u )
				goto tr595;
		} else if ( (*p) > 19u ) {
			if ( 22u <= (*p) && (*p) <= 27u )
				goto tr595;
		} else
			goto tr595;
	} else if ( (*p) > 31u ) {
		if ( (*p) < 136u ) {
			if ( 72u <= (*p) && (*p) <= 95u )
				goto tr596;
		} else if ( (*p) > 159u ) {
			if ( 200u <= (*p) && (*p) <= 223u )
				goto tr551;
		} else
			goto tr597;
	} else
		goto tr595;
	goto tr33;
tr647:
#line 235 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX2(*p);
  }
	goto st604;
st604:
	if ( ++p == pe )
		goto _test_eof604;
case 604:
#line 29954 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 1u: goto tr858;
		case 2u: goto tr801;
		case 3u: goto tr802;
		case 4u: goto tr803;
		case 5u: goto tr804;
		case 6u: goto tr757;
		case 7u: goto tr805;
		case 9u: goto tr858;
		case 10u: goto tr801;
		case 11u: goto tr802;
		case 12u: goto tr803;
		case 13u: goto tr804;
		case 14u: goto tr757;
		case 15u: goto tr805;
		case 17u: goto tr858;
		case 18u: goto tr801;
		case 19u: goto tr802;
		case 20u: goto tr803;
		case 21u: goto tr804;
		case 22u: goto tr757;
		case 23u: goto tr805;
		case 25u: goto tr858;
		case 26u: goto tr801;
		case 27u: goto tr802;
		case 28u: goto tr803;
		case 29u: goto tr804;
		case 30u: goto tr757;
		case 31u: goto tr805;
		case 33u: goto tr858;
		case 34u: goto tr801;
		case 35u: goto tr802;
		case 36u: goto tr803;
		case 37u: goto tr804;
		case 38u: goto tr757;
		case 39u: goto tr805;
		case 41u: goto tr858;
		case 42u: goto tr801;
		case 43u: goto tr802;
		case 44u: goto tr803;
		case 45u: goto tr804;
		case 46u: goto tr757;
		case 47u: goto tr805;
		case 49u: goto tr858;
		case 50u: goto tr801;
		case 51u: goto tr802;
		case 52u: goto tr803;
		case 53u: goto tr804;
		case 54u: goto tr757;
		case 55u: goto tr805;
		case 57u: goto tr858;
		case 58u: goto tr801;
		case 59u: goto tr802;
		case 60u: goto tr803;
		case 61u: goto tr804;
		case 62u: goto tr757;
		case 63u: goto tr805;
		case 65u: goto tr858;
		case 66u: goto tr801;
		case 67u: goto tr802;
		case 68u: goto tr803;
		case 69u: goto tr804;
		case 70u: goto tr757;
		case 71u: goto tr805;
		case 73u: goto tr858;
		case 74u: goto tr801;
		case 75u: goto tr802;
		case 76u: goto tr803;
		case 77u: goto tr804;
		case 78u: goto tr757;
		case 79u: goto tr805;
		case 81u: goto tr858;
		case 82u: goto tr801;
		case 83u: goto tr802;
		case 84u: goto tr803;
		case 85u: goto tr804;
		case 86u: goto tr757;
		case 87u: goto tr805;
		case 89u: goto tr858;
		case 90u: goto tr801;
		case 91u: goto tr802;
		case 92u: goto tr803;
		case 93u: goto tr804;
		case 94u: goto tr757;
		case 95u: goto tr805;
		case 97u: goto tr858;
		case 98u: goto tr801;
		case 99u: goto tr802;
		case 100u: goto tr803;
		case 101u: goto tr804;
		case 102u: goto tr757;
		case 103u: goto tr805;
		case 105u: goto tr858;
		case 106u: goto tr801;
		case 107u: goto tr802;
		case 108u: goto tr803;
		case 109u: goto tr804;
		case 110u: goto tr757;
		case 111u: goto tr805;
		case 113u: goto tr858;
		case 114u: goto tr801;
		case 115u: goto tr802;
		case 116u: goto tr803;
		case 117u: goto tr804;
		case 118u: goto tr757;
		case 119u: goto tr805;
		case 120u: goto tr859;
		case 121u: goto tr860;
		case 122u: goto tr808;
		case 123u: goto tr809;
		case 124u: goto tr861;
		case 125u: goto tr811;
		case 126u: goto tr812;
		case 127u: goto tr813;
		case 249u: goto tr815;
		case 253u: goto tr817;
	}
	if ( (*p) < 186u ) {
		if ( (*p) < 146u ) {
			if ( (*p) < 130u ) {
				if ( (*p) <= 112u )
					goto tr799;
			} else if ( (*p) > 131u ) {
				if ( 138u <= (*p) && (*p) <= 139u )
					goto tr814;
			} else
				goto tr814;
		} else if ( (*p) > 147u ) {
			if ( (*p) < 162u ) {
				if ( 154u <= (*p) && (*p) <= 155u )
					goto tr814;
			} else if ( (*p) > 163u ) {
				if ( (*p) > 171u ) {
					if ( 178u <= (*p) && (*p) <= 179u )
						goto tr814;
				} else if ( (*p) >= 170u )
					goto tr814;
			} else
				goto tr814;
		} else
			goto tr814;
	} else if ( (*p) > 187u ) {
		if ( (*p) < 218u ) {
			if ( (*p) < 202u ) {
				if ( 194u <= (*p) && (*p) <= 195u )
					goto tr814;
			} else if ( (*p) > 203u ) {
				if ( 210u <= (*p) && (*p) <= 211u )
					goto tr814;
			} else
				goto tr814;
		} else if ( (*p) > 219u ) {
			if ( (*p) < 234u ) {
				if ( 226u <= (*p) && (*p) <= 227u )
					goto tr814;
			} else if ( (*p) > 235u ) {
				if ( (*p) > 243u ) {
					if ( 250u <= (*p) && (*p) <= 251u )
						goto tr816;
				} else if ( (*p) >= 242u )
					goto tr814;
			} else
				goto tr814;
		} else
			goto tr814;
	} else
		goto tr814;
	goto tr33;
tr858:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st605;
tr882:
#line 243 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    /* This emulates two prefixes case. */
    SET_VEX_PREFIX2((p[0] & 0x80) | 0x61);
    SET_VEX_PREFIX3(p[0] & 0x7f);
  }
	goto st605;
st605:
	if ( ++p == pe )
		goto _test_eof605;
case 605:
#line 30141 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 18u: goto st39;
		case 81u: goto st38;
		case 115u: goto st595;
		case 194u: goto st43;
		case 198u: goto st43;
	}
	if ( (*p) < 116u ) {
		if ( (*p) < 46u ) {
			if ( (*p) > 21u ) {
				if ( 22u <= (*p) && (*p) <= 23u )
					goto st39;
			} else if ( (*p) >= 20u )
				goto st38;
		} else if ( (*p) > 47u ) {
			if ( (*p) < 92u ) {
				if ( 84u <= (*p) && (*p) <= 89u )
					goto st38;
			} else if ( (*p) > 109u ) {
				if ( 113u <= (*p) && (*p) <= 114u )
					goto st52;
			} else
				goto st38;
		} else
			goto st38;
	} else if ( (*p) > 118u ) {
		if ( (*p) < 216u ) {
			if ( (*p) > 125u ) {
				if ( 208u <= (*p) && (*p) <= 213u )
					goto st38;
			} else if ( (*p) >= 124u )
				goto st38;
		} else if ( (*p) > 229u ) {
			if ( (*p) < 241u ) {
				if ( 232u <= (*p) && (*p) <= 239u )
					goto st38;
			} else if ( (*p) > 246u ) {
				if ( 248u <= (*p) && (*p) <= 254u )
					goto st38;
			} else
				goto st38;
		} else
			goto st38;
	} else
		goto st38;
	goto tr33;
tr859:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st606;
tr883:
#line 243 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    /* This emulates two prefixes case. */
    SET_VEX_PREFIX2((p[0] & 0x80) | 0x61);
    SET_VEX_PREFIX3(p[0] & 0x7f);
  }
	goto st606;
st606:
	if ( ++p == pe )
		goto _test_eof606;
case 606:
#line 30206 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 19u: goto st39;
		case 23u: goto st39;
		case 43u: goto st39;
		case 80u: goto tr41;
		case 119u: goto tr34;
		case 174u: goto st237;
		case 194u: goto st43;
		case 198u: goto st43;
	}
	if ( (*p) < 40u ) {
		if ( 16u <= (*p) && (*p) <= 22u )
			goto st38;
	} else if ( (*p) > 41u ) {
		if ( (*p) > 47u ) {
			if ( 81u <= (*p) && (*p) <= 95u )
				goto st38;
		} else if ( (*p) >= 46u )
			goto st38;
	} else
		goto st38;
	goto tr33;
tr860:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st607;
tr884:
#line 243 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    /* This emulates two prefixes case. */
    SET_VEX_PREFIX2((p[0] & 0x80) | 0x61);
    SET_VEX_PREFIX3(p[0] & 0x7f);
  }
	goto st607;
st607:
	if ( ++p == pe )
		goto _test_eof607;
case 607:
#line 30247 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 43u: goto st39;
		case 80u: goto tr41;
		case 81u: goto st38;
		case 112u: goto st43;
		case 115u: goto st595;
		case 127u: goto st38;
		case 194u: goto st43;
		case 197u: goto tr52;
		case 215u: goto tr41;
		case 231u: goto st39;
		case 247u: goto st64;
	}
	if ( (*p) < 84u ) {
		if ( (*p) < 20u ) {
			if ( (*p) > 17u ) {
				if ( 18u <= (*p) && (*p) <= 19u )
					goto st39;
			} else if ( (*p) >= 16u )
				goto st38;
		} else if ( (*p) > 21u ) {
			if ( (*p) < 40u ) {
				if ( 22u <= (*p) && (*p) <= 23u )
					goto st39;
			} else if ( (*p) > 41u ) {
				if ( 46u <= (*p) && (*p) <= 47u )
					goto st38;
			} else
				goto st38;
		} else
			goto st38;
	} else if ( (*p) > 111u ) {
		if ( (*p) < 196u ) {
			if ( (*p) < 116u ) {
				if ( 113u <= (*p) && (*p) <= 114u )
					goto st52;
			} else if ( (*p) > 118u ) {
				if ( 124u <= (*p) && (*p) <= 125u )
					goto st38;
			} else
				goto st38;
		} else if ( (*p) > 198u ) {
			if ( (*p) < 216u ) {
				if ( 208u <= (*p) && (*p) <= 213u )
					goto st38;
			} else if ( (*p) > 239u ) {
				if ( 241u <= (*p) && (*p) <= 254u )
					goto st38;
			} else
				goto st38;
		} else
			goto st43;
	} else
		goto st38;
	goto tr33;
tr861:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st608;
tr885:
#line 243 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    /* This emulates two prefixes case. */
    SET_VEX_PREFIX2((p[0] & 0x80) | 0x61);
    SET_VEX_PREFIX3(p[0] & 0x7f);
  }
	goto st608;
st608:
	if ( ++p == pe )
		goto _test_eof608;
case 608:
#line 30321 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 43u: goto st39;
		case 80u: goto tr41;
		case 119u: goto tr34;
		case 194u: goto st43;
		case 198u: goto st43;
	}
	if ( (*p) < 20u ) {
		if ( 16u <= (*p) && (*p) <= 17u )
			goto st38;
	} else if ( (*p) > 21u ) {
		if ( (*p) > 41u ) {
			if ( 81u <= (*p) && (*p) <= 95u )
				goto st38;
		} else if ( (*p) >= 40u )
			goto st38;
	} else
		goto st38;
	goto tr33;
tr648:
#line 235 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX2(*p);
  }
	goto st609;
st609:
	if ( ++p == pe )
		goto _test_eof609;
case 609:
#line 30351 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 0u: goto tr862;
		case 1u: goto tr819;
		case 5u: goto tr820;
		case 8u: goto tr862;
		case 9u: goto tr819;
		case 13u: goto tr820;
		case 16u: goto tr862;
		case 17u: goto tr819;
		case 21u: goto tr820;
		case 24u: goto tr862;
		case 25u: goto tr819;
		case 29u: goto tr820;
		case 32u: goto tr862;
		case 33u: goto tr819;
		case 37u: goto tr820;
		case 40u: goto tr862;
		case 41u: goto tr819;
		case 45u: goto tr820;
		case 48u: goto tr862;
		case 49u: goto tr819;
		case 53u: goto tr820;
		case 56u: goto tr862;
		case 57u: goto tr819;
		case 61u: goto tr820;
		case 64u: goto tr862;
		case 65u: goto tr819;
		case 69u: goto tr820;
		case 72u: goto tr862;
		case 73u: goto tr819;
		case 77u: goto tr820;
		case 80u: goto tr862;
		case 81u: goto tr819;
		case 85u: goto tr820;
		case 88u: goto tr862;
		case 89u: goto tr819;
		case 93u: goto tr820;
		case 96u: goto tr862;
		case 97u: goto tr819;
		case 101u: goto tr820;
		case 104u: goto tr862;
		case 105u: goto tr819;
		case 109u: goto tr820;
		case 112u: goto tr862;
		case 113u: goto tr819;
		case 117u: goto tr820;
		case 120u: goto tr862;
		case 121u: goto tr821;
		case 125u: goto tr822;
		case 128u: goto tr863;
		case 129u: goto tr824;
		case 133u: goto tr825;
		case 136u: goto tr863;
		case 137u: goto tr824;
		case 141u: goto tr825;
		case 144u: goto tr863;
		case 145u: goto tr824;
		case 149u: goto tr825;
		case 152u: goto tr863;
		case 153u: goto tr824;
		case 157u: goto tr825;
		case 160u: goto tr863;
		case 161u: goto tr824;
		case 165u: goto tr825;
		case 168u: goto tr863;
		case 169u: goto tr824;
		case 173u: goto tr825;
		case 176u: goto tr863;
		case 177u: goto tr824;
		case 181u: goto tr825;
		case 184u: goto tr863;
		case 185u: goto tr824;
		case 189u: goto tr825;
		case 192u: goto tr863;
		case 193u: goto tr824;
		case 197u: goto tr825;
		case 200u: goto tr863;
		case 201u: goto tr824;
		case 205u: goto tr825;
		case 208u: goto tr863;
		case 209u: goto tr824;
		case 213u: goto tr825;
		case 216u: goto tr863;
		case 217u: goto tr824;
		case 221u: goto tr825;
		case 224u: goto tr863;
		case 225u: goto tr824;
		case 229u: goto tr825;
		case 232u: goto tr863;
		case 233u: goto tr824;
		case 237u: goto tr825;
		case 240u: goto tr863;
		case 241u: goto tr824;
		case 245u: goto tr825;
		case 248u: goto tr863;
		case 249u: goto tr824;
		case 253u: goto tr825;
	}
	goto tr33;
tr862:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st610;
st610:
	if ( ++p == pe )
		goto _test_eof610;
case 610:
#line 30461 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 242u: goto tr32;
		case 243u: goto st611;
		case 247u: goto tr32;
	}
	goto tr33;
st611:
	if ( ++p == pe )
		goto _test_eof611;
case 611:
	switch( (*p) ) {
		case 12u: goto tr571;
		case 13u: goto tr617;
		case 20u: goto tr571;
		case 21u: goto tr617;
		case 28u: goto tr571;
		case 29u: goto tr617;
		case 76u: goto tr543;
		case 84u: goto tr543;
		case 92u: goto tr543;
		case 140u: goto tr544;
		case 148u: goto tr544;
		case 156u: goto tr544;
	}
	if ( (*p) < 72u ) {
		if ( 8u <= (*p) && (*p) <= 31u )
			goto tr589;
	} else if ( (*p) > 95u ) {
		if ( (*p) > 159u ) {
			if ( 200u <= (*p) && (*p) <= 223u )
				goto tr545;
		} else if ( (*p) >= 136u )
			goto tr591;
	} else
		goto tr590;
	goto tr33;
tr863:
#line 239 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_VEX_PREFIX3(*p);
  }
	goto st612;
st612:
	if ( ++p == pe )
		goto _test_eof612;
case 612:
#line 30508 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 242u: goto tr221;
		case 243u: goto st613;
		case 247u: goto tr221;
	}
	goto tr33;
st613:
	if ( ++p == pe )
		goto _test_eof613;
case 613:
	switch( (*p) ) {
		case 12u: goto tr574;
		case 13u: goto tr620;
		case 20u: goto tr574;
		case 21u: goto tr620;
		case 28u: goto tr574;
		case 29u: goto tr620;
		case 76u: goto tr549;
		case 84u: goto tr549;
		case 92u: goto tr549;
		case 140u: goto tr550;
		case 148u: goto tr550;
		case 156u: goto tr550;
	}
	if ( (*p) < 72u ) {
		if ( 8u <= (*p) && (*p) <= 31u )
			goto tr595;
	} else if ( (*p) > 95u ) {
		if ( (*p) > 159u ) {
			if ( 200u <= (*p) && (*p) <= 223u )
				goto tr551;
		} else if ( (*p) >= 136u )
			goto tr597;
	} else
		goto tr596;
	goto tr33;
tr1020:
#line 329 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
        begin = p;
        BitmapSetBit(valid_targets, p - data);
        SET_REX_PREFIX(FALSE);
        SET_VEX_PREFIX2(0xe0);
        SET_VEX_PREFIX3(0x00);
        operand_states = 0;
     }
	goto st614;
st614:
	if ( ++p == pe )
		goto _test_eof614;
case 614:
#line 30560 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 0u: goto tr866;
		case 1u: goto tr867;
		case 2u: goto tr868;
		case 3u: goto tr869;
		case 4u: goto tr870;
		case 5u: goto tr871;
		case 6u: goto tr872;
		case 8u: goto tr866;
		case 9u: goto tr867;
		case 10u: goto tr868;
		case 11u: goto tr869;
		case 12u: goto tr870;
		case 13u: goto tr871;
		case 14u: goto tr872;
		case 16u: goto tr866;
		case 17u: goto tr867;
		case 18u: goto tr868;
		case 19u: goto tr869;
		case 20u: goto tr870;
		case 21u: goto tr871;
		case 22u: goto tr872;
		case 24u: goto tr866;
		case 25u: goto tr867;
		case 26u: goto tr868;
		case 27u: goto tr869;
		case 28u: goto tr870;
		case 29u: goto tr871;
		case 30u: goto tr872;
		case 32u: goto tr866;
		case 33u: goto tr867;
		case 34u: goto tr868;
		case 35u: goto tr869;
		case 36u: goto tr870;
		case 37u: goto tr871;
		case 38u: goto tr872;
		case 40u: goto tr866;
		case 41u: goto tr867;
		case 42u: goto tr868;
		case 43u: goto tr869;
		case 44u: goto tr870;
		case 45u: goto tr871;
		case 46u: goto tr872;
		case 48u: goto tr866;
		case 49u: goto tr867;
		case 50u: goto tr868;
		case 51u: goto tr869;
		case 52u: goto tr870;
		case 53u: goto tr871;
		case 54u: goto tr872;
		case 56u: goto tr866;
		case 57u: goto tr867;
		case 58u: goto tr868;
		case 59u: goto tr869;
		case 60u: goto tr870;
		case 61u: goto tr871;
		case 62u: goto tr872;
		case 64u: goto tr866;
		case 65u: goto tr867;
		case 66u: goto tr868;
		case 67u: goto tr869;
		case 68u: goto tr870;
		case 69u: goto tr871;
		case 70u: goto tr872;
		case 72u: goto tr866;
		case 73u: goto tr867;
		case 74u: goto tr868;
		case 75u: goto tr869;
		case 76u: goto tr870;
		case 77u: goto tr871;
		case 78u: goto tr872;
		case 80u: goto tr866;
		case 81u: goto tr867;
		case 82u: goto tr868;
		case 83u: goto tr869;
		case 84u: goto tr870;
		case 85u: goto tr871;
		case 86u: goto tr872;
		case 88u: goto tr866;
		case 89u: goto tr867;
		case 90u: goto tr868;
		case 91u: goto tr869;
		case 92u: goto tr870;
		case 93u: goto tr871;
		case 94u: goto tr872;
		case 96u: goto tr866;
		case 97u: goto tr867;
		case 98u: goto tr868;
		case 99u: goto tr869;
		case 100u: goto tr870;
		case 101u: goto tr871;
		case 102u: goto tr872;
		case 104u: goto tr866;
		case 105u: goto tr867;
		case 106u: goto tr868;
		case 107u: goto tr869;
		case 108u: goto tr870;
		case 109u: goto tr871;
		case 110u: goto tr872;
		case 112u: goto tr866;
		case 113u: goto tr867;
		case 114u: goto tr868;
		case 115u: goto tr869;
		case 116u: goto tr870;
		case 117u: goto tr871;
		case 118u: goto tr872;
		case 120u: goto tr874;
		case 121u: goto tr875;
		case 122u: goto tr876;
		case 123u: goto tr877;
		case 124u: goto tr878;
		case 125u: goto tr879;
		case 126u: goto tr880;
		case 127u: goto tr881;
		case 128u: goto tr866;
		case 129u: goto tr882;
		case 130u: goto tr868;
		case 131u: goto tr869;
		case 132u: goto tr870;
		case 133u: goto tr871;
		case 134u: goto tr872;
		case 136u: goto tr866;
		case 137u: goto tr882;
		case 138u: goto tr868;
		case 139u: goto tr869;
		case 140u: goto tr870;
		case 141u: goto tr871;
		case 142u: goto tr872;
		case 144u: goto tr866;
		case 145u: goto tr882;
		case 146u: goto tr868;
		case 147u: goto tr869;
		case 148u: goto tr870;
		case 149u: goto tr871;
		case 150u: goto tr872;
		case 152u: goto tr866;
		case 153u: goto tr882;
		case 154u: goto tr868;
		case 155u: goto tr869;
		case 156u: goto tr870;
		case 157u: goto tr871;
		case 158u: goto tr872;
		case 160u: goto tr866;
		case 161u: goto tr882;
		case 162u: goto tr868;
		case 163u: goto tr869;
		case 164u: goto tr870;
		case 165u: goto tr871;
		case 166u: goto tr872;
		case 168u: goto tr866;
		case 169u: goto tr882;
		case 170u: goto tr868;
		case 171u: goto tr869;
		case 172u: goto tr870;
		case 173u: goto tr871;
		case 174u: goto tr872;
		case 176u: goto tr866;
		case 177u: goto tr882;
		case 178u: goto tr868;
		case 179u: goto tr869;
		case 180u: goto tr870;
		case 181u: goto tr871;
		case 182u: goto tr872;
		case 184u: goto tr866;
		case 185u: goto tr882;
		case 186u: goto tr868;
		case 187u: goto tr869;
		case 188u: goto tr870;
		case 189u: goto tr871;
		case 190u: goto tr872;
		case 192u: goto tr866;
		case 193u: goto tr882;
		case 194u: goto tr868;
		case 195u: goto tr869;
		case 196u: goto tr870;
		case 197u: goto tr871;
		case 198u: goto tr872;
		case 200u: goto tr866;
		case 201u: goto tr882;
		case 202u: goto tr868;
		case 203u: goto tr869;
		case 204u: goto tr870;
		case 205u: goto tr871;
		case 206u: goto tr872;
		case 208u: goto tr866;
		case 209u: goto tr882;
		case 210u: goto tr868;
		case 211u: goto tr869;
		case 212u: goto tr870;
		case 213u: goto tr871;
		case 214u: goto tr872;
		case 216u: goto tr866;
		case 217u: goto tr882;
		case 218u: goto tr868;
		case 219u: goto tr869;
		case 220u: goto tr870;
		case 221u: goto tr871;
		case 222u: goto tr872;
		case 224u: goto tr866;
		case 225u: goto tr882;
		case 226u: goto tr868;
		case 227u: goto tr869;
		case 228u: goto tr870;
		case 229u: goto tr871;
		case 230u: goto tr872;
		case 232u: goto tr866;
		case 233u: goto tr882;
		case 234u: goto tr868;
		case 235u: goto tr869;
		case 236u: goto tr870;
		case 237u: goto tr871;
		case 238u: goto tr872;
		case 240u: goto tr866;
		case 241u: goto tr882;
		case 242u: goto tr868;
		case 243u: goto tr869;
		case 244u: goto tr870;
		case 245u: goto tr871;
		case 246u: goto tr872;
		case 248u: goto tr883;
		case 249u: goto tr884;
		case 250u: goto tr876;
		case 251u: goto tr877;
		case 252u: goto tr885;
		case 253u: goto tr879;
		case 254u: goto tr880;
		case 255u: goto tr881;
	}
	goto tr873;
tr868:
#line 243 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    /* This emulates two prefixes case. */
    SET_VEX_PREFIX2((p[0] & 0x80) | 0x61);
    SET_VEX_PREFIX3(p[0] & 0x7f);
  }
	goto st615;
st615:
	if ( ++p == pe )
		goto _test_eof615;
case 615:
#line 30802 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 81u: goto st38;
		case 83u: goto st38;
		case 194u: goto st43;
	}
	if ( (*p) > 90u ) {
		if ( 92u <= (*p) && (*p) <= 95u )
			goto st38;
	} else if ( (*p) >= 88u )
		goto st38;
	goto tr33;
tr869:
#line 243 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    /* This emulates two prefixes case. */
    SET_VEX_PREFIX2((p[0] & 0x80) | 0x61);
    SET_VEX_PREFIX3(p[0] & 0x7f);
  }
	goto st616;
st616:
	if ( ++p == pe )
		goto _test_eof616;
case 616:
#line 30826 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 81u: goto st38;
		case 194u: goto st43;
		case 208u: goto st38;
	}
	if ( (*p) < 92u ) {
		if ( 88u <= (*p) && (*p) <= 90u )
			goto st38;
	} else if ( (*p) > 95u ) {
		if ( 124u <= (*p) && (*p) <= 125u )
			goto st38;
	} else
		goto st38;
	goto tr33;
tr876:
#line 243 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    /* This emulates two prefixes case. */
    SET_VEX_PREFIX2((p[0] & 0x80) | 0x61);
    SET_VEX_PREFIX3(p[0] & 0x7f);
  }
	goto st617;
st617:
	if ( ++p == pe )
		goto _test_eof617;
case 617:
#line 30853 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 18u: goto st38;
		case 22u: goto st38;
		case 111u: goto st38;
		case 112u: goto st43;
		case 194u: goto st43;
		case 230u: goto st38;
	}
	if ( (*p) < 81u ) {
		if ( 16u <= (*p) && (*p) <= 17u )
			goto st39;
	} else if ( (*p) > 83u ) {
		if ( (*p) > 95u ) {
			if ( 126u <= (*p) && (*p) <= 127u )
				goto st38;
		} else if ( (*p) >= 88u )
			goto st38;
	} else
		goto st38;
	goto tr33;
tr877:
#line 243 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    /* This emulates two prefixes case. */
    SET_VEX_PREFIX2((p[0] & 0x80) | 0x61);
    SET_VEX_PREFIX3(p[0] & 0x7f);
  }
	goto st618;
st618:
	if ( ++p == pe )
		goto _test_eof618;
case 618:
#line 30886 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 18u: goto st38;
		case 81u: goto st38;
		case 112u: goto st43;
		case 194u: goto st43;
		case 208u: goto st38;
		case 230u: goto st38;
		case 240u: goto st39;
	}
	if ( (*p) < 88u ) {
		if ( 16u <= (*p) && (*p) <= 17u )
			goto st39;
	} else if ( (*p) > 90u ) {
		if ( (*p) > 95u ) {
			if ( 124u <= (*p) && (*p) <= 125u )
				goto st38;
		} else if ( (*p) >= 92u )
			goto st38;
	} else
		goto st38;
	goto tr33;
tr1021:
#line 329 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
        begin = p;
        BitmapSetBit(valid_targets, p - data);
        SET_REX_PREFIX(FALSE);
        SET_VEX_PREFIX2(0xe0);
        SET_VEX_PREFIX3(0x00);
        operand_states = 0;
     }
	goto st619;
st619:
	if ( ++p == pe )
		goto _test_eof619;
case 619:
#line 30923 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 4u: goto st44;
		case 5u: goto tr95;
		case 68u: goto st50;
		case 132u: goto st51;
	}
	if ( (*p) < 64u ) {
		if ( (*p) <= 7u )
			goto tr93;
	} else if ( (*p) > 71u ) {
		if ( (*p) > 135u ) {
			if ( 192u <= (*p) && (*p) <= 199u )
				goto tr184;
		} else if ( (*p) >= 128u )
			goto tr98;
	} else
		goto tr96;
	goto tr33;
tr1022:
#line 329 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
        begin = p;
        BitmapSetBit(valid_targets, p - data);
        SET_REX_PREFIX(FALSE);
        SET_VEX_PREFIX2(0xe0);
        SET_VEX_PREFIX3(0x00);
        operand_states = 0;
     }
	goto st620;
st620:
	if ( ++p == pe )
		goto _test_eof620;
case 620:
#line 30957 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 4u: goto st80;
		case 5u: goto tr248;
		case 68u: goto st86;
		case 132u: goto st87;
	}
	if ( (*p) < 64u ) {
		if ( (*p) <= 7u )
			goto tr185;
	} else if ( (*p) > 71u ) {
		if ( (*p) > 135u ) {
			if ( 192u <= (*p) && (*p) <= 199u )
				goto tr191;
		} else if ( (*p) >= 128u )
			goto tr189;
	} else
		goto tr187;
	goto tr33;
tr1023:
#line 329 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
        begin = p;
        BitmapSetBit(valid_targets, p - data);
        SET_REX_PREFIX(FALSE);
        SET_VEX_PREFIX2(0xe0);
        SET_VEX_PREFIX3(0x00);
        operand_states = 0;
     }
	goto st621;
st621:
	if ( ++p == pe )
		goto _test_eof621;
case 621:
#line 30991 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	goto st622;
st622:
	if ( ++p == pe )
		goto _test_eof622;
case 622:
	goto tr887;
tr1025:
#line 329 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
        begin = p;
        BitmapSetBit(valid_targets, p - data);
        SET_REX_PREFIX(FALSE);
        SET_VEX_PREFIX2(0xe0);
        SET_VEX_PREFIX3(0x00);
        operand_states = 0;
     }
	goto st623;
st623:
	if ( ++p == pe )
		goto _test_eof623;
case 623:
#line 31013 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 4u: goto st2;
		case 5u: goto tr2;
		case 12u: goto st2;
		case 13u: goto tr2;
		case 20u: goto st2;
		case 21u: goto tr2;
		case 28u: goto st2;
		case 29u: goto tr2;
		case 36u: goto st2;
		case 37u: goto tr2;
		case 44u: goto st2;
		case 45u: goto tr2;
		case 60u: goto st2;
		case 61u: goto tr2;
		case 68u: goto st8;
		case 76u: goto st8;
		case 84u: goto st8;
		case 92u: goto st8;
		case 100u: goto st8;
		case 108u: goto st8;
		case 124u: goto st8;
		case 132u: goto st9;
		case 140u: goto st9;
		case 148u: goto st9;
		case 156u: goto st9;
		case 164u: goto st9;
		case 172u: goto st9;
		case 188u: goto st9;
	}
	if ( (*p) < 112u ) {
		if ( (*p) < 48u ) {
			if ( (*p) <= 47u )
				goto tr0;
		} else if ( (*p) > 55u ) {
			if ( (*p) > 63u ) {
				if ( 64u <= (*p) && (*p) <= 111u )
					goto tr3;
			} else if ( (*p) >= 56u )
				goto tr0;
		} else
			goto tr33;
	} else if ( (*p) > 119u ) {
		if ( (*p) < 176u ) {
			if ( (*p) > 127u ) {
				if ( 128u <= (*p) && (*p) <= 175u )
					goto tr5;
			} else if ( (*p) >= 120u )
				goto tr3;
		} else if ( (*p) > 183u ) {
			if ( (*p) > 191u ) {
				if ( 240u <= (*p) && (*p) <= 247u )
					goto tr33;
			} else if ( (*p) >= 184u )
				goto tr5;
		} else
			goto tr33;
	} else
		goto tr33;
	goto tr210;
tr1026:
#line 329 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
        begin = p;
        BitmapSetBit(valid_targets, p - data);
        SET_REX_PREFIX(FALSE);
        SET_VEX_PREFIX2(0xe0);
        SET_VEX_PREFIX3(0x00);
        operand_states = 0;
     }
	goto st624;
st624:
	if ( ++p == pe )
		goto _test_eof624;
case 624:
#line 31089 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 4u: goto st2;
		case 5u: goto tr2;
		case 12u: goto st2;
		case 13u: goto tr2;
		case 20u: goto st2;
		case 21u: goto tr2;
		case 28u: goto st2;
		case 29u: goto tr2;
		case 36u: goto st2;
		case 37u: goto tr2;
		case 44u: goto st2;
		case 45u: goto tr2;
		case 60u: goto st2;
		case 61u: goto tr2;
		case 68u: goto st8;
		case 76u: goto st8;
		case 84u: goto st8;
		case 92u: goto st8;
		case 100u: goto st8;
		case 108u: goto st8;
		case 124u: goto st8;
		case 132u: goto st9;
		case 140u: goto st9;
		case 148u: goto st9;
		case 156u: goto st9;
		case 164u: goto st9;
		case 172u: goto st9;
		case 188u: goto st9;
	}
	if ( (*p) < 112u ) {
		if ( (*p) < 48u ) {
			if ( (*p) <= 47u )
				goto tr0;
		} else if ( (*p) > 55u ) {
			if ( (*p) > 63u ) {
				if ( 64u <= (*p) && (*p) <= 111u )
					goto tr3;
			} else if ( (*p) >= 56u )
				goto tr0;
		} else
			goto tr33;
	} else if ( (*p) > 119u ) {
		if ( (*p) < 176u ) {
			if ( (*p) > 127u ) {
				if ( 128u <= (*p) && (*p) <= 175u )
					goto tr5;
			} else if ( (*p) >= 120u )
				goto tr3;
		} else if ( (*p) > 183u ) {
			if ( (*p) > 191u ) {
				if ( 240u <= (*p) && (*p) <= 247u )
					goto tr33;
			} else if ( (*p) >= 184u )
				goto tr5;
		} else
			goto tr33;
	} else
		goto tr33;
	goto tr56;
tr1027:
#line 329 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
        begin = p;
        BitmapSetBit(valid_targets, p - data);
        SET_REX_PREFIX(FALSE);
        SET_VEX_PREFIX2(0xe0);
        SET_VEX_PREFIX3(0x00);
        operand_states = 0;
     }
	goto st625;
st625:
	if ( ++p == pe )
		goto _test_eof625;
case 625:
#line 31165 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 4u: goto st2;
		case 5u: goto tr2;
		case 20u: goto st2;
		case 21u: goto tr2;
		case 28u: goto st2;
		case 29u: goto tr2;
		case 36u: goto st2;
		case 37u: goto tr2;
		case 44u: goto st2;
		case 45u: goto tr2;
		case 52u: goto st2;
		case 53u: goto tr2;
		case 60u: goto st2;
		case 61u: goto tr2;
		case 68u: goto st8;
		case 84u: goto st8;
		case 92u: goto st8;
		case 100u: goto st8;
		case 108u: goto st8;
		case 116u: goto st8;
		case 124u: goto st8;
		case 132u: goto st9;
		case 148u: goto st9;
		case 156u: goto st9;
		case 164u: goto st9;
		case 172u: goto st9;
		case 180u: goto st9;
		case 188u: goto st9;
		case 239u: goto tr33;
	}
	if ( (*p) < 144u ) {
		if ( (*p) < 16u ) {
			if ( (*p) > 7u ) {
				if ( 8u <= (*p) && (*p) <= 15u )
					goto tr33;
			} else
				goto tr0;
		} else if ( (*p) > 63u ) {
			if ( (*p) < 128u ) {
				if ( 72u <= (*p) && (*p) <= 79u )
					goto tr33;
			} else if ( (*p) > 135u ) {
				if ( 136u <= (*p) && (*p) <= 143u )
					goto tr33;
			} else
				goto tr5;
		} else
			goto tr0;
	} else if ( (*p) > 191u ) {
		if ( (*p) < 226u ) {
			if ( (*p) < 209u ) {
				if ( 192u <= (*p) && (*p) <= 208u )
					goto tr34;
			} else if ( (*p) > 223u ) {
				if ( 224u <= (*p) && (*p) <= 225u )
					goto tr34;
			} else
				goto tr33;
		} else if ( (*p) > 227u ) {
			if ( (*p) < 230u ) {
				if ( 228u <= (*p) && (*p) <= 229u )
					goto tr34;
			} else if ( (*p) > 231u ) {
				if ( 232u <= (*p) )
					goto tr34;
			} else
				goto tr33;
		} else
			goto tr33;
	} else
		goto tr5;
	goto tr3;
tr1028:
#line 329 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
        begin = p;
        BitmapSetBit(valid_targets, p - data);
        SET_REX_PREFIX(FALSE);
        SET_VEX_PREFIX2(0xe0);
        SET_VEX_PREFIX3(0x00);
        operand_states = 0;
     }
	goto st626;
st626:
	if ( ++p == pe )
		goto _test_eof626;
case 626:
#line 31254 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 4u: goto st2;
		case 5u: goto tr2;
		case 12u: goto st2;
		case 13u: goto tr2;
		case 20u: goto st2;
		case 21u: goto tr2;
		case 28u: goto st2;
		case 29u: goto tr2;
		case 36u: goto st2;
		case 37u: goto tr2;
		case 44u: goto st2;
		case 45u: goto tr2;
		case 52u: goto st2;
		case 53u: goto tr2;
		case 60u: goto st2;
		case 61u: goto tr2;
		case 68u: goto st8;
		case 76u: goto st8;
		case 84u: goto st8;
		case 92u: goto st8;
		case 100u: goto st8;
		case 108u: goto st8;
		case 116u: goto st8;
		case 124u: goto st8;
		case 132u: goto st9;
		case 140u: goto st9;
		case 148u: goto st9;
		case 156u: goto st9;
		case 164u: goto st9;
		case 172u: goto st9;
		case 180u: goto st9;
		case 188u: goto st9;
		case 233u: goto tr34;
	}
	if ( (*p) < 128u ) {
		if ( (*p) <= 63u )
			goto tr0;
	} else if ( (*p) > 191u ) {
		if ( (*p) > 223u ) {
			if ( 224u <= (*p) )
				goto tr33;
		} else if ( (*p) >= 192u )
			goto tr34;
	} else
		goto tr5;
	goto tr3;
tr1029:
#line 329 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
        begin = p;
        BitmapSetBit(valid_targets, p - data);
        SET_REX_PREFIX(FALSE);
        SET_VEX_PREFIX2(0xe0);
        SET_VEX_PREFIX3(0x00);
        operand_states = 0;
     }
	goto st627;
st627:
	if ( ++p == pe )
		goto _test_eof627;
case 627:
#line 31317 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 4u: goto st2;
		case 5u: goto tr2;
		case 12u: goto st2;
		case 13u: goto tr2;
		case 20u: goto st2;
		case 21u: goto tr2;
		case 28u: goto st2;
		case 29u: goto tr2;
		case 44u: goto st2;
		case 45u: goto tr2;
		case 60u: goto st2;
		case 61u: goto tr2;
		case 68u: goto st8;
		case 76u: goto st8;
		case 84u: goto st8;
		case 92u: goto st8;
		case 108u: goto st8;
		case 124u: goto st8;
		case 132u: goto st9;
		case 140u: goto st9;
		case 148u: goto st9;
		case 156u: goto st9;
		case 172u: goto st9;
		case 188u: goto st9;
	}
	if ( (*p) < 120u ) {
		if ( (*p) < 56u ) {
			if ( (*p) > 31u ) {
				if ( 40u <= (*p) && (*p) <= 47u )
					goto tr0;
			} else
				goto tr0;
		} else if ( (*p) > 63u ) {
			if ( (*p) > 95u ) {
				if ( 104u <= (*p) && (*p) <= 111u )
					goto tr3;
			} else if ( (*p) >= 64u )
				goto tr3;
		} else
			goto tr0;
	} else if ( (*p) > 127u ) {
		if ( (*p) < 184u ) {
			if ( (*p) > 159u ) {
				if ( 168u <= (*p) && (*p) <= 175u )
					goto tr5;
			} else if ( (*p) >= 128u )
				goto tr5;
		} else if ( (*p) > 191u ) {
			if ( (*p) < 226u ) {
				if ( 192u <= (*p) && (*p) <= 223u )
					goto tr34;
			} else if ( (*p) > 227u ) {
				if ( 232u <= (*p) && (*p) <= 247u )
					goto tr34;
			} else
				goto tr34;
		} else
			goto tr5;
	} else
		goto tr3;
	goto tr33;
tr1030:
#line 329 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
        begin = p;
        BitmapSetBit(valid_targets, p - data);
        SET_REX_PREFIX(FALSE);
        SET_VEX_PREFIX2(0xe0);
        SET_VEX_PREFIX3(0x00);
        operand_states = 0;
     }
	goto st628;
st628:
	if ( ++p == pe )
		goto _test_eof628;
case 628:
#line 31395 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 4u: goto st2;
		case 5u: goto tr2;
		case 12u: goto st2;
		case 13u: goto tr2;
		case 20u: goto st2;
		case 21u: goto tr2;
		case 28u: goto st2;
		case 29u: goto tr2;
		case 36u: goto st2;
		case 37u: goto tr2;
		case 44u: goto st2;
		case 45u: goto tr2;
		case 52u: goto st2;
		case 53u: goto tr2;
		case 60u: goto st2;
		case 61u: goto tr2;
		case 68u: goto st8;
		case 76u: goto st8;
		case 84u: goto st8;
		case 92u: goto st8;
		case 100u: goto st8;
		case 108u: goto st8;
		case 116u: goto st8;
		case 124u: goto st8;
		case 132u: goto st9;
		case 140u: goto st9;
		case 148u: goto st9;
		case 156u: goto st9;
		case 164u: goto st9;
		case 172u: goto st9;
		case 180u: goto st9;
		case 188u: goto st9;
	}
	if ( (*p) < 192u ) {
		if ( (*p) > 63u ) {
			if ( 128u <= (*p) && (*p) <= 191u )
				goto tr5;
		} else
			goto tr0;
	} else if ( (*p) > 207u ) {
		if ( (*p) > 223u ) {
			if ( 224u <= (*p) )
				goto tr34;
		} else if ( (*p) >= 208u )
			goto tr33;
	} else
		goto tr34;
	goto tr3;
tr1031:
#line 329 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
        begin = p;
        BitmapSetBit(valid_targets, p - data);
        SET_REX_PREFIX(FALSE);
        SET_VEX_PREFIX2(0xe0);
        SET_VEX_PREFIX3(0x00);
        operand_states = 0;
     }
	goto st629;
st629:
	if ( ++p == pe )
		goto _test_eof629;
case 629:
#line 31460 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 4u: goto st2;
		case 5u: goto tr2;
		case 12u: goto st2;
		case 13u: goto tr2;
		case 20u: goto st2;
		case 21u: goto tr2;
		case 28u: goto st2;
		case 29u: goto tr2;
		case 36u: goto st2;
		case 37u: goto tr2;
		case 52u: goto st2;
		case 53u: goto tr2;
		case 60u: goto st2;
		case 61u: goto tr2;
		case 68u: goto st8;
		case 76u: goto st8;
		case 84u: goto st8;
		case 92u: goto st8;
		case 100u: goto st8;
		case 116u: goto st8;
		case 124u: goto st8;
		case 132u: goto st9;
		case 140u: goto st9;
		case 148u: goto st9;
		case 156u: goto st9;
		case 164u: goto st9;
		case 180u: goto st9;
		case 188u: goto st9;
	}
	if ( (*p) < 168u ) {
		if ( (*p) < 48u ) {
			if ( (*p) > 39u ) {
				if ( 40u <= (*p) && (*p) <= 47u )
					goto tr33;
			} else
				goto tr0;
		} else if ( (*p) > 63u ) {
			if ( (*p) > 111u ) {
				if ( 128u <= (*p) && (*p) <= 167u )
					goto tr5;
			} else if ( (*p) >= 104u )
				goto tr33;
		} else
			goto tr0;
	} else if ( (*p) > 175u ) {
		if ( (*p) < 200u ) {
			if ( (*p) > 191u ) {
				if ( 192u <= (*p) && (*p) <= 199u )
					goto tr34;
			} else if ( (*p) >= 176u )
				goto tr5;
		} else if ( (*p) > 207u ) {
			if ( (*p) > 239u ) {
				if ( 240u <= (*p) )
					goto tr33;
			} else if ( (*p) >= 208u )
				goto tr34;
		} else
			goto tr33;
	} else
		goto tr33;
	goto tr3;
tr1032:
#line 329 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
        begin = p;
        BitmapSetBit(valid_targets, p - data);
        SET_REX_PREFIX(FALSE);
        SET_VEX_PREFIX2(0xe0);
        SET_VEX_PREFIX3(0x00);
        operand_states = 0;
     }
	goto st630;
st630:
	if ( ++p == pe )
		goto _test_eof630;
case 630:
#line 31539 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 4u: goto st2;
		case 5u: goto tr2;
		case 12u: goto st2;
		case 13u: goto tr2;
		case 20u: goto st2;
		case 21u: goto tr2;
		case 28u: goto st2;
		case 29u: goto tr2;
		case 36u: goto st2;
		case 37u: goto tr2;
		case 44u: goto st2;
		case 45u: goto tr2;
		case 52u: goto st2;
		case 53u: goto tr2;
		case 60u: goto st2;
		case 61u: goto tr2;
		case 68u: goto st8;
		case 76u: goto st8;
		case 84u: goto st8;
		case 92u: goto st8;
		case 100u: goto st8;
		case 108u: goto st8;
		case 116u: goto st8;
		case 124u: goto st8;
		case 132u: goto st9;
		case 140u: goto st9;
		case 148u: goto st9;
		case 156u: goto st9;
		case 164u: goto st9;
		case 172u: goto st9;
		case 180u: goto st9;
		case 188u: goto st9;
		case 217u: goto tr34;
	}
	if ( (*p) < 192u ) {
		if ( (*p) > 63u ) {
			if ( 128u <= (*p) && (*p) <= 191u )
				goto tr5;
		} else
			goto tr0;
	} else if ( (*p) > 207u ) {
		if ( (*p) > 223u ) {
			if ( 224u <= (*p) )
				goto tr34;
		} else if ( (*p) >= 208u )
			goto tr33;
	} else
		goto tr34;
	goto tr3;
tr1033:
#line 329 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
        begin = p;
        BitmapSetBit(valid_targets, p - data);
        SET_REX_PREFIX(FALSE);
        SET_VEX_PREFIX2(0xe0);
        SET_VEX_PREFIX3(0x00);
        operand_states = 0;
     }
	goto st631;
st631:
	if ( ++p == pe )
		goto _test_eof631;
case 631:
#line 31605 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 4u: goto st2;
		case 5u: goto tr2;
		case 12u: goto st2;
		case 13u: goto tr2;
		case 20u: goto st2;
		case 21u: goto tr2;
		case 28u: goto st2;
		case 29u: goto tr2;
		case 36u: goto st2;
		case 37u: goto tr2;
		case 44u: goto st2;
		case 45u: goto tr2;
		case 52u: goto st2;
		case 53u: goto tr2;
		case 60u: goto st2;
		case 61u: goto tr2;
		case 68u: goto st8;
		case 76u: goto st8;
		case 84u: goto st8;
		case 92u: goto st8;
		case 100u: goto st8;
		case 108u: goto st8;
		case 116u: goto st8;
		case 124u: goto st8;
		case 132u: goto st9;
		case 140u: goto st9;
		case 148u: goto st9;
		case 156u: goto st9;
		case 164u: goto st9;
		case 172u: goto st9;
		case 180u: goto st9;
		case 188u: goto st9;
		case 224u: goto tr888;
	}
	if ( (*p) < 192u ) {
		if ( (*p) > 63u ) {
			if ( 128u <= (*p) && (*p) <= 191u )
				goto tr5;
		} else
			goto tr0;
	} else if ( (*p) > 231u ) {
		if ( (*p) > 247u ) {
			if ( 248u <= (*p) )
				goto tr33;
		} else if ( (*p) >= 232u )
			goto tr34;
	} else
		goto tr33;
	goto tr3;
tr1035:
#line 329 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
        begin = p;
        BitmapSetBit(valid_targets, p - data);
        SET_REX_PREFIX(FALSE);
        SET_VEX_PREFIX2(0xe0);
        SET_VEX_PREFIX3(0x00);
        operand_states = 0;
     }
#line 13 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_LOCK_PREFIX(TRUE);
  }
	goto st632;
st632:
	if ( ++p == pe )
		goto _test_eof632;
case 632:
#line 31675 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 2u: goto tr889;
		case 3u: goto tr50;
		case 10u: goto tr889;
		case 11u: goto tr50;
		case 15u: goto st633;
		case 18u: goto tr889;
		case 19u: goto tr50;
		case 26u: goto tr889;
		case 27u: goto tr50;
		case 34u: goto tr889;
		case 35u: goto tr50;
		case 42u: goto tr889;
		case 43u: goto tr50;
		case 50u: goto tr889;
		case 51u: goto tr50;
		case 72u: goto tr892;
		case 102u: goto tr894;
		case 128u: goto st236;
		case 129u: goto st639;
		case 131u: goto st236;
		case 134u: goto tr896;
		case 135u: goto tr897;
	}
	if ( (*p) < 40u ) {
		if ( (*p) < 16u ) {
			if ( (*p) > 1u ) {
				if ( 8u <= (*p) && (*p) <= 9u )
					goto st39;
			} else
				goto st39;
		} else if ( (*p) > 17u ) {
			if ( (*p) > 25u ) {
				if ( 32u <= (*p) && (*p) <= 33u )
					goto st39;
			} else if ( (*p) >= 24u )
				goto st39;
		} else
			goto st39;
	} else if ( (*p) > 41u ) {
		if ( (*p) < 73u ) {
			if ( (*p) > 49u ) {
				if ( 64u <= (*p) && (*p) <= 71u )
					goto tr891;
			} else if ( (*p) >= 48u )
				goto st39;
		} else if ( (*p) > 79u ) {
			if ( (*p) > 247u ) {
				if ( 254u <= (*p) )
					goto st238;
			} else if ( (*p) >= 246u )
				goto st237;
		} else
			goto tr893;
	} else
		goto st39;
	goto tr33;
st633:
	if ( ++p == pe )
		goto _test_eof633;
case 633:
	switch( (*p) ) {
		case 186u: goto st226;
		case 199u: goto st63;
	}
	if ( (*p) > 177u ) {
		if ( 192u <= (*p) && (*p) <= 193u )
			goto st39;
	} else if ( (*p) >= 176u )
		goto st39;
	goto tr33;
tr891:
#line 190 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_REX_PREFIX(*p);
  }
	goto st634;
st634:
	if ( ++p == pe )
		goto _test_eof634;
case 634:
#line 31757 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 2u: goto tr889;
		case 3u: goto tr50;
		case 10u: goto tr889;
		case 11u: goto tr50;
		case 15u: goto st635;
		case 18u: goto tr889;
		case 19u: goto tr50;
		case 26u: goto tr889;
		case 27u: goto tr50;
		case 34u: goto tr889;
		case 35u: goto tr50;
		case 42u: goto tr889;
		case 43u: goto tr50;
		case 50u: goto tr889;
		case 51u: goto tr50;
		case 128u: goto st231;
		case 129u: goto st636;
		case 131u: goto st231;
		case 134u: goto tr896;
		case 135u: goto tr897;
	}
	if ( (*p) < 32u ) {
		if ( (*p) < 8u ) {
			if ( (*p) <= 1u )
				goto st39;
		} else if ( (*p) > 9u ) {
			if ( (*p) > 17u ) {
				if ( 24u <= (*p) && (*p) <= 25u )
					goto st39;
			} else if ( (*p) >= 16u )
				goto st39;
		} else
			goto st39;
	} else if ( (*p) > 33u ) {
		if ( (*p) < 48u ) {
			if ( 40u <= (*p) && (*p) <= 41u )
				goto st39;
		} else if ( (*p) > 49u ) {
			if ( (*p) > 247u ) {
				if ( 254u <= (*p) )
					goto st234;
			} else if ( (*p) >= 246u )
				goto st233;
		} else
			goto st39;
	} else
		goto st39;
	goto tr33;
st635:
	if ( ++p == pe )
		goto _test_eof635;
case 635:
	switch( (*p) ) {
		case 186u: goto st229;
		case 199u: goto st78;
	}
	if ( (*p) > 177u ) {
		if ( 192u <= (*p) && (*p) <= 193u )
			goto st39;
	} else if ( (*p) >= 176u )
		goto st39;
	goto tr33;
st636:
	if ( ++p == pe )
		goto _test_eof636;
case 636:
	switch( (*p) ) {
		case 4u: goto st80;
		case 12u: goto st80;
		case 20u: goto st80;
		case 28u: goto st80;
		case 36u: goto st80;
		case 44u: goto st80;
		case 52u: goto st80;
		case 68u: goto st86;
		case 76u: goto st86;
		case 84u: goto st86;
		case 92u: goto st86;
		case 100u: goto st86;
		case 108u: goto st86;
		case 116u: goto st86;
		case 132u: goto st87;
		case 140u: goto st87;
		case 148u: goto st87;
		case 156u: goto st87;
		case 164u: goto st87;
		case 172u: goto st87;
		case 180u: goto st87;
	}
	if ( (*p) < 30u ) {
		if ( (*p) < 6u ) {
			if ( (*p) <= 3u )
				goto tr185;
		} else if ( (*p) > 11u ) {
			if ( (*p) > 19u ) {
				if ( 22u <= (*p) && (*p) <= 27u )
					goto tr185;
			} else if ( (*p) >= 14u )
				goto tr185;
		} else
			goto tr185;
	} else if ( (*p) > 35u ) {
		if ( (*p) < 54u ) {
			if ( (*p) > 43u ) {
				if ( 46u <= (*p) && (*p) <= 51u )
					goto tr185;
			} else if ( (*p) >= 38u )
				goto tr185;
		} else if ( (*p) > 55u ) {
			if ( (*p) > 119u ) {
				if ( 128u <= (*p) && (*p) <= 183u )
					goto tr189;
			} else if ( (*p) >= 64u )
				goto tr187;
		} else
			goto tr185;
	} else
		goto tr185;
	goto tr33;
tr892:
#line 190 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_REX_PREFIX(*p);
  }
	goto st637;
st637:
	if ( ++p == pe )
		goto _test_eof637;
case 637:
#line 31888 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 1u: goto st39;
		case 3u: goto tr244;
		case 9u: goto st39;
		case 11u: goto tr244;
		case 15u: goto st638;
		case 17u: goto st39;
		case 19u: goto tr244;
		case 25u: goto st39;
		case 27u: goto tr244;
		case 33u: goto st39;
		case 35u: goto tr244;
		case 41u: goto st39;
		case 43u: goto tr244;
		case 49u: goto st39;
		case 51u: goto tr244;
		case 129u: goto st639;
		case 131u: goto st236;
		case 135u: goto tr901;
		case 247u: goto st237;
		case 255u: goto st238;
	}
	goto tr33;
st638:
	if ( ++p == pe )
		goto _test_eof638;
case 638:
	switch( (*p) ) {
		case 177u: goto st39;
		case 186u: goto st226;
		case 193u: goto st39;
		case 199u: goto st63;
	}
	goto tr33;
st639:
	if ( ++p == pe )
		goto _test_eof639;
case 639:
	switch( (*p) ) {
		case 4u: goto st80;
		case 5u: goto tr248;
		case 12u: goto st80;
		case 13u: goto tr248;
		case 20u: goto st80;
		case 21u: goto tr248;
		case 28u: goto st80;
		case 29u: goto tr248;
		case 36u: goto st80;
		case 37u: goto tr248;
		case 44u: goto st80;
		case 45u: goto tr248;
		case 52u: goto st80;
		case 53u: goto tr248;
		case 68u: goto st86;
		case 76u: goto st86;
		case 84u: goto st86;
		case 92u: goto st86;
		case 100u: goto st86;
		case 108u: goto st86;
		case 116u: goto st86;
		case 132u: goto st87;
		case 140u: goto st87;
		case 148u: goto st87;
		case 156u: goto st87;
		case 164u: goto st87;
		case 172u: goto st87;
		case 180u: goto st87;
	}
	if ( (*p) < 64u ) {
		if ( (*p) <= 55u )
			goto tr185;
	} else if ( (*p) > 119u ) {
		if ( 128u <= (*p) && (*p) <= 183u )
			goto tr189;
	} else
		goto tr187;
	goto tr33;
tr893:
#line 190 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_REX_PREFIX(*p);
  }
	goto st640;
st640:
	if ( ++p == pe )
		goto _test_eof640;
case 640:
#line 31976 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 1u: goto st39;
		case 3u: goto tr244;
		case 9u: goto st39;
		case 11u: goto tr244;
		case 15u: goto st641;
		case 17u: goto st39;
		case 19u: goto tr244;
		case 25u: goto st39;
		case 27u: goto tr244;
		case 33u: goto st39;
		case 35u: goto tr244;
		case 41u: goto st39;
		case 43u: goto tr244;
		case 49u: goto st39;
		case 51u: goto tr244;
		case 129u: goto st636;
		case 131u: goto st231;
		case 135u: goto tr901;
		case 247u: goto st233;
		case 255u: goto st234;
	}
	goto tr33;
st641:
	if ( ++p == pe )
		goto _test_eof641;
case 641:
	switch( (*p) ) {
		case 177u: goto st39;
		case 186u: goto st229;
		case 193u: goto st39;
		case 199u: goto st78;
	}
	goto tr33;
tr1036:
#line 329 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
        begin = p;
        BitmapSetBit(valid_targets, p - data);
        SET_REX_PREFIX(FALSE);
        SET_VEX_PREFIX2(0xe0);
        SET_VEX_PREFIX3(0x00);
        operand_states = 0;
     }
#line 22 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_REPNZ_PREFIX(TRUE);
  }
	goto st642;
st642:
	if ( ++p == pe )
		goto _test_eof642;
case 642:
#line 32030 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 15u: goto st643;
		case 72u: goto tr905;
		case 102u: goto tr907;
	}
	if ( (*p) < 73u ) {
		if ( 64u <= (*p) && (*p) <= 71u )
			goto tr904;
	} else if ( (*p) > 79u ) {
		if ( (*p) > 167u ) {
			if ( 174u <= (*p) && (*p) <= 175u )
				goto tr233;
		} else if ( (*p) >= 166u )
			goto tr232;
	} else
		goto tr906;
	goto tr33;
st643:
	if ( ++p == pe )
		goto _test_eof643;
case 643:
	switch( (*p) ) {
		case 42u: goto tr908;
		case 43u: goto tr909;
		case 56u: goto st644;
		case 81u: goto tr908;
		case 112u: goto tr911;
		case 120u: goto tr912;
		case 121u: goto tr913;
		case 194u: goto tr911;
		case 208u: goto tr908;
		case 214u: goto tr913;
		case 230u: goto tr908;
		case 240u: goto tr909;
	}
	if ( (*p) < 88u ) {
		if ( (*p) > 18u ) {
			if ( 44u <= (*p) && (*p) <= 45u )
				goto tr429;
		} else if ( (*p) >= 16u )
			goto tr908;
	} else if ( (*p) > 90u ) {
		if ( (*p) > 95u ) {
			if ( 124u <= (*p) && (*p) <= 125u )
				goto tr908;
		} else if ( (*p) >= 92u )
			goto tr908;
	} else
		goto tr908;
	goto tr33;
st644:
	if ( ++p == pe )
		goto _test_eof644;
case 644:
	if ( 240u <= (*p) && (*p) <= 241u )
		goto tr429;
	goto tr33;
tr912:
#line 36 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_REPNZ_PREFIX(FALSE);
  }
	goto st645;
st645:
	if ( ++p == pe )
		goto _test_eof645;
case 645:
#line 32098 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	if ( 192u <= (*p) )
		goto st646;
	goto tr33;
st646:
	if ( ++p == pe )
		goto _test_eof646;
case 646:
	goto tr915;
tr904:
#line 190 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_REX_PREFIX(*p);
  }
	goto st647;
st647:
	if ( ++p == pe )
		goto _test_eof647;
case 647:
#line 32117 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	if ( (*p) == 15u )
		goto st643;
	goto tr33;
tr905:
#line 190 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_REX_PREFIX(*p);
  }
	goto st648;
st648:
	if ( ++p == pe )
		goto _test_eof648;
case 648:
#line 32131 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 15u: goto st649;
		case 167u: goto tr232;
		case 175u: goto tr233;
	}
	goto tr33;
st649:
	if ( ++p == pe )
		goto _test_eof649;
case 649:
	switch( (*p) ) {
		case 42u: goto tr908;
		case 56u: goto st650;
	}
	if ( 44u <= (*p) && (*p) <= 45u )
		goto tr917;
	goto tr33;
st650:
	if ( ++p == pe )
		goto _test_eof650;
case 650:
	if ( (*p) == 241u )
		goto tr917;
	goto tr33;
tr906:
#line 190 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_REX_PREFIX(*p);
  }
	goto st651;
st651:
	if ( ++p == pe )
		goto _test_eof651;
case 651:
#line 32166 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	if ( (*p) == 15u )
		goto st649;
	goto tr33;
tr1037:
#line 329 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
        begin = p;
        BitmapSetBit(valid_targets, p - data);
        SET_REX_PREFIX(FALSE);
        SET_VEX_PREFIX2(0xe0);
        SET_VEX_PREFIX3(0x00);
        operand_states = 0;
     }
#line 16 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_REPZ_PREFIX(TRUE);
  }
#line 19 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_REPZ_PREFIX(TRUE);
  }
	goto st652;
st652:
	if ( ++p == pe )
		goto _test_eof652;
case 652:
#line 32193 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 15u: goto st653;
		case 72u: goto tr921;
		case 102u: goto tr923;
		case 144u: goto tr924;
	}
	if ( (*p) < 164u ) {
		if ( (*p) > 71u ) {
			if ( 73u <= (*p) && (*p) <= 79u )
				goto tr922;
		} else if ( (*p) >= 64u )
			goto tr920;
	} else if ( (*p) > 167u ) {
		if ( (*p) < 172u ) {
			if ( 170u <= (*p) && (*p) <= 171u )
				goto tr233;
		} else if ( (*p) > 173u ) {
			if ( 174u <= (*p) && (*p) <= 175u )
				goto tr233;
		} else
			goto tr234;
	} else
		goto tr232;
	goto tr33;
st653:
	if ( ++p == pe )
		goto _test_eof653;
case 653:
	switch( (*p) ) {
		case 22u: goto tr925;
		case 42u: goto tr925;
		case 43u: goto tr926;
		case 111u: goto tr925;
		case 112u: goto tr928;
		case 184u: goto tr927;
		case 194u: goto tr928;
		case 214u: goto tr929;
		case 230u: goto tr925;
	}
	if ( (*p) < 81u ) {
		if ( (*p) > 18u ) {
			if ( 44u <= (*p) && (*p) <= 45u )
				goto tr927;
		} else if ( (*p) >= 16u )
			goto tr925;
	} else if ( (*p) > 83u ) {
		if ( (*p) < 126u ) {
			if ( 88u <= (*p) && (*p) <= 95u )
				goto tr925;
		} else if ( (*p) > 127u ) {
			if ( 188u <= (*p) && (*p) <= 189u )
				goto tr927;
		} else
			goto tr925;
	} else
		goto tr925;
	goto tr33;
tr920:
#line 190 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_REX_PREFIX(*p);
  }
	goto st654;
st654:
	if ( ++p == pe )
		goto _test_eof654;
case 654:
#line 32261 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	if ( (*p) == 15u )
		goto st653;
	goto tr33;
tr921:
#line 190 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_REX_PREFIX(*p);
  }
	goto st655;
st655:
	if ( ++p == pe )
		goto _test_eof655;
case 655:
#line 32275 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 15u: goto st656;
		case 165u: goto tr232;
		case 167u: goto tr232;
		case 171u: goto tr233;
		case 173u: goto tr234;
		case 175u: goto tr233;
	}
	goto tr33;
st656:
	if ( ++p == pe )
		goto _test_eof656;
case 656:
	switch( (*p) ) {
		case 42u: goto tr925;
		case 184u: goto tr931;
	}
	if ( (*p) > 45u ) {
		if ( 188u <= (*p) && (*p) <= 189u )
			goto tr931;
	} else if ( (*p) >= 44u )
		goto tr931;
	goto tr33;
tr922:
#line 190 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_REX_PREFIX(*p);
  }
	goto st657;
st657:
	if ( ++p == pe )
		goto _test_eof657;
case 657:
#line 32309 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	if ( (*p) == 15u )
		goto st656;
	goto tr33;
tr1038:
#line 329 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
        begin = p;
        BitmapSetBit(valid_targets, p - data);
        SET_REX_PREFIX(FALSE);
        SET_VEX_PREFIX2(0xe0);
        SET_VEX_PREFIX3(0x00);
        operand_states = 0;
     }
	goto st658;
st658:
	if ( ++p == pe )
		goto _test_eof658;
case 658:
#line 32328 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 4u: goto st44;
		case 5u: goto tr95;
		case 20u: goto st2;
		case 21u: goto tr2;
		case 28u: goto st2;
		case 29u: goto tr2;
		case 36u: goto st2;
		case 37u: goto tr2;
		case 44u: goto st2;
		case 45u: goto tr2;
		case 52u: goto st2;
		case 53u: goto tr2;
		case 60u: goto st2;
		case 61u: goto tr2;
		case 68u: goto st50;
		case 84u: goto st8;
		case 92u: goto st8;
		case 100u: goto st8;
		case 108u: goto st8;
		case 116u: goto st8;
		case 124u: goto st8;
		case 132u: goto st51;
		case 148u: goto st9;
		case 156u: goto st9;
		case 164u: goto st9;
		case 172u: goto st9;
		case 180u: goto st9;
		case 188u: goto st9;
	}
	if ( (*p) < 80u ) {
		if ( (*p) < 16u ) {
			if ( (*p) > 7u ) {
				if ( 8u <= (*p) && (*p) <= 15u )
					goto tr33;
			} else
				goto tr93;
		} else if ( (*p) > 63u ) {
			if ( (*p) > 71u ) {
				if ( 72u <= (*p) && (*p) <= 79u )
					goto tr33;
			} else if ( (*p) >= 64u )
				goto tr96;
		} else
			goto tr0;
	} else if ( (*p) > 127u ) {
		if ( (*p) < 144u ) {
			if ( (*p) > 135u ) {
				if ( 136u <= (*p) && (*p) <= 143u )
					goto tr33;
			} else if ( (*p) >= 128u )
				goto tr98;
		} else if ( (*p) > 191u ) {
			if ( (*p) > 199u ) {
				if ( 200u <= (*p) && (*p) <= 207u )
					goto tr33;
			} else if ( (*p) >= 192u )
				goto tr184;
		} else
			goto tr5;
	} else
		goto tr3;
	goto tr210;
tr1039:
#line 329 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
        begin = p;
        BitmapSetBit(valid_targets, p - data);
        SET_REX_PREFIX(FALSE);
        SET_VEX_PREFIX2(0xe0);
        SET_VEX_PREFIX3(0x00);
        operand_states = 0;
     }
	goto st659;
st659:
	if ( ++p == pe )
		goto _test_eof659;
case 659:
#line 32407 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 4u: goto st80;
		case 5u: goto tr248;
		case 20u: goto st2;
		case 21u: goto tr2;
		case 28u: goto st2;
		case 29u: goto tr2;
		case 36u: goto st2;
		case 37u: goto tr2;
		case 44u: goto st2;
		case 45u: goto tr2;
		case 52u: goto st2;
		case 53u: goto tr2;
		case 60u: goto st2;
		case 61u: goto tr2;
		case 68u: goto st86;
		case 84u: goto st8;
		case 92u: goto st8;
		case 100u: goto st8;
		case 108u: goto st8;
		case 116u: goto st8;
		case 124u: goto st8;
		case 132u: goto st87;
		case 148u: goto st9;
		case 156u: goto st9;
		case 164u: goto st9;
		case 172u: goto st9;
		case 180u: goto st9;
		case 188u: goto st9;
	}
	if ( (*p) < 80u ) {
		if ( (*p) < 16u ) {
			if ( (*p) > 7u ) {
				if ( 8u <= (*p) && (*p) <= 15u )
					goto tr33;
			} else
				goto tr185;
		} else if ( (*p) > 63u ) {
			if ( (*p) > 71u ) {
				if ( 72u <= (*p) && (*p) <= 79u )
					goto tr33;
			} else if ( (*p) >= 64u )
				goto tr187;
		} else
			goto tr0;
	} else if ( (*p) > 127u ) {
		if ( (*p) < 144u ) {
			if ( (*p) > 135u ) {
				if ( 136u <= (*p) && (*p) <= 143u )
					goto tr33;
			} else if ( (*p) >= 128u )
				goto tr189;
		} else if ( (*p) > 191u ) {
			if ( (*p) > 199u ) {
				if ( 200u <= (*p) && (*p) <= 207u )
					goto tr33;
			} else if ( (*p) >= 192u )
				goto tr191;
		} else
			goto tr5;
	} else
		goto tr3;
	goto tr56;
tr1040:
#line 329 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
        begin = p;
        BitmapSetBit(valid_targets, p - data);
        SET_REX_PREFIX(FALSE);
        SET_VEX_PREFIX2(0xe0);
        SET_VEX_PREFIX3(0x00);
        operand_states = 0;
     }
	goto st660;
st660:
	if ( ++p == pe )
		goto _test_eof660;
case 660:
#line 32486 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 4u: goto st2;
		case 5u: goto tr2;
		case 12u: goto st2;
		case 13u: goto tr2;
		case 68u: goto st8;
		case 76u: goto st8;
		case 132u: goto st9;
		case 140u: goto st9;
	}
	if ( (*p) < 64u ) {
		if ( (*p) <= 15u )
			goto tr0;
	} else if ( (*p) > 79u ) {
		if ( (*p) > 143u ) {
			if ( 192u <= (*p) && (*p) <= 207u )
				goto tr210;
		} else if ( (*p) >= 128u )
			goto tr5;
	} else
		goto tr3;
	goto tr33;
tr1045:
#line 329 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
        begin = p;
        BitmapSetBit(valid_targets, p - data);
        SET_REX_PREFIX(FALSE);
        SET_VEX_PREFIX2(0xe0);
        SET_VEX_PREFIX3(0x00);
        operand_states = 0;
     }
	goto st661;
st661:
	if ( ++p == pe )
		goto _test_eof661;
case 661:
#line 32524 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 4u: goto st2;
		case 5u: goto tr2;
		case 12u: goto st2;
		case 13u: goto tr2;
		case 52u: goto st2;
		case 53u: goto tr2;
		case 68u: goto st8;
		case 76u: goto st8;
		case 116u: goto st8;
		case 132u: goto st9;
		case 140u: goto st9;
		case 180u: goto st9;
		case 208u: goto tr932;
		case 224u: goto tr932;
	}
	if ( (*p) < 112u ) {
		if ( (*p) < 48u ) {
			if ( (*p) <= 15u )
				goto tr0;
		} else if ( (*p) > 55u ) {
			if ( 64u <= (*p) && (*p) <= 79u )
				goto tr3;
		} else
			goto tr0;
	} else if ( (*p) > 119u ) {
		if ( (*p) < 176u ) {
			if ( 128u <= (*p) && (*p) <= 143u )
				goto tr5;
		} else if ( (*p) > 183u ) {
			if ( (*p) > 207u ) {
				if ( 240u <= (*p) && (*p) <= 247u )
					goto tr34;
			} else if ( (*p) >= 192u )
				goto tr56;
		} else
			goto tr5;
	} else
		goto tr3;
	goto tr33;
tr1041:
#line 329 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
        begin = p;
        BitmapSetBit(valid_targets, p - data);
        SET_REX_PREFIX(FALSE);
        SET_VEX_PREFIX2(0xe0);
        SET_VEX_PREFIX3(0x00);
        operand_states = 0;
     }
	goto st662;
st662:
	if ( ++p == pe )
		goto _test_eof662;
case 662:
#line 32580 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 4u: goto st2;
		case 5u: goto tr2;
		case 12u: goto st2;
		case 13u: goto tr2;
		case 52u: goto st2;
		case 53u: goto tr2;
		case 68u: goto st8;
		case 76u: goto st8;
		case 116u: goto st8;
		case 132u: goto st9;
		case 140u: goto st9;
		case 180u: goto st9;
	}
	if ( (*p) < 112u ) {
		if ( (*p) < 48u ) {
			if ( (*p) <= 15u )
				goto tr0;
		} else if ( (*p) > 55u ) {
			if ( 64u <= (*p) && (*p) <= 79u )
				goto tr3;
		} else
			goto tr0;
	} else if ( (*p) > 119u ) {
		if ( (*p) < 176u ) {
			if ( 128u <= (*p) && (*p) <= 143u )
				goto tr5;
		} else if ( (*p) > 183u ) {
			if ( (*p) > 207u ) {
				if ( 240u <= (*p) && (*p) <= 247u )
					goto tr34;
			} else if ( (*p) >= 192u )
				goto tr56;
		} else
			goto tr5;
	} else
		goto tr3;
	goto tr33;
tr434:
#line 295 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(0, OperandSize32bit);
  }
#line 384 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_NAME(0, ((*p) & 0x07) |
                           ((GET_REX_PREFIX() & 0x01) << 3) |
                           (((~GET_VEX_PREFIX2()) & 0x20) >> 2));
  }
	goto st663;
st663:
	if ( ++p == pe )
		goto _test_eof663;
case 663:
#line 32635 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	if ( (*p) == 224u )
		goto tr933;
	goto tr25;
tr933:
#line 58 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_IMM_TYPE(IMM8);
    SET_IMM_PTR(p);
  }
#line 93 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    /* Restricted %rsp or %rbp must be processed by appropriate nacl-special
       instruction, not with regular instruction.  */
    if (restricted_register == REG_RSP) {
      PrintError("Incorrectly modified register %%rsp\n", begin - data);
      result = 1;
      goto error_detected;
    } else if (restricted_register == REG_RBP) {
      PrintError("Incorrectly modified register %%rbp\n", begin - data);
      result = 1;
      goto error_detected;
    }
    /* If Sandboxed Rsi is destroyed then we must note that.  */
    if (restricted_register == kSandboxedRsi) {
      if (CHECK_OPERAND(0, REG_RSI, OperandSandboxRestricted) ||
          CHECK_OPERAND(0, REG_RSI, OperandSandboxUnrestricted) ||
          CHECK_OPERAND(1, REG_RSI, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_RSI, OperandSandboxUnrestricted)) {
        restricted_register = kNoRestrictedReg;
      }
    }
    if (restricted_register == kSandboxedRsi) {
      if (CHECK_OPERAND(0, REG_RDI, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_RDI, OperandSandboxRestricted)) {
        sandboxed_rsi_restricted_rdi = begin;
        restricted_register = kSandboxedRsiRestrictedRdi;
      }
    }
    if (restricted_register != kSandboxedRsiRestrictedRdi) {
      restricted_register = kNoRestrictedReg;
      if (CHECK_OPERAND(0, REG_R15, OperandSandbox8bit) ||
          CHECK_OPERAND(0, REG_R15, OperandSandboxRestricted) ||
          CHECK_OPERAND(0, REG_R15, OperandSandboxUnrestricted) ||
          CHECK_OPERAND(1, REG_R15, OperandSandbox8bit) ||
          CHECK_OPERAND(1, REG_R15, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_R15, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%r15\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((CHECK_OPERAND(0, REG_RBP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(0, REG_RBP, OperandSandboxUnrestricted) ||
                 (CHECK_OPERAND(1, REG_RBP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(1, REG_RBP, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%rbp\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((CHECK_OPERAND(0, REG_RSP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(0, REG_RSP, OperandSandboxUnrestricted) ||
                 (CHECK_OPERAND(1, REG_RSP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(1, REG_RSP, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%rsp\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((operand_states & 0x70) == (OperandSandboxRestricted << 5)) {
        restricted_register = operand_states & 0x0f;
      } else if ((operand_states & 0x7000) ==
                                        (OperandSandboxRestricted << (5 + 8))) {
        restricted_register = (operand_states & 0x0f00) >> 8;
      }
    }
  }
#line 337 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
       /* On successful match the instruction start must point to the next byte
        * to be able to report the new offset as the start of instruction
        * causing error.  */
       begin = p + 1;
     }
	goto st726;
st726:
	if ( ++p == pe )
		goto _test_eof726;
case 726:
#line 32723 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 0u: goto tr978;
		case 1u: goto tr979;
		case 2u: goto tr980;
		case 3u: goto tr981;
		case 4u: goto tr982;
		case 5u: goto tr983;
		case 8u: goto tr978;
		case 9u: goto tr979;
		case 10u: goto tr980;
		case 11u: goto tr981;
		case 12u: goto tr982;
		case 13u: goto tr983;
		case 15u: goto tr984;
		case 16u: goto tr978;
		case 17u: goto tr979;
		case 18u: goto tr980;
		case 19u: goto tr981;
		case 20u: goto tr982;
		case 21u: goto tr983;
		case 24u: goto tr978;
		case 25u: goto tr979;
		case 26u: goto tr980;
		case 27u: goto tr981;
		case 28u: goto tr982;
		case 29u: goto tr983;
		case 32u: goto tr978;
		case 33u: goto tr979;
		case 34u: goto tr980;
		case 35u: goto tr981;
		case 36u: goto tr982;
		case 37u: goto tr983;
		case 40u: goto tr978;
		case 41u: goto tr979;
		case 42u: goto tr980;
		case 43u: goto tr981;
		case 44u: goto tr982;
		case 45u: goto tr983;
		case 46u: goto tr985;
		case 48u: goto tr978;
		case 49u: goto tr979;
		case 50u: goto tr980;
		case 51u: goto tr981;
		case 52u: goto tr982;
		case 53u: goto tr983;
		case 60u: goto tr987;
		case 61u: goto tr988;
		case 62u: goto tr989;
		case 65u: goto tr991;
		case 72u: goto tr992;
		case 73u: goto tr993;
		case 74u: goto tr994;
		case 76u: goto tr1046;
		case 99u: goto tr981;
		case 102u: goto tr999;
		case 104u: goto tr988;
		case 105u: goto tr1000;
		case 106u: goto tr987;
		case 107u: goto tr1001;
		case 128u: goto tr1003;
		case 129u: goto tr1004;
		case 131u: goto tr1005;
		case 133u: goto tr979;
		case 134u: goto tr1006;
		case 135u: goto tr1007;
		case 137u: goto tr979;
		case 138u: goto tr980;
		case 139u: goto tr981;
		case 141u: goto tr1008;
		case 143u: goto tr1009;
		case 144u: goto tr1010;
		case 155u: goto tr1010;
		case 168u: goto tr982;
		case 169u: goto tr983;
		case 192u: goto tr1017;
		case 193u: goto tr1018;
		case 196u: goto tr1019;
		case 197u: goto tr1020;
		case 198u: goto tr1021;
		case 199u: goto tr1022;
		case 200u: goto tr1023;
		case 202u: goto tr1024;
		case 203u: goto tr1010;
		case 209u: goto tr1026;
		case 211u: goto tr1026;
		case 216u: goto tr986;
		case 217u: goto tr1027;
		case 218u: goto tr1028;
		case 219u: goto tr1029;
		case 220u: goto tr1030;
		case 221u: goto tr1031;
		case 222u: goto tr1032;
		case 223u: goto tr1033;
		case 235u: goto tr1002;
		case 240u: goto tr1035;
		case 242u: goto tr1036;
		case 243u: goto tr1037;
		case 246u: goto tr1038;
		case 247u: goto tr1039;
		case 254u: goto tr1040;
		case 255u: goto tr1041;
	}
	if ( (*p) < 164u ) {
		if ( (*p) < 88u ) {
			if ( (*p) < 64u ) {
				if ( 56u <= (*p) && (*p) <= 59u )
					goto tr986;
			} else if ( (*p) > 71u ) {
				if ( (*p) > 79u ) {
					if ( 80u <= (*p) && (*p) <= 87u )
						goto tr997;
				} else if ( (*p) >= 75u )
					goto tr995;
			} else
				goto tr990;
		} else if ( (*p) > 95u ) {
			if ( (*p) < 132u ) {
				if ( 112u <= (*p) && (*p) <= 127u )
					goto tr1002;
			} else if ( (*p) > 136u ) {
				if ( (*p) > 151u ) {
					if ( 152u <= (*p) && (*p) <= 153u )
						goto tr1010;
				} else if ( (*p) >= 145u )
					goto tr1011;
			} else
				goto tr978;
		} else
			goto tr998;
	} else if ( (*p) > 167u ) {
		if ( (*p) < 184u ) {
			if ( (*p) < 172u ) {
				if ( 170u <= (*p) && (*p) <= 171u )
					goto tr1013;
			} else if ( (*p) > 173u ) {
				if ( (*p) > 175u ) {
					if ( 176u <= (*p) && (*p) <= 183u )
						goto tr1015;
				} else if ( (*p) >= 174u )
					goto tr1013;
			} else
				goto tr1014;
		} else if ( (*p) > 191u ) {
			if ( (*p) < 232u ) {
				if ( 208u <= (*p) && (*p) <= 210u )
					goto tr1025;
			} else if ( (*p) > 233u ) {
				if ( (*p) > 249u ) {
					if ( 252u <= (*p) && (*p) <= 253u )
						goto tr1010;
				} else if ( (*p) >= 244u )
					goto tr1010;
			} else
				goto tr1034;
		} else
			goto tr1016;
	} else
		goto tr1012;
	goto tr33;
tr1046:
#line 329 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
        begin = p;
        BitmapSetBit(valid_targets, p - data);
        SET_REX_PREFIX(FALSE);
        SET_VEX_PREFIX2(0xe0);
        SET_VEX_PREFIX3(0x00);
        operand_states = 0;
     }
#line 190 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_REX_PREFIX(*p);
  }
	goto st664;
st664:
	if ( ++p == pe )
		goto _test_eof664;
case 664:
#line 32902 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 1u: goto tr934;
		case 3u: goto tr221;
		case 9u: goto tr220;
		case 11u: goto tr221;
		case 15u: goto st142;
		case 17u: goto tr220;
		case 19u: goto tr221;
		case 25u: goto tr220;
		case 27u: goto tr221;
		case 33u: goto tr220;
		case 35u: goto tr221;
		case 41u: goto tr220;
		case 43u: goto tr221;
		case 49u: goto tr220;
		case 51u: goto tr221;
		case 57u: goto st38;
		case 59u: goto st38;
		case 99u: goto tr221;
		case 105u: goto tr224;
		case 107u: goto tr225;
		case 129u: goto st144;
		case 131u: goto st145;
		case 133u: goto tr220;
		case 135u: goto tr228;
		case 137u: goto tr220;
		case 139u: goto tr221;
		case 141u: goto tr230;
		case 193u: goto st150;
		case 199u: goto st151;
		case 209u: goto st152;
		case 211u: goto st152;
		case 247u: goto st153;
		case 255u: goto st154;
	}
	if ( (*p) > 151u ) {
		if ( 184u <= (*p) && (*p) <= 191u )
			goto tr235;
	} else if ( (*p) >= 145u )
		goto tr231;
	goto tr33;
tr934:
#line 298 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(0, OperandSize64bit);
  }
	goto st665;
st665:
	if ( ++p == pe )
		goto _test_eof665;
case 665:
#line 32954 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 4u: goto st2;
		case 5u: goto tr2;
		case 12u: goto st2;
		case 13u: goto tr2;
		case 20u: goto st2;
		case 21u: goto tr2;
		case 28u: goto st2;
		case 29u: goto tr2;
		case 36u: goto st2;
		case 37u: goto tr2;
		case 44u: goto st2;
		case 45u: goto tr2;
		case 52u: goto st2;
		case 53u: goto tr2;
		case 60u: goto st2;
		case 61u: goto tr2;
		case 68u: goto st8;
		case 76u: goto st8;
		case 84u: goto st8;
		case 92u: goto st8;
		case 100u: goto st8;
		case 108u: goto st8;
		case 116u: goto st8;
		case 124u: goto st8;
		case 132u: goto st9;
		case 140u: goto st9;
		case 148u: goto st9;
		case 156u: goto st9;
		case 164u: goto st9;
		case 172u: goto st9;
		case 180u: goto st9;
		case 188u: goto st9;
		case 249u: goto tr935;
		case 252u: goto tr286;
		case 253u: goto tr280;
	}
	if ( (*p) < 64u ) {
		if ( (*p) <= 63u )
			goto tr0;
	} else if ( (*p) > 127u ) {
		if ( 128u <= (*p) && (*p) <= 191u )
			goto tr5;
	} else
		goto tr3;
	goto tr7;
tr935:
#line 384 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_NAME(0, ((*p) & 0x07) |
                           ((GET_REX_PREFIX() & 0x01) << 3) |
                           (((~GET_VEX_PREFIX2()) & 0x20) >> 2));
  }
#line 93 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    /* Restricted %rsp or %rbp must be processed by appropriate nacl-special
       instruction, not with regular instruction.  */
    if (restricted_register == REG_RSP) {
      PrintError("Incorrectly modified register %%rsp\n", begin - data);
      result = 1;
      goto error_detected;
    } else if (restricted_register == REG_RBP) {
      PrintError("Incorrectly modified register %%rbp\n", begin - data);
      result = 1;
      goto error_detected;
    }
    /* If Sandboxed Rsi is destroyed then we must note that.  */
    if (restricted_register == kSandboxedRsi) {
      if (CHECK_OPERAND(0, REG_RSI, OperandSandboxRestricted) ||
          CHECK_OPERAND(0, REG_RSI, OperandSandboxUnrestricted) ||
          CHECK_OPERAND(1, REG_RSI, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_RSI, OperandSandboxUnrestricted)) {
        restricted_register = kNoRestrictedReg;
      }
    }
    if (restricted_register == kSandboxedRsi) {
      if (CHECK_OPERAND(0, REG_RDI, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_RDI, OperandSandboxRestricted)) {
        sandboxed_rsi_restricted_rdi = begin;
        restricted_register = kSandboxedRsiRestrictedRdi;
      }
    }
    if (restricted_register != kSandboxedRsiRestrictedRdi) {
      restricted_register = kNoRestrictedReg;
      if (CHECK_OPERAND(0, REG_R15, OperandSandbox8bit) ||
          CHECK_OPERAND(0, REG_R15, OperandSandboxRestricted) ||
          CHECK_OPERAND(0, REG_R15, OperandSandboxUnrestricted) ||
          CHECK_OPERAND(1, REG_R15, OperandSandbox8bit) ||
          CHECK_OPERAND(1, REG_R15, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_R15, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%r15\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((CHECK_OPERAND(0, REG_RBP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(0, REG_RBP, OperandSandboxUnrestricted) ||
                 (CHECK_OPERAND(1, REG_RBP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(1, REG_RBP, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%rbp\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((CHECK_OPERAND(0, REG_RSP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(0, REG_RSP, OperandSandboxUnrestricted) ||
                 (CHECK_OPERAND(1, REG_RSP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(1, REG_RSP, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%rsp\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((operand_states & 0x70) == (OperandSandboxRestricted << 5)) {
        restricted_register = operand_states & 0x0f;
      } else if ((operand_states & 0x7000) ==
                                        (OperandSandboxRestricted << (5 + 8))) {
        restricted_register = (operand_states & 0x0f00) >> 8;
      }
    }
  }
#line 337 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
       /* On successful match the instruction start must point to the next byte
        * to be able to report the new offset as the start of instruction
        * causing error.  */
       begin = p + 1;
     }
	goto st727;
st727:
	if ( ++p == pe )
		goto _test_eof727;
case 727:
#line 33086 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 0u: goto tr978;
		case 1u: goto tr979;
		case 2u: goto tr980;
		case 3u: goto tr981;
		case 4u: goto tr982;
		case 5u: goto tr983;
		case 8u: goto tr978;
		case 9u: goto tr979;
		case 10u: goto tr980;
		case 11u: goto tr981;
		case 12u: goto tr982;
		case 13u: goto tr983;
		case 15u: goto tr984;
		case 16u: goto tr978;
		case 17u: goto tr979;
		case 18u: goto tr980;
		case 19u: goto tr981;
		case 20u: goto tr982;
		case 21u: goto tr983;
		case 24u: goto tr978;
		case 25u: goto tr979;
		case 26u: goto tr980;
		case 27u: goto tr981;
		case 28u: goto tr982;
		case 29u: goto tr983;
		case 32u: goto tr978;
		case 33u: goto tr979;
		case 34u: goto tr980;
		case 35u: goto tr981;
		case 36u: goto tr982;
		case 37u: goto tr983;
		case 40u: goto tr978;
		case 41u: goto tr979;
		case 42u: goto tr980;
		case 43u: goto tr981;
		case 44u: goto tr982;
		case 45u: goto tr983;
		case 46u: goto tr985;
		case 48u: goto tr978;
		case 49u: goto tr979;
		case 50u: goto tr980;
		case 51u: goto tr981;
		case 52u: goto tr982;
		case 53u: goto tr983;
		case 60u: goto tr987;
		case 61u: goto tr988;
		case 62u: goto tr989;
		case 65u: goto tr991;
		case 72u: goto tr992;
		case 73u: goto tr993;
		case 74u: goto tr994;
		case 76u: goto tr996;
		case 99u: goto tr981;
		case 102u: goto tr999;
		case 104u: goto tr988;
		case 105u: goto tr1000;
		case 106u: goto tr987;
		case 107u: goto tr1001;
		case 128u: goto tr1003;
		case 129u: goto tr1004;
		case 131u: goto tr1005;
		case 133u: goto tr979;
		case 134u: goto tr1006;
		case 135u: goto tr1007;
		case 137u: goto tr979;
		case 138u: goto tr980;
		case 139u: goto tr981;
		case 141u: goto tr1008;
		case 143u: goto tr1009;
		case 144u: goto tr1010;
		case 155u: goto tr1010;
		case 168u: goto tr982;
		case 169u: goto tr983;
		case 192u: goto tr1017;
		case 193u: goto tr1018;
		case 196u: goto tr1019;
		case 197u: goto tr1020;
		case 198u: goto tr1021;
		case 199u: goto tr1022;
		case 200u: goto tr1023;
		case 202u: goto tr1024;
		case 203u: goto tr1010;
		case 209u: goto tr1026;
		case 211u: goto tr1026;
		case 216u: goto tr986;
		case 217u: goto tr1027;
		case 218u: goto tr1028;
		case 219u: goto tr1029;
		case 220u: goto tr1030;
		case 221u: goto tr1031;
		case 222u: goto tr1032;
		case 223u: goto tr1033;
		case 235u: goto tr1002;
		case 240u: goto tr1035;
		case 242u: goto tr1036;
		case 243u: goto tr1037;
		case 246u: goto tr1038;
		case 247u: goto tr1039;
		case 254u: goto tr1040;
		case 255u: goto tr1047;
	}
	if ( (*p) < 164u ) {
		if ( (*p) < 88u ) {
			if ( (*p) < 64u ) {
				if ( 56u <= (*p) && (*p) <= 59u )
					goto tr986;
			} else if ( (*p) > 71u ) {
				if ( (*p) > 79u ) {
					if ( 80u <= (*p) && (*p) <= 87u )
						goto tr997;
				} else if ( (*p) >= 75u )
					goto tr995;
			} else
				goto tr990;
		} else if ( (*p) > 95u ) {
			if ( (*p) < 132u ) {
				if ( 112u <= (*p) && (*p) <= 127u )
					goto tr1002;
			} else if ( (*p) > 136u ) {
				if ( (*p) > 151u ) {
					if ( 152u <= (*p) && (*p) <= 153u )
						goto tr1010;
				} else if ( (*p) >= 145u )
					goto tr1011;
			} else
				goto tr978;
		} else
			goto tr998;
	} else if ( (*p) > 167u ) {
		if ( (*p) < 184u ) {
			if ( (*p) < 172u ) {
				if ( 170u <= (*p) && (*p) <= 171u )
					goto tr1013;
			} else if ( (*p) > 173u ) {
				if ( (*p) > 175u ) {
					if ( 176u <= (*p) && (*p) <= 183u )
						goto tr1015;
				} else if ( (*p) >= 174u )
					goto tr1013;
			} else
				goto tr1014;
		} else if ( (*p) > 191u ) {
			if ( (*p) < 232u ) {
				if ( 208u <= (*p) && (*p) <= 210u )
					goto tr1025;
			} else if ( (*p) > 233u ) {
				if ( (*p) > 249u ) {
					if ( 252u <= (*p) && (*p) <= 253u )
						goto tr1010;
				} else if ( (*p) >= 244u )
					goto tr1010;
			} else
				goto tr1034;
		} else
			goto tr1016;
	} else
		goto tr1012;
	goto tr33;
tr1047:
#line 329 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
        begin = p;
        BitmapSetBit(valid_targets, p - data);
        SET_REX_PREFIX(FALSE);
        SET_VEX_PREFIX2(0xe0);
        SET_VEX_PREFIX3(0x00);
        operand_states = 0;
     }
	goto st666;
st666:
	if ( ++p == pe )
		goto _test_eof666;
case 666:
#line 33261 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 4u: goto st2;
		case 5u: goto tr2;
		case 12u: goto st2;
		case 13u: goto tr2;
		case 52u: goto st2;
		case 53u: goto tr2;
		case 68u: goto st8;
		case 76u: goto st8;
		case 116u: goto st8;
		case 132u: goto st9;
		case 140u: goto st9;
		case 180u: goto st9;
		case 209u: goto tr932;
		case 225u: goto tr932;
	}
	if ( (*p) < 112u ) {
		if ( (*p) < 48u ) {
			if ( (*p) <= 15u )
				goto tr0;
		} else if ( (*p) > 55u ) {
			if ( 64u <= (*p) && (*p) <= 79u )
				goto tr3;
		} else
			goto tr0;
	} else if ( (*p) > 119u ) {
		if ( (*p) < 176u ) {
			if ( 128u <= (*p) && (*p) <= 143u )
				goto tr5;
		} else if ( (*p) > 183u ) {
			if ( (*p) > 207u ) {
				if ( 240u <= (*p) && (*p) <= 247u )
					goto tr34;
			} else if ( (*p) >= 192u )
				goto tr56;
		} else
			goto tr5;
	} else
		goto tr3;
	goto tr33;
tr435:
#line 295 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(0, OperandSize32bit);
  }
#line 384 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_NAME(0, ((*p) & 0x07) |
                           ((GET_REX_PREFIX() & 0x01) << 3) |
                           (((~GET_VEX_PREFIX2()) & 0x20) >> 2));
  }
	goto st667;
st667:
	if ( ++p == pe )
		goto _test_eof667;
case 667:
#line 33318 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	if ( (*p) == 224u )
		goto tr936;
	goto tr25;
tr936:
#line 58 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_IMM_TYPE(IMM8);
    SET_IMM_PTR(p);
  }
#line 93 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    /* Restricted %rsp or %rbp must be processed by appropriate nacl-special
       instruction, not with regular instruction.  */
    if (restricted_register == REG_RSP) {
      PrintError("Incorrectly modified register %%rsp\n", begin - data);
      result = 1;
      goto error_detected;
    } else if (restricted_register == REG_RBP) {
      PrintError("Incorrectly modified register %%rbp\n", begin - data);
      result = 1;
      goto error_detected;
    }
    /* If Sandboxed Rsi is destroyed then we must note that.  */
    if (restricted_register == kSandboxedRsi) {
      if (CHECK_OPERAND(0, REG_RSI, OperandSandboxRestricted) ||
          CHECK_OPERAND(0, REG_RSI, OperandSandboxUnrestricted) ||
          CHECK_OPERAND(1, REG_RSI, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_RSI, OperandSandboxUnrestricted)) {
        restricted_register = kNoRestrictedReg;
      }
    }
    if (restricted_register == kSandboxedRsi) {
      if (CHECK_OPERAND(0, REG_RDI, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_RDI, OperandSandboxRestricted)) {
        sandboxed_rsi_restricted_rdi = begin;
        restricted_register = kSandboxedRsiRestrictedRdi;
      }
    }
    if (restricted_register != kSandboxedRsiRestrictedRdi) {
      restricted_register = kNoRestrictedReg;
      if (CHECK_OPERAND(0, REG_R15, OperandSandbox8bit) ||
          CHECK_OPERAND(0, REG_R15, OperandSandboxRestricted) ||
          CHECK_OPERAND(0, REG_R15, OperandSandboxUnrestricted) ||
          CHECK_OPERAND(1, REG_R15, OperandSandbox8bit) ||
          CHECK_OPERAND(1, REG_R15, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_R15, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%r15\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((CHECK_OPERAND(0, REG_RBP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(0, REG_RBP, OperandSandboxUnrestricted) ||
                 (CHECK_OPERAND(1, REG_RBP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(1, REG_RBP, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%rbp\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((CHECK_OPERAND(0, REG_RSP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(0, REG_RSP, OperandSandboxUnrestricted) ||
                 (CHECK_OPERAND(1, REG_RSP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(1, REG_RSP, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%rsp\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((operand_states & 0x70) == (OperandSandboxRestricted << 5)) {
        restricted_register = operand_states & 0x0f;
      } else if ((operand_states & 0x7000) ==
                                        (OperandSandboxRestricted << (5 + 8))) {
        restricted_register = (operand_states & 0x0f00) >> 8;
      }
    }
  }
#line 337 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
       /* On successful match the instruction start must point to the next byte
        * to be able to report the new offset as the start of instruction
        * causing error.  */
       begin = p + 1;
     }
	goto st728;
st728:
	if ( ++p == pe )
		goto _test_eof728;
case 728:
#line 33406 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 0u: goto tr978;
		case 1u: goto tr979;
		case 2u: goto tr980;
		case 3u: goto tr981;
		case 4u: goto tr982;
		case 5u: goto tr983;
		case 8u: goto tr978;
		case 9u: goto tr979;
		case 10u: goto tr980;
		case 11u: goto tr981;
		case 12u: goto tr982;
		case 13u: goto tr983;
		case 15u: goto tr984;
		case 16u: goto tr978;
		case 17u: goto tr979;
		case 18u: goto tr980;
		case 19u: goto tr981;
		case 20u: goto tr982;
		case 21u: goto tr983;
		case 24u: goto tr978;
		case 25u: goto tr979;
		case 26u: goto tr980;
		case 27u: goto tr981;
		case 28u: goto tr982;
		case 29u: goto tr983;
		case 32u: goto tr978;
		case 33u: goto tr979;
		case 34u: goto tr980;
		case 35u: goto tr981;
		case 36u: goto tr982;
		case 37u: goto tr983;
		case 40u: goto tr978;
		case 41u: goto tr979;
		case 42u: goto tr980;
		case 43u: goto tr981;
		case 44u: goto tr982;
		case 45u: goto tr983;
		case 46u: goto tr985;
		case 48u: goto tr978;
		case 49u: goto tr979;
		case 50u: goto tr980;
		case 51u: goto tr981;
		case 52u: goto tr982;
		case 53u: goto tr983;
		case 60u: goto tr987;
		case 61u: goto tr988;
		case 62u: goto tr989;
		case 65u: goto tr991;
		case 72u: goto tr992;
		case 73u: goto tr993;
		case 74u: goto tr994;
		case 76u: goto tr1048;
		case 99u: goto tr981;
		case 102u: goto tr999;
		case 104u: goto tr988;
		case 105u: goto tr1000;
		case 106u: goto tr987;
		case 107u: goto tr1001;
		case 128u: goto tr1003;
		case 129u: goto tr1004;
		case 131u: goto tr1005;
		case 133u: goto tr979;
		case 134u: goto tr1006;
		case 135u: goto tr1007;
		case 137u: goto tr979;
		case 138u: goto tr980;
		case 139u: goto tr981;
		case 141u: goto tr1008;
		case 143u: goto tr1009;
		case 144u: goto tr1010;
		case 155u: goto tr1010;
		case 168u: goto tr982;
		case 169u: goto tr983;
		case 192u: goto tr1017;
		case 193u: goto tr1018;
		case 196u: goto tr1019;
		case 197u: goto tr1020;
		case 198u: goto tr1021;
		case 199u: goto tr1022;
		case 200u: goto tr1023;
		case 202u: goto tr1024;
		case 203u: goto tr1010;
		case 209u: goto tr1026;
		case 211u: goto tr1026;
		case 216u: goto tr986;
		case 217u: goto tr1027;
		case 218u: goto tr1028;
		case 219u: goto tr1029;
		case 220u: goto tr1030;
		case 221u: goto tr1031;
		case 222u: goto tr1032;
		case 223u: goto tr1033;
		case 235u: goto tr1002;
		case 240u: goto tr1035;
		case 242u: goto tr1036;
		case 243u: goto tr1037;
		case 246u: goto tr1038;
		case 247u: goto tr1039;
		case 254u: goto tr1040;
		case 255u: goto tr1041;
	}
	if ( (*p) < 164u ) {
		if ( (*p) < 88u ) {
			if ( (*p) < 64u ) {
				if ( 56u <= (*p) && (*p) <= 59u )
					goto tr986;
			} else if ( (*p) > 71u ) {
				if ( (*p) > 79u ) {
					if ( 80u <= (*p) && (*p) <= 87u )
						goto tr997;
				} else if ( (*p) >= 75u )
					goto tr995;
			} else
				goto tr990;
		} else if ( (*p) > 95u ) {
			if ( (*p) < 132u ) {
				if ( 112u <= (*p) && (*p) <= 127u )
					goto tr1002;
			} else if ( (*p) > 136u ) {
				if ( (*p) > 151u ) {
					if ( 152u <= (*p) && (*p) <= 153u )
						goto tr1010;
				} else if ( (*p) >= 145u )
					goto tr1011;
			} else
				goto tr978;
		} else
			goto tr998;
	} else if ( (*p) > 167u ) {
		if ( (*p) < 184u ) {
			if ( (*p) < 172u ) {
				if ( 170u <= (*p) && (*p) <= 171u )
					goto tr1013;
			} else if ( (*p) > 173u ) {
				if ( (*p) > 175u ) {
					if ( 176u <= (*p) && (*p) <= 183u )
						goto tr1015;
				} else if ( (*p) >= 174u )
					goto tr1013;
			} else
				goto tr1014;
		} else if ( (*p) > 191u ) {
			if ( (*p) < 232u ) {
				if ( 208u <= (*p) && (*p) <= 210u )
					goto tr1025;
			} else if ( (*p) > 233u ) {
				if ( (*p) > 249u ) {
					if ( 252u <= (*p) && (*p) <= 253u )
						goto tr1010;
				} else if ( (*p) >= 244u )
					goto tr1010;
			} else
				goto tr1034;
		} else
			goto tr1016;
	} else
		goto tr1012;
	goto tr33;
tr1048:
#line 329 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
        begin = p;
        BitmapSetBit(valid_targets, p - data);
        SET_REX_PREFIX(FALSE);
        SET_VEX_PREFIX2(0xe0);
        SET_VEX_PREFIX3(0x00);
        operand_states = 0;
     }
#line 190 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_REX_PREFIX(*p);
  }
	goto st668;
st668:
	if ( ++p == pe )
		goto _test_eof668;
case 668:
#line 33585 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 1u: goto tr937;
		case 3u: goto tr221;
		case 9u: goto tr220;
		case 11u: goto tr221;
		case 15u: goto st142;
		case 17u: goto tr220;
		case 19u: goto tr221;
		case 25u: goto tr220;
		case 27u: goto tr221;
		case 33u: goto tr220;
		case 35u: goto tr221;
		case 41u: goto tr220;
		case 43u: goto tr221;
		case 49u: goto tr220;
		case 51u: goto tr221;
		case 57u: goto st38;
		case 59u: goto st38;
		case 99u: goto tr221;
		case 105u: goto tr224;
		case 107u: goto tr225;
		case 129u: goto st144;
		case 131u: goto st145;
		case 133u: goto tr220;
		case 135u: goto tr228;
		case 137u: goto tr220;
		case 139u: goto tr221;
		case 141u: goto tr230;
		case 193u: goto st150;
		case 199u: goto st151;
		case 209u: goto st152;
		case 211u: goto st152;
		case 247u: goto st153;
		case 255u: goto st154;
	}
	if ( (*p) > 151u ) {
		if ( 184u <= (*p) && (*p) <= 191u )
			goto tr235;
	} else if ( (*p) >= 145u )
		goto tr231;
	goto tr33;
tr937:
#line 298 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(0, OperandSize64bit);
  }
	goto st669;
st669:
	if ( ++p == pe )
		goto _test_eof669;
case 669:
#line 33637 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 4u: goto st2;
		case 5u: goto tr2;
		case 12u: goto st2;
		case 13u: goto tr2;
		case 20u: goto st2;
		case 21u: goto tr2;
		case 28u: goto st2;
		case 29u: goto tr2;
		case 36u: goto st2;
		case 37u: goto tr2;
		case 44u: goto st2;
		case 45u: goto tr2;
		case 52u: goto st2;
		case 53u: goto tr2;
		case 60u: goto st2;
		case 61u: goto tr2;
		case 68u: goto st8;
		case 76u: goto st8;
		case 84u: goto st8;
		case 92u: goto st8;
		case 100u: goto st8;
		case 108u: goto st8;
		case 116u: goto st8;
		case 124u: goto st8;
		case 132u: goto st9;
		case 140u: goto st9;
		case 148u: goto st9;
		case 156u: goto st9;
		case 164u: goto st9;
		case 172u: goto st9;
		case 180u: goto st9;
		case 188u: goto st9;
		case 250u: goto tr938;
		case 252u: goto tr286;
		case 253u: goto tr280;
	}
	if ( (*p) < 64u ) {
		if ( (*p) <= 63u )
			goto tr0;
	} else if ( (*p) > 127u ) {
		if ( 128u <= (*p) && (*p) <= 191u )
			goto tr5;
	} else
		goto tr3;
	goto tr7;
tr938:
#line 384 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_NAME(0, ((*p) & 0x07) |
                           ((GET_REX_PREFIX() & 0x01) << 3) |
                           (((~GET_VEX_PREFIX2()) & 0x20) >> 2));
  }
#line 93 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    /* Restricted %rsp or %rbp must be processed by appropriate nacl-special
       instruction, not with regular instruction.  */
    if (restricted_register == REG_RSP) {
      PrintError("Incorrectly modified register %%rsp\n", begin - data);
      result = 1;
      goto error_detected;
    } else if (restricted_register == REG_RBP) {
      PrintError("Incorrectly modified register %%rbp\n", begin - data);
      result = 1;
      goto error_detected;
    }
    /* If Sandboxed Rsi is destroyed then we must note that.  */
    if (restricted_register == kSandboxedRsi) {
      if (CHECK_OPERAND(0, REG_RSI, OperandSandboxRestricted) ||
          CHECK_OPERAND(0, REG_RSI, OperandSandboxUnrestricted) ||
          CHECK_OPERAND(1, REG_RSI, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_RSI, OperandSandboxUnrestricted)) {
        restricted_register = kNoRestrictedReg;
      }
    }
    if (restricted_register == kSandboxedRsi) {
      if (CHECK_OPERAND(0, REG_RDI, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_RDI, OperandSandboxRestricted)) {
        sandboxed_rsi_restricted_rdi = begin;
        restricted_register = kSandboxedRsiRestrictedRdi;
      }
    }
    if (restricted_register != kSandboxedRsiRestrictedRdi) {
      restricted_register = kNoRestrictedReg;
      if (CHECK_OPERAND(0, REG_R15, OperandSandbox8bit) ||
          CHECK_OPERAND(0, REG_R15, OperandSandboxRestricted) ||
          CHECK_OPERAND(0, REG_R15, OperandSandboxUnrestricted) ||
          CHECK_OPERAND(1, REG_R15, OperandSandbox8bit) ||
          CHECK_OPERAND(1, REG_R15, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_R15, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%r15\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((CHECK_OPERAND(0, REG_RBP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(0, REG_RBP, OperandSandboxUnrestricted) ||
                 (CHECK_OPERAND(1, REG_RBP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(1, REG_RBP, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%rbp\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((CHECK_OPERAND(0, REG_RSP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(0, REG_RSP, OperandSandboxUnrestricted) ||
                 (CHECK_OPERAND(1, REG_RSP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(1, REG_RSP, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%rsp\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((operand_states & 0x70) == (OperandSandboxRestricted << 5)) {
        restricted_register = operand_states & 0x0f;
      } else if ((operand_states & 0x7000) ==
                                        (OperandSandboxRestricted << (5 + 8))) {
        restricted_register = (operand_states & 0x0f00) >> 8;
      }
    }
  }
#line 337 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
       /* On successful match the instruction start must point to the next byte
        * to be able to report the new offset as the start of instruction
        * causing error.  */
       begin = p + 1;
     }
	goto st729;
st729:
	if ( ++p == pe )
		goto _test_eof729;
case 729:
#line 33769 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 0u: goto tr978;
		case 1u: goto tr979;
		case 2u: goto tr980;
		case 3u: goto tr981;
		case 4u: goto tr982;
		case 5u: goto tr983;
		case 8u: goto tr978;
		case 9u: goto tr979;
		case 10u: goto tr980;
		case 11u: goto tr981;
		case 12u: goto tr982;
		case 13u: goto tr983;
		case 15u: goto tr984;
		case 16u: goto tr978;
		case 17u: goto tr979;
		case 18u: goto tr980;
		case 19u: goto tr981;
		case 20u: goto tr982;
		case 21u: goto tr983;
		case 24u: goto tr978;
		case 25u: goto tr979;
		case 26u: goto tr980;
		case 27u: goto tr981;
		case 28u: goto tr982;
		case 29u: goto tr983;
		case 32u: goto tr978;
		case 33u: goto tr979;
		case 34u: goto tr980;
		case 35u: goto tr981;
		case 36u: goto tr982;
		case 37u: goto tr983;
		case 40u: goto tr978;
		case 41u: goto tr979;
		case 42u: goto tr980;
		case 43u: goto tr981;
		case 44u: goto tr982;
		case 45u: goto tr983;
		case 46u: goto tr985;
		case 48u: goto tr978;
		case 49u: goto tr979;
		case 50u: goto tr980;
		case 51u: goto tr981;
		case 52u: goto tr982;
		case 53u: goto tr983;
		case 60u: goto tr987;
		case 61u: goto tr988;
		case 62u: goto tr989;
		case 65u: goto tr991;
		case 72u: goto tr992;
		case 73u: goto tr993;
		case 74u: goto tr994;
		case 76u: goto tr996;
		case 99u: goto tr981;
		case 102u: goto tr999;
		case 104u: goto tr988;
		case 105u: goto tr1000;
		case 106u: goto tr987;
		case 107u: goto tr1001;
		case 128u: goto tr1003;
		case 129u: goto tr1004;
		case 131u: goto tr1005;
		case 133u: goto tr979;
		case 134u: goto tr1006;
		case 135u: goto tr1007;
		case 137u: goto tr979;
		case 138u: goto tr980;
		case 139u: goto tr981;
		case 141u: goto tr1008;
		case 143u: goto tr1009;
		case 144u: goto tr1010;
		case 155u: goto tr1010;
		case 168u: goto tr982;
		case 169u: goto tr983;
		case 192u: goto tr1017;
		case 193u: goto tr1018;
		case 196u: goto tr1019;
		case 197u: goto tr1020;
		case 198u: goto tr1021;
		case 199u: goto tr1022;
		case 200u: goto tr1023;
		case 202u: goto tr1024;
		case 203u: goto tr1010;
		case 209u: goto tr1026;
		case 211u: goto tr1026;
		case 216u: goto tr986;
		case 217u: goto tr1027;
		case 218u: goto tr1028;
		case 219u: goto tr1029;
		case 220u: goto tr1030;
		case 221u: goto tr1031;
		case 222u: goto tr1032;
		case 223u: goto tr1033;
		case 235u: goto tr1002;
		case 240u: goto tr1035;
		case 242u: goto tr1036;
		case 243u: goto tr1037;
		case 246u: goto tr1038;
		case 247u: goto tr1039;
		case 254u: goto tr1040;
		case 255u: goto tr1049;
	}
	if ( (*p) < 164u ) {
		if ( (*p) < 88u ) {
			if ( (*p) < 64u ) {
				if ( 56u <= (*p) && (*p) <= 59u )
					goto tr986;
			} else if ( (*p) > 71u ) {
				if ( (*p) > 79u ) {
					if ( 80u <= (*p) && (*p) <= 87u )
						goto tr997;
				} else if ( (*p) >= 75u )
					goto tr995;
			} else
				goto tr990;
		} else if ( (*p) > 95u ) {
			if ( (*p) < 132u ) {
				if ( 112u <= (*p) && (*p) <= 127u )
					goto tr1002;
			} else if ( (*p) > 136u ) {
				if ( (*p) > 151u ) {
					if ( 152u <= (*p) && (*p) <= 153u )
						goto tr1010;
				} else if ( (*p) >= 145u )
					goto tr1011;
			} else
				goto tr978;
		} else
			goto tr998;
	} else if ( (*p) > 167u ) {
		if ( (*p) < 184u ) {
			if ( (*p) < 172u ) {
				if ( 170u <= (*p) && (*p) <= 171u )
					goto tr1013;
			} else if ( (*p) > 173u ) {
				if ( (*p) > 175u ) {
					if ( 176u <= (*p) && (*p) <= 183u )
						goto tr1015;
				} else if ( (*p) >= 174u )
					goto tr1013;
			} else
				goto tr1014;
		} else if ( (*p) > 191u ) {
			if ( (*p) < 232u ) {
				if ( 208u <= (*p) && (*p) <= 210u )
					goto tr1025;
			} else if ( (*p) > 233u ) {
				if ( (*p) > 249u ) {
					if ( 252u <= (*p) && (*p) <= 253u )
						goto tr1010;
				} else if ( (*p) >= 244u )
					goto tr1010;
			} else
				goto tr1034;
		} else
			goto tr1016;
	} else
		goto tr1012;
	goto tr33;
tr1049:
#line 329 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
        begin = p;
        BitmapSetBit(valid_targets, p - data);
        SET_REX_PREFIX(FALSE);
        SET_VEX_PREFIX2(0xe0);
        SET_VEX_PREFIX3(0x00);
        operand_states = 0;
     }
	goto st670;
st670:
	if ( ++p == pe )
		goto _test_eof670;
case 670:
#line 33944 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 4u: goto st2;
		case 5u: goto tr2;
		case 12u: goto st2;
		case 13u: goto tr2;
		case 52u: goto st2;
		case 53u: goto tr2;
		case 68u: goto st8;
		case 76u: goto st8;
		case 116u: goto st8;
		case 132u: goto st9;
		case 140u: goto st9;
		case 180u: goto st9;
		case 210u: goto tr932;
		case 226u: goto tr932;
	}
	if ( (*p) < 112u ) {
		if ( (*p) < 48u ) {
			if ( (*p) <= 15u )
				goto tr0;
		} else if ( (*p) > 55u ) {
			if ( 64u <= (*p) && (*p) <= 79u )
				goto tr3;
		} else
			goto tr0;
	} else if ( (*p) > 119u ) {
		if ( (*p) < 176u ) {
			if ( 128u <= (*p) && (*p) <= 143u )
				goto tr5;
		} else if ( (*p) > 183u ) {
			if ( (*p) > 207u ) {
				if ( 240u <= (*p) && (*p) <= 247u )
					goto tr34;
			} else if ( (*p) >= 192u )
				goto tr56;
		} else
			goto tr5;
	} else
		goto tr3;
	goto tr33;
tr436:
#line 295 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(0, OperandSize32bit);
  }
#line 384 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_NAME(0, ((*p) & 0x07) |
                           ((GET_REX_PREFIX() & 0x01) << 3) |
                           (((~GET_VEX_PREFIX2()) & 0x20) >> 2));
  }
	goto st671;
st671:
	if ( ++p == pe )
		goto _test_eof671;
case 671:
#line 34001 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	if ( (*p) == 224u )
		goto tr939;
	goto tr25;
tr939:
#line 58 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_IMM_TYPE(IMM8);
    SET_IMM_PTR(p);
  }
#line 93 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    /* Restricted %rsp or %rbp must be processed by appropriate nacl-special
       instruction, not with regular instruction.  */
    if (restricted_register == REG_RSP) {
      PrintError("Incorrectly modified register %%rsp\n", begin - data);
      result = 1;
      goto error_detected;
    } else if (restricted_register == REG_RBP) {
      PrintError("Incorrectly modified register %%rbp\n", begin - data);
      result = 1;
      goto error_detected;
    }
    /* If Sandboxed Rsi is destroyed then we must note that.  */
    if (restricted_register == kSandboxedRsi) {
      if (CHECK_OPERAND(0, REG_RSI, OperandSandboxRestricted) ||
          CHECK_OPERAND(0, REG_RSI, OperandSandboxUnrestricted) ||
          CHECK_OPERAND(1, REG_RSI, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_RSI, OperandSandboxUnrestricted)) {
        restricted_register = kNoRestrictedReg;
      }
    }
    if (restricted_register == kSandboxedRsi) {
      if (CHECK_OPERAND(0, REG_RDI, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_RDI, OperandSandboxRestricted)) {
        sandboxed_rsi_restricted_rdi = begin;
        restricted_register = kSandboxedRsiRestrictedRdi;
      }
    }
    if (restricted_register != kSandboxedRsiRestrictedRdi) {
      restricted_register = kNoRestrictedReg;
      if (CHECK_OPERAND(0, REG_R15, OperandSandbox8bit) ||
          CHECK_OPERAND(0, REG_R15, OperandSandboxRestricted) ||
          CHECK_OPERAND(0, REG_R15, OperandSandboxUnrestricted) ||
          CHECK_OPERAND(1, REG_R15, OperandSandbox8bit) ||
          CHECK_OPERAND(1, REG_R15, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_R15, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%r15\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((CHECK_OPERAND(0, REG_RBP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(0, REG_RBP, OperandSandboxUnrestricted) ||
                 (CHECK_OPERAND(1, REG_RBP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(1, REG_RBP, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%rbp\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((CHECK_OPERAND(0, REG_RSP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(0, REG_RSP, OperandSandboxUnrestricted) ||
                 (CHECK_OPERAND(1, REG_RSP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(1, REG_RSP, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%rsp\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((operand_states & 0x70) == (OperandSandboxRestricted << 5)) {
        restricted_register = operand_states & 0x0f;
      } else if ((operand_states & 0x7000) ==
                                        (OperandSandboxRestricted << (5 + 8))) {
        restricted_register = (operand_states & 0x0f00) >> 8;
      }
    }
  }
#line 337 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
       /* On successful match the instruction start must point to the next byte
        * to be able to report the new offset as the start of instruction
        * causing error.  */
       begin = p + 1;
     }
	goto st730;
st730:
	if ( ++p == pe )
		goto _test_eof730;
case 730:
#line 34089 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 0u: goto tr978;
		case 1u: goto tr979;
		case 2u: goto tr980;
		case 3u: goto tr981;
		case 4u: goto tr982;
		case 5u: goto tr983;
		case 8u: goto tr978;
		case 9u: goto tr979;
		case 10u: goto tr980;
		case 11u: goto tr981;
		case 12u: goto tr982;
		case 13u: goto tr983;
		case 15u: goto tr984;
		case 16u: goto tr978;
		case 17u: goto tr979;
		case 18u: goto tr980;
		case 19u: goto tr981;
		case 20u: goto tr982;
		case 21u: goto tr983;
		case 24u: goto tr978;
		case 25u: goto tr979;
		case 26u: goto tr980;
		case 27u: goto tr981;
		case 28u: goto tr982;
		case 29u: goto tr983;
		case 32u: goto tr978;
		case 33u: goto tr979;
		case 34u: goto tr980;
		case 35u: goto tr981;
		case 36u: goto tr982;
		case 37u: goto tr983;
		case 40u: goto tr978;
		case 41u: goto tr979;
		case 42u: goto tr980;
		case 43u: goto tr981;
		case 44u: goto tr982;
		case 45u: goto tr983;
		case 46u: goto tr985;
		case 48u: goto tr978;
		case 49u: goto tr979;
		case 50u: goto tr980;
		case 51u: goto tr981;
		case 52u: goto tr982;
		case 53u: goto tr983;
		case 60u: goto tr987;
		case 61u: goto tr988;
		case 62u: goto tr989;
		case 65u: goto tr991;
		case 72u: goto tr992;
		case 73u: goto tr993;
		case 74u: goto tr994;
		case 76u: goto tr1050;
		case 99u: goto tr981;
		case 102u: goto tr999;
		case 104u: goto tr988;
		case 105u: goto tr1000;
		case 106u: goto tr987;
		case 107u: goto tr1001;
		case 128u: goto tr1003;
		case 129u: goto tr1004;
		case 131u: goto tr1005;
		case 133u: goto tr979;
		case 134u: goto tr1006;
		case 135u: goto tr1007;
		case 137u: goto tr979;
		case 138u: goto tr980;
		case 139u: goto tr981;
		case 141u: goto tr1008;
		case 143u: goto tr1009;
		case 144u: goto tr1010;
		case 155u: goto tr1010;
		case 168u: goto tr982;
		case 169u: goto tr983;
		case 192u: goto tr1017;
		case 193u: goto tr1018;
		case 196u: goto tr1019;
		case 197u: goto tr1020;
		case 198u: goto tr1021;
		case 199u: goto tr1022;
		case 200u: goto tr1023;
		case 202u: goto tr1024;
		case 203u: goto tr1010;
		case 209u: goto tr1026;
		case 211u: goto tr1026;
		case 216u: goto tr986;
		case 217u: goto tr1027;
		case 218u: goto tr1028;
		case 219u: goto tr1029;
		case 220u: goto tr1030;
		case 221u: goto tr1031;
		case 222u: goto tr1032;
		case 223u: goto tr1033;
		case 235u: goto tr1002;
		case 240u: goto tr1035;
		case 242u: goto tr1036;
		case 243u: goto tr1037;
		case 246u: goto tr1038;
		case 247u: goto tr1039;
		case 254u: goto tr1040;
		case 255u: goto tr1041;
	}
	if ( (*p) < 164u ) {
		if ( (*p) < 88u ) {
			if ( (*p) < 64u ) {
				if ( 56u <= (*p) && (*p) <= 59u )
					goto tr986;
			} else if ( (*p) > 71u ) {
				if ( (*p) > 79u ) {
					if ( 80u <= (*p) && (*p) <= 87u )
						goto tr997;
				} else if ( (*p) >= 75u )
					goto tr995;
			} else
				goto tr990;
		} else if ( (*p) > 95u ) {
			if ( (*p) < 132u ) {
				if ( 112u <= (*p) && (*p) <= 127u )
					goto tr1002;
			} else if ( (*p) > 136u ) {
				if ( (*p) > 151u ) {
					if ( 152u <= (*p) && (*p) <= 153u )
						goto tr1010;
				} else if ( (*p) >= 145u )
					goto tr1011;
			} else
				goto tr978;
		} else
			goto tr998;
	} else if ( (*p) > 167u ) {
		if ( (*p) < 184u ) {
			if ( (*p) < 172u ) {
				if ( 170u <= (*p) && (*p) <= 171u )
					goto tr1013;
			} else if ( (*p) > 173u ) {
				if ( (*p) > 175u ) {
					if ( 176u <= (*p) && (*p) <= 183u )
						goto tr1015;
				} else if ( (*p) >= 174u )
					goto tr1013;
			} else
				goto tr1014;
		} else if ( (*p) > 191u ) {
			if ( (*p) < 232u ) {
				if ( 208u <= (*p) && (*p) <= 210u )
					goto tr1025;
			} else if ( (*p) > 233u ) {
				if ( (*p) > 249u ) {
					if ( 252u <= (*p) && (*p) <= 253u )
						goto tr1010;
				} else if ( (*p) >= 244u )
					goto tr1010;
			} else
				goto tr1034;
		} else
			goto tr1016;
	} else
		goto tr1012;
	goto tr33;
tr1050:
#line 329 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
        begin = p;
        BitmapSetBit(valid_targets, p - data);
        SET_REX_PREFIX(FALSE);
        SET_VEX_PREFIX2(0xe0);
        SET_VEX_PREFIX3(0x00);
        operand_states = 0;
     }
#line 190 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_REX_PREFIX(*p);
  }
	goto st672;
st672:
	if ( ++p == pe )
		goto _test_eof672;
case 672:
#line 34268 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 1u: goto tr940;
		case 3u: goto tr221;
		case 9u: goto tr220;
		case 11u: goto tr221;
		case 15u: goto st142;
		case 17u: goto tr220;
		case 19u: goto tr221;
		case 25u: goto tr220;
		case 27u: goto tr221;
		case 33u: goto tr220;
		case 35u: goto tr221;
		case 41u: goto tr220;
		case 43u: goto tr221;
		case 49u: goto tr220;
		case 51u: goto tr221;
		case 57u: goto st38;
		case 59u: goto st38;
		case 99u: goto tr221;
		case 105u: goto tr224;
		case 107u: goto tr225;
		case 129u: goto st144;
		case 131u: goto st145;
		case 133u: goto tr220;
		case 135u: goto tr228;
		case 137u: goto tr220;
		case 139u: goto tr221;
		case 141u: goto tr230;
		case 193u: goto st150;
		case 199u: goto st151;
		case 209u: goto st152;
		case 211u: goto st152;
		case 247u: goto st153;
		case 255u: goto st154;
	}
	if ( (*p) > 151u ) {
		if ( 184u <= (*p) && (*p) <= 191u )
			goto tr235;
	} else if ( (*p) >= 145u )
		goto tr231;
	goto tr33;
tr940:
#line 298 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(0, OperandSize64bit);
  }
	goto st673;
st673:
	if ( ++p == pe )
		goto _test_eof673;
case 673:
#line 34320 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 4u: goto st2;
		case 5u: goto tr2;
		case 12u: goto st2;
		case 13u: goto tr2;
		case 20u: goto st2;
		case 21u: goto tr2;
		case 28u: goto st2;
		case 29u: goto tr2;
		case 36u: goto st2;
		case 37u: goto tr2;
		case 44u: goto st2;
		case 45u: goto tr2;
		case 52u: goto st2;
		case 53u: goto tr2;
		case 60u: goto st2;
		case 61u: goto tr2;
		case 68u: goto st8;
		case 76u: goto st8;
		case 84u: goto st8;
		case 92u: goto st8;
		case 100u: goto st8;
		case 108u: goto st8;
		case 116u: goto st8;
		case 124u: goto st8;
		case 132u: goto st9;
		case 140u: goto st9;
		case 148u: goto st9;
		case 156u: goto st9;
		case 164u: goto st9;
		case 172u: goto st9;
		case 180u: goto st9;
		case 188u: goto st9;
		case 251u: goto tr941;
		case 252u: goto tr286;
		case 253u: goto tr280;
	}
	if ( (*p) < 64u ) {
		if ( (*p) <= 63u )
			goto tr0;
	} else if ( (*p) > 127u ) {
		if ( 128u <= (*p) && (*p) <= 191u )
			goto tr5;
	} else
		goto tr3;
	goto tr7;
tr941:
#line 384 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_NAME(0, ((*p) & 0x07) |
                           ((GET_REX_PREFIX() & 0x01) << 3) |
                           (((~GET_VEX_PREFIX2()) & 0x20) >> 2));
  }
#line 93 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    /* Restricted %rsp or %rbp must be processed by appropriate nacl-special
       instruction, not with regular instruction.  */
    if (restricted_register == REG_RSP) {
      PrintError("Incorrectly modified register %%rsp\n", begin - data);
      result = 1;
      goto error_detected;
    } else if (restricted_register == REG_RBP) {
      PrintError("Incorrectly modified register %%rbp\n", begin - data);
      result = 1;
      goto error_detected;
    }
    /* If Sandboxed Rsi is destroyed then we must note that.  */
    if (restricted_register == kSandboxedRsi) {
      if (CHECK_OPERAND(0, REG_RSI, OperandSandboxRestricted) ||
          CHECK_OPERAND(0, REG_RSI, OperandSandboxUnrestricted) ||
          CHECK_OPERAND(1, REG_RSI, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_RSI, OperandSandboxUnrestricted)) {
        restricted_register = kNoRestrictedReg;
      }
    }
    if (restricted_register == kSandboxedRsi) {
      if (CHECK_OPERAND(0, REG_RDI, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_RDI, OperandSandboxRestricted)) {
        sandboxed_rsi_restricted_rdi = begin;
        restricted_register = kSandboxedRsiRestrictedRdi;
      }
    }
    if (restricted_register != kSandboxedRsiRestrictedRdi) {
      restricted_register = kNoRestrictedReg;
      if (CHECK_OPERAND(0, REG_R15, OperandSandbox8bit) ||
          CHECK_OPERAND(0, REG_R15, OperandSandboxRestricted) ||
          CHECK_OPERAND(0, REG_R15, OperandSandboxUnrestricted) ||
          CHECK_OPERAND(1, REG_R15, OperandSandbox8bit) ||
          CHECK_OPERAND(1, REG_R15, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_R15, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%r15\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((CHECK_OPERAND(0, REG_RBP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(0, REG_RBP, OperandSandboxUnrestricted) ||
                 (CHECK_OPERAND(1, REG_RBP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(1, REG_RBP, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%rbp\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((CHECK_OPERAND(0, REG_RSP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(0, REG_RSP, OperandSandboxUnrestricted) ||
                 (CHECK_OPERAND(1, REG_RSP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(1, REG_RSP, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%rsp\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((operand_states & 0x70) == (OperandSandboxRestricted << 5)) {
        restricted_register = operand_states & 0x0f;
      } else if ((operand_states & 0x7000) ==
                                        (OperandSandboxRestricted << (5 + 8))) {
        restricted_register = (operand_states & 0x0f00) >> 8;
      }
    }
  }
#line 337 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
       /* On successful match the instruction start must point to the next byte
        * to be able to report the new offset as the start of instruction
        * causing error.  */
       begin = p + 1;
     }
	goto st731;
st731:
	if ( ++p == pe )
		goto _test_eof731;
case 731:
#line 34452 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 0u: goto tr978;
		case 1u: goto tr979;
		case 2u: goto tr980;
		case 3u: goto tr981;
		case 4u: goto tr982;
		case 5u: goto tr983;
		case 8u: goto tr978;
		case 9u: goto tr979;
		case 10u: goto tr980;
		case 11u: goto tr981;
		case 12u: goto tr982;
		case 13u: goto tr983;
		case 15u: goto tr984;
		case 16u: goto tr978;
		case 17u: goto tr979;
		case 18u: goto tr980;
		case 19u: goto tr981;
		case 20u: goto tr982;
		case 21u: goto tr983;
		case 24u: goto tr978;
		case 25u: goto tr979;
		case 26u: goto tr980;
		case 27u: goto tr981;
		case 28u: goto tr982;
		case 29u: goto tr983;
		case 32u: goto tr978;
		case 33u: goto tr979;
		case 34u: goto tr980;
		case 35u: goto tr981;
		case 36u: goto tr982;
		case 37u: goto tr983;
		case 40u: goto tr978;
		case 41u: goto tr979;
		case 42u: goto tr980;
		case 43u: goto tr981;
		case 44u: goto tr982;
		case 45u: goto tr983;
		case 46u: goto tr985;
		case 48u: goto tr978;
		case 49u: goto tr979;
		case 50u: goto tr980;
		case 51u: goto tr981;
		case 52u: goto tr982;
		case 53u: goto tr983;
		case 60u: goto tr987;
		case 61u: goto tr988;
		case 62u: goto tr989;
		case 65u: goto tr991;
		case 72u: goto tr992;
		case 73u: goto tr993;
		case 74u: goto tr994;
		case 76u: goto tr996;
		case 99u: goto tr981;
		case 102u: goto tr999;
		case 104u: goto tr988;
		case 105u: goto tr1000;
		case 106u: goto tr987;
		case 107u: goto tr1001;
		case 128u: goto tr1003;
		case 129u: goto tr1004;
		case 131u: goto tr1005;
		case 133u: goto tr979;
		case 134u: goto tr1006;
		case 135u: goto tr1007;
		case 137u: goto tr979;
		case 138u: goto tr980;
		case 139u: goto tr981;
		case 141u: goto tr1008;
		case 143u: goto tr1009;
		case 144u: goto tr1010;
		case 155u: goto tr1010;
		case 168u: goto tr982;
		case 169u: goto tr983;
		case 192u: goto tr1017;
		case 193u: goto tr1018;
		case 196u: goto tr1019;
		case 197u: goto tr1020;
		case 198u: goto tr1021;
		case 199u: goto tr1022;
		case 200u: goto tr1023;
		case 202u: goto tr1024;
		case 203u: goto tr1010;
		case 209u: goto tr1026;
		case 211u: goto tr1026;
		case 216u: goto tr986;
		case 217u: goto tr1027;
		case 218u: goto tr1028;
		case 219u: goto tr1029;
		case 220u: goto tr1030;
		case 221u: goto tr1031;
		case 222u: goto tr1032;
		case 223u: goto tr1033;
		case 235u: goto tr1002;
		case 240u: goto tr1035;
		case 242u: goto tr1036;
		case 243u: goto tr1037;
		case 246u: goto tr1038;
		case 247u: goto tr1039;
		case 254u: goto tr1040;
		case 255u: goto tr1051;
	}
	if ( (*p) < 164u ) {
		if ( (*p) < 88u ) {
			if ( (*p) < 64u ) {
				if ( 56u <= (*p) && (*p) <= 59u )
					goto tr986;
			} else if ( (*p) > 71u ) {
				if ( (*p) > 79u ) {
					if ( 80u <= (*p) && (*p) <= 87u )
						goto tr997;
				} else if ( (*p) >= 75u )
					goto tr995;
			} else
				goto tr990;
		} else if ( (*p) > 95u ) {
			if ( (*p) < 132u ) {
				if ( 112u <= (*p) && (*p) <= 127u )
					goto tr1002;
			} else if ( (*p) > 136u ) {
				if ( (*p) > 151u ) {
					if ( 152u <= (*p) && (*p) <= 153u )
						goto tr1010;
				} else if ( (*p) >= 145u )
					goto tr1011;
			} else
				goto tr978;
		} else
			goto tr998;
	} else if ( (*p) > 167u ) {
		if ( (*p) < 184u ) {
			if ( (*p) < 172u ) {
				if ( 170u <= (*p) && (*p) <= 171u )
					goto tr1013;
			} else if ( (*p) > 173u ) {
				if ( (*p) > 175u ) {
					if ( 176u <= (*p) && (*p) <= 183u )
						goto tr1015;
				} else if ( (*p) >= 174u )
					goto tr1013;
			} else
				goto tr1014;
		} else if ( (*p) > 191u ) {
			if ( (*p) < 232u ) {
				if ( 208u <= (*p) && (*p) <= 210u )
					goto tr1025;
			} else if ( (*p) > 233u ) {
				if ( (*p) > 249u ) {
					if ( 252u <= (*p) && (*p) <= 253u )
						goto tr1010;
				} else if ( (*p) >= 244u )
					goto tr1010;
			} else
				goto tr1034;
		} else
			goto tr1016;
	} else
		goto tr1012;
	goto tr33;
tr1051:
#line 329 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
        begin = p;
        BitmapSetBit(valid_targets, p - data);
        SET_REX_PREFIX(FALSE);
        SET_VEX_PREFIX2(0xe0);
        SET_VEX_PREFIX3(0x00);
        operand_states = 0;
     }
	goto st674;
st674:
	if ( ++p == pe )
		goto _test_eof674;
case 674:
#line 34627 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 4u: goto st2;
		case 5u: goto tr2;
		case 12u: goto st2;
		case 13u: goto tr2;
		case 52u: goto st2;
		case 53u: goto tr2;
		case 68u: goto st8;
		case 76u: goto st8;
		case 116u: goto st8;
		case 132u: goto st9;
		case 140u: goto st9;
		case 180u: goto st9;
		case 211u: goto tr932;
		case 227u: goto tr932;
	}
	if ( (*p) < 112u ) {
		if ( (*p) < 48u ) {
			if ( (*p) <= 15u )
				goto tr0;
		} else if ( (*p) > 55u ) {
			if ( 64u <= (*p) && (*p) <= 79u )
				goto tr3;
		} else
			goto tr0;
	} else if ( (*p) > 119u ) {
		if ( (*p) < 176u ) {
			if ( 128u <= (*p) && (*p) <= 143u )
				goto tr5;
		} else if ( (*p) > 183u ) {
			if ( (*p) > 207u ) {
				if ( 240u <= (*p) && (*p) <= 247u )
					goto tr34;
			} else if ( (*p) >= 192u )
				goto tr56;
		} else
			goto tr5;
	} else
		goto tr3;
	goto tr33;
tr437:
#line 295 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(0, OperandSize32bit);
  }
#line 384 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_NAME(0, ((*p) & 0x07) |
                           ((GET_REX_PREFIX() & 0x01) << 3) |
                           (((~GET_VEX_PREFIX2()) & 0x20) >> 2));
  }
	goto st675;
st675:
	if ( ++p == pe )
		goto _test_eof675;
case 675:
#line 34684 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	if ( (*p) == 224u )
		goto tr942;
	goto tr25;
tr942:
#line 58 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_IMM_TYPE(IMM8);
    SET_IMM_PTR(p);
  }
#line 93 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    /* Restricted %rsp or %rbp must be processed by appropriate nacl-special
       instruction, not with regular instruction.  */
    if (restricted_register == REG_RSP) {
      PrintError("Incorrectly modified register %%rsp\n", begin - data);
      result = 1;
      goto error_detected;
    } else if (restricted_register == REG_RBP) {
      PrintError("Incorrectly modified register %%rbp\n", begin - data);
      result = 1;
      goto error_detected;
    }
    /* If Sandboxed Rsi is destroyed then we must note that.  */
    if (restricted_register == kSandboxedRsi) {
      if (CHECK_OPERAND(0, REG_RSI, OperandSandboxRestricted) ||
          CHECK_OPERAND(0, REG_RSI, OperandSandboxUnrestricted) ||
          CHECK_OPERAND(1, REG_RSI, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_RSI, OperandSandboxUnrestricted)) {
        restricted_register = kNoRestrictedReg;
      }
    }
    if (restricted_register == kSandboxedRsi) {
      if (CHECK_OPERAND(0, REG_RDI, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_RDI, OperandSandboxRestricted)) {
        sandboxed_rsi_restricted_rdi = begin;
        restricted_register = kSandboxedRsiRestrictedRdi;
      }
    }
    if (restricted_register != kSandboxedRsiRestrictedRdi) {
      restricted_register = kNoRestrictedReg;
      if (CHECK_OPERAND(0, REG_R15, OperandSandbox8bit) ||
          CHECK_OPERAND(0, REG_R15, OperandSandboxRestricted) ||
          CHECK_OPERAND(0, REG_R15, OperandSandboxUnrestricted) ||
          CHECK_OPERAND(1, REG_R15, OperandSandbox8bit) ||
          CHECK_OPERAND(1, REG_R15, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_R15, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%r15\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((CHECK_OPERAND(0, REG_RBP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(0, REG_RBP, OperandSandboxUnrestricted) ||
                 (CHECK_OPERAND(1, REG_RBP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(1, REG_RBP, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%rbp\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((CHECK_OPERAND(0, REG_RSP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(0, REG_RSP, OperandSandboxUnrestricted) ||
                 (CHECK_OPERAND(1, REG_RSP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(1, REG_RSP, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%rsp\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((operand_states & 0x70) == (OperandSandboxRestricted << 5)) {
        restricted_register = operand_states & 0x0f;
      } else if ((operand_states & 0x7000) ==
                                        (OperandSandboxRestricted << (5 + 8))) {
        restricted_register = (operand_states & 0x0f00) >> 8;
      }
    }
  }
#line 337 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
       /* On successful match the instruction start must point to the next byte
        * to be able to report the new offset as the start of instruction
        * causing error.  */
       begin = p + 1;
     }
	goto st732;
st732:
	if ( ++p == pe )
		goto _test_eof732;
case 732:
#line 34772 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 0u: goto tr978;
		case 1u: goto tr979;
		case 2u: goto tr980;
		case 3u: goto tr981;
		case 4u: goto tr982;
		case 5u: goto tr983;
		case 8u: goto tr978;
		case 9u: goto tr979;
		case 10u: goto tr980;
		case 11u: goto tr981;
		case 12u: goto tr982;
		case 13u: goto tr983;
		case 15u: goto tr984;
		case 16u: goto tr978;
		case 17u: goto tr979;
		case 18u: goto tr980;
		case 19u: goto tr981;
		case 20u: goto tr982;
		case 21u: goto tr983;
		case 24u: goto tr978;
		case 25u: goto tr979;
		case 26u: goto tr980;
		case 27u: goto tr981;
		case 28u: goto tr982;
		case 29u: goto tr983;
		case 32u: goto tr978;
		case 33u: goto tr979;
		case 34u: goto tr980;
		case 35u: goto tr981;
		case 36u: goto tr982;
		case 37u: goto tr983;
		case 40u: goto tr978;
		case 41u: goto tr979;
		case 42u: goto tr980;
		case 43u: goto tr981;
		case 44u: goto tr982;
		case 45u: goto tr983;
		case 46u: goto tr985;
		case 48u: goto tr978;
		case 49u: goto tr979;
		case 50u: goto tr980;
		case 51u: goto tr981;
		case 52u: goto tr982;
		case 53u: goto tr983;
		case 60u: goto tr987;
		case 61u: goto tr988;
		case 62u: goto tr989;
		case 65u: goto tr991;
		case 72u: goto tr992;
		case 73u: goto tr993;
		case 74u: goto tr994;
		case 76u: goto tr1052;
		case 99u: goto tr981;
		case 102u: goto tr999;
		case 104u: goto tr988;
		case 105u: goto tr1000;
		case 106u: goto tr987;
		case 107u: goto tr1001;
		case 128u: goto tr1003;
		case 129u: goto tr1004;
		case 131u: goto tr1005;
		case 133u: goto tr979;
		case 134u: goto tr1006;
		case 135u: goto tr1007;
		case 137u: goto tr979;
		case 138u: goto tr980;
		case 139u: goto tr981;
		case 141u: goto tr1008;
		case 143u: goto tr1009;
		case 144u: goto tr1010;
		case 155u: goto tr1010;
		case 168u: goto tr982;
		case 169u: goto tr983;
		case 192u: goto tr1017;
		case 193u: goto tr1018;
		case 196u: goto tr1019;
		case 197u: goto tr1020;
		case 198u: goto tr1021;
		case 199u: goto tr1022;
		case 200u: goto tr1023;
		case 202u: goto tr1024;
		case 203u: goto tr1010;
		case 209u: goto tr1026;
		case 211u: goto tr1026;
		case 216u: goto tr986;
		case 217u: goto tr1027;
		case 218u: goto tr1028;
		case 219u: goto tr1029;
		case 220u: goto tr1030;
		case 221u: goto tr1031;
		case 222u: goto tr1032;
		case 223u: goto tr1033;
		case 235u: goto tr1002;
		case 240u: goto tr1035;
		case 242u: goto tr1036;
		case 243u: goto tr1037;
		case 246u: goto tr1038;
		case 247u: goto tr1039;
		case 254u: goto tr1040;
		case 255u: goto tr1041;
	}
	if ( (*p) < 164u ) {
		if ( (*p) < 88u ) {
			if ( (*p) < 64u ) {
				if ( 56u <= (*p) && (*p) <= 59u )
					goto tr986;
			} else if ( (*p) > 71u ) {
				if ( (*p) > 79u ) {
					if ( 80u <= (*p) && (*p) <= 87u )
						goto tr997;
				} else if ( (*p) >= 75u )
					goto tr995;
			} else
				goto tr990;
		} else if ( (*p) > 95u ) {
			if ( (*p) < 132u ) {
				if ( 112u <= (*p) && (*p) <= 127u )
					goto tr1002;
			} else if ( (*p) > 136u ) {
				if ( (*p) > 151u ) {
					if ( 152u <= (*p) && (*p) <= 153u )
						goto tr1010;
				} else if ( (*p) >= 145u )
					goto tr1011;
			} else
				goto tr978;
		} else
			goto tr998;
	} else if ( (*p) > 167u ) {
		if ( (*p) < 184u ) {
			if ( (*p) < 172u ) {
				if ( 170u <= (*p) && (*p) <= 171u )
					goto tr1013;
			} else if ( (*p) > 173u ) {
				if ( (*p) > 175u ) {
					if ( 176u <= (*p) && (*p) <= 183u )
						goto tr1015;
				} else if ( (*p) >= 174u )
					goto tr1013;
			} else
				goto tr1014;
		} else if ( (*p) > 191u ) {
			if ( (*p) < 232u ) {
				if ( 208u <= (*p) && (*p) <= 210u )
					goto tr1025;
			} else if ( (*p) > 233u ) {
				if ( (*p) > 249u ) {
					if ( 252u <= (*p) && (*p) <= 253u )
						goto tr1010;
				} else if ( (*p) >= 244u )
					goto tr1010;
			} else
				goto tr1034;
		} else
			goto tr1016;
	} else
		goto tr1012;
	goto tr33;
tr1052:
#line 329 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
        begin = p;
        BitmapSetBit(valid_targets, p - data);
        SET_REX_PREFIX(FALSE);
        SET_VEX_PREFIX2(0xe0);
        SET_VEX_PREFIX3(0x00);
        operand_states = 0;
     }
#line 190 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_REX_PREFIX(*p);
  }
	goto st676;
st676:
	if ( ++p == pe )
		goto _test_eof676;
case 676:
#line 34951 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 1u: goto tr943;
		case 3u: goto tr221;
		case 9u: goto tr220;
		case 11u: goto tr221;
		case 15u: goto st142;
		case 17u: goto tr220;
		case 19u: goto tr221;
		case 25u: goto tr220;
		case 27u: goto tr221;
		case 33u: goto tr220;
		case 35u: goto tr221;
		case 41u: goto tr220;
		case 43u: goto tr221;
		case 49u: goto tr220;
		case 51u: goto tr221;
		case 57u: goto st38;
		case 59u: goto st38;
		case 99u: goto tr221;
		case 105u: goto tr224;
		case 107u: goto tr225;
		case 129u: goto st144;
		case 131u: goto st145;
		case 133u: goto tr220;
		case 135u: goto tr228;
		case 137u: goto tr220;
		case 139u: goto tr221;
		case 141u: goto tr230;
		case 193u: goto st150;
		case 199u: goto st151;
		case 209u: goto st152;
		case 211u: goto st152;
		case 247u: goto st153;
		case 255u: goto st154;
	}
	if ( (*p) > 151u ) {
		if ( 184u <= (*p) && (*p) <= 191u )
			goto tr235;
	} else if ( (*p) >= 145u )
		goto tr231;
	goto tr33;
tr943:
#line 298 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(0, OperandSize64bit);
  }
	goto st677;
st677:
	if ( ++p == pe )
		goto _test_eof677;
case 677:
#line 35003 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 4u: goto st2;
		case 5u: goto tr2;
		case 12u: goto st2;
		case 13u: goto tr2;
		case 20u: goto st2;
		case 21u: goto tr2;
		case 28u: goto st2;
		case 29u: goto tr2;
		case 36u: goto st2;
		case 37u: goto tr2;
		case 44u: goto st2;
		case 45u: goto tr2;
		case 52u: goto st2;
		case 53u: goto tr2;
		case 60u: goto st2;
		case 61u: goto tr2;
		case 68u: goto st8;
		case 76u: goto st8;
		case 84u: goto st8;
		case 92u: goto st8;
		case 100u: goto st8;
		case 108u: goto st8;
		case 116u: goto st8;
		case 124u: goto st8;
		case 132u: goto st9;
		case 140u: goto st9;
		case 148u: goto st9;
		case 156u: goto st9;
		case 164u: goto st9;
		case 172u: goto st9;
		case 180u: goto st9;
		case 188u: goto st9;
		case 252u: goto tr944;
		case 253u: goto tr280;
	}
	if ( (*p) < 64u ) {
		if ( (*p) <= 63u )
			goto tr0;
	} else if ( (*p) > 127u ) {
		if ( 128u <= (*p) && (*p) <= 191u )
			goto tr5;
	} else
		goto tr3;
	goto tr7;
tr944:
#line 213 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{ if (restricted_register != REG_RSP) {
         PrintError("Incorrectly sandboxed %%rsp\n", begin - data);
         result = 1;
         goto error_detected;
       }
       restricted_register = kNoRestrictedReg;
       BitmapClearBit(valid_targets, (begin - data));
    }
#line 337 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
       /* On successful match the instruction start must point to the next byte
        * to be able to report the new offset as the start of instruction
        * causing error.  */
       begin = p + 1;
     }
	goto st733;
st733:
	if ( ++p == pe )
		goto _test_eof733;
case 733:
#line 35071 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 0u: goto tr978;
		case 1u: goto tr979;
		case 2u: goto tr980;
		case 3u: goto tr981;
		case 4u: goto tr982;
		case 5u: goto tr983;
		case 8u: goto tr978;
		case 9u: goto tr979;
		case 10u: goto tr980;
		case 11u: goto tr981;
		case 12u: goto tr982;
		case 13u: goto tr983;
		case 15u: goto tr984;
		case 16u: goto tr978;
		case 17u: goto tr979;
		case 18u: goto tr980;
		case 19u: goto tr981;
		case 20u: goto tr982;
		case 21u: goto tr983;
		case 24u: goto tr978;
		case 25u: goto tr979;
		case 26u: goto tr980;
		case 27u: goto tr981;
		case 28u: goto tr982;
		case 29u: goto tr983;
		case 32u: goto tr978;
		case 33u: goto tr979;
		case 34u: goto tr980;
		case 35u: goto tr981;
		case 36u: goto tr982;
		case 37u: goto tr983;
		case 40u: goto tr978;
		case 41u: goto tr979;
		case 42u: goto tr980;
		case 43u: goto tr981;
		case 44u: goto tr982;
		case 45u: goto tr983;
		case 46u: goto tr985;
		case 48u: goto tr978;
		case 49u: goto tr979;
		case 50u: goto tr980;
		case 51u: goto tr981;
		case 52u: goto tr982;
		case 53u: goto tr983;
		case 60u: goto tr987;
		case 61u: goto tr988;
		case 62u: goto tr989;
		case 65u: goto tr991;
		case 72u: goto tr992;
		case 73u: goto tr993;
		case 74u: goto tr994;
		case 76u: goto tr996;
		case 99u: goto tr981;
		case 102u: goto tr999;
		case 104u: goto tr988;
		case 105u: goto tr1000;
		case 106u: goto tr987;
		case 107u: goto tr1001;
		case 128u: goto tr1003;
		case 129u: goto tr1004;
		case 131u: goto tr1005;
		case 133u: goto tr979;
		case 134u: goto tr1006;
		case 135u: goto tr1007;
		case 137u: goto tr979;
		case 138u: goto tr980;
		case 139u: goto tr981;
		case 141u: goto tr1008;
		case 143u: goto tr1009;
		case 144u: goto tr1010;
		case 155u: goto tr1010;
		case 168u: goto tr982;
		case 169u: goto tr983;
		case 192u: goto tr1017;
		case 193u: goto tr1018;
		case 196u: goto tr1019;
		case 197u: goto tr1020;
		case 198u: goto tr1021;
		case 199u: goto tr1022;
		case 200u: goto tr1023;
		case 202u: goto tr1024;
		case 203u: goto tr1010;
		case 209u: goto tr1026;
		case 211u: goto tr1026;
		case 216u: goto tr986;
		case 217u: goto tr1027;
		case 218u: goto tr1028;
		case 219u: goto tr1029;
		case 220u: goto tr1030;
		case 221u: goto tr1031;
		case 222u: goto tr1032;
		case 223u: goto tr1033;
		case 235u: goto tr1002;
		case 240u: goto tr1035;
		case 242u: goto tr1036;
		case 243u: goto tr1037;
		case 246u: goto tr1038;
		case 247u: goto tr1039;
		case 254u: goto tr1040;
		case 255u: goto tr1053;
	}
	if ( (*p) < 164u ) {
		if ( (*p) < 88u ) {
			if ( (*p) < 64u ) {
				if ( 56u <= (*p) && (*p) <= 59u )
					goto tr986;
			} else if ( (*p) > 71u ) {
				if ( (*p) > 79u ) {
					if ( 80u <= (*p) && (*p) <= 87u )
						goto tr997;
				} else if ( (*p) >= 75u )
					goto tr995;
			} else
				goto tr990;
		} else if ( (*p) > 95u ) {
			if ( (*p) < 132u ) {
				if ( 112u <= (*p) && (*p) <= 127u )
					goto tr1002;
			} else if ( (*p) > 136u ) {
				if ( (*p) > 151u ) {
					if ( 152u <= (*p) && (*p) <= 153u )
						goto tr1010;
				} else if ( (*p) >= 145u )
					goto tr1011;
			} else
				goto tr978;
		} else
			goto tr998;
	} else if ( (*p) > 167u ) {
		if ( (*p) < 184u ) {
			if ( (*p) < 172u ) {
				if ( 170u <= (*p) && (*p) <= 171u )
					goto tr1013;
			} else if ( (*p) > 173u ) {
				if ( (*p) > 175u ) {
					if ( 176u <= (*p) && (*p) <= 183u )
						goto tr1015;
				} else if ( (*p) >= 174u )
					goto tr1013;
			} else
				goto tr1014;
		} else if ( (*p) > 191u ) {
			if ( (*p) < 232u ) {
				if ( 208u <= (*p) && (*p) <= 210u )
					goto tr1025;
			} else if ( (*p) > 233u ) {
				if ( (*p) > 249u ) {
					if ( 252u <= (*p) && (*p) <= 253u )
						goto tr1010;
				} else if ( (*p) >= 244u )
					goto tr1010;
			} else
				goto tr1034;
		} else
			goto tr1016;
	} else
		goto tr1012;
	goto tr33;
tr1053:
#line 329 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
        begin = p;
        BitmapSetBit(valid_targets, p - data);
        SET_REX_PREFIX(FALSE);
        SET_VEX_PREFIX2(0xe0);
        SET_VEX_PREFIX3(0x00);
        operand_states = 0;
     }
	goto st678;
st678:
	if ( ++p == pe )
		goto _test_eof678;
case 678:
#line 35246 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 4u: goto st2;
		case 5u: goto tr2;
		case 12u: goto st2;
		case 13u: goto tr2;
		case 52u: goto st2;
		case 53u: goto tr2;
		case 68u: goto st8;
		case 76u: goto st8;
		case 116u: goto st8;
		case 132u: goto st9;
		case 140u: goto st9;
		case 180u: goto st9;
		case 212u: goto tr932;
		case 228u: goto tr932;
	}
	if ( (*p) < 112u ) {
		if ( (*p) < 48u ) {
			if ( (*p) <= 15u )
				goto tr0;
		} else if ( (*p) > 55u ) {
			if ( 64u <= (*p) && (*p) <= 79u )
				goto tr3;
		} else
			goto tr0;
	} else if ( (*p) > 119u ) {
		if ( (*p) < 176u ) {
			if ( 128u <= (*p) && (*p) <= 143u )
				goto tr5;
		} else if ( (*p) > 183u ) {
			if ( (*p) > 207u ) {
				if ( 240u <= (*p) && (*p) <= 247u )
					goto tr34;
			} else if ( (*p) >= 192u )
				goto tr56;
		} else
			goto tr5;
	} else
		goto tr3;
	goto tr33;
tr438:
#line 295 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(0, OperandSize32bit);
  }
#line 384 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_NAME(0, ((*p) & 0x07) |
                           ((GET_REX_PREFIX() & 0x01) << 3) |
                           (((~GET_VEX_PREFIX2()) & 0x20) >> 2));
  }
	goto st679;
st679:
	if ( ++p == pe )
		goto _test_eof679;
case 679:
#line 35303 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	if ( (*p) == 224u )
		goto tr945;
	goto tr25;
tr945:
#line 58 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_IMM_TYPE(IMM8);
    SET_IMM_PTR(p);
  }
#line 93 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    /* Restricted %rsp or %rbp must be processed by appropriate nacl-special
       instruction, not with regular instruction.  */
    if (restricted_register == REG_RSP) {
      PrintError("Incorrectly modified register %%rsp\n", begin - data);
      result = 1;
      goto error_detected;
    } else if (restricted_register == REG_RBP) {
      PrintError("Incorrectly modified register %%rbp\n", begin - data);
      result = 1;
      goto error_detected;
    }
    /* If Sandboxed Rsi is destroyed then we must note that.  */
    if (restricted_register == kSandboxedRsi) {
      if (CHECK_OPERAND(0, REG_RSI, OperandSandboxRestricted) ||
          CHECK_OPERAND(0, REG_RSI, OperandSandboxUnrestricted) ||
          CHECK_OPERAND(1, REG_RSI, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_RSI, OperandSandboxUnrestricted)) {
        restricted_register = kNoRestrictedReg;
      }
    }
    if (restricted_register == kSandboxedRsi) {
      if (CHECK_OPERAND(0, REG_RDI, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_RDI, OperandSandboxRestricted)) {
        sandboxed_rsi_restricted_rdi = begin;
        restricted_register = kSandboxedRsiRestrictedRdi;
      }
    }
    if (restricted_register != kSandboxedRsiRestrictedRdi) {
      restricted_register = kNoRestrictedReg;
      if (CHECK_OPERAND(0, REG_R15, OperandSandbox8bit) ||
          CHECK_OPERAND(0, REG_R15, OperandSandboxRestricted) ||
          CHECK_OPERAND(0, REG_R15, OperandSandboxUnrestricted) ||
          CHECK_OPERAND(1, REG_R15, OperandSandbox8bit) ||
          CHECK_OPERAND(1, REG_R15, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_R15, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%r15\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((CHECK_OPERAND(0, REG_RBP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(0, REG_RBP, OperandSandboxUnrestricted) ||
                 (CHECK_OPERAND(1, REG_RBP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(1, REG_RBP, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%rbp\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((CHECK_OPERAND(0, REG_RSP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(0, REG_RSP, OperandSandboxUnrestricted) ||
                 (CHECK_OPERAND(1, REG_RSP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(1, REG_RSP, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%rsp\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((operand_states & 0x70) == (OperandSandboxRestricted << 5)) {
        restricted_register = operand_states & 0x0f;
      } else if ((operand_states & 0x7000) ==
                                        (OperandSandboxRestricted << (5 + 8))) {
        restricted_register = (operand_states & 0x0f00) >> 8;
      }
    }
  }
#line 337 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
       /* On successful match the instruction start must point to the next byte
        * to be able to report the new offset as the start of instruction
        * causing error.  */
       begin = p + 1;
     }
	goto st734;
st734:
	if ( ++p == pe )
		goto _test_eof734;
case 734:
#line 35391 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 0u: goto tr978;
		case 1u: goto tr979;
		case 2u: goto tr980;
		case 3u: goto tr981;
		case 4u: goto tr982;
		case 5u: goto tr983;
		case 8u: goto tr978;
		case 9u: goto tr979;
		case 10u: goto tr980;
		case 11u: goto tr981;
		case 12u: goto tr982;
		case 13u: goto tr983;
		case 15u: goto tr984;
		case 16u: goto tr978;
		case 17u: goto tr979;
		case 18u: goto tr980;
		case 19u: goto tr981;
		case 20u: goto tr982;
		case 21u: goto tr983;
		case 24u: goto tr978;
		case 25u: goto tr979;
		case 26u: goto tr980;
		case 27u: goto tr981;
		case 28u: goto tr982;
		case 29u: goto tr983;
		case 32u: goto tr978;
		case 33u: goto tr979;
		case 34u: goto tr980;
		case 35u: goto tr981;
		case 36u: goto tr982;
		case 37u: goto tr983;
		case 40u: goto tr978;
		case 41u: goto tr979;
		case 42u: goto tr980;
		case 43u: goto tr981;
		case 44u: goto tr982;
		case 45u: goto tr983;
		case 46u: goto tr985;
		case 48u: goto tr978;
		case 49u: goto tr979;
		case 50u: goto tr980;
		case 51u: goto tr981;
		case 52u: goto tr982;
		case 53u: goto tr983;
		case 60u: goto tr987;
		case 61u: goto tr988;
		case 62u: goto tr989;
		case 65u: goto tr991;
		case 72u: goto tr992;
		case 73u: goto tr993;
		case 74u: goto tr994;
		case 76u: goto tr1054;
		case 99u: goto tr981;
		case 102u: goto tr999;
		case 104u: goto tr988;
		case 105u: goto tr1000;
		case 106u: goto tr987;
		case 107u: goto tr1001;
		case 128u: goto tr1003;
		case 129u: goto tr1004;
		case 131u: goto tr1005;
		case 133u: goto tr979;
		case 134u: goto tr1006;
		case 135u: goto tr1007;
		case 137u: goto tr979;
		case 138u: goto tr980;
		case 139u: goto tr981;
		case 141u: goto tr1008;
		case 143u: goto tr1009;
		case 144u: goto tr1010;
		case 155u: goto tr1010;
		case 168u: goto tr982;
		case 169u: goto tr983;
		case 192u: goto tr1017;
		case 193u: goto tr1018;
		case 196u: goto tr1019;
		case 197u: goto tr1020;
		case 198u: goto tr1021;
		case 199u: goto tr1022;
		case 200u: goto tr1023;
		case 202u: goto tr1024;
		case 203u: goto tr1010;
		case 209u: goto tr1026;
		case 211u: goto tr1026;
		case 216u: goto tr986;
		case 217u: goto tr1027;
		case 218u: goto tr1028;
		case 219u: goto tr1029;
		case 220u: goto tr1030;
		case 221u: goto tr1031;
		case 222u: goto tr1032;
		case 223u: goto tr1033;
		case 235u: goto tr1002;
		case 240u: goto tr1035;
		case 242u: goto tr1036;
		case 243u: goto tr1037;
		case 246u: goto tr1038;
		case 247u: goto tr1039;
		case 254u: goto tr1040;
		case 255u: goto tr1041;
	}
	if ( (*p) < 164u ) {
		if ( (*p) < 88u ) {
			if ( (*p) < 64u ) {
				if ( 56u <= (*p) && (*p) <= 59u )
					goto tr986;
			} else if ( (*p) > 71u ) {
				if ( (*p) > 79u ) {
					if ( 80u <= (*p) && (*p) <= 87u )
						goto tr997;
				} else if ( (*p) >= 75u )
					goto tr995;
			} else
				goto tr990;
		} else if ( (*p) > 95u ) {
			if ( (*p) < 132u ) {
				if ( 112u <= (*p) && (*p) <= 127u )
					goto tr1002;
			} else if ( (*p) > 136u ) {
				if ( (*p) > 151u ) {
					if ( 152u <= (*p) && (*p) <= 153u )
						goto tr1010;
				} else if ( (*p) >= 145u )
					goto tr1011;
			} else
				goto tr978;
		} else
			goto tr998;
	} else if ( (*p) > 167u ) {
		if ( (*p) < 184u ) {
			if ( (*p) < 172u ) {
				if ( 170u <= (*p) && (*p) <= 171u )
					goto tr1013;
			} else if ( (*p) > 173u ) {
				if ( (*p) > 175u ) {
					if ( 176u <= (*p) && (*p) <= 183u )
						goto tr1015;
				} else if ( (*p) >= 174u )
					goto tr1013;
			} else
				goto tr1014;
		} else if ( (*p) > 191u ) {
			if ( (*p) < 232u ) {
				if ( 208u <= (*p) && (*p) <= 210u )
					goto tr1025;
			} else if ( (*p) > 233u ) {
				if ( (*p) > 249u ) {
					if ( 252u <= (*p) && (*p) <= 253u )
						goto tr1010;
				} else if ( (*p) >= 244u )
					goto tr1010;
			} else
				goto tr1034;
		} else
			goto tr1016;
	} else
		goto tr1012;
	goto tr33;
tr1054:
#line 329 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
        begin = p;
        BitmapSetBit(valid_targets, p - data);
        SET_REX_PREFIX(FALSE);
        SET_VEX_PREFIX2(0xe0);
        SET_VEX_PREFIX3(0x00);
        operand_states = 0;
     }
#line 190 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_REX_PREFIX(*p);
  }
	goto st680;
st680:
	if ( ++p == pe )
		goto _test_eof680;
case 680:
#line 35570 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 1u: goto tr946;
		case 3u: goto tr221;
		case 9u: goto tr220;
		case 11u: goto tr221;
		case 15u: goto st142;
		case 17u: goto tr220;
		case 19u: goto tr221;
		case 25u: goto tr220;
		case 27u: goto tr221;
		case 33u: goto tr220;
		case 35u: goto tr221;
		case 41u: goto tr220;
		case 43u: goto tr221;
		case 49u: goto tr220;
		case 51u: goto tr221;
		case 57u: goto st38;
		case 59u: goto st38;
		case 99u: goto tr221;
		case 105u: goto tr224;
		case 107u: goto tr225;
		case 129u: goto st144;
		case 131u: goto st145;
		case 133u: goto tr220;
		case 135u: goto tr228;
		case 137u: goto tr220;
		case 139u: goto tr221;
		case 141u: goto tr230;
		case 193u: goto st150;
		case 199u: goto st151;
		case 209u: goto st152;
		case 211u: goto st152;
		case 247u: goto st153;
		case 255u: goto st154;
	}
	if ( (*p) > 151u ) {
		if ( 184u <= (*p) && (*p) <= 191u )
			goto tr235;
	} else if ( (*p) >= 145u )
		goto tr231;
	goto tr33;
tr946:
#line 298 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(0, OperandSize64bit);
  }
	goto st681;
st681:
	if ( ++p == pe )
		goto _test_eof681;
case 681:
#line 35622 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 4u: goto st2;
		case 5u: goto tr2;
		case 12u: goto st2;
		case 13u: goto tr2;
		case 20u: goto st2;
		case 21u: goto tr2;
		case 28u: goto st2;
		case 29u: goto tr2;
		case 36u: goto st2;
		case 37u: goto tr2;
		case 44u: goto st2;
		case 45u: goto tr2;
		case 52u: goto st2;
		case 53u: goto tr2;
		case 60u: goto st2;
		case 61u: goto tr2;
		case 68u: goto st8;
		case 76u: goto st8;
		case 84u: goto st8;
		case 92u: goto st8;
		case 100u: goto st8;
		case 108u: goto st8;
		case 116u: goto st8;
		case 124u: goto st8;
		case 132u: goto st9;
		case 140u: goto st9;
		case 148u: goto st9;
		case 156u: goto st9;
		case 164u: goto st9;
		case 172u: goto st9;
		case 180u: goto st9;
		case 188u: goto st9;
		case 252u: goto tr286;
		case 253u: goto tr947;
	}
	if ( (*p) < 64u ) {
		if ( (*p) <= 63u )
			goto tr0;
	} else if ( (*p) > 127u ) {
		if ( 128u <= (*p) && (*p) <= 191u )
			goto tr5;
	} else
		goto tr3;
	goto tr7;
tr947:
#line 203 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{ if (restricted_register != REG_RBP) {
         PrintError("Incorrectly sandboxed %%rbp\n", begin - data);
         result = 1;
         goto error_detected;
       }
       restricted_register = kNoRestrictedReg;
       BitmapClearBit(valid_targets, (begin - data));
    }
#line 337 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
       /* On successful match the instruction start must point to the next byte
        * to be able to report the new offset as the start of instruction
        * causing error.  */
       begin = p + 1;
     }
	goto st735;
st735:
	if ( ++p == pe )
		goto _test_eof735;
case 735:
#line 35690 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 0u: goto tr978;
		case 1u: goto tr979;
		case 2u: goto tr980;
		case 3u: goto tr981;
		case 4u: goto tr982;
		case 5u: goto tr983;
		case 8u: goto tr978;
		case 9u: goto tr979;
		case 10u: goto tr980;
		case 11u: goto tr981;
		case 12u: goto tr982;
		case 13u: goto tr983;
		case 15u: goto tr984;
		case 16u: goto tr978;
		case 17u: goto tr979;
		case 18u: goto tr980;
		case 19u: goto tr981;
		case 20u: goto tr982;
		case 21u: goto tr983;
		case 24u: goto tr978;
		case 25u: goto tr979;
		case 26u: goto tr980;
		case 27u: goto tr981;
		case 28u: goto tr982;
		case 29u: goto tr983;
		case 32u: goto tr978;
		case 33u: goto tr979;
		case 34u: goto tr980;
		case 35u: goto tr981;
		case 36u: goto tr982;
		case 37u: goto tr983;
		case 40u: goto tr978;
		case 41u: goto tr979;
		case 42u: goto tr980;
		case 43u: goto tr981;
		case 44u: goto tr982;
		case 45u: goto tr983;
		case 46u: goto tr985;
		case 48u: goto tr978;
		case 49u: goto tr979;
		case 50u: goto tr980;
		case 51u: goto tr981;
		case 52u: goto tr982;
		case 53u: goto tr983;
		case 60u: goto tr987;
		case 61u: goto tr988;
		case 62u: goto tr989;
		case 65u: goto tr991;
		case 72u: goto tr992;
		case 73u: goto tr993;
		case 74u: goto tr994;
		case 76u: goto tr996;
		case 99u: goto tr981;
		case 102u: goto tr999;
		case 104u: goto tr988;
		case 105u: goto tr1000;
		case 106u: goto tr987;
		case 107u: goto tr1001;
		case 128u: goto tr1003;
		case 129u: goto tr1004;
		case 131u: goto tr1005;
		case 133u: goto tr979;
		case 134u: goto tr1006;
		case 135u: goto tr1007;
		case 137u: goto tr979;
		case 138u: goto tr980;
		case 139u: goto tr981;
		case 141u: goto tr1008;
		case 143u: goto tr1009;
		case 144u: goto tr1010;
		case 155u: goto tr1010;
		case 168u: goto tr982;
		case 169u: goto tr983;
		case 192u: goto tr1017;
		case 193u: goto tr1018;
		case 196u: goto tr1019;
		case 197u: goto tr1020;
		case 198u: goto tr1021;
		case 199u: goto tr1022;
		case 200u: goto tr1023;
		case 202u: goto tr1024;
		case 203u: goto tr1010;
		case 209u: goto tr1026;
		case 211u: goto tr1026;
		case 216u: goto tr986;
		case 217u: goto tr1027;
		case 218u: goto tr1028;
		case 219u: goto tr1029;
		case 220u: goto tr1030;
		case 221u: goto tr1031;
		case 222u: goto tr1032;
		case 223u: goto tr1033;
		case 235u: goto tr1002;
		case 240u: goto tr1035;
		case 242u: goto tr1036;
		case 243u: goto tr1037;
		case 246u: goto tr1038;
		case 247u: goto tr1039;
		case 254u: goto tr1040;
		case 255u: goto tr1055;
	}
	if ( (*p) < 164u ) {
		if ( (*p) < 88u ) {
			if ( (*p) < 64u ) {
				if ( 56u <= (*p) && (*p) <= 59u )
					goto tr986;
			} else if ( (*p) > 71u ) {
				if ( (*p) > 79u ) {
					if ( 80u <= (*p) && (*p) <= 87u )
						goto tr997;
				} else if ( (*p) >= 75u )
					goto tr995;
			} else
				goto tr990;
		} else if ( (*p) > 95u ) {
			if ( (*p) < 132u ) {
				if ( 112u <= (*p) && (*p) <= 127u )
					goto tr1002;
			} else if ( (*p) > 136u ) {
				if ( (*p) > 151u ) {
					if ( 152u <= (*p) && (*p) <= 153u )
						goto tr1010;
				} else if ( (*p) >= 145u )
					goto tr1011;
			} else
				goto tr978;
		} else
			goto tr998;
	} else if ( (*p) > 167u ) {
		if ( (*p) < 184u ) {
			if ( (*p) < 172u ) {
				if ( 170u <= (*p) && (*p) <= 171u )
					goto tr1013;
			} else if ( (*p) > 173u ) {
				if ( (*p) > 175u ) {
					if ( 176u <= (*p) && (*p) <= 183u )
						goto tr1015;
				} else if ( (*p) >= 174u )
					goto tr1013;
			} else
				goto tr1014;
		} else if ( (*p) > 191u ) {
			if ( (*p) < 232u ) {
				if ( 208u <= (*p) && (*p) <= 210u )
					goto tr1025;
			} else if ( (*p) > 233u ) {
				if ( (*p) > 249u ) {
					if ( 252u <= (*p) && (*p) <= 253u )
						goto tr1010;
				} else if ( (*p) >= 244u )
					goto tr1010;
			} else
				goto tr1034;
		} else
			goto tr1016;
	} else
		goto tr1012;
	goto tr33;
tr1055:
#line 329 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
        begin = p;
        BitmapSetBit(valid_targets, p - data);
        SET_REX_PREFIX(FALSE);
        SET_VEX_PREFIX2(0xe0);
        SET_VEX_PREFIX3(0x00);
        operand_states = 0;
     }
	goto st682;
st682:
	if ( ++p == pe )
		goto _test_eof682;
case 682:
#line 35865 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 4u: goto st2;
		case 5u: goto tr2;
		case 12u: goto st2;
		case 13u: goto tr2;
		case 52u: goto st2;
		case 53u: goto tr2;
		case 68u: goto st8;
		case 76u: goto st8;
		case 116u: goto st8;
		case 132u: goto st9;
		case 140u: goto st9;
		case 180u: goto st9;
		case 213u: goto tr932;
		case 229u: goto tr932;
	}
	if ( (*p) < 112u ) {
		if ( (*p) < 48u ) {
			if ( (*p) <= 15u )
				goto tr0;
		} else if ( (*p) > 55u ) {
			if ( 64u <= (*p) && (*p) <= 79u )
				goto tr3;
		} else
			goto tr0;
	} else if ( (*p) > 119u ) {
		if ( (*p) < 176u ) {
			if ( 128u <= (*p) && (*p) <= 143u )
				goto tr5;
		} else if ( (*p) > 183u ) {
			if ( (*p) > 207u ) {
				if ( 240u <= (*p) && (*p) <= 247u )
					goto tr34;
			} else if ( (*p) >= 192u )
				goto tr56;
		} else
			goto tr5;
	} else
		goto tr3;
	goto tr33;
tr439:
#line 295 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(0, OperandSize32bit);
  }
#line 384 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_NAME(0, ((*p) & 0x07) |
                           ((GET_REX_PREFIX() & 0x01) << 3) |
                           (((~GET_VEX_PREFIX2()) & 0x20) >> 2));
  }
	goto st683;
st683:
	if ( ++p == pe )
		goto _test_eof683;
case 683:
#line 35922 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	if ( (*p) == 224u )
		goto tr948;
	goto tr25;
tr948:
#line 58 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_IMM_TYPE(IMM8);
    SET_IMM_PTR(p);
  }
#line 93 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    /* Restricted %rsp or %rbp must be processed by appropriate nacl-special
       instruction, not with regular instruction.  */
    if (restricted_register == REG_RSP) {
      PrintError("Incorrectly modified register %%rsp\n", begin - data);
      result = 1;
      goto error_detected;
    } else if (restricted_register == REG_RBP) {
      PrintError("Incorrectly modified register %%rbp\n", begin - data);
      result = 1;
      goto error_detected;
    }
    /* If Sandboxed Rsi is destroyed then we must note that.  */
    if (restricted_register == kSandboxedRsi) {
      if (CHECK_OPERAND(0, REG_RSI, OperandSandboxRestricted) ||
          CHECK_OPERAND(0, REG_RSI, OperandSandboxUnrestricted) ||
          CHECK_OPERAND(1, REG_RSI, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_RSI, OperandSandboxUnrestricted)) {
        restricted_register = kNoRestrictedReg;
      }
    }
    if (restricted_register == kSandboxedRsi) {
      if (CHECK_OPERAND(0, REG_RDI, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_RDI, OperandSandboxRestricted)) {
        sandboxed_rsi_restricted_rdi = begin;
        restricted_register = kSandboxedRsiRestrictedRdi;
      }
    }
    if (restricted_register != kSandboxedRsiRestrictedRdi) {
      restricted_register = kNoRestrictedReg;
      if (CHECK_OPERAND(0, REG_R15, OperandSandbox8bit) ||
          CHECK_OPERAND(0, REG_R15, OperandSandboxRestricted) ||
          CHECK_OPERAND(0, REG_R15, OperandSandboxUnrestricted) ||
          CHECK_OPERAND(1, REG_R15, OperandSandbox8bit) ||
          CHECK_OPERAND(1, REG_R15, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_R15, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%r15\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((CHECK_OPERAND(0, REG_RBP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(0, REG_RBP, OperandSandboxUnrestricted) ||
                 (CHECK_OPERAND(1, REG_RBP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(1, REG_RBP, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%rbp\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((CHECK_OPERAND(0, REG_RSP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(0, REG_RSP, OperandSandboxUnrestricted) ||
                 (CHECK_OPERAND(1, REG_RSP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(1, REG_RSP, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%rsp\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((operand_states & 0x70) == (OperandSandboxRestricted << 5)) {
        restricted_register = operand_states & 0x0f;
      } else if ((operand_states & 0x7000) ==
                                        (OperandSandboxRestricted << (5 + 8))) {
        restricted_register = (operand_states & 0x0f00) >> 8;
      }
    }
  }
#line 337 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
       /* On successful match the instruction start must point to the next byte
        * to be able to report the new offset as the start of instruction
        * causing error.  */
       begin = p + 1;
     }
	goto st736;
st736:
	if ( ++p == pe )
		goto _test_eof736;
case 736:
#line 36010 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 0u: goto tr978;
		case 1u: goto tr979;
		case 2u: goto tr980;
		case 3u: goto tr981;
		case 4u: goto tr982;
		case 5u: goto tr983;
		case 8u: goto tr978;
		case 9u: goto tr979;
		case 10u: goto tr980;
		case 11u: goto tr981;
		case 12u: goto tr982;
		case 13u: goto tr983;
		case 15u: goto tr984;
		case 16u: goto tr978;
		case 17u: goto tr979;
		case 18u: goto tr980;
		case 19u: goto tr981;
		case 20u: goto tr982;
		case 21u: goto tr983;
		case 24u: goto tr978;
		case 25u: goto tr979;
		case 26u: goto tr980;
		case 27u: goto tr981;
		case 28u: goto tr982;
		case 29u: goto tr983;
		case 32u: goto tr978;
		case 33u: goto tr979;
		case 34u: goto tr980;
		case 35u: goto tr981;
		case 36u: goto tr982;
		case 37u: goto tr983;
		case 40u: goto tr978;
		case 41u: goto tr979;
		case 42u: goto tr980;
		case 43u: goto tr981;
		case 44u: goto tr982;
		case 45u: goto tr983;
		case 46u: goto tr985;
		case 48u: goto tr978;
		case 49u: goto tr979;
		case 50u: goto tr980;
		case 51u: goto tr981;
		case 52u: goto tr982;
		case 53u: goto tr983;
		case 60u: goto tr987;
		case 61u: goto tr988;
		case 62u: goto tr989;
		case 65u: goto tr991;
		case 72u: goto tr992;
		case 73u: goto tr993;
		case 74u: goto tr994;
		case 76u: goto tr1056;
		case 99u: goto tr981;
		case 102u: goto tr999;
		case 104u: goto tr988;
		case 105u: goto tr1000;
		case 106u: goto tr987;
		case 107u: goto tr1001;
		case 128u: goto tr1003;
		case 129u: goto tr1004;
		case 131u: goto tr1005;
		case 133u: goto tr979;
		case 134u: goto tr1006;
		case 135u: goto tr1007;
		case 137u: goto tr979;
		case 138u: goto tr980;
		case 139u: goto tr981;
		case 141u: goto tr1008;
		case 143u: goto tr1009;
		case 144u: goto tr1010;
		case 155u: goto tr1010;
		case 168u: goto tr982;
		case 169u: goto tr983;
		case 192u: goto tr1017;
		case 193u: goto tr1018;
		case 196u: goto tr1019;
		case 197u: goto tr1020;
		case 198u: goto tr1021;
		case 199u: goto tr1022;
		case 200u: goto tr1023;
		case 202u: goto tr1024;
		case 203u: goto tr1010;
		case 209u: goto tr1026;
		case 211u: goto tr1026;
		case 216u: goto tr986;
		case 217u: goto tr1027;
		case 218u: goto tr1028;
		case 219u: goto tr1029;
		case 220u: goto tr1030;
		case 221u: goto tr1031;
		case 222u: goto tr1032;
		case 223u: goto tr1033;
		case 235u: goto tr1002;
		case 240u: goto tr1035;
		case 242u: goto tr1036;
		case 243u: goto tr1037;
		case 246u: goto tr1038;
		case 247u: goto tr1039;
		case 254u: goto tr1040;
		case 255u: goto tr1041;
	}
	if ( (*p) < 164u ) {
		if ( (*p) < 88u ) {
			if ( (*p) < 64u ) {
				if ( 56u <= (*p) && (*p) <= 59u )
					goto tr986;
			} else if ( (*p) > 71u ) {
				if ( (*p) > 79u ) {
					if ( 80u <= (*p) && (*p) <= 87u )
						goto tr997;
				} else if ( (*p) >= 75u )
					goto tr995;
			} else
				goto tr990;
		} else if ( (*p) > 95u ) {
			if ( (*p) < 132u ) {
				if ( 112u <= (*p) && (*p) <= 127u )
					goto tr1002;
			} else if ( (*p) > 136u ) {
				if ( (*p) > 151u ) {
					if ( 152u <= (*p) && (*p) <= 153u )
						goto tr1010;
				} else if ( (*p) >= 145u )
					goto tr1011;
			} else
				goto tr978;
		} else
			goto tr998;
	} else if ( (*p) > 167u ) {
		if ( (*p) < 184u ) {
			if ( (*p) < 172u ) {
				if ( 170u <= (*p) && (*p) <= 171u )
					goto tr1013;
			} else if ( (*p) > 173u ) {
				if ( (*p) > 175u ) {
					if ( 176u <= (*p) && (*p) <= 183u )
						goto tr1015;
				} else if ( (*p) >= 174u )
					goto tr1013;
			} else
				goto tr1014;
		} else if ( (*p) > 191u ) {
			if ( (*p) < 232u ) {
				if ( 208u <= (*p) && (*p) <= 210u )
					goto tr1025;
			} else if ( (*p) > 233u ) {
				if ( (*p) > 249u ) {
					if ( 252u <= (*p) && (*p) <= 253u )
						goto tr1010;
				} else if ( (*p) >= 244u )
					goto tr1010;
			} else
				goto tr1034;
		} else
			goto tr1016;
	} else
		goto tr1012;
	goto tr33;
tr1056:
#line 329 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
        begin = p;
        BitmapSetBit(valid_targets, p - data);
        SET_REX_PREFIX(FALSE);
        SET_VEX_PREFIX2(0xe0);
        SET_VEX_PREFIX3(0x00);
        operand_states = 0;
     }
#line 190 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_REX_PREFIX(*p);
  }
	goto st684;
st684:
	if ( ++p == pe )
		goto _test_eof684;
case 684:
#line 36189 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 1u: goto tr949;
		case 3u: goto tr221;
		case 9u: goto tr220;
		case 11u: goto tr221;
		case 15u: goto st142;
		case 17u: goto tr220;
		case 19u: goto tr221;
		case 25u: goto tr220;
		case 27u: goto tr221;
		case 33u: goto tr220;
		case 35u: goto tr221;
		case 41u: goto tr220;
		case 43u: goto tr221;
		case 49u: goto tr220;
		case 51u: goto tr221;
		case 57u: goto st38;
		case 59u: goto st38;
		case 99u: goto tr221;
		case 105u: goto tr224;
		case 107u: goto tr225;
		case 129u: goto st144;
		case 131u: goto st145;
		case 133u: goto tr220;
		case 135u: goto tr228;
		case 137u: goto tr220;
		case 139u: goto tr221;
		case 141u: goto tr230;
		case 193u: goto st150;
		case 199u: goto st151;
		case 209u: goto st152;
		case 211u: goto st152;
		case 247u: goto st153;
		case 255u: goto st154;
	}
	if ( (*p) > 151u ) {
		if ( 184u <= (*p) && (*p) <= 191u )
			goto tr235;
	} else if ( (*p) >= 145u )
		goto tr231;
	goto tr33;
tr949:
#line 298 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(0, OperandSize64bit);
  }
	goto st685;
st685:
	if ( ++p == pe )
		goto _test_eof685;
case 685:
#line 36241 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 4u: goto st2;
		case 5u: goto tr2;
		case 12u: goto st2;
		case 13u: goto tr2;
		case 20u: goto st2;
		case 21u: goto tr2;
		case 28u: goto st2;
		case 29u: goto tr2;
		case 36u: goto st2;
		case 37u: goto tr2;
		case 44u: goto st2;
		case 45u: goto tr2;
		case 52u: goto st2;
		case 53u: goto tr2;
		case 60u: goto st2;
		case 61u: goto tr2;
		case 68u: goto st8;
		case 76u: goto st8;
		case 84u: goto st8;
		case 92u: goto st8;
		case 100u: goto st8;
		case 108u: goto st8;
		case 116u: goto st8;
		case 124u: goto st8;
		case 132u: goto st9;
		case 140u: goto st9;
		case 148u: goto st9;
		case 156u: goto st9;
		case 164u: goto st9;
		case 172u: goto st9;
		case 180u: goto st9;
		case 188u: goto st9;
		case 252u: goto tr286;
		case 253u: goto tr280;
		case 254u: goto tr950;
	}
	if ( (*p) < 64u ) {
		if ( (*p) <= 63u )
			goto tr0;
	} else if ( (*p) > 127u ) {
		if ( 128u <= (*p) && (*p) <= 191u )
			goto tr5;
	} else
		goto tr3;
	goto tr7;
tr950:
#line 384 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_NAME(0, ((*p) & 0x07) |
                           ((GET_REX_PREFIX() & 0x01) << 3) |
                           (((~GET_VEX_PREFIX2()) & 0x20) >> 2));
  }
#line 93 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    /* Restricted %rsp or %rbp must be processed by appropriate nacl-special
       instruction, not with regular instruction.  */
    if (restricted_register == REG_RSP) {
      PrintError("Incorrectly modified register %%rsp\n", begin - data);
      result = 1;
      goto error_detected;
    } else if (restricted_register == REG_RBP) {
      PrintError("Incorrectly modified register %%rbp\n", begin - data);
      result = 1;
      goto error_detected;
    }
    /* If Sandboxed Rsi is destroyed then we must note that.  */
    if (restricted_register == kSandboxedRsi) {
      if (CHECK_OPERAND(0, REG_RSI, OperandSandboxRestricted) ||
          CHECK_OPERAND(0, REG_RSI, OperandSandboxUnrestricted) ||
          CHECK_OPERAND(1, REG_RSI, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_RSI, OperandSandboxUnrestricted)) {
        restricted_register = kNoRestrictedReg;
      }
    }
    if (restricted_register == kSandboxedRsi) {
      if (CHECK_OPERAND(0, REG_RDI, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_RDI, OperandSandboxRestricted)) {
        sandboxed_rsi_restricted_rdi = begin;
        restricted_register = kSandboxedRsiRestrictedRdi;
      }
    }
    if (restricted_register != kSandboxedRsiRestrictedRdi) {
      restricted_register = kNoRestrictedReg;
      if (CHECK_OPERAND(0, REG_R15, OperandSandbox8bit) ||
          CHECK_OPERAND(0, REG_R15, OperandSandboxRestricted) ||
          CHECK_OPERAND(0, REG_R15, OperandSandboxUnrestricted) ||
          CHECK_OPERAND(1, REG_R15, OperandSandbox8bit) ||
          CHECK_OPERAND(1, REG_R15, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_R15, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%r15\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((CHECK_OPERAND(0, REG_RBP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(0, REG_RBP, OperandSandboxUnrestricted) ||
                 (CHECK_OPERAND(1, REG_RBP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(1, REG_RBP, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%rbp\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((CHECK_OPERAND(0, REG_RSP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(0, REG_RSP, OperandSandboxUnrestricted) ||
                 (CHECK_OPERAND(1, REG_RSP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(1, REG_RSP, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%rsp\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((operand_states & 0x70) == (OperandSandboxRestricted << 5)) {
        restricted_register = operand_states & 0x0f;
      } else if ((operand_states & 0x7000) ==
                                        (OperandSandboxRestricted << (5 + 8))) {
        restricted_register = (operand_states & 0x0f00) >> 8;
      }
    }
  }
#line 337 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
       /* On successful match the instruction start must point to the next byte
        * to be able to report the new offset as the start of instruction
        * causing error.  */
       begin = p + 1;
     }
	goto st737;
st737:
	if ( ++p == pe )
		goto _test_eof737;
case 737:
#line 36373 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 0u: goto tr978;
		case 1u: goto tr979;
		case 2u: goto tr980;
		case 3u: goto tr981;
		case 4u: goto tr982;
		case 5u: goto tr983;
		case 8u: goto tr978;
		case 9u: goto tr979;
		case 10u: goto tr980;
		case 11u: goto tr981;
		case 12u: goto tr982;
		case 13u: goto tr983;
		case 15u: goto tr984;
		case 16u: goto tr978;
		case 17u: goto tr979;
		case 18u: goto tr980;
		case 19u: goto tr981;
		case 20u: goto tr982;
		case 21u: goto tr983;
		case 24u: goto tr978;
		case 25u: goto tr979;
		case 26u: goto tr980;
		case 27u: goto tr981;
		case 28u: goto tr982;
		case 29u: goto tr983;
		case 32u: goto tr978;
		case 33u: goto tr979;
		case 34u: goto tr980;
		case 35u: goto tr981;
		case 36u: goto tr982;
		case 37u: goto tr983;
		case 40u: goto tr978;
		case 41u: goto tr979;
		case 42u: goto tr980;
		case 43u: goto tr981;
		case 44u: goto tr982;
		case 45u: goto tr983;
		case 46u: goto tr985;
		case 48u: goto tr978;
		case 49u: goto tr979;
		case 50u: goto tr980;
		case 51u: goto tr981;
		case 52u: goto tr982;
		case 53u: goto tr983;
		case 60u: goto tr987;
		case 61u: goto tr988;
		case 62u: goto tr989;
		case 65u: goto tr991;
		case 72u: goto tr992;
		case 73u: goto tr993;
		case 74u: goto tr994;
		case 76u: goto tr996;
		case 99u: goto tr981;
		case 102u: goto tr999;
		case 104u: goto tr988;
		case 105u: goto tr1000;
		case 106u: goto tr987;
		case 107u: goto tr1001;
		case 128u: goto tr1003;
		case 129u: goto tr1004;
		case 131u: goto tr1005;
		case 133u: goto tr979;
		case 134u: goto tr1006;
		case 135u: goto tr1007;
		case 137u: goto tr979;
		case 138u: goto tr980;
		case 139u: goto tr981;
		case 141u: goto tr1008;
		case 143u: goto tr1009;
		case 144u: goto tr1010;
		case 155u: goto tr1010;
		case 168u: goto tr982;
		case 169u: goto tr983;
		case 192u: goto tr1017;
		case 193u: goto tr1018;
		case 196u: goto tr1019;
		case 197u: goto tr1020;
		case 198u: goto tr1021;
		case 199u: goto tr1022;
		case 200u: goto tr1023;
		case 202u: goto tr1024;
		case 203u: goto tr1010;
		case 209u: goto tr1026;
		case 211u: goto tr1026;
		case 216u: goto tr986;
		case 217u: goto tr1027;
		case 218u: goto tr1028;
		case 219u: goto tr1029;
		case 220u: goto tr1030;
		case 221u: goto tr1031;
		case 222u: goto tr1032;
		case 223u: goto tr1033;
		case 235u: goto tr1002;
		case 240u: goto tr1035;
		case 242u: goto tr1036;
		case 243u: goto tr1037;
		case 246u: goto tr1038;
		case 247u: goto tr1039;
		case 254u: goto tr1040;
		case 255u: goto tr1057;
	}
	if ( (*p) < 164u ) {
		if ( (*p) < 88u ) {
			if ( (*p) < 64u ) {
				if ( 56u <= (*p) && (*p) <= 59u )
					goto tr986;
			} else if ( (*p) > 71u ) {
				if ( (*p) > 79u ) {
					if ( 80u <= (*p) && (*p) <= 87u )
						goto tr997;
				} else if ( (*p) >= 75u )
					goto tr995;
			} else
				goto tr990;
		} else if ( (*p) > 95u ) {
			if ( (*p) < 132u ) {
				if ( 112u <= (*p) && (*p) <= 127u )
					goto tr1002;
			} else if ( (*p) > 136u ) {
				if ( (*p) > 151u ) {
					if ( 152u <= (*p) && (*p) <= 153u )
						goto tr1010;
				} else if ( (*p) >= 145u )
					goto tr1011;
			} else
				goto tr978;
		} else
			goto tr998;
	} else if ( (*p) > 167u ) {
		if ( (*p) < 184u ) {
			if ( (*p) < 172u ) {
				if ( 170u <= (*p) && (*p) <= 171u )
					goto tr1013;
			} else if ( (*p) > 173u ) {
				if ( (*p) > 175u ) {
					if ( 176u <= (*p) && (*p) <= 183u )
						goto tr1015;
				} else if ( (*p) >= 174u )
					goto tr1013;
			} else
				goto tr1014;
		} else if ( (*p) > 191u ) {
			if ( (*p) < 232u ) {
				if ( 208u <= (*p) && (*p) <= 210u )
					goto tr1025;
			} else if ( (*p) > 233u ) {
				if ( (*p) > 249u ) {
					if ( 252u <= (*p) && (*p) <= 253u )
						goto tr1010;
				} else if ( (*p) >= 244u )
					goto tr1010;
			} else
				goto tr1034;
		} else
			goto tr1016;
	} else
		goto tr1012;
	goto tr33;
tr1057:
#line 329 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
        begin = p;
        BitmapSetBit(valid_targets, p - data);
        SET_REX_PREFIX(FALSE);
        SET_VEX_PREFIX2(0xe0);
        SET_VEX_PREFIX3(0x00);
        operand_states = 0;
     }
	goto st686;
st686:
	if ( ++p == pe )
		goto _test_eof686;
case 686:
#line 36548 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 4u: goto st2;
		case 5u: goto tr2;
		case 12u: goto st2;
		case 13u: goto tr2;
		case 52u: goto st2;
		case 53u: goto tr2;
		case 68u: goto st8;
		case 76u: goto st8;
		case 116u: goto st8;
		case 132u: goto st9;
		case 140u: goto st9;
		case 180u: goto st9;
		case 214u: goto tr932;
		case 230u: goto tr932;
	}
	if ( (*p) < 112u ) {
		if ( (*p) < 48u ) {
			if ( (*p) <= 15u )
				goto tr0;
		} else if ( (*p) > 55u ) {
			if ( 64u <= (*p) && (*p) <= 79u )
				goto tr3;
		} else
			goto tr0;
	} else if ( (*p) > 119u ) {
		if ( (*p) < 176u ) {
			if ( 128u <= (*p) && (*p) <= 143u )
				goto tr5;
		} else if ( (*p) > 183u ) {
			if ( (*p) > 207u ) {
				if ( 240u <= (*p) && (*p) <= 247u )
					goto tr34;
			} else if ( (*p) >= 192u )
				goto tr56;
		} else
			goto tr5;
	} else
		goto tr3;
	goto tr33;
tr440:
#line 295 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(0, OperandSize32bit);
  }
#line 384 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_NAME(0, ((*p) & 0x07) |
                           ((GET_REX_PREFIX() & 0x01) << 3) |
                           (((~GET_VEX_PREFIX2()) & 0x20) >> 2));
  }
	goto st687;
st687:
	if ( ++p == pe )
		goto _test_eof687;
case 687:
#line 36605 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	if ( (*p) == 224u )
		goto tr951;
	goto tr25;
tr951:
#line 58 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_IMM_TYPE(IMM8);
    SET_IMM_PTR(p);
  }
#line 93 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    /* Restricted %rsp or %rbp must be processed by appropriate nacl-special
       instruction, not with regular instruction.  */
    if (restricted_register == REG_RSP) {
      PrintError("Incorrectly modified register %%rsp\n", begin - data);
      result = 1;
      goto error_detected;
    } else if (restricted_register == REG_RBP) {
      PrintError("Incorrectly modified register %%rbp\n", begin - data);
      result = 1;
      goto error_detected;
    }
    /* If Sandboxed Rsi is destroyed then we must note that.  */
    if (restricted_register == kSandboxedRsi) {
      if (CHECK_OPERAND(0, REG_RSI, OperandSandboxRestricted) ||
          CHECK_OPERAND(0, REG_RSI, OperandSandboxUnrestricted) ||
          CHECK_OPERAND(1, REG_RSI, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_RSI, OperandSandboxUnrestricted)) {
        restricted_register = kNoRestrictedReg;
      }
    }
    if (restricted_register == kSandboxedRsi) {
      if (CHECK_OPERAND(0, REG_RDI, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_RDI, OperandSandboxRestricted)) {
        sandboxed_rsi_restricted_rdi = begin;
        restricted_register = kSandboxedRsiRestrictedRdi;
      }
    }
    if (restricted_register != kSandboxedRsiRestrictedRdi) {
      restricted_register = kNoRestrictedReg;
      if (CHECK_OPERAND(0, REG_R15, OperandSandbox8bit) ||
          CHECK_OPERAND(0, REG_R15, OperandSandboxRestricted) ||
          CHECK_OPERAND(0, REG_R15, OperandSandboxUnrestricted) ||
          CHECK_OPERAND(1, REG_R15, OperandSandbox8bit) ||
          CHECK_OPERAND(1, REG_R15, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_R15, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%r15\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((CHECK_OPERAND(0, REG_RBP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(0, REG_RBP, OperandSandboxUnrestricted) ||
                 (CHECK_OPERAND(1, REG_RBP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(1, REG_RBP, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%rbp\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((CHECK_OPERAND(0, REG_RSP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(0, REG_RSP, OperandSandboxUnrestricted) ||
                 (CHECK_OPERAND(1, REG_RSP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(1, REG_RSP, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%rsp\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((operand_states & 0x70) == (OperandSandboxRestricted << 5)) {
        restricted_register = operand_states & 0x0f;
      } else if ((operand_states & 0x7000) ==
                                        (OperandSandboxRestricted << (5 + 8))) {
        restricted_register = (operand_states & 0x0f00) >> 8;
      }
    }
  }
#line 337 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
       /* On successful match the instruction start must point to the next byte
        * to be able to report the new offset as the start of instruction
        * causing error.  */
       begin = p + 1;
     }
	goto st738;
st738:
	if ( ++p == pe )
		goto _test_eof738;
case 738:
#line 36693 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 0u: goto tr978;
		case 1u: goto tr979;
		case 2u: goto tr980;
		case 3u: goto tr981;
		case 4u: goto tr982;
		case 5u: goto tr983;
		case 8u: goto tr978;
		case 9u: goto tr979;
		case 10u: goto tr980;
		case 11u: goto tr981;
		case 12u: goto tr982;
		case 13u: goto tr983;
		case 15u: goto tr984;
		case 16u: goto tr978;
		case 17u: goto tr979;
		case 18u: goto tr980;
		case 19u: goto tr981;
		case 20u: goto tr982;
		case 21u: goto tr983;
		case 24u: goto tr978;
		case 25u: goto tr979;
		case 26u: goto tr980;
		case 27u: goto tr981;
		case 28u: goto tr982;
		case 29u: goto tr983;
		case 32u: goto tr978;
		case 33u: goto tr979;
		case 34u: goto tr980;
		case 35u: goto tr981;
		case 36u: goto tr982;
		case 37u: goto tr983;
		case 40u: goto tr978;
		case 41u: goto tr979;
		case 42u: goto tr980;
		case 43u: goto tr981;
		case 44u: goto tr982;
		case 45u: goto tr983;
		case 46u: goto tr985;
		case 48u: goto tr978;
		case 49u: goto tr979;
		case 50u: goto tr980;
		case 51u: goto tr981;
		case 52u: goto tr982;
		case 53u: goto tr983;
		case 60u: goto tr987;
		case 61u: goto tr988;
		case 62u: goto tr989;
		case 65u: goto tr991;
		case 72u: goto tr992;
		case 73u: goto tr993;
		case 74u: goto tr994;
		case 76u: goto tr1058;
		case 99u: goto tr981;
		case 102u: goto tr999;
		case 104u: goto tr988;
		case 105u: goto tr1000;
		case 106u: goto tr987;
		case 107u: goto tr1001;
		case 128u: goto tr1003;
		case 129u: goto tr1004;
		case 131u: goto tr1005;
		case 133u: goto tr979;
		case 134u: goto tr1006;
		case 135u: goto tr1007;
		case 137u: goto tr979;
		case 138u: goto tr980;
		case 139u: goto tr981;
		case 141u: goto tr1008;
		case 143u: goto tr1009;
		case 144u: goto tr1010;
		case 155u: goto tr1010;
		case 168u: goto tr982;
		case 169u: goto tr983;
		case 192u: goto tr1017;
		case 193u: goto tr1018;
		case 196u: goto tr1019;
		case 197u: goto tr1020;
		case 198u: goto tr1021;
		case 199u: goto tr1022;
		case 200u: goto tr1023;
		case 202u: goto tr1024;
		case 203u: goto tr1010;
		case 209u: goto tr1026;
		case 211u: goto tr1026;
		case 216u: goto tr986;
		case 217u: goto tr1027;
		case 218u: goto tr1028;
		case 219u: goto tr1029;
		case 220u: goto tr1030;
		case 221u: goto tr1031;
		case 222u: goto tr1032;
		case 223u: goto tr1033;
		case 235u: goto tr1002;
		case 240u: goto tr1035;
		case 242u: goto tr1036;
		case 243u: goto tr1037;
		case 246u: goto tr1038;
		case 247u: goto tr1039;
		case 254u: goto tr1040;
		case 255u: goto tr1041;
	}
	if ( (*p) < 164u ) {
		if ( (*p) < 88u ) {
			if ( (*p) < 64u ) {
				if ( 56u <= (*p) && (*p) <= 59u )
					goto tr986;
			} else if ( (*p) > 71u ) {
				if ( (*p) > 79u ) {
					if ( 80u <= (*p) && (*p) <= 87u )
						goto tr997;
				} else if ( (*p) >= 75u )
					goto tr995;
			} else
				goto tr990;
		} else if ( (*p) > 95u ) {
			if ( (*p) < 132u ) {
				if ( 112u <= (*p) && (*p) <= 127u )
					goto tr1002;
			} else if ( (*p) > 136u ) {
				if ( (*p) > 151u ) {
					if ( 152u <= (*p) && (*p) <= 153u )
						goto tr1010;
				} else if ( (*p) >= 145u )
					goto tr1011;
			} else
				goto tr978;
		} else
			goto tr998;
	} else if ( (*p) > 167u ) {
		if ( (*p) < 184u ) {
			if ( (*p) < 172u ) {
				if ( 170u <= (*p) && (*p) <= 171u )
					goto tr1013;
			} else if ( (*p) > 173u ) {
				if ( (*p) > 175u ) {
					if ( 176u <= (*p) && (*p) <= 183u )
						goto tr1015;
				} else if ( (*p) >= 174u )
					goto tr1013;
			} else
				goto tr1014;
		} else if ( (*p) > 191u ) {
			if ( (*p) < 232u ) {
				if ( 208u <= (*p) && (*p) <= 210u )
					goto tr1025;
			} else if ( (*p) > 233u ) {
				if ( (*p) > 249u ) {
					if ( 252u <= (*p) && (*p) <= 253u )
						goto tr1010;
				} else if ( (*p) >= 244u )
					goto tr1010;
			} else
				goto tr1034;
		} else
			goto tr1016;
	} else
		goto tr1012;
	goto tr33;
tr1058:
#line 329 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
        begin = p;
        BitmapSetBit(valid_targets, p - data);
        SET_REX_PREFIX(FALSE);
        SET_VEX_PREFIX2(0xe0);
        SET_VEX_PREFIX3(0x00);
        operand_states = 0;
     }
#line 190 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_REX_PREFIX(*p);
  }
	goto st688;
st688:
	if ( ++p == pe )
		goto _test_eof688;
case 688:
#line 36872 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 1u: goto tr952;
		case 3u: goto tr221;
		case 9u: goto tr220;
		case 11u: goto tr221;
		case 15u: goto st142;
		case 17u: goto tr220;
		case 19u: goto tr221;
		case 25u: goto tr220;
		case 27u: goto tr221;
		case 33u: goto tr220;
		case 35u: goto tr221;
		case 41u: goto tr220;
		case 43u: goto tr221;
		case 49u: goto tr220;
		case 51u: goto tr221;
		case 57u: goto st38;
		case 59u: goto st38;
		case 99u: goto tr221;
		case 105u: goto tr224;
		case 107u: goto tr225;
		case 129u: goto st144;
		case 131u: goto st145;
		case 133u: goto tr220;
		case 135u: goto tr228;
		case 137u: goto tr220;
		case 139u: goto tr221;
		case 141u: goto tr230;
		case 193u: goto st150;
		case 199u: goto st151;
		case 209u: goto st152;
		case 211u: goto st152;
		case 247u: goto st153;
		case 255u: goto st154;
	}
	if ( (*p) > 151u ) {
		if ( 184u <= (*p) && (*p) <= 191u )
			goto tr235;
	} else if ( (*p) >= 145u )
		goto tr231;
	goto tr33;
tr952:
#line 298 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(0, OperandSize64bit);
  }
	goto st689;
st689:
	if ( ++p == pe )
		goto _test_eof689;
case 689:
#line 36924 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 4u: goto st2;
		case 5u: goto tr2;
		case 12u: goto st2;
		case 13u: goto tr2;
		case 20u: goto st2;
		case 21u: goto tr2;
		case 28u: goto st2;
		case 29u: goto tr2;
		case 36u: goto st2;
		case 37u: goto tr2;
		case 44u: goto st2;
		case 45u: goto tr2;
		case 52u: goto st2;
		case 53u: goto tr2;
		case 60u: goto st2;
		case 61u: goto tr2;
		case 68u: goto st8;
		case 76u: goto st8;
		case 84u: goto st8;
		case 92u: goto st8;
		case 100u: goto st8;
		case 108u: goto st8;
		case 116u: goto st8;
		case 124u: goto st8;
		case 132u: goto st9;
		case 140u: goto st9;
		case 148u: goto st9;
		case 156u: goto st9;
		case 164u: goto st9;
		case 172u: goto st9;
		case 180u: goto st9;
		case 188u: goto st9;
		case 252u: goto tr286;
		case 253u: goto tr280;
		case 255u: goto tr953;
	}
	if ( (*p) < 64u ) {
		if ( (*p) <= 63u )
			goto tr0;
	} else if ( (*p) > 127u ) {
		if ( 128u <= (*p) && (*p) <= 191u )
			goto tr5;
	} else
		goto tr3;
	goto tr7;
tr953:
#line 384 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_NAME(0, ((*p) & 0x07) |
                           ((GET_REX_PREFIX() & 0x01) << 3) |
                           (((~GET_VEX_PREFIX2()) & 0x20) >> 2));
  }
#line 93 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    /* Restricted %rsp or %rbp must be processed by appropriate nacl-special
       instruction, not with regular instruction.  */
    if (restricted_register == REG_RSP) {
      PrintError("Incorrectly modified register %%rsp\n", begin - data);
      result = 1;
      goto error_detected;
    } else if (restricted_register == REG_RBP) {
      PrintError("Incorrectly modified register %%rbp\n", begin - data);
      result = 1;
      goto error_detected;
    }
    /* If Sandboxed Rsi is destroyed then we must note that.  */
    if (restricted_register == kSandboxedRsi) {
      if (CHECK_OPERAND(0, REG_RSI, OperandSandboxRestricted) ||
          CHECK_OPERAND(0, REG_RSI, OperandSandboxUnrestricted) ||
          CHECK_OPERAND(1, REG_RSI, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_RSI, OperandSandboxUnrestricted)) {
        restricted_register = kNoRestrictedReg;
      }
    }
    if (restricted_register == kSandboxedRsi) {
      if (CHECK_OPERAND(0, REG_RDI, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_RDI, OperandSandboxRestricted)) {
        sandboxed_rsi_restricted_rdi = begin;
        restricted_register = kSandboxedRsiRestrictedRdi;
      }
    }
    if (restricted_register != kSandboxedRsiRestrictedRdi) {
      restricted_register = kNoRestrictedReg;
      if (CHECK_OPERAND(0, REG_R15, OperandSandbox8bit) ||
          CHECK_OPERAND(0, REG_R15, OperandSandboxRestricted) ||
          CHECK_OPERAND(0, REG_R15, OperandSandboxUnrestricted) ||
          CHECK_OPERAND(1, REG_R15, OperandSandbox8bit) ||
          CHECK_OPERAND(1, REG_R15, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_R15, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%r15\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((CHECK_OPERAND(0, REG_RBP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(0, REG_RBP, OperandSandboxUnrestricted) ||
                 (CHECK_OPERAND(1, REG_RBP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(1, REG_RBP, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%rbp\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((CHECK_OPERAND(0, REG_RSP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(0, REG_RSP, OperandSandboxUnrestricted) ||
                 (CHECK_OPERAND(1, REG_RSP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(1, REG_RSP, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%rsp\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((operand_states & 0x70) == (OperandSandboxRestricted << 5)) {
        restricted_register = operand_states & 0x0f;
      } else if ((operand_states & 0x7000) ==
                                        (OperandSandboxRestricted << (5 + 8))) {
        restricted_register = (operand_states & 0x0f00) >> 8;
      }
    }
  }
#line 337 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
       /* On successful match the instruction start must point to the next byte
        * to be able to report the new offset as the start of instruction
        * causing error.  */
       begin = p + 1;
     }
	goto st739;
st739:
	if ( ++p == pe )
		goto _test_eof739;
case 739:
#line 37056 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 0u: goto tr978;
		case 1u: goto tr979;
		case 2u: goto tr980;
		case 3u: goto tr981;
		case 4u: goto tr982;
		case 5u: goto tr983;
		case 8u: goto tr978;
		case 9u: goto tr979;
		case 10u: goto tr980;
		case 11u: goto tr981;
		case 12u: goto tr982;
		case 13u: goto tr983;
		case 15u: goto tr984;
		case 16u: goto tr978;
		case 17u: goto tr979;
		case 18u: goto tr980;
		case 19u: goto tr981;
		case 20u: goto tr982;
		case 21u: goto tr983;
		case 24u: goto tr978;
		case 25u: goto tr979;
		case 26u: goto tr980;
		case 27u: goto tr981;
		case 28u: goto tr982;
		case 29u: goto tr983;
		case 32u: goto tr978;
		case 33u: goto tr979;
		case 34u: goto tr980;
		case 35u: goto tr981;
		case 36u: goto tr982;
		case 37u: goto tr983;
		case 40u: goto tr978;
		case 41u: goto tr979;
		case 42u: goto tr980;
		case 43u: goto tr981;
		case 44u: goto tr982;
		case 45u: goto tr983;
		case 46u: goto tr985;
		case 48u: goto tr978;
		case 49u: goto tr979;
		case 50u: goto tr980;
		case 51u: goto tr981;
		case 52u: goto tr982;
		case 53u: goto tr983;
		case 60u: goto tr987;
		case 61u: goto tr988;
		case 62u: goto tr989;
		case 65u: goto tr991;
		case 72u: goto tr992;
		case 73u: goto tr993;
		case 74u: goto tr994;
		case 76u: goto tr996;
		case 99u: goto tr981;
		case 102u: goto tr999;
		case 104u: goto tr988;
		case 105u: goto tr1000;
		case 106u: goto tr987;
		case 107u: goto tr1001;
		case 128u: goto tr1003;
		case 129u: goto tr1004;
		case 131u: goto tr1005;
		case 133u: goto tr979;
		case 134u: goto tr1006;
		case 135u: goto tr1007;
		case 137u: goto tr979;
		case 138u: goto tr980;
		case 139u: goto tr981;
		case 141u: goto tr1008;
		case 143u: goto tr1009;
		case 144u: goto tr1010;
		case 155u: goto tr1010;
		case 168u: goto tr982;
		case 169u: goto tr983;
		case 192u: goto tr1017;
		case 193u: goto tr1018;
		case 196u: goto tr1019;
		case 197u: goto tr1020;
		case 198u: goto tr1021;
		case 199u: goto tr1022;
		case 200u: goto tr1023;
		case 202u: goto tr1024;
		case 203u: goto tr1010;
		case 209u: goto tr1026;
		case 211u: goto tr1026;
		case 216u: goto tr986;
		case 217u: goto tr1027;
		case 218u: goto tr1028;
		case 219u: goto tr1029;
		case 220u: goto tr1030;
		case 221u: goto tr1031;
		case 222u: goto tr1032;
		case 223u: goto tr1033;
		case 235u: goto tr1002;
		case 240u: goto tr1035;
		case 242u: goto tr1036;
		case 243u: goto tr1037;
		case 246u: goto tr1038;
		case 247u: goto tr1039;
		case 254u: goto tr1040;
		case 255u: goto tr1059;
	}
	if ( (*p) < 164u ) {
		if ( (*p) < 88u ) {
			if ( (*p) < 64u ) {
				if ( 56u <= (*p) && (*p) <= 59u )
					goto tr986;
			} else if ( (*p) > 71u ) {
				if ( (*p) > 79u ) {
					if ( 80u <= (*p) && (*p) <= 87u )
						goto tr997;
				} else if ( (*p) >= 75u )
					goto tr995;
			} else
				goto tr990;
		} else if ( (*p) > 95u ) {
			if ( (*p) < 132u ) {
				if ( 112u <= (*p) && (*p) <= 127u )
					goto tr1002;
			} else if ( (*p) > 136u ) {
				if ( (*p) > 151u ) {
					if ( 152u <= (*p) && (*p) <= 153u )
						goto tr1010;
				} else if ( (*p) >= 145u )
					goto tr1011;
			} else
				goto tr978;
		} else
			goto tr998;
	} else if ( (*p) > 167u ) {
		if ( (*p) < 184u ) {
			if ( (*p) < 172u ) {
				if ( 170u <= (*p) && (*p) <= 171u )
					goto tr1013;
			} else if ( (*p) > 173u ) {
				if ( (*p) > 175u ) {
					if ( 176u <= (*p) && (*p) <= 183u )
						goto tr1015;
				} else if ( (*p) >= 174u )
					goto tr1013;
			} else
				goto tr1014;
		} else if ( (*p) > 191u ) {
			if ( (*p) < 232u ) {
				if ( 208u <= (*p) && (*p) <= 210u )
					goto tr1025;
			} else if ( (*p) > 233u ) {
				if ( (*p) > 249u ) {
					if ( 252u <= (*p) && (*p) <= 253u )
						goto tr1010;
				} else if ( (*p) >= 244u )
					goto tr1010;
			} else
				goto tr1034;
		} else
			goto tr1016;
	} else
		goto tr1012;
	goto tr33;
tr1059:
#line 329 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
        begin = p;
        BitmapSetBit(valid_targets, p - data);
        SET_REX_PREFIX(FALSE);
        SET_VEX_PREFIX2(0xe0);
        SET_VEX_PREFIX3(0x00);
        operand_states = 0;
     }
	goto st690;
st690:
	if ( ++p == pe )
		goto _test_eof690;
case 690:
#line 37231 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 4u: goto st2;
		case 5u: goto tr2;
		case 12u: goto st2;
		case 13u: goto tr2;
		case 52u: goto st2;
		case 53u: goto tr2;
		case 68u: goto st8;
		case 76u: goto st8;
		case 116u: goto st8;
		case 132u: goto st9;
		case 140u: goto st9;
		case 180u: goto st9;
		case 215u: goto tr932;
		case 231u: goto tr932;
	}
	if ( (*p) < 112u ) {
		if ( (*p) < 48u ) {
			if ( (*p) <= 15u )
				goto tr0;
		} else if ( (*p) > 55u ) {
			if ( 64u <= (*p) && (*p) <= 79u )
				goto tr3;
		} else
			goto tr0;
	} else if ( (*p) > 119u ) {
		if ( (*p) < 176u ) {
			if ( 128u <= (*p) && (*p) <= 143u )
				goto tr5;
		} else if ( (*p) > 183u ) {
			if ( (*p) > 207u ) {
				if ( 240u <= (*p) && (*p) <= 247u )
					goto tr34;
			} else if ( (*p) >= 192u )
				goto tr56;
		} else
			goto tr5;
	} else
		goto tr3;
	goto tr33;
tr213:
#line 295 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(0, OperandSize32bit);
  }
#line 384 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_NAME(0, ((*p) & 0x07) |
                           ((GET_REX_PREFIX() & 0x01) << 3) |
                           (((~GET_VEX_PREFIX2()) & 0x20) >> 2));
  }
	goto st691;
st691:
	if ( ++p == pe )
		goto _test_eof691;
case 691:
#line 37288 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	if ( (*p) == 224u )
		goto tr954;
	goto tr25;
tr954:
#line 58 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_IMM_TYPE(IMM8);
    SET_IMM_PTR(p);
  }
#line 93 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    /* Restricted %rsp or %rbp must be processed by appropriate nacl-special
       instruction, not with regular instruction.  */
    if (restricted_register == REG_RSP) {
      PrintError("Incorrectly modified register %%rsp\n", begin - data);
      result = 1;
      goto error_detected;
    } else if (restricted_register == REG_RBP) {
      PrintError("Incorrectly modified register %%rbp\n", begin - data);
      result = 1;
      goto error_detected;
    }
    /* If Sandboxed Rsi is destroyed then we must note that.  */
    if (restricted_register == kSandboxedRsi) {
      if (CHECK_OPERAND(0, REG_RSI, OperandSandboxRestricted) ||
          CHECK_OPERAND(0, REG_RSI, OperandSandboxUnrestricted) ||
          CHECK_OPERAND(1, REG_RSI, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_RSI, OperandSandboxUnrestricted)) {
        restricted_register = kNoRestrictedReg;
      }
    }
    if (restricted_register == kSandboxedRsi) {
      if (CHECK_OPERAND(0, REG_RDI, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_RDI, OperandSandboxRestricted)) {
        sandboxed_rsi_restricted_rdi = begin;
        restricted_register = kSandboxedRsiRestrictedRdi;
      }
    }
    if (restricted_register != kSandboxedRsiRestrictedRdi) {
      restricted_register = kNoRestrictedReg;
      if (CHECK_OPERAND(0, REG_R15, OperandSandbox8bit) ||
          CHECK_OPERAND(0, REG_R15, OperandSandboxRestricted) ||
          CHECK_OPERAND(0, REG_R15, OperandSandboxUnrestricted) ||
          CHECK_OPERAND(1, REG_R15, OperandSandbox8bit) ||
          CHECK_OPERAND(1, REG_R15, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_R15, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%r15\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((CHECK_OPERAND(0, REG_RBP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(0, REG_RBP, OperandSandboxUnrestricted) ||
                 (CHECK_OPERAND(1, REG_RBP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(1, REG_RBP, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%rbp\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((CHECK_OPERAND(0, REG_RSP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(0, REG_RSP, OperandSandboxUnrestricted) ||
                 (CHECK_OPERAND(1, REG_RSP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(1, REG_RSP, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%rsp\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((operand_states & 0x70) == (OperandSandboxRestricted << 5)) {
        restricted_register = operand_states & 0x0f;
      } else if ((operand_states & 0x7000) ==
                                        (OperandSandboxRestricted << (5 + 8))) {
        restricted_register = (operand_states & 0x0f00) >> 8;
      }
    }
  }
#line 337 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
       /* On successful match the instruction start must point to the next byte
        * to be able to report the new offset as the start of instruction
        * causing error.  */
       begin = p + 1;
     }
	goto st740;
st740:
	if ( ++p == pe )
		goto _test_eof740;
case 740:
#line 37376 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 0u: goto tr978;
		case 1u: goto tr979;
		case 2u: goto tr980;
		case 3u: goto tr981;
		case 4u: goto tr982;
		case 5u: goto tr983;
		case 8u: goto tr978;
		case 9u: goto tr979;
		case 10u: goto tr980;
		case 11u: goto tr981;
		case 12u: goto tr982;
		case 13u: goto tr983;
		case 15u: goto tr984;
		case 16u: goto tr978;
		case 17u: goto tr979;
		case 18u: goto tr980;
		case 19u: goto tr981;
		case 20u: goto tr982;
		case 21u: goto tr983;
		case 24u: goto tr978;
		case 25u: goto tr979;
		case 26u: goto tr980;
		case 27u: goto tr981;
		case 28u: goto tr982;
		case 29u: goto tr983;
		case 32u: goto tr978;
		case 33u: goto tr979;
		case 34u: goto tr980;
		case 35u: goto tr981;
		case 36u: goto tr982;
		case 37u: goto tr983;
		case 40u: goto tr978;
		case 41u: goto tr979;
		case 42u: goto tr980;
		case 43u: goto tr981;
		case 44u: goto tr982;
		case 45u: goto tr983;
		case 46u: goto tr985;
		case 48u: goto tr978;
		case 49u: goto tr979;
		case 50u: goto tr980;
		case 51u: goto tr981;
		case 52u: goto tr982;
		case 53u: goto tr983;
		case 60u: goto tr987;
		case 61u: goto tr988;
		case 62u: goto tr989;
		case 65u: goto tr991;
		case 72u: goto tr992;
		case 73u: goto tr993;
		case 74u: goto tr994;
		case 76u: goto tr996;
		case 77u: goto tr1060;
		case 99u: goto tr981;
		case 102u: goto tr999;
		case 104u: goto tr988;
		case 105u: goto tr1000;
		case 106u: goto tr987;
		case 107u: goto tr1001;
		case 128u: goto tr1003;
		case 129u: goto tr1004;
		case 131u: goto tr1005;
		case 133u: goto tr979;
		case 134u: goto tr1006;
		case 135u: goto tr1007;
		case 137u: goto tr979;
		case 138u: goto tr980;
		case 139u: goto tr981;
		case 141u: goto tr1008;
		case 143u: goto tr1009;
		case 144u: goto tr1010;
		case 155u: goto tr1010;
		case 168u: goto tr982;
		case 169u: goto tr983;
		case 192u: goto tr1017;
		case 193u: goto tr1018;
		case 196u: goto tr1019;
		case 197u: goto tr1020;
		case 198u: goto tr1021;
		case 199u: goto tr1022;
		case 200u: goto tr1023;
		case 202u: goto tr1024;
		case 203u: goto tr1010;
		case 209u: goto tr1026;
		case 211u: goto tr1026;
		case 216u: goto tr986;
		case 217u: goto tr1027;
		case 218u: goto tr1028;
		case 219u: goto tr1029;
		case 220u: goto tr1030;
		case 221u: goto tr1031;
		case 222u: goto tr1032;
		case 223u: goto tr1033;
		case 235u: goto tr1002;
		case 240u: goto tr1035;
		case 242u: goto tr1036;
		case 243u: goto tr1037;
		case 246u: goto tr1038;
		case 247u: goto tr1039;
		case 254u: goto tr1040;
		case 255u: goto tr1041;
	}
	if ( (*p) < 164u ) {
		if ( (*p) < 88u ) {
			if ( (*p) < 64u ) {
				if ( 56u <= (*p) && (*p) <= 59u )
					goto tr986;
			} else if ( (*p) > 71u ) {
				if ( (*p) > 79u ) {
					if ( 80u <= (*p) && (*p) <= 87u )
						goto tr997;
				} else if ( (*p) >= 75u )
					goto tr995;
			} else
				goto tr990;
		} else if ( (*p) > 95u ) {
			if ( (*p) < 132u ) {
				if ( 112u <= (*p) && (*p) <= 127u )
					goto tr1002;
			} else if ( (*p) > 136u ) {
				if ( (*p) > 151u ) {
					if ( 152u <= (*p) && (*p) <= 153u )
						goto tr1010;
				} else if ( (*p) >= 145u )
					goto tr1011;
			} else
				goto tr978;
		} else
			goto tr998;
	} else if ( (*p) > 167u ) {
		if ( (*p) < 184u ) {
			if ( (*p) < 172u ) {
				if ( 170u <= (*p) && (*p) <= 171u )
					goto tr1013;
			} else if ( (*p) > 173u ) {
				if ( (*p) > 175u ) {
					if ( 176u <= (*p) && (*p) <= 183u )
						goto tr1015;
				} else if ( (*p) >= 174u )
					goto tr1013;
			} else
				goto tr1014;
		} else if ( (*p) > 191u ) {
			if ( (*p) < 232u ) {
				if ( 208u <= (*p) && (*p) <= 210u )
					goto tr1025;
			} else if ( (*p) > 233u ) {
				if ( (*p) > 249u ) {
					if ( 252u <= (*p) && (*p) <= 253u )
						goto tr1010;
				} else if ( (*p) >= 244u )
					goto tr1010;
			} else
				goto tr1034;
		} else
			goto tr1016;
	} else
		goto tr1012;
	goto tr33;
tr1060:
#line 329 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
        begin = p;
        BitmapSetBit(valid_targets, p - data);
        SET_REX_PREFIX(FALSE);
        SET_VEX_PREFIX2(0xe0);
        SET_VEX_PREFIX3(0x00);
        operand_states = 0;
     }
#line 190 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_REX_PREFIX(*p);
  }
	goto st692;
st692:
	if ( ++p == pe )
		goto _test_eof692;
case 692:
#line 37556 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 1u: goto tr955;
		case 3u: goto tr221;
		case 9u: goto tr220;
		case 11u: goto tr221;
		case 15u: goto st142;
		case 17u: goto tr220;
		case 19u: goto tr221;
		case 25u: goto tr220;
		case 27u: goto tr221;
		case 33u: goto tr220;
		case 35u: goto tr221;
		case 41u: goto tr220;
		case 43u: goto tr221;
		case 49u: goto tr220;
		case 51u: goto tr221;
		case 57u: goto st38;
		case 59u: goto st38;
		case 99u: goto tr221;
		case 105u: goto tr224;
		case 107u: goto tr225;
		case 129u: goto st144;
		case 131u: goto st145;
		case 133u: goto tr220;
		case 135u: goto tr228;
		case 137u: goto tr220;
		case 139u: goto tr221;
		case 141u: goto tr230;
		case 193u: goto st150;
		case 199u: goto st151;
		case 209u: goto st152;
		case 211u: goto st152;
		case 247u: goto st153;
		case 255u: goto st154;
	}
	if ( (*p) > 151u ) {
		if ( 184u <= (*p) && (*p) <= 191u )
			goto tr235;
	} else if ( (*p) >= 145u )
		goto tr231;
	goto tr33;
tr955:
#line 298 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(0, OperandSize64bit);
  }
	goto st693;
st693:
	if ( ++p == pe )
		goto _test_eof693;
case 693:
#line 37608 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 4u: goto st2;
		case 5u: goto tr2;
		case 12u: goto st2;
		case 13u: goto tr2;
		case 20u: goto st2;
		case 21u: goto tr2;
		case 28u: goto st2;
		case 29u: goto tr2;
		case 36u: goto st2;
		case 37u: goto tr2;
		case 44u: goto st2;
		case 45u: goto tr2;
		case 52u: goto st2;
		case 53u: goto tr2;
		case 60u: goto st2;
		case 61u: goto tr2;
		case 68u: goto st8;
		case 76u: goto st8;
		case 84u: goto st8;
		case 92u: goto st8;
		case 100u: goto st8;
		case 108u: goto st8;
		case 116u: goto st8;
		case 124u: goto st8;
		case 132u: goto st9;
		case 140u: goto st9;
		case 148u: goto st9;
		case 156u: goto st9;
		case 164u: goto st9;
		case 172u: goto st9;
		case 180u: goto st9;
		case 188u: goto st9;
		case 249u: goto tr956;
	}
	if ( (*p) < 64u ) {
		if ( (*p) <= 63u )
			goto tr0;
	} else if ( (*p) > 127u ) {
		if ( 128u <= (*p) && (*p) <= 191u )
			goto tr5;
	} else
		goto tr3;
	goto tr7;
tr956:
#line 384 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_NAME(0, ((*p) & 0x07) |
                           ((GET_REX_PREFIX() & 0x01) << 3) |
                           (((~GET_VEX_PREFIX2()) & 0x20) >> 2));
  }
#line 93 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    /* Restricted %rsp or %rbp must be processed by appropriate nacl-special
       instruction, not with regular instruction.  */
    if (restricted_register == REG_RSP) {
      PrintError("Incorrectly modified register %%rsp\n", begin - data);
      result = 1;
      goto error_detected;
    } else if (restricted_register == REG_RBP) {
      PrintError("Incorrectly modified register %%rbp\n", begin - data);
      result = 1;
      goto error_detected;
    }
    /* If Sandboxed Rsi is destroyed then we must note that.  */
    if (restricted_register == kSandboxedRsi) {
      if (CHECK_OPERAND(0, REG_RSI, OperandSandboxRestricted) ||
          CHECK_OPERAND(0, REG_RSI, OperandSandboxUnrestricted) ||
          CHECK_OPERAND(1, REG_RSI, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_RSI, OperandSandboxUnrestricted)) {
        restricted_register = kNoRestrictedReg;
      }
    }
    if (restricted_register == kSandboxedRsi) {
      if (CHECK_OPERAND(0, REG_RDI, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_RDI, OperandSandboxRestricted)) {
        sandboxed_rsi_restricted_rdi = begin;
        restricted_register = kSandboxedRsiRestrictedRdi;
      }
    }
    if (restricted_register != kSandboxedRsiRestrictedRdi) {
      restricted_register = kNoRestrictedReg;
      if (CHECK_OPERAND(0, REG_R15, OperandSandbox8bit) ||
          CHECK_OPERAND(0, REG_R15, OperandSandboxRestricted) ||
          CHECK_OPERAND(0, REG_R15, OperandSandboxUnrestricted) ||
          CHECK_OPERAND(1, REG_R15, OperandSandbox8bit) ||
          CHECK_OPERAND(1, REG_R15, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_R15, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%r15\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((CHECK_OPERAND(0, REG_RBP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(0, REG_RBP, OperandSandboxUnrestricted) ||
                 (CHECK_OPERAND(1, REG_RBP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(1, REG_RBP, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%rbp\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((CHECK_OPERAND(0, REG_RSP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(0, REG_RSP, OperandSandboxUnrestricted) ||
                 (CHECK_OPERAND(1, REG_RSP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(1, REG_RSP, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%rsp\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((operand_states & 0x70) == (OperandSandboxRestricted << 5)) {
        restricted_register = operand_states & 0x0f;
      } else if ((operand_states & 0x7000) ==
                                        (OperandSandboxRestricted << (5 + 8))) {
        restricted_register = (operand_states & 0x0f00) >> 8;
      }
    }
  }
#line 337 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
       /* On successful match the instruction start must point to the next byte
        * to be able to report the new offset as the start of instruction
        * causing error.  */
       begin = p + 1;
     }
	goto st741;
st741:
	if ( ++p == pe )
		goto _test_eof741;
case 741:
#line 37738 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 0u: goto tr978;
		case 1u: goto tr979;
		case 2u: goto tr980;
		case 3u: goto tr981;
		case 4u: goto tr982;
		case 5u: goto tr983;
		case 8u: goto tr978;
		case 9u: goto tr979;
		case 10u: goto tr980;
		case 11u: goto tr981;
		case 12u: goto tr982;
		case 13u: goto tr983;
		case 15u: goto tr984;
		case 16u: goto tr978;
		case 17u: goto tr979;
		case 18u: goto tr980;
		case 19u: goto tr981;
		case 20u: goto tr982;
		case 21u: goto tr983;
		case 24u: goto tr978;
		case 25u: goto tr979;
		case 26u: goto tr980;
		case 27u: goto tr981;
		case 28u: goto tr982;
		case 29u: goto tr983;
		case 32u: goto tr978;
		case 33u: goto tr979;
		case 34u: goto tr980;
		case 35u: goto tr981;
		case 36u: goto tr982;
		case 37u: goto tr983;
		case 40u: goto tr978;
		case 41u: goto tr979;
		case 42u: goto tr980;
		case 43u: goto tr981;
		case 44u: goto tr982;
		case 45u: goto tr983;
		case 46u: goto tr985;
		case 48u: goto tr978;
		case 49u: goto tr979;
		case 50u: goto tr980;
		case 51u: goto tr981;
		case 52u: goto tr982;
		case 53u: goto tr983;
		case 60u: goto tr987;
		case 61u: goto tr988;
		case 62u: goto tr989;
		case 65u: goto tr1061;
		case 72u: goto tr992;
		case 73u: goto tr993;
		case 74u: goto tr994;
		case 76u: goto tr996;
		case 99u: goto tr981;
		case 102u: goto tr999;
		case 104u: goto tr988;
		case 105u: goto tr1000;
		case 106u: goto tr987;
		case 107u: goto tr1001;
		case 128u: goto tr1003;
		case 129u: goto tr1004;
		case 131u: goto tr1005;
		case 133u: goto tr979;
		case 134u: goto tr1006;
		case 135u: goto tr1007;
		case 137u: goto tr979;
		case 138u: goto tr980;
		case 139u: goto tr981;
		case 141u: goto tr1008;
		case 143u: goto tr1009;
		case 144u: goto tr1010;
		case 155u: goto tr1010;
		case 168u: goto tr982;
		case 169u: goto tr983;
		case 192u: goto tr1017;
		case 193u: goto tr1018;
		case 196u: goto tr1019;
		case 197u: goto tr1020;
		case 198u: goto tr1021;
		case 199u: goto tr1022;
		case 200u: goto tr1023;
		case 202u: goto tr1024;
		case 203u: goto tr1010;
		case 209u: goto tr1026;
		case 211u: goto tr1026;
		case 216u: goto tr986;
		case 217u: goto tr1027;
		case 218u: goto tr1028;
		case 219u: goto tr1029;
		case 220u: goto tr1030;
		case 221u: goto tr1031;
		case 222u: goto tr1032;
		case 223u: goto tr1033;
		case 235u: goto tr1002;
		case 240u: goto tr1035;
		case 242u: goto tr1036;
		case 243u: goto tr1037;
		case 246u: goto tr1038;
		case 247u: goto tr1039;
		case 254u: goto tr1040;
		case 255u: goto tr1041;
	}
	if ( (*p) < 164u ) {
		if ( (*p) < 88u ) {
			if ( (*p) < 64u ) {
				if ( 56u <= (*p) && (*p) <= 59u )
					goto tr986;
			} else if ( (*p) > 71u ) {
				if ( (*p) > 79u ) {
					if ( 80u <= (*p) && (*p) <= 87u )
						goto tr997;
				} else if ( (*p) >= 75u )
					goto tr995;
			} else
				goto tr990;
		} else if ( (*p) > 95u ) {
			if ( (*p) < 132u ) {
				if ( 112u <= (*p) && (*p) <= 127u )
					goto tr1002;
			} else if ( (*p) > 136u ) {
				if ( (*p) > 151u ) {
					if ( 152u <= (*p) && (*p) <= 153u )
						goto tr1010;
				} else if ( (*p) >= 145u )
					goto tr1011;
			} else
				goto tr978;
		} else
			goto tr998;
	} else if ( (*p) > 167u ) {
		if ( (*p) < 184u ) {
			if ( (*p) < 172u ) {
				if ( 170u <= (*p) && (*p) <= 171u )
					goto tr1013;
			} else if ( (*p) > 173u ) {
				if ( (*p) > 175u ) {
					if ( 176u <= (*p) && (*p) <= 183u )
						goto tr1015;
				} else if ( (*p) >= 174u )
					goto tr1013;
			} else
				goto tr1014;
		} else if ( (*p) > 191u ) {
			if ( (*p) < 232u ) {
				if ( 208u <= (*p) && (*p) <= 210u )
					goto tr1025;
			} else if ( (*p) > 233u ) {
				if ( (*p) > 249u ) {
					if ( 252u <= (*p) && (*p) <= 253u )
						goto tr1010;
				} else if ( (*p) >= 244u )
					goto tr1010;
			} else
				goto tr1034;
		} else
			goto tr1016;
	} else
		goto tr1012;
	goto tr33;
tr1061:
#line 329 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
        begin = p;
        BitmapSetBit(valid_targets, p - data);
        SET_REX_PREFIX(FALSE);
        SET_VEX_PREFIX2(0xe0);
        SET_VEX_PREFIX3(0x00);
        operand_states = 0;
     }
#line 190 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_REX_PREFIX(*p);
  }
	goto st694;
st694:
	if ( ++p == pe )
		goto _test_eof694;
case 694:
#line 37917 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 0u: goto tr47;
		case 1u: goto tr45;
		case 2u: goto tr120;
		case 3u: goto tr32;
		case 8u: goto tr47;
		case 9u: goto tr45;
		case 10u: goto tr120;
		case 11u: goto tr32;
		case 15u: goto st69;
		case 16u: goto tr47;
		case 17u: goto tr45;
		case 18u: goto tr120;
		case 19u: goto tr32;
		case 24u: goto tr47;
		case 25u: goto tr45;
		case 26u: goto tr120;
		case 27u: goto tr32;
		case 32u: goto tr47;
		case 33u: goto tr45;
		case 34u: goto tr120;
		case 35u: goto tr32;
		case 40u: goto tr47;
		case 41u: goto tr45;
		case 42u: goto tr120;
		case 43u: goto tr32;
		case 48u: goto tr47;
		case 49u: goto tr45;
		case 50u: goto tr120;
		case 51u: goto tr32;
		case 99u: goto tr32;
		case 105u: goto tr124;
		case 107u: goto tr125;
		case 128u: goto st89;
		case 129u: goto st90;
		case 131u: goto st112;
		case 133u: goto tr45;
		case 134u: goto tr129;
		case 135u: goto tr130;
		case 137u: goto tr45;
		case 138u: goto tr120;
		case 139u: goto tr32;
		case 141u: goto tr131;
		case 143u: goto st94;
		case 155u: goto st95;
		case 192u: goto st97;
		case 193u: goto st98;
		case 198u: goto st99;
		case 199u: goto st100;
		case 209u: goto st102;
		case 211u: goto st102;
		case 217u: goto st104;
		case 219u: goto st105;
		case 221u: goto st106;
		case 246u: goto st107;
		case 247u: goto st108;
		case 254u: goto st109;
		case 255u: goto st695;
	}
	if ( (*p) < 145u ) {
		if ( (*p) < 80u ) {
			if ( 56u <= (*p) && (*p) <= 59u )
				goto st38;
		} else if ( (*p) > 87u ) {
			if ( (*p) > 95u ) {
				if ( 132u <= (*p) && (*p) <= 136u )
					goto tr47;
			} else if ( (*p) >= 88u )
				goto tr123;
		} else
			goto tr122;
	} else if ( (*p) > 151u ) {
		if ( (*p) < 184u ) {
			if ( 176u <= (*p) && (*p) <= 183u )
				goto tr135;
		} else if ( (*p) > 191u ) {
			if ( (*p) > 210u ) {
				if ( 216u <= (*p) && (*p) <= 223u )
					goto st103;
			} else if ( (*p) >= 208u )
				goto st101;
		} else
			goto tr136;
	} else
		goto tr133;
	goto tr33;
st695:
	if ( ++p == pe )
		goto _test_eof695;
case 695:
	switch( (*p) ) {
		case 4u: goto st2;
		case 12u: goto st2;
		case 52u: goto st2;
		case 68u: goto st8;
		case 76u: goto st8;
		case 116u: goto st8;
		case 132u: goto st9;
		case 140u: goto st9;
		case 180u: goto st9;
		case 209u: goto tr292;
		case 225u: goto tr292;
	}
	if ( (*p) < 64u ) {
		if ( (*p) < 14u ) {
			if ( (*p) > 3u ) {
				if ( 6u <= (*p) && (*p) <= 11u )
					goto tr0;
			} else
				goto tr0;
		} else if ( (*p) > 15u ) {
			if ( (*p) > 51u ) {
				if ( 54u <= (*p) && (*p) <= 55u )
					goto tr0;
			} else if ( (*p) >= 48u )
				goto tr0;
		} else
			goto tr0;
	} else if ( (*p) > 79u ) {
		if ( (*p) < 176u ) {
			if ( (*p) > 119u ) {
				if ( 128u <= (*p) && (*p) <= 143u )
					goto tr5;
			} else if ( (*p) >= 112u )
				goto tr3;
		} else if ( (*p) > 183u ) {
			if ( (*p) > 207u ) {
				if ( 240u <= (*p) && (*p) <= 247u )
					goto tr34;
			} else if ( (*p) >= 192u )
				goto tr56;
		} else
			goto tr5;
	} else
		goto tr3;
	goto tr33;
tr214:
#line 295 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(0, OperandSize32bit);
  }
#line 384 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_NAME(0, ((*p) & 0x07) |
                           ((GET_REX_PREFIX() & 0x01) << 3) |
                           (((~GET_VEX_PREFIX2()) & 0x20) >> 2));
  }
	goto st696;
st696:
	if ( ++p == pe )
		goto _test_eof696;
case 696:
#line 38070 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	if ( (*p) == 224u )
		goto tr958;
	goto tr25;
tr958:
#line 58 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_IMM_TYPE(IMM8);
    SET_IMM_PTR(p);
  }
#line 93 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    /* Restricted %rsp or %rbp must be processed by appropriate nacl-special
       instruction, not with regular instruction.  */
    if (restricted_register == REG_RSP) {
      PrintError("Incorrectly modified register %%rsp\n", begin - data);
      result = 1;
      goto error_detected;
    } else if (restricted_register == REG_RBP) {
      PrintError("Incorrectly modified register %%rbp\n", begin - data);
      result = 1;
      goto error_detected;
    }
    /* If Sandboxed Rsi is destroyed then we must note that.  */
    if (restricted_register == kSandboxedRsi) {
      if (CHECK_OPERAND(0, REG_RSI, OperandSandboxRestricted) ||
          CHECK_OPERAND(0, REG_RSI, OperandSandboxUnrestricted) ||
          CHECK_OPERAND(1, REG_RSI, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_RSI, OperandSandboxUnrestricted)) {
        restricted_register = kNoRestrictedReg;
      }
    }
    if (restricted_register == kSandboxedRsi) {
      if (CHECK_OPERAND(0, REG_RDI, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_RDI, OperandSandboxRestricted)) {
        sandboxed_rsi_restricted_rdi = begin;
        restricted_register = kSandboxedRsiRestrictedRdi;
      }
    }
    if (restricted_register != kSandboxedRsiRestrictedRdi) {
      restricted_register = kNoRestrictedReg;
      if (CHECK_OPERAND(0, REG_R15, OperandSandbox8bit) ||
          CHECK_OPERAND(0, REG_R15, OperandSandboxRestricted) ||
          CHECK_OPERAND(0, REG_R15, OperandSandboxUnrestricted) ||
          CHECK_OPERAND(1, REG_R15, OperandSandbox8bit) ||
          CHECK_OPERAND(1, REG_R15, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_R15, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%r15\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((CHECK_OPERAND(0, REG_RBP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(0, REG_RBP, OperandSandboxUnrestricted) ||
                 (CHECK_OPERAND(1, REG_RBP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(1, REG_RBP, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%rbp\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((CHECK_OPERAND(0, REG_RSP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(0, REG_RSP, OperandSandboxUnrestricted) ||
                 (CHECK_OPERAND(1, REG_RSP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(1, REG_RSP, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%rsp\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((operand_states & 0x70) == (OperandSandboxRestricted << 5)) {
        restricted_register = operand_states & 0x0f;
      } else if ((operand_states & 0x7000) ==
                                        (OperandSandboxRestricted << (5 + 8))) {
        restricted_register = (operand_states & 0x0f00) >> 8;
      }
    }
  }
#line 337 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
       /* On successful match the instruction start must point to the next byte
        * to be able to report the new offset as the start of instruction
        * causing error.  */
       begin = p + 1;
     }
	goto st742;
st742:
	if ( ++p == pe )
		goto _test_eof742;
case 742:
#line 38158 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 0u: goto tr978;
		case 1u: goto tr979;
		case 2u: goto tr980;
		case 3u: goto tr981;
		case 4u: goto tr982;
		case 5u: goto tr983;
		case 8u: goto tr978;
		case 9u: goto tr979;
		case 10u: goto tr980;
		case 11u: goto tr981;
		case 12u: goto tr982;
		case 13u: goto tr983;
		case 15u: goto tr984;
		case 16u: goto tr978;
		case 17u: goto tr979;
		case 18u: goto tr980;
		case 19u: goto tr981;
		case 20u: goto tr982;
		case 21u: goto tr983;
		case 24u: goto tr978;
		case 25u: goto tr979;
		case 26u: goto tr980;
		case 27u: goto tr981;
		case 28u: goto tr982;
		case 29u: goto tr983;
		case 32u: goto tr978;
		case 33u: goto tr979;
		case 34u: goto tr980;
		case 35u: goto tr981;
		case 36u: goto tr982;
		case 37u: goto tr983;
		case 40u: goto tr978;
		case 41u: goto tr979;
		case 42u: goto tr980;
		case 43u: goto tr981;
		case 44u: goto tr982;
		case 45u: goto tr983;
		case 46u: goto tr985;
		case 48u: goto tr978;
		case 49u: goto tr979;
		case 50u: goto tr980;
		case 51u: goto tr981;
		case 52u: goto tr982;
		case 53u: goto tr983;
		case 60u: goto tr987;
		case 61u: goto tr988;
		case 62u: goto tr989;
		case 65u: goto tr991;
		case 72u: goto tr992;
		case 73u: goto tr993;
		case 74u: goto tr994;
		case 76u: goto tr996;
		case 77u: goto tr1062;
		case 99u: goto tr981;
		case 102u: goto tr999;
		case 104u: goto tr988;
		case 105u: goto tr1000;
		case 106u: goto tr987;
		case 107u: goto tr1001;
		case 128u: goto tr1003;
		case 129u: goto tr1004;
		case 131u: goto tr1005;
		case 133u: goto tr979;
		case 134u: goto tr1006;
		case 135u: goto tr1007;
		case 137u: goto tr979;
		case 138u: goto tr980;
		case 139u: goto tr981;
		case 141u: goto tr1008;
		case 143u: goto tr1009;
		case 144u: goto tr1010;
		case 155u: goto tr1010;
		case 168u: goto tr982;
		case 169u: goto tr983;
		case 192u: goto tr1017;
		case 193u: goto tr1018;
		case 196u: goto tr1019;
		case 197u: goto tr1020;
		case 198u: goto tr1021;
		case 199u: goto tr1022;
		case 200u: goto tr1023;
		case 202u: goto tr1024;
		case 203u: goto tr1010;
		case 209u: goto tr1026;
		case 211u: goto tr1026;
		case 216u: goto tr986;
		case 217u: goto tr1027;
		case 218u: goto tr1028;
		case 219u: goto tr1029;
		case 220u: goto tr1030;
		case 221u: goto tr1031;
		case 222u: goto tr1032;
		case 223u: goto tr1033;
		case 235u: goto tr1002;
		case 240u: goto tr1035;
		case 242u: goto tr1036;
		case 243u: goto tr1037;
		case 246u: goto tr1038;
		case 247u: goto tr1039;
		case 254u: goto tr1040;
		case 255u: goto tr1041;
	}
	if ( (*p) < 164u ) {
		if ( (*p) < 88u ) {
			if ( (*p) < 64u ) {
				if ( 56u <= (*p) && (*p) <= 59u )
					goto tr986;
			} else if ( (*p) > 71u ) {
				if ( (*p) > 79u ) {
					if ( 80u <= (*p) && (*p) <= 87u )
						goto tr997;
				} else if ( (*p) >= 75u )
					goto tr995;
			} else
				goto tr990;
		} else if ( (*p) > 95u ) {
			if ( (*p) < 132u ) {
				if ( 112u <= (*p) && (*p) <= 127u )
					goto tr1002;
			} else if ( (*p) > 136u ) {
				if ( (*p) > 151u ) {
					if ( 152u <= (*p) && (*p) <= 153u )
						goto tr1010;
				} else if ( (*p) >= 145u )
					goto tr1011;
			} else
				goto tr978;
		} else
			goto tr998;
	} else if ( (*p) > 167u ) {
		if ( (*p) < 184u ) {
			if ( (*p) < 172u ) {
				if ( 170u <= (*p) && (*p) <= 171u )
					goto tr1013;
			} else if ( (*p) > 173u ) {
				if ( (*p) > 175u ) {
					if ( 176u <= (*p) && (*p) <= 183u )
						goto tr1015;
				} else if ( (*p) >= 174u )
					goto tr1013;
			} else
				goto tr1014;
		} else if ( (*p) > 191u ) {
			if ( (*p) < 232u ) {
				if ( 208u <= (*p) && (*p) <= 210u )
					goto tr1025;
			} else if ( (*p) > 233u ) {
				if ( (*p) > 249u ) {
					if ( 252u <= (*p) && (*p) <= 253u )
						goto tr1010;
				} else if ( (*p) >= 244u )
					goto tr1010;
			} else
				goto tr1034;
		} else
			goto tr1016;
	} else
		goto tr1012;
	goto tr33;
tr1062:
#line 329 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
        begin = p;
        BitmapSetBit(valid_targets, p - data);
        SET_REX_PREFIX(FALSE);
        SET_VEX_PREFIX2(0xe0);
        SET_VEX_PREFIX3(0x00);
        operand_states = 0;
     }
#line 190 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_REX_PREFIX(*p);
  }
	goto st697;
st697:
	if ( ++p == pe )
		goto _test_eof697;
case 697:
#line 38338 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 1u: goto tr959;
		case 3u: goto tr221;
		case 9u: goto tr220;
		case 11u: goto tr221;
		case 15u: goto st142;
		case 17u: goto tr220;
		case 19u: goto tr221;
		case 25u: goto tr220;
		case 27u: goto tr221;
		case 33u: goto tr220;
		case 35u: goto tr221;
		case 41u: goto tr220;
		case 43u: goto tr221;
		case 49u: goto tr220;
		case 51u: goto tr221;
		case 57u: goto st38;
		case 59u: goto st38;
		case 99u: goto tr221;
		case 105u: goto tr224;
		case 107u: goto tr225;
		case 129u: goto st144;
		case 131u: goto st145;
		case 133u: goto tr220;
		case 135u: goto tr228;
		case 137u: goto tr220;
		case 139u: goto tr221;
		case 141u: goto tr230;
		case 193u: goto st150;
		case 199u: goto st151;
		case 209u: goto st152;
		case 211u: goto st152;
		case 247u: goto st153;
		case 255u: goto st154;
	}
	if ( (*p) > 151u ) {
		if ( 184u <= (*p) && (*p) <= 191u )
			goto tr235;
	} else if ( (*p) >= 145u )
		goto tr231;
	goto tr33;
tr959:
#line 298 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(0, OperandSize64bit);
  }
	goto st698;
st698:
	if ( ++p == pe )
		goto _test_eof698;
case 698:
#line 38390 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 4u: goto st2;
		case 5u: goto tr2;
		case 12u: goto st2;
		case 13u: goto tr2;
		case 20u: goto st2;
		case 21u: goto tr2;
		case 28u: goto st2;
		case 29u: goto tr2;
		case 36u: goto st2;
		case 37u: goto tr2;
		case 44u: goto st2;
		case 45u: goto tr2;
		case 52u: goto st2;
		case 53u: goto tr2;
		case 60u: goto st2;
		case 61u: goto tr2;
		case 68u: goto st8;
		case 76u: goto st8;
		case 84u: goto st8;
		case 92u: goto st8;
		case 100u: goto st8;
		case 108u: goto st8;
		case 116u: goto st8;
		case 124u: goto st8;
		case 132u: goto st9;
		case 140u: goto st9;
		case 148u: goto st9;
		case 156u: goto st9;
		case 164u: goto st9;
		case 172u: goto st9;
		case 180u: goto st9;
		case 188u: goto st9;
		case 250u: goto tr960;
	}
	if ( (*p) < 64u ) {
		if ( (*p) <= 63u )
			goto tr0;
	} else if ( (*p) > 127u ) {
		if ( 128u <= (*p) && (*p) <= 191u )
			goto tr5;
	} else
		goto tr3;
	goto tr7;
tr960:
#line 384 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_NAME(0, ((*p) & 0x07) |
                           ((GET_REX_PREFIX() & 0x01) << 3) |
                           (((~GET_VEX_PREFIX2()) & 0x20) >> 2));
  }
#line 93 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    /* Restricted %rsp or %rbp must be processed by appropriate nacl-special
       instruction, not with regular instruction.  */
    if (restricted_register == REG_RSP) {
      PrintError("Incorrectly modified register %%rsp\n", begin - data);
      result = 1;
      goto error_detected;
    } else if (restricted_register == REG_RBP) {
      PrintError("Incorrectly modified register %%rbp\n", begin - data);
      result = 1;
      goto error_detected;
    }
    /* If Sandboxed Rsi is destroyed then we must note that.  */
    if (restricted_register == kSandboxedRsi) {
      if (CHECK_OPERAND(0, REG_RSI, OperandSandboxRestricted) ||
          CHECK_OPERAND(0, REG_RSI, OperandSandboxUnrestricted) ||
          CHECK_OPERAND(1, REG_RSI, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_RSI, OperandSandboxUnrestricted)) {
        restricted_register = kNoRestrictedReg;
      }
    }
    if (restricted_register == kSandboxedRsi) {
      if (CHECK_OPERAND(0, REG_RDI, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_RDI, OperandSandboxRestricted)) {
        sandboxed_rsi_restricted_rdi = begin;
        restricted_register = kSandboxedRsiRestrictedRdi;
      }
    }
    if (restricted_register != kSandboxedRsiRestrictedRdi) {
      restricted_register = kNoRestrictedReg;
      if (CHECK_OPERAND(0, REG_R15, OperandSandbox8bit) ||
          CHECK_OPERAND(0, REG_R15, OperandSandboxRestricted) ||
          CHECK_OPERAND(0, REG_R15, OperandSandboxUnrestricted) ||
          CHECK_OPERAND(1, REG_R15, OperandSandbox8bit) ||
          CHECK_OPERAND(1, REG_R15, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_R15, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%r15\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((CHECK_OPERAND(0, REG_RBP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(0, REG_RBP, OperandSandboxUnrestricted) ||
                 (CHECK_OPERAND(1, REG_RBP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(1, REG_RBP, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%rbp\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((CHECK_OPERAND(0, REG_RSP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(0, REG_RSP, OperandSandboxUnrestricted) ||
                 (CHECK_OPERAND(1, REG_RSP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(1, REG_RSP, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%rsp\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((operand_states & 0x70) == (OperandSandboxRestricted << 5)) {
        restricted_register = operand_states & 0x0f;
      } else if ((operand_states & 0x7000) ==
                                        (OperandSandboxRestricted << (5 + 8))) {
        restricted_register = (operand_states & 0x0f00) >> 8;
      }
    }
  }
#line 337 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
       /* On successful match the instruction start must point to the next byte
        * to be able to report the new offset as the start of instruction
        * causing error.  */
       begin = p + 1;
     }
	goto st743;
st743:
	if ( ++p == pe )
		goto _test_eof743;
case 743:
#line 38520 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 0u: goto tr978;
		case 1u: goto tr979;
		case 2u: goto tr980;
		case 3u: goto tr981;
		case 4u: goto tr982;
		case 5u: goto tr983;
		case 8u: goto tr978;
		case 9u: goto tr979;
		case 10u: goto tr980;
		case 11u: goto tr981;
		case 12u: goto tr982;
		case 13u: goto tr983;
		case 15u: goto tr984;
		case 16u: goto tr978;
		case 17u: goto tr979;
		case 18u: goto tr980;
		case 19u: goto tr981;
		case 20u: goto tr982;
		case 21u: goto tr983;
		case 24u: goto tr978;
		case 25u: goto tr979;
		case 26u: goto tr980;
		case 27u: goto tr981;
		case 28u: goto tr982;
		case 29u: goto tr983;
		case 32u: goto tr978;
		case 33u: goto tr979;
		case 34u: goto tr980;
		case 35u: goto tr981;
		case 36u: goto tr982;
		case 37u: goto tr983;
		case 40u: goto tr978;
		case 41u: goto tr979;
		case 42u: goto tr980;
		case 43u: goto tr981;
		case 44u: goto tr982;
		case 45u: goto tr983;
		case 46u: goto tr985;
		case 48u: goto tr978;
		case 49u: goto tr979;
		case 50u: goto tr980;
		case 51u: goto tr981;
		case 52u: goto tr982;
		case 53u: goto tr983;
		case 60u: goto tr987;
		case 61u: goto tr988;
		case 62u: goto tr989;
		case 65u: goto tr1063;
		case 72u: goto tr992;
		case 73u: goto tr993;
		case 74u: goto tr994;
		case 76u: goto tr996;
		case 99u: goto tr981;
		case 102u: goto tr999;
		case 104u: goto tr988;
		case 105u: goto tr1000;
		case 106u: goto tr987;
		case 107u: goto tr1001;
		case 128u: goto tr1003;
		case 129u: goto tr1004;
		case 131u: goto tr1005;
		case 133u: goto tr979;
		case 134u: goto tr1006;
		case 135u: goto tr1007;
		case 137u: goto tr979;
		case 138u: goto tr980;
		case 139u: goto tr981;
		case 141u: goto tr1008;
		case 143u: goto tr1009;
		case 144u: goto tr1010;
		case 155u: goto tr1010;
		case 168u: goto tr982;
		case 169u: goto tr983;
		case 192u: goto tr1017;
		case 193u: goto tr1018;
		case 196u: goto tr1019;
		case 197u: goto tr1020;
		case 198u: goto tr1021;
		case 199u: goto tr1022;
		case 200u: goto tr1023;
		case 202u: goto tr1024;
		case 203u: goto tr1010;
		case 209u: goto tr1026;
		case 211u: goto tr1026;
		case 216u: goto tr986;
		case 217u: goto tr1027;
		case 218u: goto tr1028;
		case 219u: goto tr1029;
		case 220u: goto tr1030;
		case 221u: goto tr1031;
		case 222u: goto tr1032;
		case 223u: goto tr1033;
		case 235u: goto tr1002;
		case 240u: goto tr1035;
		case 242u: goto tr1036;
		case 243u: goto tr1037;
		case 246u: goto tr1038;
		case 247u: goto tr1039;
		case 254u: goto tr1040;
		case 255u: goto tr1041;
	}
	if ( (*p) < 164u ) {
		if ( (*p) < 88u ) {
			if ( (*p) < 64u ) {
				if ( 56u <= (*p) && (*p) <= 59u )
					goto tr986;
			} else if ( (*p) > 71u ) {
				if ( (*p) > 79u ) {
					if ( 80u <= (*p) && (*p) <= 87u )
						goto tr997;
				} else if ( (*p) >= 75u )
					goto tr995;
			} else
				goto tr990;
		} else if ( (*p) > 95u ) {
			if ( (*p) < 132u ) {
				if ( 112u <= (*p) && (*p) <= 127u )
					goto tr1002;
			} else if ( (*p) > 136u ) {
				if ( (*p) > 151u ) {
					if ( 152u <= (*p) && (*p) <= 153u )
						goto tr1010;
				} else if ( (*p) >= 145u )
					goto tr1011;
			} else
				goto tr978;
		} else
			goto tr998;
	} else if ( (*p) > 167u ) {
		if ( (*p) < 184u ) {
			if ( (*p) < 172u ) {
				if ( 170u <= (*p) && (*p) <= 171u )
					goto tr1013;
			} else if ( (*p) > 173u ) {
				if ( (*p) > 175u ) {
					if ( 176u <= (*p) && (*p) <= 183u )
						goto tr1015;
				} else if ( (*p) >= 174u )
					goto tr1013;
			} else
				goto tr1014;
		} else if ( (*p) > 191u ) {
			if ( (*p) < 232u ) {
				if ( 208u <= (*p) && (*p) <= 210u )
					goto tr1025;
			} else if ( (*p) > 233u ) {
				if ( (*p) > 249u ) {
					if ( 252u <= (*p) && (*p) <= 253u )
						goto tr1010;
				} else if ( (*p) >= 244u )
					goto tr1010;
			} else
				goto tr1034;
		} else
			goto tr1016;
	} else
		goto tr1012;
	goto tr33;
tr1063:
#line 329 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
        begin = p;
        BitmapSetBit(valid_targets, p - data);
        SET_REX_PREFIX(FALSE);
        SET_VEX_PREFIX2(0xe0);
        SET_VEX_PREFIX3(0x00);
        operand_states = 0;
     }
#line 190 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_REX_PREFIX(*p);
  }
	goto st699;
st699:
	if ( ++p == pe )
		goto _test_eof699;
case 699:
#line 38699 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 0u: goto tr47;
		case 1u: goto tr45;
		case 2u: goto tr120;
		case 3u: goto tr32;
		case 8u: goto tr47;
		case 9u: goto tr45;
		case 10u: goto tr120;
		case 11u: goto tr32;
		case 15u: goto st69;
		case 16u: goto tr47;
		case 17u: goto tr45;
		case 18u: goto tr120;
		case 19u: goto tr32;
		case 24u: goto tr47;
		case 25u: goto tr45;
		case 26u: goto tr120;
		case 27u: goto tr32;
		case 32u: goto tr47;
		case 33u: goto tr45;
		case 34u: goto tr120;
		case 35u: goto tr32;
		case 40u: goto tr47;
		case 41u: goto tr45;
		case 42u: goto tr120;
		case 43u: goto tr32;
		case 48u: goto tr47;
		case 49u: goto tr45;
		case 50u: goto tr120;
		case 51u: goto tr32;
		case 99u: goto tr32;
		case 105u: goto tr124;
		case 107u: goto tr125;
		case 128u: goto st89;
		case 129u: goto st90;
		case 131u: goto st112;
		case 133u: goto tr45;
		case 134u: goto tr129;
		case 135u: goto tr130;
		case 137u: goto tr45;
		case 138u: goto tr120;
		case 139u: goto tr32;
		case 141u: goto tr131;
		case 143u: goto st94;
		case 155u: goto st95;
		case 192u: goto st97;
		case 193u: goto st98;
		case 198u: goto st99;
		case 199u: goto st100;
		case 209u: goto st102;
		case 211u: goto st102;
		case 217u: goto st104;
		case 219u: goto st105;
		case 221u: goto st106;
		case 246u: goto st107;
		case 247u: goto st108;
		case 254u: goto st109;
		case 255u: goto st700;
	}
	if ( (*p) < 145u ) {
		if ( (*p) < 80u ) {
			if ( 56u <= (*p) && (*p) <= 59u )
				goto st38;
		} else if ( (*p) > 87u ) {
			if ( (*p) > 95u ) {
				if ( 132u <= (*p) && (*p) <= 136u )
					goto tr47;
			} else if ( (*p) >= 88u )
				goto tr123;
		} else
			goto tr122;
	} else if ( (*p) > 151u ) {
		if ( (*p) < 184u ) {
			if ( 176u <= (*p) && (*p) <= 183u )
				goto tr135;
		} else if ( (*p) > 191u ) {
			if ( (*p) > 210u ) {
				if ( 216u <= (*p) && (*p) <= 223u )
					goto st103;
			} else if ( (*p) >= 208u )
				goto st101;
		} else
			goto tr136;
	} else
		goto tr133;
	goto tr33;
st700:
	if ( ++p == pe )
		goto _test_eof700;
case 700:
	switch( (*p) ) {
		case 4u: goto st2;
		case 12u: goto st2;
		case 52u: goto st2;
		case 68u: goto st8;
		case 76u: goto st8;
		case 116u: goto st8;
		case 132u: goto st9;
		case 140u: goto st9;
		case 180u: goto st9;
		case 210u: goto tr292;
		case 226u: goto tr292;
	}
	if ( (*p) < 64u ) {
		if ( (*p) < 14u ) {
			if ( (*p) > 3u ) {
				if ( 6u <= (*p) && (*p) <= 11u )
					goto tr0;
			} else
				goto tr0;
		} else if ( (*p) > 15u ) {
			if ( (*p) > 51u ) {
				if ( 54u <= (*p) && (*p) <= 55u )
					goto tr0;
			} else if ( (*p) >= 48u )
				goto tr0;
		} else
			goto tr0;
	} else if ( (*p) > 79u ) {
		if ( (*p) < 176u ) {
			if ( (*p) > 119u ) {
				if ( 128u <= (*p) && (*p) <= 143u )
					goto tr5;
			} else if ( (*p) >= 112u )
				goto tr3;
		} else if ( (*p) > 183u ) {
			if ( (*p) > 207u ) {
				if ( 240u <= (*p) && (*p) <= 247u )
					goto tr34;
			} else if ( (*p) >= 192u )
				goto tr56;
		} else
			goto tr5;
	} else
		goto tr3;
	goto tr33;
tr215:
#line 295 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(0, OperandSize32bit);
  }
#line 384 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_NAME(0, ((*p) & 0x07) |
                           ((GET_REX_PREFIX() & 0x01) << 3) |
                           (((~GET_VEX_PREFIX2()) & 0x20) >> 2));
  }
	goto st701;
st701:
	if ( ++p == pe )
		goto _test_eof701;
case 701:
#line 38852 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	if ( (*p) == 224u )
		goto tr962;
	goto tr25;
tr962:
#line 58 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_IMM_TYPE(IMM8);
    SET_IMM_PTR(p);
  }
#line 93 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    /* Restricted %rsp or %rbp must be processed by appropriate nacl-special
       instruction, not with regular instruction.  */
    if (restricted_register == REG_RSP) {
      PrintError("Incorrectly modified register %%rsp\n", begin - data);
      result = 1;
      goto error_detected;
    } else if (restricted_register == REG_RBP) {
      PrintError("Incorrectly modified register %%rbp\n", begin - data);
      result = 1;
      goto error_detected;
    }
    /* If Sandboxed Rsi is destroyed then we must note that.  */
    if (restricted_register == kSandboxedRsi) {
      if (CHECK_OPERAND(0, REG_RSI, OperandSandboxRestricted) ||
          CHECK_OPERAND(0, REG_RSI, OperandSandboxUnrestricted) ||
          CHECK_OPERAND(1, REG_RSI, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_RSI, OperandSandboxUnrestricted)) {
        restricted_register = kNoRestrictedReg;
      }
    }
    if (restricted_register == kSandboxedRsi) {
      if (CHECK_OPERAND(0, REG_RDI, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_RDI, OperandSandboxRestricted)) {
        sandboxed_rsi_restricted_rdi = begin;
        restricted_register = kSandboxedRsiRestrictedRdi;
      }
    }
    if (restricted_register != kSandboxedRsiRestrictedRdi) {
      restricted_register = kNoRestrictedReg;
      if (CHECK_OPERAND(0, REG_R15, OperandSandbox8bit) ||
          CHECK_OPERAND(0, REG_R15, OperandSandboxRestricted) ||
          CHECK_OPERAND(0, REG_R15, OperandSandboxUnrestricted) ||
          CHECK_OPERAND(1, REG_R15, OperandSandbox8bit) ||
          CHECK_OPERAND(1, REG_R15, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_R15, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%r15\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((CHECK_OPERAND(0, REG_RBP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(0, REG_RBP, OperandSandboxUnrestricted) ||
                 (CHECK_OPERAND(1, REG_RBP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(1, REG_RBP, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%rbp\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((CHECK_OPERAND(0, REG_RSP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(0, REG_RSP, OperandSandboxUnrestricted) ||
                 (CHECK_OPERAND(1, REG_RSP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(1, REG_RSP, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%rsp\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((operand_states & 0x70) == (OperandSandboxRestricted << 5)) {
        restricted_register = operand_states & 0x0f;
      } else if ((operand_states & 0x7000) ==
                                        (OperandSandboxRestricted << (5 + 8))) {
        restricted_register = (operand_states & 0x0f00) >> 8;
      }
    }
  }
#line 337 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
       /* On successful match the instruction start must point to the next byte
        * to be able to report the new offset as the start of instruction
        * causing error.  */
       begin = p + 1;
     }
	goto st744;
st744:
	if ( ++p == pe )
		goto _test_eof744;
case 744:
#line 38940 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 0u: goto tr978;
		case 1u: goto tr979;
		case 2u: goto tr980;
		case 3u: goto tr981;
		case 4u: goto tr982;
		case 5u: goto tr983;
		case 8u: goto tr978;
		case 9u: goto tr979;
		case 10u: goto tr980;
		case 11u: goto tr981;
		case 12u: goto tr982;
		case 13u: goto tr983;
		case 15u: goto tr984;
		case 16u: goto tr978;
		case 17u: goto tr979;
		case 18u: goto tr980;
		case 19u: goto tr981;
		case 20u: goto tr982;
		case 21u: goto tr983;
		case 24u: goto tr978;
		case 25u: goto tr979;
		case 26u: goto tr980;
		case 27u: goto tr981;
		case 28u: goto tr982;
		case 29u: goto tr983;
		case 32u: goto tr978;
		case 33u: goto tr979;
		case 34u: goto tr980;
		case 35u: goto tr981;
		case 36u: goto tr982;
		case 37u: goto tr983;
		case 40u: goto tr978;
		case 41u: goto tr979;
		case 42u: goto tr980;
		case 43u: goto tr981;
		case 44u: goto tr982;
		case 45u: goto tr983;
		case 46u: goto tr985;
		case 48u: goto tr978;
		case 49u: goto tr979;
		case 50u: goto tr980;
		case 51u: goto tr981;
		case 52u: goto tr982;
		case 53u: goto tr983;
		case 60u: goto tr987;
		case 61u: goto tr988;
		case 62u: goto tr989;
		case 65u: goto tr991;
		case 72u: goto tr992;
		case 73u: goto tr993;
		case 74u: goto tr994;
		case 76u: goto tr996;
		case 77u: goto tr1064;
		case 99u: goto tr981;
		case 102u: goto tr999;
		case 104u: goto tr988;
		case 105u: goto tr1000;
		case 106u: goto tr987;
		case 107u: goto tr1001;
		case 128u: goto tr1003;
		case 129u: goto tr1004;
		case 131u: goto tr1005;
		case 133u: goto tr979;
		case 134u: goto tr1006;
		case 135u: goto tr1007;
		case 137u: goto tr979;
		case 138u: goto tr980;
		case 139u: goto tr981;
		case 141u: goto tr1008;
		case 143u: goto tr1009;
		case 144u: goto tr1010;
		case 155u: goto tr1010;
		case 168u: goto tr982;
		case 169u: goto tr983;
		case 192u: goto tr1017;
		case 193u: goto tr1018;
		case 196u: goto tr1019;
		case 197u: goto tr1020;
		case 198u: goto tr1021;
		case 199u: goto tr1022;
		case 200u: goto tr1023;
		case 202u: goto tr1024;
		case 203u: goto tr1010;
		case 209u: goto tr1026;
		case 211u: goto tr1026;
		case 216u: goto tr986;
		case 217u: goto tr1027;
		case 218u: goto tr1028;
		case 219u: goto tr1029;
		case 220u: goto tr1030;
		case 221u: goto tr1031;
		case 222u: goto tr1032;
		case 223u: goto tr1033;
		case 235u: goto tr1002;
		case 240u: goto tr1035;
		case 242u: goto tr1036;
		case 243u: goto tr1037;
		case 246u: goto tr1038;
		case 247u: goto tr1039;
		case 254u: goto tr1040;
		case 255u: goto tr1041;
	}
	if ( (*p) < 164u ) {
		if ( (*p) < 88u ) {
			if ( (*p) < 64u ) {
				if ( 56u <= (*p) && (*p) <= 59u )
					goto tr986;
			} else if ( (*p) > 71u ) {
				if ( (*p) > 79u ) {
					if ( 80u <= (*p) && (*p) <= 87u )
						goto tr997;
				} else if ( (*p) >= 75u )
					goto tr995;
			} else
				goto tr990;
		} else if ( (*p) > 95u ) {
			if ( (*p) < 132u ) {
				if ( 112u <= (*p) && (*p) <= 127u )
					goto tr1002;
			} else if ( (*p) > 136u ) {
				if ( (*p) > 151u ) {
					if ( 152u <= (*p) && (*p) <= 153u )
						goto tr1010;
				} else if ( (*p) >= 145u )
					goto tr1011;
			} else
				goto tr978;
		} else
			goto tr998;
	} else if ( (*p) > 167u ) {
		if ( (*p) < 184u ) {
			if ( (*p) < 172u ) {
				if ( 170u <= (*p) && (*p) <= 171u )
					goto tr1013;
			} else if ( (*p) > 173u ) {
				if ( (*p) > 175u ) {
					if ( 176u <= (*p) && (*p) <= 183u )
						goto tr1015;
				} else if ( (*p) >= 174u )
					goto tr1013;
			} else
				goto tr1014;
		} else if ( (*p) > 191u ) {
			if ( (*p) < 232u ) {
				if ( 208u <= (*p) && (*p) <= 210u )
					goto tr1025;
			} else if ( (*p) > 233u ) {
				if ( (*p) > 249u ) {
					if ( 252u <= (*p) && (*p) <= 253u )
						goto tr1010;
				} else if ( (*p) >= 244u )
					goto tr1010;
			} else
				goto tr1034;
		} else
			goto tr1016;
	} else
		goto tr1012;
	goto tr33;
tr1064:
#line 329 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
        begin = p;
        BitmapSetBit(valid_targets, p - data);
        SET_REX_PREFIX(FALSE);
        SET_VEX_PREFIX2(0xe0);
        SET_VEX_PREFIX3(0x00);
        operand_states = 0;
     }
#line 190 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_REX_PREFIX(*p);
  }
	goto st702;
st702:
	if ( ++p == pe )
		goto _test_eof702;
case 702:
#line 39120 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 1u: goto tr963;
		case 3u: goto tr221;
		case 9u: goto tr220;
		case 11u: goto tr221;
		case 15u: goto st142;
		case 17u: goto tr220;
		case 19u: goto tr221;
		case 25u: goto tr220;
		case 27u: goto tr221;
		case 33u: goto tr220;
		case 35u: goto tr221;
		case 41u: goto tr220;
		case 43u: goto tr221;
		case 49u: goto tr220;
		case 51u: goto tr221;
		case 57u: goto st38;
		case 59u: goto st38;
		case 99u: goto tr221;
		case 105u: goto tr224;
		case 107u: goto tr225;
		case 129u: goto st144;
		case 131u: goto st145;
		case 133u: goto tr220;
		case 135u: goto tr228;
		case 137u: goto tr220;
		case 139u: goto tr221;
		case 141u: goto tr230;
		case 193u: goto st150;
		case 199u: goto st151;
		case 209u: goto st152;
		case 211u: goto st152;
		case 247u: goto st153;
		case 255u: goto st154;
	}
	if ( (*p) > 151u ) {
		if ( 184u <= (*p) && (*p) <= 191u )
			goto tr235;
	} else if ( (*p) >= 145u )
		goto tr231;
	goto tr33;
tr963:
#line 298 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(0, OperandSize64bit);
  }
	goto st703;
st703:
	if ( ++p == pe )
		goto _test_eof703;
case 703:
#line 39172 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 4u: goto st2;
		case 5u: goto tr2;
		case 12u: goto st2;
		case 13u: goto tr2;
		case 20u: goto st2;
		case 21u: goto tr2;
		case 28u: goto st2;
		case 29u: goto tr2;
		case 36u: goto st2;
		case 37u: goto tr2;
		case 44u: goto st2;
		case 45u: goto tr2;
		case 52u: goto st2;
		case 53u: goto tr2;
		case 60u: goto st2;
		case 61u: goto tr2;
		case 68u: goto st8;
		case 76u: goto st8;
		case 84u: goto st8;
		case 92u: goto st8;
		case 100u: goto st8;
		case 108u: goto st8;
		case 116u: goto st8;
		case 124u: goto st8;
		case 132u: goto st9;
		case 140u: goto st9;
		case 148u: goto st9;
		case 156u: goto st9;
		case 164u: goto st9;
		case 172u: goto st9;
		case 180u: goto st9;
		case 188u: goto st9;
		case 251u: goto tr964;
	}
	if ( (*p) < 64u ) {
		if ( (*p) <= 63u )
			goto tr0;
	} else if ( (*p) > 127u ) {
		if ( 128u <= (*p) && (*p) <= 191u )
			goto tr5;
	} else
		goto tr3;
	goto tr7;
tr964:
#line 384 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_NAME(0, ((*p) & 0x07) |
                           ((GET_REX_PREFIX() & 0x01) << 3) |
                           (((~GET_VEX_PREFIX2()) & 0x20) >> 2));
  }
#line 93 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    /* Restricted %rsp or %rbp must be processed by appropriate nacl-special
       instruction, not with regular instruction.  */
    if (restricted_register == REG_RSP) {
      PrintError("Incorrectly modified register %%rsp\n", begin - data);
      result = 1;
      goto error_detected;
    } else if (restricted_register == REG_RBP) {
      PrintError("Incorrectly modified register %%rbp\n", begin - data);
      result = 1;
      goto error_detected;
    }
    /* If Sandboxed Rsi is destroyed then we must note that.  */
    if (restricted_register == kSandboxedRsi) {
      if (CHECK_OPERAND(0, REG_RSI, OperandSandboxRestricted) ||
          CHECK_OPERAND(0, REG_RSI, OperandSandboxUnrestricted) ||
          CHECK_OPERAND(1, REG_RSI, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_RSI, OperandSandboxUnrestricted)) {
        restricted_register = kNoRestrictedReg;
      }
    }
    if (restricted_register == kSandboxedRsi) {
      if (CHECK_OPERAND(0, REG_RDI, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_RDI, OperandSandboxRestricted)) {
        sandboxed_rsi_restricted_rdi = begin;
        restricted_register = kSandboxedRsiRestrictedRdi;
      }
    }
    if (restricted_register != kSandboxedRsiRestrictedRdi) {
      restricted_register = kNoRestrictedReg;
      if (CHECK_OPERAND(0, REG_R15, OperandSandbox8bit) ||
          CHECK_OPERAND(0, REG_R15, OperandSandboxRestricted) ||
          CHECK_OPERAND(0, REG_R15, OperandSandboxUnrestricted) ||
          CHECK_OPERAND(1, REG_R15, OperandSandbox8bit) ||
          CHECK_OPERAND(1, REG_R15, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_R15, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%r15\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((CHECK_OPERAND(0, REG_RBP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(0, REG_RBP, OperandSandboxUnrestricted) ||
                 (CHECK_OPERAND(1, REG_RBP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(1, REG_RBP, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%rbp\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((CHECK_OPERAND(0, REG_RSP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(0, REG_RSP, OperandSandboxUnrestricted) ||
                 (CHECK_OPERAND(1, REG_RSP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(1, REG_RSP, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%rsp\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((operand_states & 0x70) == (OperandSandboxRestricted << 5)) {
        restricted_register = operand_states & 0x0f;
      } else if ((operand_states & 0x7000) ==
                                        (OperandSandboxRestricted << (5 + 8))) {
        restricted_register = (operand_states & 0x0f00) >> 8;
      }
    }
  }
#line 337 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
       /* On successful match the instruction start must point to the next byte
        * to be able to report the new offset as the start of instruction
        * causing error.  */
       begin = p + 1;
     }
	goto st745;
st745:
	if ( ++p == pe )
		goto _test_eof745;
case 745:
#line 39302 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 0u: goto tr978;
		case 1u: goto tr979;
		case 2u: goto tr980;
		case 3u: goto tr981;
		case 4u: goto tr982;
		case 5u: goto tr983;
		case 8u: goto tr978;
		case 9u: goto tr979;
		case 10u: goto tr980;
		case 11u: goto tr981;
		case 12u: goto tr982;
		case 13u: goto tr983;
		case 15u: goto tr984;
		case 16u: goto tr978;
		case 17u: goto tr979;
		case 18u: goto tr980;
		case 19u: goto tr981;
		case 20u: goto tr982;
		case 21u: goto tr983;
		case 24u: goto tr978;
		case 25u: goto tr979;
		case 26u: goto tr980;
		case 27u: goto tr981;
		case 28u: goto tr982;
		case 29u: goto tr983;
		case 32u: goto tr978;
		case 33u: goto tr979;
		case 34u: goto tr980;
		case 35u: goto tr981;
		case 36u: goto tr982;
		case 37u: goto tr983;
		case 40u: goto tr978;
		case 41u: goto tr979;
		case 42u: goto tr980;
		case 43u: goto tr981;
		case 44u: goto tr982;
		case 45u: goto tr983;
		case 46u: goto tr985;
		case 48u: goto tr978;
		case 49u: goto tr979;
		case 50u: goto tr980;
		case 51u: goto tr981;
		case 52u: goto tr982;
		case 53u: goto tr983;
		case 60u: goto tr987;
		case 61u: goto tr988;
		case 62u: goto tr989;
		case 65u: goto tr1065;
		case 72u: goto tr992;
		case 73u: goto tr993;
		case 74u: goto tr994;
		case 76u: goto tr996;
		case 99u: goto tr981;
		case 102u: goto tr999;
		case 104u: goto tr988;
		case 105u: goto tr1000;
		case 106u: goto tr987;
		case 107u: goto tr1001;
		case 128u: goto tr1003;
		case 129u: goto tr1004;
		case 131u: goto tr1005;
		case 133u: goto tr979;
		case 134u: goto tr1006;
		case 135u: goto tr1007;
		case 137u: goto tr979;
		case 138u: goto tr980;
		case 139u: goto tr981;
		case 141u: goto tr1008;
		case 143u: goto tr1009;
		case 144u: goto tr1010;
		case 155u: goto tr1010;
		case 168u: goto tr982;
		case 169u: goto tr983;
		case 192u: goto tr1017;
		case 193u: goto tr1018;
		case 196u: goto tr1019;
		case 197u: goto tr1020;
		case 198u: goto tr1021;
		case 199u: goto tr1022;
		case 200u: goto tr1023;
		case 202u: goto tr1024;
		case 203u: goto tr1010;
		case 209u: goto tr1026;
		case 211u: goto tr1026;
		case 216u: goto tr986;
		case 217u: goto tr1027;
		case 218u: goto tr1028;
		case 219u: goto tr1029;
		case 220u: goto tr1030;
		case 221u: goto tr1031;
		case 222u: goto tr1032;
		case 223u: goto tr1033;
		case 235u: goto tr1002;
		case 240u: goto tr1035;
		case 242u: goto tr1036;
		case 243u: goto tr1037;
		case 246u: goto tr1038;
		case 247u: goto tr1039;
		case 254u: goto tr1040;
		case 255u: goto tr1041;
	}
	if ( (*p) < 164u ) {
		if ( (*p) < 88u ) {
			if ( (*p) < 64u ) {
				if ( 56u <= (*p) && (*p) <= 59u )
					goto tr986;
			} else if ( (*p) > 71u ) {
				if ( (*p) > 79u ) {
					if ( 80u <= (*p) && (*p) <= 87u )
						goto tr997;
				} else if ( (*p) >= 75u )
					goto tr995;
			} else
				goto tr990;
		} else if ( (*p) > 95u ) {
			if ( (*p) < 132u ) {
				if ( 112u <= (*p) && (*p) <= 127u )
					goto tr1002;
			} else if ( (*p) > 136u ) {
				if ( (*p) > 151u ) {
					if ( 152u <= (*p) && (*p) <= 153u )
						goto tr1010;
				} else if ( (*p) >= 145u )
					goto tr1011;
			} else
				goto tr978;
		} else
			goto tr998;
	} else if ( (*p) > 167u ) {
		if ( (*p) < 184u ) {
			if ( (*p) < 172u ) {
				if ( 170u <= (*p) && (*p) <= 171u )
					goto tr1013;
			} else if ( (*p) > 173u ) {
				if ( (*p) > 175u ) {
					if ( 176u <= (*p) && (*p) <= 183u )
						goto tr1015;
				} else if ( (*p) >= 174u )
					goto tr1013;
			} else
				goto tr1014;
		} else if ( (*p) > 191u ) {
			if ( (*p) < 232u ) {
				if ( 208u <= (*p) && (*p) <= 210u )
					goto tr1025;
			} else if ( (*p) > 233u ) {
				if ( (*p) > 249u ) {
					if ( 252u <= (*p) && (*p) <= 253u )
						goto tr1010;
				} else if ( (*p) >= 244u )
					goto tr1010;
			} else
				goto tr1034;
		} else
			goto tr1016;
	} else
		goto tr1012;
	goto tr33;
tr1065:
#line 329 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
        begin = p;
        BitmapSetBit(valid_targets, p - data);
        SET_REX_PREFIX(FALSE);
        SET_VEX_PREFIX2(0xe0);
        SET_VEX_PREFIX3(0x00);
        operand_states = 0;
     }
#line 190 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_REX_PREFIX(*p);
  }
	goto st704;
st704:
	if ( ++p == pe )
		goto _test_eof704;
case 704:
#line 39481 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 0u: goto tr47;
		case 1u: goto tr45;
		case 2u: goto tr120;
		case 3u: goto tr32;
		case 8u: goto tr47;
		case 9u: goto tr45;
		case 10u: goto tr120;
		case 11u: goto tr32;
		case 15u: goto st69;
		case 16u: goto tr47;
		case 17u: goto tr45;
		case 18u: goto tr120;
		case 19u: goto tr32;
		case 24u: goto tr47;
		case 25u: goto tr45;
		case 26u: goto tr120;
		case 27u: goto tr32;
		case 32u: goto tr47;
		case 33u: goto tr45;
		case 34u: goto tr120;
		case 35u: goto tr32;
		case 40u: goto tr47;
		case 41u: goto tr45;
		case 42u: goto tr120;
		case 43u: goto tr32;
		case 48u: goto tr47;
		case 49u: goto tr45;
		case 50u: goto tr120;
		case 51u: goto tr32;
		case 99u: goto tr32;
		case 105u: goto tr124;
		case 107u: goto tr125;
		case 128u: goto st89;
		case 129u: goto st90;
		case 131u: goto st112;
		case 133u: goto tr45;
		case 134u: goto tr129;
		case 135u: goto tr130;
		case 137u: goto tr45;
		case 138u: goto tr120;
		case 139u: goto tr32;
		case 141u: goto tr131;
		case 143u: goto st94;
		case 155u: goto st95;
		case 192u: goto st97;
		case 193u: goto st98;
		case 198u: goto st99;
		case 199u: goto st100;
		case 209u: goto st102;
		case 211u: goto st102;
		case 217u: goto st104;
		case 219u: goto st105;
		case 221u: goto st106;
		case 246u: goto st107;
		case 247u: goto st108;
		case 254u: goto st109;
		case 255u: goto st705;
	}
	if ( (*p) < 145u ) {
		if ( (*p) < 80u ) {
			if ( 56u <= (*p) && (*p) <= 59u )
				goto st38;
		} else if ( (*p) > 87u ) {
			if ( (*p) > 95u ) {
				if ( 132u <= (*p) && (*p) <= 136u )
					goto tr47;
			} else if ( (*p) >= 88u )
				goto tr123;
		} else
			goto tr122;
	} else if ( (*p) > 151u ) {
		if ( (*p) < 184u ) {
			if ( 176u <= (*p) && (*p) <= 183u )
				goto tr135;
		} else if ( (*p) > 191u ) {
			if ( (*p) > 210u ) {
				if ( 216u <= (*p) && (*p) <= 223u )
					goto st103;
			} else if ( (*p) >= 208u )
				goto st101;
		} else
			goto tr136;
	} else
		goto tr133;
	goto tr33;
st705:
	if ( ++p == pe )
		goto _test_eof705;
case 705:
	switch( (*p) ) {
		case 4u: goto st2;
		case 12u: goto st2;
		case 52u: goto st2;
		case 68u: goto st8;
		case 76u: goto st8;
		case 116u: goto st8;
		case 132u: goto st9;
		case 140u: goto st9;
		case 180u: goto st9;
		case 211u: goto tr292;
		case 227u: goto tr292;
	}
	if ( (*p) < 64u ) {
		if ( (*p) < 14u ) {
			if ( (*p) > 3u ) {
				if ( 6u <= (*p) && (*p) <= 11u )
					goto tr0;
			} else
				goto tr0;
		} else if ( (*p) > 15u ) {
			if ( (*p) > 51u ) {
				if ( 54u <= (*p) && (*p) <= 55u )
					goto tr0;
			} else if ( (*p) >= 48u )
				goto tr0;
		} else
			goto tr0;
	} else if ( (*p) > 79u ) {
		if ( (*p) < 176u ) {
			if ( (*p) > 119u ) {
				if ( 128u <= (*p) && (*p) <= 143u )
					goto tr5;
			} else if ( (*p) >= 112u )
				goto tr3;
		} else if ( (*p) > 183u ) {
			if ( (*p) > 207u ) {
				if ( 240u <= (*p) && (*p) <= 247u )
					goto tr34;
			} else if ( (*p) >= 192u )
				goto tr56;
		} else
			goto tr5;
	} else
		goto tr3;
	goto tr33;
tr216:
#line 295 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(0, OperandSize32bit);
  }
#line 384 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_NAME(0, ((*p) & 0x07) |
                           ((GET_REX_PREFIX() & 0x01) << 3) |
                           (((~GET_VEX_PREFIX2()) & 0x20) >> 2));
  }
	goto st706;
st706:
	if ( ++p == pe )
		goto _test_eof706;
case 706:
#line 39634 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	if ( (*p) == 224u )
		goto tr966;
	goto tr25;
tr966:
#line 58 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_IMM_TYPE(IMM8);
    SET_IMM_PTR(p);
  }
#line 93 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    /* Restricted %rsp or %rbp must be processed by appropriate nacl-special
       instruction, not with regular instruction.  */
    if (restricted_register == REG_RSP) {
      PrintError("Incorrectly modified register %%rsp\n", begin - data);
      result = 1;
      goto error_detected;
    } else if (restricted_register == REG_RBP) {
      PrintError("Incorrectly modified register %%rbp\n", begin - data);
      result = 1;
      goto error_detected;
    }
    /* If Sandboxed Rsi is destroyed then we must note that.  */
    if (restricted_register == kSandboxedRsi) {
      if (CHECK_OPERAND(0, REG_RSI, OperandSandboxRestricted) ||
          CHECK_OPERAND(0, REG_RSI, OperandSandboxUnrestricted) ||
          CHECK_OPERAND(1, REG_RSI, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_RSI, OperandSandboxUnrestricted)) {
        restricted_register = kNoRestrictedReg;
      }
    }
    if (restricted_register == kSandboxedRsi) {
      if (CHECK_OPERAND(0, REG_RDI, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_RDI, OperandSandboxRestricted)) {
        sandboxed_rsi_restricted_rdi = begin;
        restricted_register = kSandboxedRsiRestrictedRdi;
      }
    }
    if (restricted_register != kSandboxedRsiRestrictedRdi) {
      restricted_register = kNoRestrictedReg;
      if (CHECK_OPERAND(0, REG_R15, OperandSandbox8bit) ||
          CHECK_OPERAND(0, REG_R15, OperandSandboxRestricted) ||
          CHECK_OPERAND(0, REG_R15, OperandSandboxUnrestricted) ||
          CHECK_OPERAND(1, REG_R15, OperandSandbox8bit) ||
          CHECK_OPERAND(1, REG_R15, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_R15, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%r15\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((CHECK_OPERAND(0, REG_RBP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(0, REG_RBP, OperandSandboxUnrestricted) ||
                 (CHECK_OPERAND(1, REG_RBP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(1, REG_RBP, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%rbp\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((CHECK_OPERAND(0, REG_RSP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(0, REG_RSP, OperandSandboxUnrestricted) ||
                 (CHECK_OPERAND(1, REG_RSP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(1, REG_RSP, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%rsp\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((operand_states & 0x70) == (OperandSandboxRestricted << 5)) {
        restricted_register = operand_states & 0x0f;
      } else if ((operand_states & 0x7000) ==
                                        (OperandSandboxRestricted << (5 + 8))) {
        restricted_register = (operand_states & 0x0f00) >> 8;
      }
    }
  }
#line 337 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
       /* On successful match the instruction start must point to the next byte
        * to be able to report the new offset as the start of instruction
        * causing error.  */
       begin = p + 1;
     }
	goto st746;
st746:
	if ( ++p == pe )
		goto _test_eof746;
case 746:
#line 39722 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 0u: goto tr978;
		case 1u: goto tr979;
		case 2u: goto tr980;
		case 3u: goto tr981;
		case 4u: goto tr982;
		case 5u: goto tr983;
		case 8u: goto tr978;
		case 9u: goto tr979;
		case 10u: goto tr980;
		case 11u: goto tr981;
		case 12u: goto tr982;
		case 13u: goto tr983;
		case 15u: goto tr984;
		case 16u: goto tr978;
		case 17u: goto tr979;
		case 18u: goto tr980;
		case 19u: goto tr981;
		case 20u: goto tr982;
		case 21u: goto tr983;
		case 24u: goto tr978;
		case 25u: goto tr979;
		case 26u: goto tr980;
		case 27u: goto tr981;
		case 28u: goto tr982;
		case 29u: goto tr983;
		case 32u: goto tr978;
		case 33u: goto tr979;
		case 34u: goto tr980;
		case 35u: goto tr981;
		case 36u: goto tr982;
		case 37u: goto tr983;
		case 40u: goto tr978;
		case 41u: goto tr979;
		case 42u: goto tr980;
		case 43u: goto tr981;
		case 44u: goto tr982;
		case 45u: goto tr983;
		case 46u: goto tr985;
		case 48u: goto tr978;
		case 49u: goto tr979;
		case 50u: goto tr980;
		case 51u: goto tr981;
		case 52u: goto tr982;
		case 53u: goto tr983;
		case 60u: goto tr987;
		case 61u: goto tr988;
		case 62u: goto tr989;
		case 65u: goto tr991;
		case 72u: goto tr992;
		case 73u: goto tr993;
		case 74u: goto tr994;
		case 76u: goto tr996;
		case 77u: goto tr1066;
		case 99u: goto tr981;
		case 102u: goto tr999;
		case 104u: goto tr988;
		case 105u: goto tr1000;
		case 106u: goto tr987;
		case 107u: goto tr1001;
		case 128u: goto tr1003;
		case 129u: goto tr1004;
		case 131u: goto tr1005;
		case 133u: goto tr979;
		case 134u: goto tr1006;
		case 135u: goto tr1007;
		case 137u: goto tr979;
		case 138u: goto tr980;
		case 139u: goto tr981;
		case 141u: goto tr1008;
		case 143u: goto tr1009;
		case 144u: goto tr1010;
		case 155u: goto tr1010;
		case 168u: goto tr982;
		case 169u: goto tr983;
		case 192u: goto tr1017;
		case 193u: goto tr1018;
		case 196u: goto tr1019;
		case 197u: goto tr1020;
		case 198u: goto tr1021;
		case 199u: goto tr1022;
		case 200u: goto tr1023;
		case 202u: goto tr1024;
		case 203u: goto tr1010;
		case 209u: goto tr1026;
		case 211u: goto tr1026;
		case 216u: goto tr986;
		case 217u: goto tr1027;
		case 218u: goto tr1028;
		case 219u: goto tr1029;
		case 220u: goto tr1030;
		case 221u: goto tr1031;
		case 222u: goto tr1032;
		case 223u: goto tr1033;
		case 235u: goto tr1002;
		case 240u: goto tr1035;
		case 242u: goto tr1036;
		case 243u: goto tr1037;
		case 246u: goto tr1038;
		case 247u: goto tr1039;
		case 254u: goto tr1040;
		case 255u: goto tr1041;
	}
	if ( (*p) < 164u ) {
		if ( (*p) < 88u ) {
			if ( (*p) < 64u ) {
				if ( 56u <= (*p) && (*p) <= 59u )
					goto tr986;
			} else if ( (*p) > 71u ) {
				if ( (*p) > 79u ) {
					if ( 80u <= (*p) && (*p) <= 87u )
						goto tr997;
				} else if ( (*p) >= 75u )
					goto tr995;
			} else
				goto tr990;
		} else if ( (*p) > 95u ) {
			if ( (*p) < 132u ) {
				if ( 112u <= (*p) && (*p) <= 127u )
					goto tr1002;
			} else if ( (*p) > 136u ) {
				if ( (*p) > 151u ) {
					if ( 152u <= (*p) && (*p) <= 153u )
						goto tr1010;
				} else if ( (*p) >= 145u )
					goto tr1011;
			} else
				goto tr978;
		} else
			goto tr998;
	} else if ( (*p) > 167u ) {
		if ( (*p) < 184u ) {
			if ( (*p) < 172u ) {
				if ( 170u <= (*p) && (*p) <= 171u )
					goto tr1013;
			} else if ( (*p) > 173u ) {
				if ( (*p) > 175u ) {
					if ( 176u <= (*p) && (*p) <= 183u )
						goto tr1015;
				} else if ( (*p) >= 174u )
					goto tr1013;
			} else
				goto tr1014;
		} else if ( (*p) > 191u ) {
			if ( (*p) < 232u ) {
				if ( 208u <= (*p) && (*p) <= 210u )
					goto tr1025;
			} else if ( (*p) > 233u ) {
				if ( (*p) > 249u ) {
					if ( 252u <= (*p) && (*p) <= 253u )
						goto tr1010;
				} else if ( (*p) >= 244u )
					goto tr1010;
			} else
				goto tr1034;
		} else
			goto tr1016;
	} else
		goto tr1012;
	goto tr33;
tr1066:
#line 329 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
        begin = p;
        BitmapSetBit(valid_targets, p - data);
        SET_REX_PREFIX(FALSE);
        SET_VEX_PREFIX2(0xe0);
        SET_VEX_PREFIX3(0x00);
        operand_states = 0;
     }
#line 190 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_REX_PREFIX(*p);
  }
	goto st707;
st707:
	if ( ++p == pe )
		goto _test_eof707;
case 707:
#line 39902 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 1u: goto tr967;
		case 3u: goto tr221;
		case 9u: goto tr220;
		case 11u: goto tr221;
		case 15u: goto st142;
		case 17u: goto tr220;
		case 19u: goto tr221;
		case 25u: goto tr220;
		case 27u: goto tr221;
		case 33u: goto tr220;
		case 35u: goto tr221;
		case 41u: goto tr220;
		case 43u: goto tr221;
		case 49u: goto tr220;
		case 51u: goto tr221;
		case 57u: goto st38;
		case 59u: goto st38;
		case 99u: goto tr221;
		case 105u: goto tr224;
		case 107u: goto tr225;
		case 129u: goto st144;
		case 131u: goto st145;
		case 133u: goto tr220;
		case 135u: goto tr228;
		case 137u: goto tr220;
		case 139u: goto tr221;
		case 141u: goto tr230;
		case 193u: goto st150;
		case 199u: goto st151;
		case 209u: goto st152;
		case 211u: goto st152;
		case 247u: goto st153;
		case 255u: goto st154;
	}
	if ( (*p) > 151u ) {
		if ( 184u <= (*p) && (*p) <= 191u )
			goto tr235;
	} else if ( (*p) >= 145u )
		goto tr231;
	goto tr33;
tr967:
#line 298 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(0, OperandSize64bit);
  }
	goto st708;
st708:
	if ( ++p == pe )
		goto _test_eof708;
case 708:
#line 39954 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 4u: goto st2;
		case 5u: goto tr2;
		case 12u: goto st2;
		case 13u: goto tr2;
		case 20u: goto st2;
		case 21u: goto tr2;
		case 28u: goto st2;
		case 29u: goto tr2;
		case 36u: goto st2;
		case 37u: goto tr2;
		case 44u: goto st2;
		case 45u: goto tr2;
		case 52u: goto st2;
		case 53u: goto tr2;
		case 60u: goto st2;
		case 61u: goto tr2;
		case 68u: goto st8;
		case 76u: goto st8;
		case 84u: goto st8;
		case 92u: goto st8;
		case 100u: goto st8;
		case 108u: goto st8;
		case 116u: goto st8;
		case 124u: goto st8;
		case 132u: goto st9;
		case 140u: goto st9;
		case 148u: goto st9;
		case 156u: goto st9;
		case 164u: goto st9;
		case 172u: goto st9;
		case 180u: goto st9;
		case 188u: goto st9;
		case 252u: goto tr968;
	}
	if ( (*p) < 64u ) {
		if ( (*p) <= 63u )
			goto tr0;
	} else if ( (*p) > 127u ) {
		if ( 128u <= (*p) && (*p) <= 191u )
			goto tr5;
	} else
		goto tr3;
	goto tr7;
tr968:
#line 384 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_NAME(0, ((*p) & 0x07) |
                           ((GET_REX_PREFIX() & 0x01) << 3) |
                           (((~GET_VEX_PREFIX2()) & 0x20) >> 2));
  }
#line 93 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    /* Restricted %rsp or %rbp must be processed by appropriate nacl-special
       instruction, not with regular instruction.  */
    if (restricted_register == REG_RSP) {
      PrintError("Incorrectly modified register %%rsp\n", begin - data);
      result = 1;
      goto error_detected;
    } else if (restricted_register == REG_RBP) {
      PrintError("Incorrectly modified register %%rbp\n", begin - data);
      result = 1;
      goto error_detected;
    }
    /* If Sandboxed Rsi is destroyed then we must note that.  */
    if (restricted_register == kSandboxedRsi) {
      if (CHECK_OPERAND(0, REG_RSI, OperandSandboxRestricted) ||
          CHECK_OPERAND(0, REG_RSI, OperandSandboxUnrestricted) ||
          CHECK_OPERAND(1, REG_RSI, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_RSI, OperandSandboxUnrestricted)) {
        restricted_register = kNoRestrictedReg;
      }
    }
    if (restricted_register == kSandboxedRsi) {
      if (CHECK_OPERAND(0, REG_RDI, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_RDI, OperandSandboxRestricted)) {
        sandboxed_rsi_restricted_rdi = begin;
        restricted_register = kSandboxedRsiRestrictedRdi;
      }
    }
    if (restricted_register != kSandboxedRsiRestrictedRdi) {
      restricted_register = kNoRestrictedReg;
      if (CHECK_OPERAND(0, REG_R15, OperandSandbox8bit) ||
          CHECK_OPERAND(0, REG_R15, OperandSandboxRestricted) ||
          CHECK_OPERAND(0, REG_R15, OperandSandboxUnrestricted) ||
          CHECK_OPERAND(1, REG_R15, OperandSandbox8bit) ||
          CHECK_OPERAND(1, REG_R15, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_R15, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%r15\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((CHECK_OPERAND(0, REG_RBP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(0, REG_RBP, OperandSandboxUnrestricted) ||
                 (CHECK_OPERAND(1, REG_RBP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(1, REG_RBP, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%rbp\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((CHECK_OPERAND(0, REG_RSP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(0, REG_RSP, OperandSandboxUnrestricted) ||
                 (CHECK_OPERAND(1, REG_RSP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(1, REG_RSP, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%rsp\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((operand_states & 0x70) == (OperandSandboxRestricted << 5)) {
        restricted_register = operand_states & 0x0f;
      } else if ((operand_states & 0x7000) ==
                                        (OperandSandboxRestricted << (5 + 8))) {
        restricted_register = (operand_states & 0x0f00) >> 8;
      }
    }
  }
#line 337 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
       /* On successful match the instruction start must point to the next byte
        * to be able to report the new offset as the start of instruction
        * causing error.  */
       begin = p + 1;
     }
	goto st747;
st747:
	if ( ++p == pe )
		goto _test_eof747;
case 747:
#line 40084 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 0u: goto tr978;
		case 1u: goto tr979;
		case 2u: goto tr980;
		case 3u: goto tr981;
		case 4u: goto tr982;
		case 5u: goto tr983;
		case 8u: goto tr978;
		case 9u: goto tr979;
		case 10u: goto tr980;
		case 11u: goto tr981;
		case 12u: goto tr982;
		case 13u: goto tr983;
		case 15u: goto tr984;
		case 16u: goto tr978;
		case 17u: goto tr979;
		case 18u: goto tr980;
		case 19u: goto tr981;
		case 20u: goto tr982;
		case 21u: goto tr983;
		case 24u: goto tr978;
		case 25u: goto tr979;
		case 26u: goto tr980;
		case 27u: goto tr981;
		case 28u: goto tr982;
		case 29u: goto tr983;
		case 32u: goto tr978;
		case 33u: goto tr979;
		case 34u: goto tr980;
		case 35u: goto tr981;
		case 36u: goto tr982;
		case 37u: goto tr983;
		case 40u: goto tr978;
		case 41u: goto tr979;
		case 42u: goto tr980;
		case 43u: goto tr981;
		case 44u: goto tr982;
		case 45u: goto tr983;
		case 46u: goto tr985;
		case 48u: goto tr978;
		case 49u: goto tr979;
		case 50u: goto tr980;
		case 51u: goto tr981;
		case 52u: goto tr982;
		case 53u: goto tr983;
		case 60u: goto tr987;
		case 61u: goto tr988;
		case 62u: goto tr989;
		case 65u: goto tr1067;
		case 72u: goto tr992;
		case 73u: goto tr993;
		case 74u: goto tr994;
		case 76u: goto tr996;
		case 99u: goto tr981;
		case 102u: goto tr999;
		case 104u: goto tr988;
		case 105u: goto tr1000;
		case 106u: goto tr987;
		case 107u: goto tr1001;
		case 128u: goto tr1003;
		case 129u: goto tr1004;
		case 131u: goto tr1005;
		case 133u: goto tr979;
		case 134u: goto tr1006;
		case 135u: goto tr1007;
		case 137u: goto tr979;
		case 138u: goto tr980;
		case 139u: goto tr981;
		case 141u: goto tr1008;
		case 143u: goto tr1009;
		case 144u: goto tr1010;
		case 155u: goto tr1010;
		case 168u: goto tr982;
		case 169u: goto tr983;
		case 192u: goto tr1017;
		case 193u: goto tr1018;
		case 196u: goto tr1019;
		case 197u: goto tr1020;
		case 198u: goto tr1021;
		case 199u: goto tr1022;
		case 200u: goto tr1023;
		case 202u: goto tr1024;
		case 203u: goto tr1010;
		case 209u: goto tr1026;
		case 211u: goto tr1026;
		case 216u: goto tr986;
		case 217u: goto tr1027;
		case 218u: goto tr1028;
		case 219u: goto tr1029;
		case 220u: goto tr1030;
		case 221u: goto tr1031;
		case 222u: goto tr1032;
		case 223u: goto tr1033;
		case 235u: goto tr1002;
		case 240u: goto tr1035;
		case 242u: goto tr1036;
		case 243u: goto tr1037;
		case 246u: goto tr1038;
		case 247u: goto tr1039;
		case 254u: goto tr1040;
		case 255u: goto tr1041;
	}
	if ( (*p) < 164u ) {
		if ( (*p) < 88u ) {
			if ( (*p) < 64u ) {
				if ( 56u <= (*p) && (*p) <= 59u )
					goto tr986;
			} else if ( (*p) > 71u ) {
				if ( (*p) > 79u ) {
					if ( 80u <= (*p) && (*p) <= 87u )
						goto tr997;
				} else if ( (*p) >= 75u )
					goto tr995;
			} else
				goto tr990;
		} else if ( (*p) > 95u ) {
			if ( (*p) < 132u ) {
				if ( 112u <= (*p) && (*p) <= 127u )
					goto tr1002;
			} else if ( (*p) > 136u ) {
				if ( (*p) > 151u ) {
					if ( 152u <= (*p) && (*p) <= 153u )
						goto tr1010;
				} else if ( (*p) >= 145u )
					goto tr1011;
			} else
				goto tr978;
		} else
			goto tr998;
	} else if ( (*p) > 167u ) {
		if ( (*p) < 184u ) {
			if ( (*p) < 172u ) {
				if ( 170u <= (*p) && (*p) <= 171u )
					goto tr1013;
			} else if ( (*p) > 173u ) {
				if ( (*p) > 175u ) {
					if ( 176u <= (*p) && (*p) <= 183u )
						goto tr1015;
				} else if ( (*p) >= 174u )
					goto tr1013;
			} else
				goto tr1014;
		} else if ( (*p) > 191u ) {
			if ( (*p) < 232u ) {
				if ( 208u <= (*p) && (*p) <= 210u )
					goto tr1025;
			} else if ( (*p) > 233u ) {
				if ( (*p) > 249u ) {
					if ( 252u <= (*p) && (*p) <= 253u )
						goto tr1010;
				} else if ( (*p) >= 244u )
					goto tr1010;
			} else
				goto tr1034;
		} else
			goto tr1016;
	} else
		goto tr1012;
	goto tr33;
tr1067:
#line 329 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
        begin = p;
        BitmapSetBit(valid_targets, p - data);
        SET_REX_PREFIX(FALSE);
        SET_VEX_PREFIX2(0xe0);
        SET_VEX_PREFIX3(0x00);
        operand_states = 0;
     }
#line 190 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_REX_PREFIX(*p);
  }
	goto st709;
st709:
	if ( ++p == pe )
		goto _test_eof709;
case 709:
#line 40263 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 0u: goto tr47;
		case 1u: goto tr45;
		case 2u: goto tr120;
		case 3u: goto tr32;
		case 8u: goto tr47;
		case 9u: goto tr45;
		case 10u: goto tr120;
		case 11u: goto tr32;
		case 15u: goto st69;
		case 16u: goto tr47;
		case 17u: goto tr45;
		case 18u: goto tr120;
		case 19u: goto tr32;
		case 24u: goto tr47;
		case 25u: goto tr45;
		case 26u: goto tr120;
		case 27u: goto tr32;
		case 32u: goto tr47;
		case 33u: goto tr45;
		case 34u: goto tr120;
		case 35u: goto tr32;
		case 40u: goto tr47;
		case 41u: goto tr45;
		case 42u: goto tr120;
		case 43u: goto tr32;
		case 48u: goto tr47;
		case 49u: goto tr45;
		case 50u: goto tr120;
		case 51u: goto tr32;
		case 99u: goto tr32;
		case 105u: goto tr124;
		case 107u: goto tr125;
		case 128u: goto st89;
		case 129u: goto st90;
		case 131u: goto st112;
		case 133u: goto tr45;
		case 134u: goto tr129;
		case 135u: goto tr130;
		case 137u: goto tr45;
		case 138u: goto tr120;
		case 139u: goto tr32;
		case 141u: goto tr131;
		case 143u: goto st94;
		case 155u: goto st95;
		case 192u: goto st97;
		case 193u: goto st98;
		case 198u: goto st99;
		case 199u: goto st100;
		case 209u: goto st102;
		case 211u: goto st102;
		case 217u: goto st104;
		case 219u: goto st105;
		case 221u: goto st106;
		case 246u: goto st107;
		case 247u: goto st108;
		case 254u: goto st109;
		case 255u: goto st710;
	}
	if ( (*p) < 145u ) {
		if ( (*p) < 80u ) {
			if ( 56u <= (*p) && (*p) <= 59u )
				goto st38;
		} else if ( (*p) > 87u ) {
			if ( (*p) > 95u ) {
				if ( 132u <= (*p) && (*p) <= 136u )
					goto tr47;
			} else if ( (*p) >= 88u )
				goto tr123;
		} else
			goto tr122;
	} else if ( (*p) > 151u ) {
		if ( (*p) < 184u ) {
			if ( 176u <= (*p) && (*p) <= 183u )
				goto tr135;
		} else if ( (*p) > 191u ) {
			if ( (*p) > 210u ) {
				if ( 216u <= (*p) && (*p) <= 223u )
					goto st103;
			} else if ( (*p) >= 208u )
				goto st101;
		} else
			goto tr136;
	} else
		goto tr133;
	goto tr33;
st710:
	if ( ++p == pe )
		goto _test_eof710;
case 710:
	switch( (*p) ) {
		case 4u: goto st2;
		case 12u: goto st2;
		case 52u: goto st2;
		case 68u: goto st8;
		case 76u: goto st8;
		case 116u: goto st8;
		case 132u: goto st9;
		case 140u: goto st9;
		case 180u: goto st9;
		case 212u: goto tr292;
		case 228u: goto tr292;
	}
	if ( (*p) < 64u ) {
		if ( (*p) < 14u ) {
			if ( (*p) > 3u ) {
				if ( 6u <= (*p) && (*p) <= 11u )
					goto tr0;
			} else
				goto tr0;
		} else if ( (*p) > 15u ) {
			if ( (*p) > 51u ) {
				if ( 54u <= (*p) && (*p) <= 55u )
					goto tr0;
			} else if ( (*p) >= 48u )
				goto tr0;
		} else
			goto tr0;
	} else if ( (*p) > 79u ) {
		if ( (*p) < 176u ) {
			if ( (*p) > 119u ) {
				if ( 128u <= (*p) && (*p) <= 143u )
					goto tr5;
			} else if ( (*p) >= 112u )
				goto tr3;
		} else if ( (*p) > 183u ) {
			if ( (*p) > 207u ) {
				if ( 240u <= (*p) && (*p) <= 247u )
					goto tr34;
			} else if ( (*p) >= 192u )
				goto tr56;
		} else
			goto tr5;
	} else
		goto tr3;
	goto tr33;
tr217:
#line 295 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(0, OperandSize32bit);
  }
#line 384 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_NAME(0, ((*p) & 0x07) |
                           ((GET_REX_PREFIX() & 0x01) << 3) |
                           (((~GET_VEX_PREFIX2()) & 0x20) >> 2));
  }
	goto st711;
st711:
	if ( ++p == pe )
		goto _test_eof711;
case 711:
#line 40416 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	if ( (*p) == 224u )
		goto tr970;
	goto tr25;
tr970:
#line 58 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_IMM_TYPE(IMM8);
    SET_IMM_PTR(p);
  }
#line 93 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    /* Restricted %rsp or %rbp must be processed by appropriate nacl-special
       instruction, not with regular instruction.  */
    if (restricted_register == REG_RSP) {
      PrintError("Incorrectly modified register %%rsp\n", begin - data);
      result = 1;
      goto error_detected;
    } else if (restricted_register == REG_RBP) {
      PrintError("Incorrectly modified register %%rbp\n", begin - data);
      result = 1;
      goto error_detected;
    }
    /* If Sandboxed Rsi is destroyed then we must note that.  */
    if (restricted_register == kSandboxedRsi) {
      if (CHECK_OPERAND(0, REG_RSI, OperandSandboxRestricted) ||
          CHECK_OPERAND(0, REG_RSI, OperandSandboxUnrestricted) ||
          CHECK_OPERAND(1, REG_RSI, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_RSI, OperandSandboxUnrestricted)) {
        restricted_register = kNoRestrictedReg;
      }
    }
    if (restricted_register == kSandboxedRsi) {
      if (CHECK_OPERAND(0, REG_RDI, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_RDI, OperandSandboxRestricted)) {
        sandboxed_rsi_restricted_rdi = begin;
        restricted_register = kSandboxedRsiRestrictedRdi;
      }
    }
    if (restricted_register != kSandboxedRsiRestrictedRdi) {
      restricted_register = kNoRestrictedReg;
      if (CHECK_OPERAND(0, REG_R15, OperandSandbox8bit) ||
          CHECK_OPERAND(0, REG_R15, OperandSandboxRestricted) ||
          CHECK_OPERAND(0, REG_R15, OperandSandboxUnrestricted) ||
          CHECK_OPERAND(1, REG_R15, OperandSandbox8bit) ||
          CHECK_OPERAND(1, REG_R15, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_R15, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%r15\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((CHECK_OPERAND(0, REG_RBP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(0, REG_RBP, OperandSandboxUnrestricted) ||
                 (CHECK_OPERAND(1, REG_RBP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(1, REG_RBP, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%rbp\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((CHECK_OPERAND(0, REG_RSP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(0, REG_RSP, OperandSandboxUnrestricted) ||
                 (CHECK_OPERAND(1, REG_RSP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(1, REG_RSP, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%rsp\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((operand_states & 0x70) == (OperandSandboxRestricted << 5)) {
        restricted_register = operand_states & 0x0f;
      } else if ((operand_states & 0x7000) ==
                                        (OperandSandboxRestricted << (5 + 8))) {
        restricted_register = (operand_states & 0x0f00) >> 8;
      }
    }
  }
#line 337 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
       /* On successful match the instruction start must point to the next byte
        * to be able to report the new offset as the start of instruction
        * causing error.  */
       begin = p + 1;
     }
	goto st748;
st748:
	if ( ++p == pe )
		goto _test_eof748;
case 748:
#line 40504 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 0u: goto tr978;
		case 1u: goto tr979;
		case 2u: goto tr980;
		case 3u: goto tr981;
		case 4u: goto tr982;
		case 5u: goto tr983;
		case 8u: goto tr978;
		case 9u: goto tr979;
		case 10u: goto tr980;
		case 11u: goto tr981;
		case 12u: goto tr982;
		case 13u: goto tr983;
		case 15u: goto tr984;
		case 16u: goto tr978;
		case 17u: goto tr979;
		case 18u: goto tr980;
		case 19u: goto tr981;
		case 20u: goto tr982;
		case 21u: goto tr983;
		case 24u: goto tr978;
		case 25u: goto tr979;
		case 26u: goto tr980;
		case 27u: goto tr981;
		case 28u: goto tr982;
		case 29u: goto tr983;
		case 32u: goto tr978;
		case 33u: goto tr979;
		case 34u: goto tr980;
		case 35u: goto tr981;
		case 36u: goto tr982;
		case 37u: goto tr983;
		case 40u: goto tr978;
		case 41u: goto tr979;
		case 42u: goto tr980;
		case 43u: goto tr981;
		case 44u: goto tr982;
		case 45u: goto tr983;
		case 46u: goto tr985;
		case 48u: goto tr978;
		case 49u: goto tr979;
		case 50u: goto tr980;
		case 51u: goto tr981;
		case 52u: goto tr982;
		case 53u: goto tr983;
		case 60u: goto tr987;
		case 61u: goto tr988;
		case 62u: goto tr989;
		case 65u: goto tr991;
		case 72u: goto tr992;
		case 73u: goto tr993;
		case 74u: goto tr994;
		case 76u: goto tr996;
		case 77u: goto tr1068;
		case 99u: goto tr981;
		case 102u: goto tr999;
		case 104u: goto tr988;
		case 105u: goto tr1000;
		case 106u: goto tr987;
		case 107u: goto tr1001;
		case 128u: goto tr1003;
		case 129u: goto tr1004;
		case 131u: goto tr1005;
		case 133u: goto tr979;
		case 134u: goto tr1006;
		case 135u: goto tr1007;
		case 137u: goto tr979;
		case 138u: goto tr980;
		case 139u: goto tr981;
		case 141u: goto tr1008;
		case 143u: goto tr1009;
		case 144u: goto tr1010;
		case 155u: goto tr1010;
		case 168u: goto tr982;
		case 169u: goto tr983;
		case 192u: goto tr1017;
		case 193u: goto tr1018;
		case 196u: goto tr1019;
		case 197u: goto tr1020;
		case 198u: goto tr1021;
		case 199u: goto tr1022;
		case 200u: goto tr1023;
		case 202u: goto tr1024;
		case 203u: goto tr1010;
		case 209u: goto tr1026;
		case 211u: goto tr1026;
		case 216u: goto tr986;
		case 217u: goto tr1027;
		case 218u: goto tr1028;
		case 219u: goto tr1029;
		case 220u: goto tr1030;
		case 221u: goto tr1031;
		case 222u: goto tr1032;
		case 223u: goto tr1033;
		case 235u: goto tr1002;
		case 240u: goto tr1035;
		case 242u: goto tr1036;
		case 243u: goto tr1037;
		case 246u: goto tr1038;
		case 247u: goto tr1039;
		case 254u: goto tr1040;
		case 255u: goto tr1041;
	}
	if ( (*p) < 164u ) {
		if ( (*p) < 88u ) {
			if ( (*p) < 64u ) {
				if ( 56u <= (*p) && (*p) <= 59u )
					goto tr986;
			} else if ( (*p) > 71u ) {
				if ( (*p) > 79u ) {
					if ( 80u <= (*p) && (*p) <= 87u )
						goto tr997;
				} else if ( (*p) >= 75u )
					goto tr995;
			} else
				goto tr990;
		} else if ( (*p) > 95u ) {
			if ( (*p) < 132u ) {
				if ( 112u <= (*p) && (*p) <= 127u )
					goto tr1002;
			} else if ( (*p) > 136u ) {
				if ( (*p) > 151u ) {
					if ( 152u <= (*p) && (*p) <= 153u )
						goto tr1010;
				} else if ( (*p) >= 145u )
					goto tr1011;
			} else
				goto tr978;
		} else
			goto tr998;
	} else if ( (*p) > 167u ) {
		if ( (*p) < 184u ) {
			if ( (*p) < 172u ) {
				if ( 170u <= (*p) && (*p) <= 171u )
					goto tr1013;
			} else if ( (*p) > 173u ) {
				if ( (*p) > 175u ) {
					if ( 176u <= (*p) && (*p) <= 183u )
						goto tr1015;
				} else if ( (*p) >= 174u )
					goto tr1013;
			} else
				goto tr1014;
		} else if ( (*p) > 191u ) {
			if ( (*p) < 232u ) {
				if ( 208u <= (*p) && (*p) <= 210u )
					goto tr1025;
			} else if ( (*p) > 233u ) {
				if ( (*p) > 249u ) {
					if ( 252u <= (*p) && (*p) <= 253u )
						goto tr1010;
				} else if ( (*p) >= 244u )
					goto tr1010;
			} else
				goto tr1034;
		} else
			goto tr1016;
	} else
		goto tr1012;
	goto tr33;
tr1068:
#line 329 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
        begin = p;
        BitmapSetBit(valid_targets, p - data);
        SET_REX_PREFIX(FALSE);
        SET_VEX_PREFIX2(0xe0);
        SET_VEX_PREFIX3(0x00);
        operand_states = 0;
     }
#line 190 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_REX_PREFIX(*p);
  }
	goto st712;
st712:
	if ( ++p == pe )
		goto _test_eof712;
case 712:
#line 40684 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 1u: goto tr971;
		case 3u: goto tr221;
		case 9u: goto tr220;
		case 11u: goto tr221;
		case 15u: goto st142;
		case 17u: goto tr220;
		case 19u: goto tr221;
		case 25u: goto tr220;
		case 27u: goto tr221;
		case 33u: goto tr220;
		case 35u: goto tr221;
		case 41u: goto tr220;
		case 43u: goto tr221;
		case 49u: goto tr220;
		case 51u: goto tr221;
		case 57u: goto st38;
		case 59u: goto st38;
		case 99u: goto tr221;
		case 105u: goto tr224;
		case 107u: goto tr225;
		case 129u: goto st144;
		case 131u: goto st145;
		case 133u: goto tr220;
		case 135u: goto tr228;
		case 137u: goto tr220;
		case 139u: goto tr221;
		case 141u: goto tr230;
		case 193u: goto st150;
		case 199u: goto st151;
		case 209u: goto st152;
		case 211u: goto st152;
		case 247u: goto st153;
		case 255u: goto st154;
	}
	if ( (*p) > 151u ) {
		if ( 184u <= (*p) && (*p) <= 191u )
			goto tr235;
	} else if ( (*p) >= 145u )
		goto tr231;
	goto tr33;
tr971:
#line 298 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(0, OperandSize64bit);
  }
	goto st713;
st713:
	if ( ++p == pe )
		goto _test_eof713;
case 713:
#line 40736 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 4u: goto st2;
		case 5u: goto tr2;
		case 12u: goto st2;
		case 13u: goto tr2;
		case 20u: goto st2;
		case 21u: goto tr2;
		case 28u: goto st2;
		case 29u: goto tr2;
		case 36u: goto st2;
		case 37u: goto tr2;
		case 44u: goto st2;
		case 45u: goto tr2;
		case 52u: goto st2;
		case 53u: goto tr2;
		case 60u: goto st2;
		case 61u: goto tr2;
		case 68u: goto st8;
		case 76u: goto st8;
		case 84u: goto st8;
		case 92u: goto st8;
		case 100u: goto st8;
		case 108u: goto st8;
		case 116u: goto st8;
		case 124u: goto st8;
		case 132u: goto st9;
		case 140u: goto st9;
		case 148u: goto st9;
		case 156u: goto st9;
		case 164u: goto st9;
		case 172u: goto st9;
		case 180u: goto st9;
		case 188u: goto st9;
		case 253u: goto tr972;
	}
	if ( (*p) < 64u ) {
		if ( (*p) <= 63u )
			goto tr0;
	} else if ( (*p) > 127u ) {
		if ( 128u <= (*p) && (*p) <= 191u )
			goto tr5;
	} else
		goto tr3;
	goto tr7;
tr972:
#line 384 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_NAME(0, ((*p) & 0x07) |
                           ((GET_REX_PREFIX() & 0x01) << 3) |
                           (((~GET_VEX_PREFIX2()) & 0x20) >> 2));
  }
#line 93 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    /* Restricted %rsp or %rbp must be processed by appropriate nacl-special
       instruction, not with regular instruction.  */
    if (restricted_register == REG_RSP) {
      PrintError("Incorrectly modified register %%rsp\n", begin - data);
      result = 1;
      goto error_detected;
    } else if (restricted_register == REG_RBP) {
      PrintError("Incorrectly modified register %%rbp\n", begin - data);
      result = 1;
      goto error_detected;
    }
    /* If Sandboxed Rsi is destroyed then we must note that.  */
    if (restricted_register == kSandboxedRsi) {
      if (CHECK_OPERAND(0, REG_RSI, OperandSandboxRestricted) ||
          CHECK_OPERAND(0, REG_RSI, OperandSandboxUnrestricted) ||
          CHECK_OPERAND(1, REG_RSI, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_RSI, OperandSandboxUnrestricted)) {
        restricted_register = kNoRestrictedReg;
      }
    }
    if (restricted_register == kSandboxedRsi) {
      if (CHECK_OPERAND(0, REG_RDI, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_RDI, OperandSandboxRestricted)) {
        sandboxed_rsi_restricted_rdi = begin;
        restricted_register = kSandboxedRsiRestrictedRdi;
      }
    }
    if (restricted_register != kSandboxedRsiRestrictedRdi) {
      restricted_register = kNoRestrictedReg;
      if (CHECK_OPERAND(0, REG_R15, OperandSandbox8bit) ||
          CHECK_OPERAND(0, REG_R15, OperandSandboxRestricted) ||
          CHECK_OPERAND(0, REG_R15, OperandSandboxUnrestricted) ||
          CHECK_OPERAND(1, REG_R15, OperandSandbox8bit) ||
          CHECK_OPERAND(1, REG_R15, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_R15, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%r15\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((CHECK_OPERAND(0, REG_RBP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(0, REG_RBP, OperandSandboxUnrestricted) ||
                 (CHECK_OPERAND(1, REG_RBP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(1, REG_RBP, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%rbp\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((CHECK_OPERAND(0, REG_RSP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(0, REG_RSP, OperandSandboxUnrestricted) ||
                 (CHECK_OPERAND(1, REG_RSP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(1, REG_RSP, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%rsp\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((operand_states & 0x70) == (OperandSandboxRestricted << 5)) {
        restricted_register = operand_states & 0x0f;
      } else if ((operand_states & 0x7000) ==
                                        (OperandSandboxRestricted << (5 + 8))) {
        restricted_register = (operand_states & 0x0f00) >> 8;
      }
    }
  }
#line 337 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
       /* On successful match the instruction start must point to the next byte
        * to be able to report the new offset as the start of instruction
        * causing error.  */
       begin = p + 1;
     }
	goto st749;
st749:
	if ( ++p == pe )
		goto _test_eof749;
case 749:
#line 40866 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 0u: goto tr978;
		case 1u: goto tr979;
		case 2u: goto tr980;
		case 3u: goto tr981;
		case 4u: goto tr982;
		case 5u: goto tr983;
		case 8u: goto tr978;
		case 9u: goto tr979;
		case 10u: goto tr980;
		case 11u: goto tr981;
		case 12u: goto tr982;
		case 13u: goto tr983;
		case 15u: goto tr984;
		case 16u: goto tr978;
		case 17u: goto tr979;
		case 18u: goto tr980;
		case 19u: goto tr981;
		case 20u: goto tr982;
		case 21u: goto tr983;
		case 24u: goto tr978;
		case 25u: goto tr979;
		case 26u: goto tr980;
		case 27u: goto tr981;
		case 28u: goto tr982;
		case 29u: goto tr983;
		case 32u: goto tr978;
		case 33u: goto tr979;
		case 34u: goto tr980;
		case 35u: goto tr981;
		case 36u: goto tr982;
		case 37u: goto tr983;
		case 40u: goto tr978;
		case 41u: goto tr979;
		case 42u: goto tr980;
		case 43u: goto tr981;
		case 44u: goto tr982;
		case 45u: goto tr983;
		case 46u: goto tr985;
		case 48u: goto tr978;
		case 49u: goto tr979;
		case 50u: goto tr980;
		case 51u: goto tr981;
		case 52u: goto tr982;
		case 53u: goto tr983;
		case 60u: goto tr987;
		case 61u: goto tr988;
		case 62u: goto tr989;
		case 65u: goto tr1069;
		case 72u: goto tr992;
		case 73u: goto tr993;
		case 74u: goto tr994;
		case 76u: goto tr996;
		case 99u: goto tr981;
		case 102u: goto tr999;
		case 104u: goto tr988;
		case 105u: goto tr1000;
		case 106u: goto tr987;
		case 107u: goto tr1001;
		case 128u: goto tr1003;
		case 129u: goto tr1004;
		case 131u: goto tr1005;
		case 133u: goto tr979;
		case 134u: goto tr1006;
		case 135u: goto tr1007;
		case 137u: goto tr979;
		case 138u: goto tr980;
		case 139u: goto tr981;
		case 141u: goto tr1008;
		case 143u: goto tr1009;
		case 144u: goto tr1010;
		case 155u: goto tr1010;
		case 168u: goto tr982;
		case 169u: goto tr983;
		case 192u: goto tr1017;
		case 193u: goto tr1018;
		case 196u: goto tr1019;
		case 197u: goto tr1020;
		case 198u: goto tr1021;
		case 199u: goto tr1022;
		case 200u: goto tr1023;
		case 202u: goto tr1024;
		case 203u: goto tr1010;
		case 209u: goto tr1026;
		case 211u: goto tr1026;
		case 216u: goto tr986;
		case 217u: goto tr1027;
		case 218u: goto tr1028;
		case 219u: goto tr1029;
		case 220u: goto tr1030;
		case 221u: goto tr1031;
		case 222u: goto tr1032;
		case 223u: goto tr1033;
		case 235u: goto tr1002;
		case 240u: goto tr1035;
		case 242u: goto tr1036;
		case 243u: goto tr1037;
		case 246u: goto tr1038;
		case 247u: goto tr1039;
		case 254u: goto tr1040;
		case 255u: goto tr1041;
	}
	if ( (*p) < 164u ) {
		if ( (*p) < 88u ) {
			if ( (*p) < 64u ) {
				if ( 56u <= (*p) && (*p) <= 59u )
					goto tr986;
			} else if ( (*p) > 71u ) {
				if ( (*p) > 79u ) {
					if ( 80u <= (*p) && (*p) <= 87u )
						goto tr997;
				} else if ( (*p) >= 75u )
					goto tr995;
			} else
				goto tr990;
		} else if ( (*p) > 95u ) {
			if ( (*p) < 132u ) {
				if ( 112u <= (*p) && (*p) <= 127u )
					goto tr1002;
			} else if ( (*p) > 136u ) {
				if ( (*p) > 151u ) {
					if ( 152u <= (*p) && (*p) <= 153u )
						goto tr1010;
				} else if ( (*p) >= 145u )
					goto tr1011;
			} else
				goto tr978;
		} else
			goto tr998;
	} else if ( (*p) > 167u ) {
		if ( (*p) < 184u ) {
			if ( (*p) < 172u ) {
				if ( 170u <= (*p) && (*p) <= 171u )
					goto tr1013;
			} else if ( (*p) > 173u ) {
				if ( (*p) > 175u ) {
					if ( 176u <= (*p) && (*p) <= 183u )
						goto tr1015;
				} else if ( (*p) >= 174u )
					goto tr1013;
			} else
				goto tr1014;
		} else if ( (*p) > 191u ) {
			if ( (*p) < 232u ) {
				if ( 208u <= (*p) && (*p) <= 210u )
					goto tr1025;
			} else if ( (*p) > 233u ) {
				if ( (*p) > 249u ) {
					if ( 252u <= (*p) && (*p) <= 253u )
						goto tr1010;
				} else if ( (*p) >= 244u )
					goto tr1010;
			} else
				goto tr1034;
		} else
			goto tr1016;
	} else
		goto tr1012;
	goto tr33;
tr1069:
#line 329 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
        begin = p;
        BitmapSetBit(valid_targets, p - data);
        SET_REX_PREFIX(FALSE);
        SET_VEX_PREFIX2(0xe0);
        SET_VEX_PREFIX3(0x00);
        operand_states = 0;
     }
#line 190 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_REX_PREFIX(*p);
  }
	goto st714;
st714:
	if ( ++p == pe )
		goto _test_eof714;
case 714:
#line 41045 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 0u: goto tr47;
		case 1u: goto tr45;
		case 2u: goto tr120;
		case 3u: goto tr32;
		case 8u: goto tr47;
		case 9u: goto tr45;
		case 10u: goto tr120;
		case 11u: goto tr32;
		case 15u: goto st69;
		case 16u: goto tr47;
		case 17u: goto tr45;
		case 18u: goto tr120;
		case 19u: goto tr32;
		case 24u: goto tr47;
		case 25u: goto tr45;
		case 26u: goto tr120;
		case 27u: goto tr32;
		case 32u: goto tr47;
		case 33u: goto tr45;
		case 34u: goto tr120;
		case 35u: goto tr32;
		case 40u: goto tr47;
		case 41u: goto tr45;
		case 42u: goto tr120;
		case 43u: goto tr32;
		case 48u: goto tr47;
		case 49u: goto tr45;
		case 50u: goto tr120;
		case 51u: goto tr32;
		case 99u: goto tr32;
		case 105u: goto tr124;
		case 107u: goto tr125;
		case 128u: goto st89;
		case 129u: goto st90;
		case 131u: goto st112;
		case 133u: goto tr45;
		case 134u: goto tr129;
		case 135u: goto tr130;
		case 137u: goto tr45;
		case 138u: goto tr120;
		case 139u: goto tr32;
		case 141u: goto tr131;
		case 143u: goto st94;
		case 155u: goto st95;
		case 192u: goto st97;
		case 193u: goto st98;
		case 198u: goto st99;
		case 199u: goto st100;
		case 209u: goto st102;
		case 211u: goto st102;
		case 217u: goto st104;
		case 219u: goto st105;
		case 221u: goto st106;
		case 246u: goto st107;
		case 247u: goto st108;
		case 254u: goto st109;
		case 255u: goto st715;
	}
	if ( (*p) < 145u ) {
		if ( (*p) < 80u ) {
			if ( 56u <= (*p) && (*p) <= 59u )
				goto st38;
		} else if ( (*p) > 87u ) {
			if ( (*p) > 95u ) {
				if ( 132u <= (*p) && (*p) <= 136u )
					goto tr47;
			} else if ( (*p) >= 88u )
				goto tr123;
		} else
			goto tr122;
	} else if ( (*p) > 151u ) {
		if ( (*p) < 184u ) {
			if ( 176u <= (*p) && (*p) <= 183u )
				goto tr135;
		} else if ( (*p) > 191u ) {
			if ( (*p) > 210u ) {
				if ( 216u <= (*p) && (*p) <= 223u )
					goto st103;
			} else if ( (*p) >= 208u )
				goto st101;
		} else
			goto tr136;
	} else
		goto tr133;
	goto tr33;
st715:
	if ( ++p == pe )
		goto _test_eof715;
case 715:
	switch( (*p) ) {
		case 4u: goto st2;
		case 12u: goto st2;
		case 52u: goto st2;
		case 68u: goto st8;
		case 76u: goto st8;
		case 116u: goto st8;
		case 132u: goto st9;
		case 140u: goto st9;
		case 180u: goto st9;
		case 213u: goto tr292;
		case 229u: goto tr292;
	}
	if ( (*p) < 64u ) {
		if ( (*p) < 14u ) {
			if ( (*p) > 3u ) {
				if ( 6u <= (*p) && (*p) <= 11u )
					goto tr0;
			} else
				goto tr0;
		} else if ( (*p) > 15u ) {
			if ( (*p) > 51u ) {
				if ( 54u <= (*p) && (*p) <= 55u )
					goto tr0;
			} else if ( (*p) >= 48u )
				goto tr0;
		} else
			goto tr0;
	} else if ( (*p) > 79u ) {
		if ( (*p) < 176u ) {
			if ( (*p) > 119u ) {
				if ( 128u <= (*p) && (*p) <= 143u )
					goto tr5;
			} else if ( (*p) >= 112u )
				goto tr3;
		} else if ( (*p) > 183u ) {
			if ( (*p) > 207u ) {
				if ( 240u <= (*p) && (*p) <= 247u )
					goto tr34;
			} else if ( (*p) >= 192u )
				goto tr56;
		} else
			goto tr5;
	} else
		goto tr3;
	goto tr33;
tr218:
#line 295 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(0, OperandSize32bit);
  }
#line 384 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_NAME(0, ((*p) & 0x07) |
                           ((GET_REX_PREFIX() & 0x01) << 3) |
                           (((~GET_VEX_PREFIX2()) & 0x20) >> 2));
  }
	goto st716;
st716:
	if ( ++p == pe )
		goto _test_eof716;
case 716:
#line 41198 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	if ( (*p) == 224u )
		goto tr974;
	goto tr25;
tr974:
#line 58 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_IMM_TYPE(IMM8);
    SET_IMM_PTR(p);
  }
#line 93 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    /* Restricted %rsp or %rbp must be processed by appropriate nacl-special
       instruction, not with regular instruction.  */
    if (restricted_register == REG_RSP) {
      PrintError("Incorrectly modified register %%rsp\n", begin - data);
      result = 1;
      goto error_detected;
    } else if (restricted_register == REG_RBP) {
      PrintError("Incorrectly modified register %%rbp\n", begin - data);
      result = 1;
      goto error_detected;
    }
    /* If Sandboxed Rsi is destroyed then we must note that.  */
    if (restricted_register == kSandboxedRsi) {
      if (CHECK_OPERAND(0, REG_RSI, OperandSandboxRestricted) ||
          CHECK_OPERAND(0, REG_RSI, OperandSandboxUnrestricted) ||
          CHECK_OPERAND(1, REG_RSI, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_RSI, OperandSandboxUnrestricted)) {
        restricted_register = kNoRestrictedReg;
      }
    }
    if (restricted_register == kSandboxedRsi) {
      if (CHECK_OPERAND(0, REG_RDI, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_RDI, OperandSandboxRestricted)) {
        sandboxed_rsi_restricted_rdi = begin;
        restricted_register = kSandboxedRsiRestrictedRdi;
      }
    }
    if (restricted_register != kSandboxedRsiRestrictedRdi) {
      restricted_register = kNoRestrictedReg;
      if (CHECK_OPERAND(0, REG_R15, OperandSandbox8bit) ||
          CHECK_OPERAND(0, REG_R15, OperandSandboxRestricted) ||
          CHECK_OPERAND(0, REG_R15, OperandSandboxUnrestricted) ||
          CHECK_OPERAND(1, REG_R15, OperandSandbox8bit) ||
          CHECK_OPERAND(1, REG_R15, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_R15, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%r15\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((CHECK_OPERAND(0, REG_RBP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(0, REG_RBP, OperandSandboxUnrestricted) ||
                 (CHECK_OPERAND(1, REG_RBP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(1, REG_RBP, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%rbp\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((CHECK_OPERAND(0, REG_RSP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(0, REG_RSP, OperandSandboxUnrestricted) ||
                 (CHECK_OPERAND(1, REG_RSP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(1, REG_RSP, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%rsp\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((operand_states & 0x70) == (OperandSandboxRestricted << 5)) {
        restricted_register = operand_states & 0x0f;
      } else if ((operand_states & 0x7000) ==
                                        (OperandSandboxRestricted << (5 + 8))) {
        restricted_register = (operand_states & 0x0f00) >> 8;
      }
    }
  }
#line 337 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
       /* On successful match the instruction start must point to the next byte
        * to be able to report the new offset as the start of instruction
        * causing error.  */
       begin = p + 1;
     }
	goto st750;
st750:
	if ( ++p == pe )
		goto _test_eof750;
case 750:
#line 41286 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 0u: goto tr978;
		case 1u: goto tr979;
		case 2u: goto tr980;
		case 3u: goto tr981;
		case 4u: goto tr982;
		case 5u: goto tr983;
		case 8u: goto tr978;
		case 9u: goto tr979;
		case 10u: goto tr980;
		case 11u: goto tr981;
		case 12u: goto tr982;
		case 13u: goto tr983;
		case 15u: goto tr984;
		case 16u: goto tr978;
		case 17u: goto tr979;
		case 18u: goto tr980;
		case 19u: goto tr981;
		case 20u: goto tr982;
		case 21u: goto tr983;
		case 24u: goto tr978;
		case 25u: goto tr979;
		case 26u: goto tr980;
		case 27u: goto tr981;
		case 28u: goto tr982;
		case 29u: goto tr983;
		case 32u: goto tr978;
		case 33u: goto tr979;
		case 34u: goto tr980;
		case 35u: goto tr981;
		case 36u: goto tr982;
		case 37u: goto tr983;
		case 40u: goto tr978;
		case 41u: goto tr979;
		case 42u: goto tr980;
		case 43u: goto tr981;
		case 44u: goto tr982;
		case 45u: goto tr983;
		case 46u: goto tr985;
		case 48u: goto tr978;
		case 49u: goto tr979;
		case 50u: goto tr980;
		case 51u: goto tr981;
		case 52u: goto tr982;
		case 53u: goto tr983;
		case 60u: goto tr987;
		case 61u: goto tr988;
		case 62u: goto tr989;
		case 65u: goto tr991;
		case 72u: goto tr992;
		case 73u: goto tr993;
		case 74u: goto tr994;
		case 76u: goto tr996;
		case 77u: goto tr1070;
		case 99u: goto tr981;
		case 102u: goto tr999;
		case 104u: goto tr988;
		case 105u: goto tr1000;
		case 106u: goto tr987;
		case 107u: goto tr1001;
		case 128u: goto tr1003;
		case 129u: goto tr1004;
		case 131u: goto tr1005;
		case 133u: goto tr979;
		case 134u: goto tr1006;
		case 135u: goto tr1007;
		case 137u: goto tr979;
		case 138u: goto tr980;
		case 139u: goto tr981;
		case 141u: goto tr1008;
		case 143u: goto tr1009;
		case 144u: goto tr1010;
		case 155u: goto tr1010;
		case 168u: goto tr982;
		case 169u: goto tr983;
		case 192u: goto tr1017;
		case 193u: goto tr1018;
		case 196u: goto tr1019;
		case 197u: goto tr1020;
		case 198u: goto tr1021;
		case 199u: goto tr1022;
		case 200u: goto tr1023;
		case 202u: goto tr1024;
		case 203u: goto tr1010;
		case 209u: goto tr1026;
		case 211u: goto tr1026;
		case 216u: goto tr986;
		case 217u: goto tr1027;
		case 218u: goto tr1028;
		case 219u: goto tr1029;
		case 220u: goto tr1030;
		case 221u: goto tr1031;
		case 222u: goto tr1032;
		case 223u: goto tr1033;
		case 235u: goto tr1002;
		case 240u: goto tr1035;
		case 242u: goto tr1036;
		case 243u: goto tr1037;
		case 246u: goto tr1038;
		case 247u: goto tr1039;
		case 254u: goto tr1040;
		case 255u: goto tr1041;
	}
	if ( (*p) < 164u ) {
		if ( (*p) < 88u ) {
			if ( (*p) < 64u ) {
				if ( 56u <= (*p) && (*p) <= 59u )
					goto tr986;
			} else if ( (*p) > 71u ) {
				if ( (*p) > 79u ) {
					if ( 80u <= (*p) && (*p) <= 87u )
						goto tr997;
				} else if ( (*p) >= 75u )
					goto tr995;
			} else
				goto tr990;
		} else if ( (*p) > 95u ) {
			if ( (*p) < 132u ) {
				if ( 112u <= (*p) && (*p) <= 127u )
					goto tr1002;
			} else if ( (*p) > 136u ) {
				if ( (*p) > 151u ) {
					if ( 152u <= (*p) && (*p) <= 153u )
						goto tr1010;
				} else if ( (*p) >= 145u )
					goto tr1011;
			} else
				goto tr978;
		} else
			goto tr998;
	} else if ( (*p) > 167u ) {
		if ( (*p) < 184u ) {
			if ( (*p) < 172u ) {
				if ( 170u <= (*p) && (*p) <= 171u )
					goto tr1013;
			} else if ( (*p) > 173u ) {
				if ( (*p) > 175u ) {
					if ( 176u <= (*p) && (*p) <= 183u )
						goto tr1015;
				} else if ( (*p) >= 174u )
					goto tr1013;
			} else
				goto tr1014;
		} else if ( (*p) > 191u ) {
			if ( (*p) < 232u ) {
				if ( 208u <= (*p) && (*p) <= 210u )
					goto tr1025;
			} else if ( (*p) > 233u ) {
				if ( (*p) > 249u ) {
					if ( 252u <= (*p) && (*p) <= 253u )
						goto tr1010;
				} else if ( (*p) >= 244u )
					goto tr1010;
			} else
				goto tr1034;
		} else
			goto tr1016;
	} else
		goto tr1012;
	goto tr33;
tr1070:
#line 329 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
        begin = p;
        BitmapSetBit(valid_targets, p - data);
        SET_REX_PREFIX(FALSE);
        SET_VEX_PREFIX2(0xe0);
        SET_VEX_PREFIX3(0x00);
        operand_states = 0;
     }
#line 190 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_REX_PREFIX(*p);
  }
	goto st717;
st717:
	if ( ++p == pe )
		goto _test_eof717;
case 717:
#line 41466 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 1u: goto tr975;
		case 3u: goto tr221;
		case 9u: goto tr220;
		case 11u: goto tr221;
		case 15u: goto st142;
		case 17u: goto tr220;
		case 19u: goto tr221;
		case 25u: goto tr220;
		case 27u: goto tr221;
		case 33u: goto tr220;
		case 35u: goto tr221;
		case 41u: goto tr220;
		case 43u: goto tr221;
		case 49u: goto tr220;
		case 51u: goto tr221;
		case 57u: goto st38;
		case 59u: goto st38;
		case 99u: goto tr221;
		case 105u: goto tr224;
		case 107u: goto tr225;
		case 129u: goto st144;
		case 131u: goto st145;
		case 133u: goto tr220;
		case 135u: goto tr228;
		case 137u: goto tr220;
		case 139u: goto tr221;
		case 141u: goto tr230;
		case 193u: goto st150;
		case 199u: goto st151;
		case 209u: goto st152;
		case 211u: goto st152;
		case 247u: goto st153;
		case 255u: goto st154;
	}
	if ( (*p) > 151u ) {
		if ( 184u <= (*p) && (*p) <= 191u )
			goto tr235;
	} else if ( (*p) >= 145u )
		goto tr231;
	goto tr33;
tr975:
#line 298 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_TYPE(0, OperandSize64bit);
  }
	goto st718;
st718:
	if ( ++p == pe )
		goto _test_eof718;
case 718:
#line 41518 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 4u: goto st2;
		case 5u: goto tr2;
		case 12u: goto st2;
		case 13u: goto tr2;
		case 20u: goto st2;
		case 21u: goto tr2;
		case 28u: goto st2;
		case 29u: goto tr2;
		case 36u: goto st2;
		case 37u: goto tr2;
		case 44u: goto st2;
		case 45u: goto tr2;
		case 52u: goto st2;
		case 53u: goto tr2;
		case 60u: goto st2;
		case 61u: goto tr2;
		case 68u: goto st8;
		case 76u: goto st8;
		case 84u: goto st8;
		case 92u: goto st8;
		case 100u: goto st8;
		case 108u: goto st8;
		case 116u: goto st8;
		case 124u: goto st8;
		case 132u: goto st9;
		case 140u: goto st9;
		case 148u: goto st9;
		case 156u: goto st9;
		case 164u: goto st9;
		case 172u: goto st9;
		case 180u: goto st9;
		case 188u: goto st9;
		case 254u: goto tr976;
	}
	if ( (*p) < 64u ) {
		if ( (*p) <= 63u )
			goto tr0;
	} else if ( (*p) > 127u ) {
		if ( 128u <= (*p) && (*p) <= 191u )
			goto tr5;
	} else
		goto tr3;
	goto tr7;
tr976:
#line 384 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_OPERAND_NAME(0, ((*p) & 0x07) |
                           ((GET_REX_PREFIX() & 0x01) << 3) |
                           (((~GET_VEX_PREFIX2()) & 0x20) >> 2));
  }
#line 93 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    /* Restricted %rsp or %rbp must be processed by appropriate nacl-special
       instruction, not with regular instruction.  */
    if (restricted_register == REG_RSP) {
      PrintError("Incorrectly modified register %%rsp\n", begin - data);
      result = 1;
      goto error_detected;
    } else if (restricted_register == REG_RBP) {
      PrintError("Incorrectly modified register %%rbp\n", begin - data);
      result = 1;
      goto error_detected;
    }
    /* If Sandboxed Rsi is destroyed then we must note that.  */
    if (restricted_register == kSandboxedRsi) {
      if (CHECK_OPERAND(0, REG_RSI, OperandSandboxRestricted) ||
          CHECK_OPERAND(0, REG_RSI, OperandSandboxUnrestricted) ||
          CHECK_OPERAND(1, REG_RSI, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_RSI, OperandSandboxUnrestricted)) {
        restricted_register = kNoRestrictedReg;
      }
    }
    if (restricted_register == kSandboxedRsi) {
      if (CHECK_OPERAND(0, REG_RDI, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_RDI, OperandSandboxRestricted)) {
        sandboxed_rsi_restricted_rdi = begin;
        restricted_register = kSandboxedRsiRestrictedRdi;
      }
    }
    if (restricted_register != kSandboxedRsiRestrictedRdi) {
      restricted_register = kNoRestrictedReg;
      if (CHECK_OPERAND(0, REG_R15, OperandSandbox8bit) ||
          CHECK_OPERAND(0, REG_R15, OperandSandboxRestricted) ||
          CHECK_OPERAND(0, REG_R15, OperandSandboxUnrestricted) ||
          CHECK_OPERAND(1, REG_R15, OperandSandbox8bit) ||
          CHECK_OPERAND(1, REG_R15, OperandSandboxRestricted) ||
          CHECK_OPERAND(1, REG_R15, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%r15\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((CHECK_OPERAND(0, REG_RBP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(0, REG_RBP, OperandSandboxUnrestricted) ||
                 (CHECK_OPERAND(1, REG_RBP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(1, REG_RBP, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%rbp\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((CHECK_OPERAND(0, REG_RSP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(0, REG_RSP, OperandSandboxUnrestricted) ||
                 (CHECK_OPERAND(1, REG_RSP, OperandSandbox8bit) &&
                  GET_REX_PREFIX()) ||
                 CHECK_OPERAND(1, REG_RSP, OperandSandboxUnrestricted)) {
        PrintError("Incorrectly modified register %%rsp\n", begin - data);
        result = 1;
        goto error_detected;
      } else if ((operand_states & 0x70) == (OperandSandboxRestricted << 5)) {
        restricted_register = operand_states & 0x0f;
      } else if ((operand_states & 0x7000) ==
                                        (OperandSandboxRestricted << (5 + 8))) {
        restricted_register = (operand_states & 0x0f00) >> 8;
      }
    }
  }
#line 337 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
       /* On successful match the instruction start must point to the next byte
        * to be able to report the new offset as the start of instruction
        * causing error.  */
       begin = p + 1;
     }
	goto st751;
st751:
	if ( ++p == pe )
		goto _test_eof751;
case 751:
#line 41648 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 0u: goto tr978;
		case 1u: goto tr979;
		case 2u: goto tr980;
		case 3u: goto tr981;
		case 4u: goto tr982;
		case 5u: goto tr983;
		case 8u: goto tr978;
		case 9u: goto tr979;
		case 10u: goto tr980;
		case 11u: goto tr981;
		case 12u: goto tr982;
		case 13u: goto tr983;
		case 15u: goto tr984;
		case 16u: goto tr978;
		case 17u: goto tr979;
		case 18u: goto tr980;
		case 19u: goto tr981;
		case 20u: goto tr982;
		case 21u: goto tr983;
		case 24u: goto tr978;
		case 25u: goto tr979;
		case 26u: goto tr980;
		case 27u: goto tr981;
		case 28u: goto tr982;
		case 29u: goto tr983;
		case 32u: goto tr978;
		case 33u: goto tr979;
		case 34u: goto tr980;
		case 35u: goto tr981;
		case 36u: goto tr982;
		case 37u: goto tr983;
		case 40u: goto tr978;
		case 41u: goto tr979;
		case 42u: goto tr980;
		case 43u: goto tr981;
		case 44u: goto tr982;
		case 45u: goto tr983;
		case 46u: goto tr985;
		case 48u: goto tr978;
		case 49u: goto tr979;
		case 50u: goto tr980;
		case 51u: goto tr981;
		case 52u: goto tr982;
		case 53u: goto tr983;
		case 60u: goto tr987;
		case 61u: goto tr988;
		case 62u: goto tr989;
		case 65u: goto tr1071;
		case 72u: goto tr992;
		case 73u: goto tr993;
		case 74u: goto tr994;
		case 76u: goto tr996;
		case 99u: goto tr981;
		case 102u: goto tr999;
		case 104u: goto tr988;
		case 105u: goto tr1000;
		case 106u: goto tr987;
		case 107u: goto tr1001;
		case 128u: goto tr1003;
		case 129u: goto tr1004;
		case 131u: goto tr1005;
		case 133u: goto tr979;
		case 134u: goto tr1006;
		case 135u: goto tr1007;
		case 137u: goto tr979;
		case 138u: goto tr980;
		case 139u: goto tr981;
		case 141u: goto tr1008;
		case 143u: goto tr1009;
		case 144u: goto tr1010;
		case 155u: goto tr1010;
		case 168u: goto tr982;
		case 169u: goto tr983;
		case 192u: goto tr1017;
		case 193u: goto tr1018;
		case 196u: goto tr1019;
		case 197u: goto tr1020;
		case 198u: goto tr1021;
		case 199u: goto tr1022;
		case 200u: goto tr1023;
		case 202u: goto tr1024;
		case 203u: goto tr1010;
		case 209u: goto tr1026;
		case 211u: goto tr1026;
		case 216u: goto tr986;
		case 217u: goto tr1027;
		case 218u: goto tr1028;
		case 219u: goto tr1029;
		case 220u: goto tr1030;
		case 221u: goto tr1031;
		case 222u: goto tr1032;
		case 223u: goto tr1033;
		case 235u: goto tr1002;
		case 240u: goto tr1035;
		case 242u: goto tr1036;
		case 243u: goto tr1037;
		case 246u: goto tr1038;
		case 247u: goto tr1039;
		case 254u: goto tr1040;
		case 255u: goto tr1041;
	}
	if ( (*p) < 164u ) {
		if ( (*p) < 88u ) {
			if ( (*p) < 64u ) {
				if ( 56u <= (*p) && (*p) <= 59u )
					goto tr986;
			} else if ( (*p) > 71u ) {
				if ( (*p) > 79u ) {
					if ( 80u <= (*p) && (*p) <= 87u )
						goto tr997;
				} else if ( (*p) >= 75u )
					goto tr995;
			} else
				goto tr990;
		} else if ( (*p) > 95u ) {
			if ( (*p) < 132u ) {
				if ( 112u <= (*p) && (*p) <= 127u )
					goto tr1002;
			} else if ( (*p) > 136u ) {
				if ( (*p) > 151u ) {
					if ( 152u <= (*p) && (*p) <= 153u )
						goto tr1010;
				} else if ( (*p) >= 145u )
					goto tr1011;
			} else
				goto tr978;
		} else
			goto tr998;
	} else if ( (*p) > 167u ) {
		if ( (*p) < 184u ) {
			if ( (*p) < 172u ) {
				if ( 170u <= (*p) && (*p) <= 171u )
					goto tr1013;
			} else if ( (*p) > 173u ) {
				if ( (*p) > 175u ) {
					if ( 176u <= (*p) && (*p) <= 183u )
						goto tr1015;
				} else if ( (*p) >= 174u )
					goto tr1013;
			} else
				goto tr1014;
		} else if ( (*p) > 191u ) {
			if ( (*p) < 232u ) {
				if ( 208u <= (*p) && (*p) <= 210u )
					goto tr1025;
			} else if ( (*p) > 233u ) {
				if ( (*p) > 249u ) {
					if ( 252u <= (*p) && (*p) <= 253u )
						goto tr1010;
				} else if ( (*p) >= 244u )
					goto tr1010;
			} else
				goto tr1034;
		} else
			goto tr1016;
	} else
		goto tr1012;
	goto tr33;
tr1071:
#line 329 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
        begin = p;
        BitmapSetBit(valid_targets, p - data);
        SET_REX_PREFIX(FALSE);
        SET_VEX_PREFIX2(0xe0);
        SET_VEX_PREFIX3(0x00);
        operand_states = 0;
     }
#line 190 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
    SET_REX_PREFIX(*p);
  }
	goto st719;
st719:
	if ( ++p == pe )
		goto _test_eof719;
case 719:
#line 41827 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	switch( (*p) ) {
		case 0u: goto tr47;
		case 1u: goto tr45;
		case 2u: goto tr120;
		case 3u: goto tr32;
		case 8u: goto tr47;
		case 9u: goto tr45;
		case 10u: goto tr120;
		case 11u: goto tr32;
		case 15u: goto st69;
		case 16u: goto tr47;
		case 17u: goto tr45;
		case 18u: goto tr120;
		case 19u: goto tr32;
		case 24u: goto tr47;
		case 25u: goto tr45;
		case 26u: goto tr120;
		case 27u: goto tr32;
		case 32u: goto tr47;
		case 33u: goto tr45;
		case 34u: goto tr120;
		case 35u: goto tr32;
		case 40u: goto tr47;
		case 41u: goto tr45;
		case 42u: goto tr120;
		case 43u: goto tr32;
		case 48u: goto tr47;
		case 49u: goto tr45;
		case 50u: goto tr120;
		case 51u: goto tr32;
		case 99u: goto tr32;
		case 105u: goto tr124;
		case 107u: goto tr125;
		case 128u: goto st89;
		case 129u: goto st90;
		case 131u: goto st112;
		case 133u: goto tr45;
		case 134u: goto tr129;
		case 135u: goto tr130;
		case 137u: goto tr45;
		case 138u: goto tr120;
		case 139u: goto tr32;
		case 141u: goto tr131;
		case 143u: goto st94;
		case 155u: goto st95;
		case 192u: goto st97;
		case 193u: goto st98;
		case 198u: goto st99;
		case 199u: goto st100;
		case 209u: goto st102;
		case 211u: goto st102;
		case 217u: goto st104;
		case 219u: goto st105;
		case 221u: goto st106;
		case 246u: goto st107;
		case 247u: goto st108;
		case 254u: goto st109;
		case 255u: goto st720;
	}
	if ( (*p) < 145u ) {
		if ( (*p) < 80u ) {
			if ( 56u <= (*p) && (*p) <= 59u )
				goto st38;
		} else if ( (*p) > 87u ) {
			if ( (*p) > 95u ) {
				if ( 132u <= (*p) && (*p) <= 136u )
					goto tr47;
			} else if ( (*p) >= 88u )
				goto tr123;
		} else
			goto tr122;
	} else if ( (*p) > 151u ) {
		if ( (*p) < 184u ) {
			if ( 176u <= (*p) && (*p) <= 183u )
				goto tr135;
		} else if ( (*p) > 191u ) {
			if ( (*p) > 210u ) {
				if ( 216u <= (*p) && (*p) <= 223u )
					goto st103;
			} else if ( (*p) >= 208u )
				goto st101;
		} else
			goto tr136;
	} else
		goto tr133;
	goto tr33;
st720:
	if ( ++p == pe )
		goto _test_eof720;
case 720:
	switch( (*p) ) {
		case 4u: goto st2;
		case 12u: goto st2;
		case 52u: goto st2;
		case 68u: goto st8;
		case 76u: goto st8;
		case 116u: goto st8;
		case 132u: goto st9;
		case 140u: goto st9;
		case 180u: goto st9;
		case 214u: goto tr292;
		case 230u: goto tr292;
	}
	if ( (*p) < 64u ) {
		if ( (*p) < 14u ) {
			if ( (*p) > 3u ) {
				if ( 6u <= (*p) && (*p) <= 11u )
					goto tr0;
			} else
				goto tr0;
		} else if ( (*p) > 15u ) {
			if ( (*p) > 51u ) {
				if ( 54u <= (*p) && (*p) <= 55u )
					goto tr0;
			} else if ( (*p) >= 48u )
				goto tr0;
		} else
			goto tr0;
	} else if ( (*p) > 79u ) {
		if ( (*p) < 176u ) {
			if ( (*p) > 119u ) {
				if ( 128u <= (*p) && (*p) <= 143u )
					goto tr5;
			} else if ( (*p) >= 112u )
				goto tr3;
		} else if ( (*p) > 183u ) {
			if ( (*p) > 207u ) {
				if ( 240u <= (*p) && (*p) <= 247u )
					goto tr34;
			} else if ( (*p) >= 192u )
				goto tr56;
		} else
			goto tr5;
	} else
		goto tr3;
	goto tr33;
	}
	_test_eof721: cs = 721; goto _test_eof; 
	_test_eof1: cs = 1; goto _test_eof; 
	_test_eof2: cs = 2; goto _test_eof; 
	_test_eof3: cs = 3; goto _test_eof; 
	_test_eof4: cs = 4; goto _test_eof; 
	_test_eof5: cs = 5; goto _test_eof; 
	_test_eof6: cs = 6; goto _test_eof; 
	_test_eof7: cs = 7; goto _test_eof; 
	_test_eof8: cs = 8; goto _test_eof; 
	_test_eof9: cs = 9; goto _test_eof; 
	_test_eof10: cs = 10; goto _test_eof; 
	_test_eof11: cs = 11; goto _test_eof; 
	_test_eof12: cs = 12; goto _test_eof; 
	_test_eof13: cs = 13; goto _test_eof; 
	_test_eof14: cs = 14; goto _test_eof; 
	_test_eof15: cs = 15; goto _test_eof; 
	_test_eof16: cs = 16; goto _test_eof; 
	_test_eof17: cs = 17; goto _test_eof; 
	_test_eof18: cs = 18; goto _test_eof; 
	_test_eof19: cs = 19; goto _test_eof; 
	_test_eof20: cs = 20; goto _test_eof; 
	_test_eof21: cs = 21; goto _test_eof; 
	_test_eof22: cs = 22; goto _test_eof; 
	_test_eof23: cs = 23; goto _test_eof; 
	_test_eof24: cs = 24; goto _test_eof; 
	_test_eof25: cs = 25; goto _test_eof; 
	_test_eof26: cs = 26; goto _test_eof; 
	_test_eof27: cs = 27; goto _test_eof; 
	_test_eof28: cs = 28; goto _test_eof; 
	_test_eof29: cs = 29; goto _test_eof; 
	_test_eof30: cs = 30; goto _test_eof; 
	_test_eof31: cs = 31; goto _test_eof; 
	_test_eof32: cs = 32; goto _test_eof; 
	_test_eof33: cs = 33; goto _test_eof; 
	_test_eof34: cs = 34; goto _test_eof; 
	_test_eof35: cs = 35; goto _test_eof; 
	_test_eof36: cs = 36; goto _test_eof; 
	_test_eof37: cs = 37; goto _test_eof; 
	_test_eof38: cs = 38; goto _test_eof; 
	_test_eof39: cs = 39; goto _test_eof; 
	_test_eof40: cs = 40; goto _test_eof; 
	_test_eof41: cs = 41; goto _test_eof; 
	_test_eof42: cs = 42; goto _test_eof; 
	_test_eof43: cs = 43; goto _test_eof; 
	_test_eof44: cs = 44; goto _test_eof; 
	_test_eof45: cs = 45; goto _test_eof; 
	_test_eof46: cs = 46; goto _test_eof; 
	_test_eof47: cs = 47; goto _test_eof; 
	_test_eof48: cs = 48; goto _test_eof; 
	_test_eof49: cs = 49; goto _test_eof; 
	_test_eof50: cs = 50; goto _test_eof; 
	_test_eof51: cs = 51; goto _test_eof; 
	_test_eof52: cs = 52; goto _test_eof; 
	_test_eof53: cs = 53; goto _test_eof; 
	_test_eof54: cs = 54; goto _test_eof; 
	_test_eof55: cs = 55; goto _test_eof; 
	_test_eof56: cs = 56; goto _test_eof; 
	_test_eof57: cs = 57; goto _test_eof; 
	_test_eof58: cs = 58; goto _test_eof; 
	_test_eof59: cs = 59; goto _test_eof; 
	_test_eof60: cs = 60; goto _test_eof; 
	_test_eof61: cs = 61; goto _test_eof; 
	_test_eof62: cs = 62; goto _test_eof; 
	_test_eof63: cs = 63; goto _test_eof; 
	_test_eof64: cs = 64; goto _test_eof; 
	_test_eof65: cs = 65; goto _test_eof; 
	_test_eof66: cs = 66; goto _test_eof; 
	_test_eof67: cs = 67; goto _test_eof; 
	_test_eof68: cs = 68; goto _test_eof; 
	_test_eof69: cs = 69; goto _test_eof; 
	_test_eof70: cs = 70; goto _test_eof; 
	_test_eof71: cs = 71; goto _test_eof; 
	_test_eof72: cs = 72; goto _test_eof; 
	_test_eof73: cs = 73; goto _test_eof; 
	_test_eof74: cs = 74; goto _test_eof; 
	_test_eof75: cs = 75; goto _test_eof; 
	_test_eof76: cs = 76; goto _test_eof; 
	_test_eof77: cs = 77; goto _test_eof; 
	_test_eof78: cs = 78; goto _test_eof; 
	_test_eof79: cs = 79; goto _test_eof; 
	_test_eof80: cs = 80; goto _test_eof; 
	_test_eof81: cs = 81; goto _test_eof; 
	_test_eof82: cs = 82; goto _test_eof; 
	_test_eof83: cs = 83; goto _test_eof; 
	_test_eof84: cs = 84; goto _test_eof; 
	_test_eof85: cs = 85; goto _test_eof; 
	_test_eof86: cs = 86; goto _test_eof; 
	_test_eof87: cs = 87; goto _test_eof; 
	_test_eof88: cs = 88; goto _test_eof; 
	_test_eof89: cs = 89; goto _test_eof; 
	_test_eof90: cs = 90; goto _test_eof; 
	_test_eof91: cs = 91; goto _test_eof; 
	_test_eof92: cs = 92; goto _test_eof; 
	_test_eof93: cs = 93; goto _test_eof; 
	_test_eof94: cs = 94; goto _test_eof; 
	_test_eof95: cs = 95; goto _test_eof; 
	_test_eof96: cs = 96; goto _test_eof; 
	_test_eof97: cs = 97; goto _test_eof; 
	_test_eof98: cs = 98; goto _test_eof; 
	_test_eof99: cs = 99; goto _test_eof; 
	_test_eof100: cs = 100; goto _test_eof; 
	_test_eof101: cs = 101; goto _test_eof; 
	_test_eof102: cs = 102; goto _test_eof; 
	_test_eof103: cs = 103; goto _test_eof; 
	_test_eof104: cs = 104; goto _test_eof; 
	_test_eof105: cs = 105; goto _test_eof; 
	_test_eof106: cs = 106; goto _test_eof; 
	_test_eof107: cs = 107; goto _test_eof; 
	_test_eof108: cs = 108; goto _test_eof; 
	_test_eof109: cs = 109; goto _test_eof; 
	_test_eof110: cs = 110; goto _test_eof; 
	_test_eof111: cs = 111; goto _test_eof; 
	_test_eof112: cs = 112; goto _test_eof; 
	_test_eof113: cs = 113; goto _test_eof; 
	_test_eof722: cs = 722; goto _test_eof; 
	_test_eof114: cs = 114; goto _test_eof; 
	_test_eof115: cs = 115; goto _test_eof; 
	_test_eof116: cs = 116; goto _test_eof; 
	_test_eof117: cs = 117; goto _test_eof; 
	_test_eof118: cs = 118; goto _test_eof; 
	_test_eof119: cs = 119; goto _test_eof; 
	_test_eof120: cs = 120; goto _test_eof; 
	_test_eof121: cs = 121; goto _test_eof; 
	_test_eof122: cs = 122; goto _test_eof; 
	_test_eof123: cs = 123; goto _test_eof; 
	_test_eof124: cs = 124; goto _test_eof; 
	_test_eof125: cs = 125; goto _test_eof; 
	_test_eof126: cs = 126; goto _test_eof; 
	_test_eof127: cs = 127; goto _test_eof; 
	_test_eof128: cs = 128; goto _test_eof; 
	_test_eof129: cs = 129; goto _test_eof; 
	_test_eof130: cs = 130; goto _test_eof; 
	_test_eof131: cs = 131; goto _test_eof; 
	_test_eof132: cs = 132; goto _test_eof; 
	_test_eof133: cs = 133; goto _test_eof; 
	_test_eof134: cs = 134; goto _test_eof; 
	_test_eof135: cs = 135; goto _test_eof; 
	_test_eof136: cs = 136; goto _test_eof; 
	_test_eof137: cs = 137; goto _test_eof; 
	_test_eof138: cs = 138; goto _test_eof; 
	_test_eof139: cs = 139; goto _test_eof; 
	_test_eof140: cs = 140; goto _test_eof; 
	_test_eof141: cs = 141; goto _test_eof; 
	_test_eof142: cs = 142; goto _test_eof; 
	_test_eof143: cs = 143; goto _test_eof; 
	_test_eof144: cs = 144; goto _test_eof; 
	_test_eof145: cs = 145; goto _test_eof; 
	_test_eof146: cs = 146; goto _test_eof; 
	_test_eof147: cs = 147; goto _test_eof; 
	_test_eof148: cs = 148; goto _test_eof; 
	_test_eof149: cs = 149; goto _test_eof; 
	_test_eof150: cs = 150; goto _test_eof; 
	_test_eof151: cs = 151; goto _test_eof; 
	_test_eof152: cs = 152; goto _test_eof; 
	_test_eof153: cs = 153; goto _test_eof; 
	_test_eof154: cs = 154; goto _test_eof; 
	_test_eof155: cs = 155; goto _test_eof; 
	_test_eof156: cs = 156; goto _test_eof; 
	_test_eof157: cs = 157; goto _test_eof; 
	_test_eof158: cs = 158; goto _test_eof; 
	_test_eof159: cs = 159; goto _test_eof; 
	_test_eof160: cs = 160; goto _test_eof; 
	_test_eof161: cs = 161; goto _test_eof; 
	_test_eof162: cs = 162; goto _test_eof; 
	_test_eof163: cs = 163; goto _test_eof; 
	_test_eof164: cs = 164; goto _test_eof; 
	_test_eof723: cs = 723; goto _test_eof; 
	_test_eof165: cs = 165; goto _test_eof; 
	_test_eof166: cs = 166; goto _test_eof; 
	_test_eof167: cs = 167; goto _test_eof; 
	_test_eof168: cs = 168; goto _test_eof; 
	_test_eof169: cs = 169; goto _test_eof; 
	_test_eof170: cs = 170; goto _test_eof; 
	_test_eof171: cs = 171; goto _test_eof; 
	_test_eof172: cs = 172; goto _test_eof; 
	_test_eof173: cs = 173; goto _test_eof; 
	_test_eof174: cs = 174; goto _test_eof; 
	_test_eof175: cs = 175; goto _test_eof; 
	_test_eof176: cs = 176; goto _test_eof; 
	_test_eof177: cs = 177; goto _test_eof; 
	_test_eof178: cs = 178; goto _test_eof; 
	_test_eof179: cs = 179; goto _test_eof; 
	_test_eof180: cs = 180; goto _test_eof; 
	_test_eof181: cs = 181; goto _test_eof; 
	_test_eof182: cs = 182; goto _test_eof; 
	_test_eof183: cs = 183; goto _test_eof; 
	_test_eof184: cs = 184; goto _test_eof; 
	_test_eof185: cs = 185; goto _test_eof; 
	_test_eof186: cs = 186; goto _test_eof; 
	_test_eof187: cs = 187; goto _test_eof; 
	_test_eof188: cs = 188; goto _test_eof; 
	_test_eof189: cs = 189; goto _test_eof; 
	_test_eof190: cs = 190; goto _test_eof; 
	_test_eof191: cs = 191; goto _test_eof; 
	_test_eof192: cs = 192; goto _test_eof; 
	_test_eof193: cs = 193; goto _test_eof; 
	_test_eof194: cs = 194; goto _test_eof; 
	_test_eof195: cs = 195; goto _test_eof; 
	_test_eof196: cs = 196; goto _test_eof; 
	_test_eof197: cs = 197; goto _test_eof; 
	_test_eof198: cs = 198; goto _test_eof; 
	_test_eof199: cs = 199; goto _test_eof; 
	_test_eof200: cs = 200; goto _test_eof; 
	_test_eof201: cs = 201; goto _test_eof; 
	_test_eof202: cs = 202; goto _test_eof; 
	_test_eof203: cs = 203; goto _test_eof; 
	_test_eof204: cs = 204; goto _test_eof; 
	_test_eof205: cs = 205; goto _test_eof; 
	_test_eof206: cs = 206; goto _test_eof; 
	_test_eof207: cs = 207; goto _test_eof; 
	_test_eof208: cs = 208; goto _test_eof; 
	_test_eof209: cs = 209; goto _test_eof; 
	_test_eof210: cs = 210; goto _test_eof; 
	_test_eof211: cs = 211; goto _test_eof; 
	_test_eof212: cs = 212; goto _test_eof; 
	_test_eof213: cs = 213; goto _test_eof; 
	_test_eof214: cs = 214; goto _test_eof; 
	_test_eof215: cs = 215; goto _test_eof; 
	_test_eof216: cs = 216; goto _test_eof; 
	_test_eof217: cs = 217; goto _test_eof; 
	_test_eof218: cs = 218; goto _test_eof; 
	_test_eof219: cs = 219; goto _test_eof; 
	_test_eof220: cs = 220; goto _test_eof; 
	_test_eof221: cs = 221; goto _test_eof; 
	_test_eof222: cs = 222; goto _test_eof; 
	_test_eof223: cs = 223; goto _test_eof; 
	_test_eof224: cs = 224; goto _test_eof; 
	_test_eof225: cs = 225; goto _test_eof; 
	_test_eof226: cs = 226; goto _test_eof; 
	_test_eof227: cs = 227; goto _test_eof; 
	_test_eof228: cs = 228; goto _test_eof; 
	_test_eof229: cs = 229; goto _test_eof; 
	_test_eof230: cs = 230; goto _test_eof; 
	_test_eof231: cs = 231; goto _test_eof; 
	_test_eof232: cs = 232; goto _test_eof; 
	_test_eof233: cs = 233; goto _test_eof; 
	_test_eof234: cs = 234; goto _test_eof; 
	_test_eof235: cs = 235; goto _test_eof; 
	_test_eof236: cs = 236; goto _test_eof; 
	_test_eof237: cs = 237; goto _test_eof; 
	_test_eof238: cs = 238; goto _test_eof; 
	_test_eof239: cs = 239; goto _test_eof; 
	_test_eof240: cs = 240; goto _test_eof; 
	_test_eof241: cs = 241; goto _test_eof; 
	_test_eof242: cs = 242; goto _test_eof; 
	_test_eof243: cs = 243; goto _test_eof; 
	_test_eof244: cs = 244; goto _test_eof; 
	_test_eof245: cs = 245; goto _test_eof; 
	_test_eof246: cs = 246; goto _test_eof; 
	_test_eof247: cs = 247; goto _test_eof; 
	_test_eof248: cs = 248; goto _test_eof; 
	_test_eof249: cs = 249; goto _test_eof; 
	_test_eof250: cs = 250; goto _test_eof; 
	_test_eof251: cs = 251; goto _test_eof; 
	_test_eof724: cs = 724; goto _test_eof; 
	_test_eof252: cs = 252; goto _test_eof; 
	_test_eof253: cs = 253; goto _test_eof; 
	_test_eof725: cs = 725; goto _test_eof; 
	_test_eof254: cs = 254; goto _test_eof; 
	_test_eof255: cs = 255; goto _test_eof; 
	_test_eof256: cs = 256; goto _test_eof; 
	_test_eof257: cs = 257; goto _test_eof; 
	_test_eof258: cs = 258; goto _test_eof; 
	_test_eof259: cs = 259; goto _test_eof; 
	_test_eof260: cs = 260; goto _test_eof; 
	_test_eof261: cs = 261; goto _test_eof; 
	_test_eof262: cs = 262; goto _test_eof; 
	_test_eof263: cs = 263; goto _test_eof; 
	_test_eof264: cs = 264; goto _test_eof; 
	_test_eof265: cs = 265; goto _test_eof; 
	_test_eof266: cs = 266; goto _test_eof; 
	_test_eof267: cs = 267; goto _test_eof; 
	_test_eof268: cs = 268; goto _test_eof; 
	_test_eof269: cs = 269; goto _test_eof; 
	_test_eof270: cs = 270; goto _test_eof; 
	_test_eof271: cs = 271; goto _test_eof; 
	_test_eof272: cs = 272; goto _test_eof; 
	_test_eof273: cs = 273; goto _test_eof; 
	_test_eof274: cs = 274; goto _test_eof; 
	_test_eof275: cs = 275; goto _test_eof; 
	_test_eof276: cs = 276; goto _test_eof; 
	_test_eof277: cs = 277; goto _test_eof; 
	_test_eof278: cs = 278; goto _test_eof; 
	_test_eof279: cs = 279; goto _test_eof; 
	_test_eof280: cs = 280; goto _test_eof; 
	_test_eof281: cs = 281; goto _test_eof; 
	_test_eof282: cs = 282; goto _test_eof; 
	_test_eof283: cs = 283; goto _test_eof; 
	_test_eof284: cs = 284; goto _test_eof; 
	_test_eof285: cs = 285; goto _test_eof; 
	_test_eof286: cs = 286; goto _test_eof; 
	_test_eof287: cs = 287; goto _test_eof; 
	_test_eof288: cs = 288; goto _test_eof; 
	_test_eof289: cs = 289; goto _test_eof; 
	_test_eof290: cs = 290; goto _test_eof; 
	_test_eof291: cs = 291; goto _test_eof; 
	_test_eof292: cs = 292; goto _test_eof; 
	_test_eof293: cs = 293; goto _test_eof; 
	_test_eof294: cs = 294; goto _test_eof; 
	_test_eof295: cs = 295; goto _test_eof; 
	_test_eof296: cs = 296; goto _test_eof; 
	_test_eof297: cs = 297; goto _test_eof; 
	_test_eof298: cs = 298; goto _test_eof; 
	_test_eof299: cs = 299; goto _test_eof; 
	_test_eof300: cs = 300; goto _test_eof; 
	_test_eof301: cs = 301; goto _test_eof; 
	_test_eof302: cs = 302; goto _test_eof; 
	_test_eof303: cs = 303; goto _test_eof; 
	_test_eof304: cs = 304; goto _test_eof; 
	_test_eof305: cs = 305; goto _test_eof; 
	_test_eof306: cs = 306; goto _test_eof; 
	_test_eof307: cs = 307; goto _test_eof; 
	_test_eof308: cs = 308; goto _test_eof; 
	_test_eof309: cs = 309; goto _test_eof; 
	_test_eof310: cs = 310; goto _test_eof; 
	_test_eof311: cs = 311; goto _test_eof; 
	_test_eof312: cs = 312; goto _test_eof; 
	_test_eof313: cs = 313; goto _test_eof; 
	_test_eof314: cs = 314; goto _test_eof; 
	_test_eof315: cs = 315; goto _test_eof; 
	_test_eof316: cs = 316; goto _test_eof; 
	_test_eof317: cs = 317; goto _test_eof; 
	_test_eof318: cs = 318; goto _test_eof; 
	_test_eof319: cs = 319; goto _test_eof; 
	_test_eof320: cs = 320; goto _test_eof; 
	_test_eof321: cs = 321; goto _test_eof; 
	_test_eof322: cs = 322; goto _test_eof; 
	_test_eof323: cs = 323; goto _test_eof; 
	_test_eof324: cs = 324; goto _test_eof; 
	_test_eof325: cs = 325; goto _test_eof; 
	_test_eof326: cs = 326; goto _test_eof; 
	_test_eof327: cs = 327; goto _test_eof; 
	_test_eof328: cs = 328; goto _test_eof; 
	_test_eof329: cs = 329; goto _test_eof; 
	_test_eof330: cs = 330; goto _test_eof; 
	_test_eof331: cs = 331; goto _test_eof; 
	_test_eof332: cs = 332; goto _test_eof; 
	_test_eof333: cs = 333; goto _test_eof; 
	_test_eof334: cs = 334; goto _test_eof; 
	_test_eof335: cs = 335; goto _test_eof; 
	_test_eof336: cs = 336; goto _test_eof; 
	_test_eof337: cs = 337; goto _test_eof; 
	_test_eof338: cs = 338; goto _test_eof; 
	_test_eof339: cs = 339; goto _test_eof; 
	_test_eof340: cs = 340; goto _test_eof; 
	_test_eof341: cs = 341; goto _test_eof; 
	_test_eof342: cs = 342; goto _test_eof; 
	_test_eof343: cs = 343; goto _test_eof; 
	_test_eof344: cs = 344; goto _test_eof; 
	_test_eof345: cs = 345; goto _test_eof; 
	_test_eof346: cs = 346; goto _test_eof; 
	_test_eof347: cs = 347; goto _test_eof; 
	_test_eof348: cs = 348; goto _test_eof; 
	_test_eof349: cs = 349; goto _test_eof; 
	_test_eof350: cs = 350; goto _test_eof; 
	_test_eof351: cs = 351; goto _test_eof; 
	_test_eof352: cs = 352; goto _test_eof; 
	_test_eof353: cs = 353; goto _test_eof; 
	_test_eof354: cs = 354; goto _test_eof; 
	_test_eof355: cs = 355; goto _test_eof; 
	_test_eof356: cs = 356; goto _test_eof; 
	_test_eof357: cs = 357; goto _test_eof; 
	_test_eof358: cs = 358; goto _test_eof; 
	_test_eof359: cs = 359; goto _test_eof; 
	_test_eof360: cs = 360; goto _test_eof; 
	_test_eof361: cs = 361; goto _test_eof; 
	_test_eof362: cs = 362; goto _test_eof; 
	_test_eof363: cs = 363; goto _test_eof; 
	_test_eof364: cs = 364; goto _test_eof; 
	_test_eof365: cs = 365; goto _test_eof; 
	_test_eof366: cs = 366; goto _test_eof; 
	_test_eof367: cs = 367; goto _test_eof; 
	_test_eof368: cs = 368; goto _test_eof; 
	_test_eof369: cs = 369; goto _test_eof; 
	_test_eof370: cs = 370; goto _test_eof; 
	_test_eof371: cs = 371; goto _test_eof; 
	_test_eof372: cs = 372; goto _test_eof; 
	_test_eof373: cs = 373; goto _test_eof; 
	_test_eof374: cs = 374; goto _test_eof; 
	_test_eof375: cs = 375; goto _test_eof; 
	_test_eof376: cs = 376; goto _test_eof; 
	_test_eof377: cs = 377; goto _test_eof; 
	_test_eof378: cs = 378; goto _test_eof; 
	_test_eof379: cs = 379; goto _test_eof; 
	_test_eof380: cs = 380; goto _test_eof; 
	_test_eof381: cs = 381; goto _test_eof; 
	_test_eof382: cs = 382; goto _test_eof; 
	_test_eof383: cs = 383; goto _test_eof; 
	_test_eof384: cs = 384; goto _test_eof; 
	_test_eof385: cs = 385; goto _test_eof; 
	_test_eof386: cs = 386; goto _test_eof; 
	_test_eof387: cs = 387; goto _test_eof; 
	_test_eof388: cs = 388; goto _test_eof; 
	_test_eof389: cs = 389; goto _test_eof; 
	_test_eof390: cs = 390; goto _test_eof; 
	_test_eof391: cs = 391; goto _test_eof; 
	_test_eof392: cs = 392; goto _test_eof; 
	_test_eof393: cs = 393; goto _test_eof; 
	_test_eof394: cs = 394; goto _test_eof; 
	_test_eof395: cs = 395; goto _test_eof; 
	_test_eof396: cs = 396; goto _test_eof; 
	_test_eof397: cs = 397; goto _test_eof; 
	_test_eof398: cs = 398; goto _test_eof; 
	_test_eof399: cs = 399; goto _test_eof; 
	_test_eof400: cs = 400; goto _test_eof; 
	_test_eof401: cs = 401; goto _test_eof; 
	_test_eof402: cs = 402; goto _test_eof; 
	_test_eof403: cs = 403; goto _test_eof; 
	_test_eof404: cs = 404; goto _test_eof; 
	_test_eof405: cs = 405; goto _test_eof; 
	_test_eof406: cs = 406; goto _test_eof; 
	_test_eof407: cs = 407; goto _test_eof; 
	_test_eof408: cs = 408; goto _test_eof; 
	_test_eof409: cs = 409; goto _test_eof; 
	_test_eof410: cs = 410; goto _test_eof; 
	_test_eof411: cs = 411; goto _test_eof; 
	_test_eof412: cs = 412; goto _test_eof; 
	_test_eof413: cs = 413; goto _test_eof; 
	_test_eof414: cs = 414; goto _test_eof; 
	_test_eof415: cs = 415; goto _test_eof; 
	_test_eof416: cs = 416; goto _test_eof; 
	_test_eof417: cs = 417; goto _test_eof; 
	_test_eof418: cs = 418; goto _test_eof; 
	_test_eof419: cs = 419; goto _test_eof; 
	_test_eof420: cs = 420; goto _test_eof; 
	_test_eof421: cs = 421; goto _test_eof; 
	_test_eof422: cs = 422; goto _test_eof; 
	_test_eof423: cs = 423; goto _test_eof; 
	_test_eof424: cs = 424; goto _test_eof; 
	_test_eof425: cs = 425; goto _test_eof; 
	_test_eof426: cs = 426; goto _test_eof; 
	_test_eof427: cs = 427; goto _test_eof; 
	_test_eof428: cs = 428; goto _test_eof; 
	_test_eof429: cs = 429; goto _test_eof; 
	_test_eof430: cs = 430; goto _test_eof; 
	_test_eof431: cs = 431; goto _test_eof; 
	_test_eof432: cs = 432; goto _test_eof; 
	_test_eof433: cs = 433; goto _test_eof; 
	_test_eof434: cs = 434; goto _test_eof; 
	_test_eof435: cs = 435; goto _test_eof; 
	_test_eof436: cs = 436; goto _test_eof; 
	_test_eof437: cs = 437; goto _test_eof; 
	_test_eof438: cs = 438; goto _test_eof; 
	_test_eof439: cs = 439; goto _test_eof; 
	_test_eof440: cs = 440; goto _test_eof; 
	_test_eof441: cs = 441; goto _test_eof; 
	_test_eof442: cs = 442; goto _test_eof; 
	_test_eof443: cs = 443; goto _test_eof; 
	_test_eof444: cs = 444; goto _test_eof; 
	_test_eof445: cs = 445; goto _test_eof; 
	_test_eof446: cs = 446; goto _test_eof; 
	_test_eof447: cs = 447; goto _test_eof; 
	_test_eof448: cs = 448; goto _test_eof; 
	_test_eof449: cs = 449; goto _test_eof; 
	_test_eof450: cs = 450; goto _test_eof; 
	_test_eof451: cs = 451; goto _test_eof; 
	_test_eof452: cs = 452; goto _test_eof; 
	_test_eof453: cs = 453; goto _test_eof; 
	_test_eof454: cs = 454; goto _test_eof; 
	_test_eof455: cs = 455; goto _test_eof; 
	_test_eof456: cs = 456; goto _test_eof; 
	_test_eof457: cs = 457; goto _test_eof; 
	_test_eof458: cs = 458; goto _test_eof; 
	_test_eof459: cs = 459; goto _test_eof; 
	_test_eof460: cs = 460; goto _test_eof; 
	_test_eof461: cs = 461; goto _test_eof; 
	_test_eof462: cs = 462; goto _test_eof; 
	_test_eof463: cs = 463; goto _test_eof; 
	_test_eof464: cs = 464; goto _test_eof; 
	_test_eof465: cs = 465; goto _test_eof; 
	_test_eof466: cs = 466; goto _test_eof; 
	_test_eof467: cs = 467; goto _test_eof; 
	_test_eof468: cs = 468; goto _test_eof; 
	_test_eof469: cs = 469; goto _test_eof; 
	_test_eof470: cs = 470; goto _test_eof; 
	_test_eof471: cs = 471; goto _test_eof; 
	_test_eof472: cs = 472; goto _test_eof; 
	_test_eof473: cs = 473; goto _test_eof; 
	_test_eof474: cs = 474; goto _test_eof; 
	_test_eof475: cs = 475; goto _test_eof; 
	_test_eof476: cs = 476; goto _test_eof; 
	_test_eof477: cs = 477; goto _test_eof; 
	_test_eof478: cs = 478; goto _test_eof; 
	_test_eof479: cs = 479; goto _test_eof; 
	_test_eof480: cs = 480; goto _test_eof; 
	_test_eof481: cs = 481; goto _test_eof; 
	_test_eof482: cs = 482; goto _test_eof; 
	_test_eof483: cs = 483; goto _test_eof; 
	_test_eof484: cs = 484; goto _test_eof; 
	_test_eof485: cs = 485; goto _test_eof; 
	_test_eof486: cs = 486; goto _test_eof; 
	_test_eof487: cs = 487; goto _test_eof; 
	_test_eof488: cs = 488; goto _test_eof; 
	_test_eof489: cs = 489; goto _test_eof; 
	_test_eof490: cs = 490; goto _test_eof; 
	_test_eof491: cs = 491; goto _test_eof; 
	_test_eof492: cs = 492; goto _test_eof; 
	_test_eof493: cs = 493; goto _test_eof; 
	_test_eof494: cs = 494; goto _test_eof; 
	_test_eof495: cs = 495; goto _test_eof; 
	_test_eof496: cs = 496; goto _test_eof; 
	_test_eof497: cs = 497; goto _test_eof; 
	_test_eof498: cs = 498; goto _test_eof; 
	_test_eof499: cs = 499; goto _test_eof; 
	_test_eof500: cs = 500; goto _test_eof; 
	_test_eof501: cs = 501; goto _test_eof; 
	_test_eof502: cs = 502; goto _test_eof; 
	_test_eof503: cs = 503; goto _test_eof; 
	_test_eof504: cs = 504; goto _test_eof; 
	_test_eof505: cs = 505; goto _test_eof; 
	_test_eof506: cs = 506; goto _test_eof; 
	_test_eof507: cs = 507; goto _test_eof; 
	_test_eof508: cs = 508; goto _test_eof; 
	_test_eof509: cs = 509; goto _test_eof; 
	_test_eof510: cs = 510; goto _test_eof; 
	_test_eof511: cs = 511; goto _test_eof; 
	_test_eof512: cs = 512; goto _test_eof; 
	_test_eof513: cs = 513; goto _test_eof; 
	_test_eof514: cs = 514; goto _test_eof; 
	_test_eof515: cs = 515; goto _test_eof; 
	_test_eof516: cs = 516; goto _test_eof; 
	_test_eof517: cs = 517; goto _test_eof; 
	_test_eof518: cs = 518; goto _test_eof; 
	_test_eof519: cs = 519; goto _test_eof; 
	_test_eof520: cs = 520; goto _test_eof; 
	_test_eof521: cs = 521; goto _test_eof; 
	_test_eof522: cs = 522; goto _test_eof; 
	_test_eof523: cs = 523; goto _test_eof; 
	_test_eof524: cs = 524; goto _test_eof; 
	_test_eof525: cs = 525; goto _test_eof; 
	_test_eof526: cs = 526; goto _test_eof; 
	_test_eof527: cs = 527; goto _test_eof; 
	_test_eof528: cs = 528; goto _test_eof; 
	_test_eof529: cs = 529; goto _test_eof; 
	_test_eof530: cs = 530; goto _test_eof; 
	_test_eof531: cs = 531; goto _test_eof; 
	_test_eof532: cs = 532; goto _test_eof; 
	_test_eof533: cs = 533; goto _test_eof; 
	_test_eof534: cs = 534; goto _test_eof; 
	_test_eof535: cs = 535; goto _test_eof; 
	_test_eof536: cs = 536; goto _test_eof; 
	_test_eof537: cs = 537; goto _test_eof; 
	_test_eof538: cs = 538; goto _test_eof; 
	_test_eof539: cs = 539; goto _test_eof; 
	_test_eof540: cs = 540; goto _test_eof; 
	_test_eof541: cs = 541; goto _test_eof; 
	_test_eof542: cs = 542; goto _test_eof; 
	_test_eof543: cs = 543; goto _test_eof; 
	_test_eof544: cs = 544; goto _test_eof; 
	_test_eof545: cs = 545; goto _test_eof; 
	_test_eof546: cs = 546; goto _test_eof; 
	_test_eof547: cs = 547; goto _test_eof; 
	_test_eof548: cs = 548; goto _test_eof; 
	_test_eof549: cs = 549; goto _test_eof; 
	_test_eof550: cs = 550; goto _test_eof; 
	_test_eof551: cs = 551; goto _test_eof; 
	_test_eof552: cs = 552; goto _test_eof; 
	_test_eof553: cs = 553; goto _test_eof; 
	_test_eof554: cs = 554; goto _test_eof; 
	_test_eof555: cs = 555; goto _test_eof; 
	_test_eof556: cs = 556; goto _test_eof; 
	_test_eof557: cs = 557; goto _test_eof; 
	_test_eof558: cs = 558; goto _test_eof; 
	_test_eof559: cs = 559; goto _test_eof; 
	_test_eof560: cs = 560; goto _test_eof; 
	_test_eof561: cs = 561; goto _test_eof; 
	_test_eof562: cs = 562; goto _test_eof; 
	_test_eof563: cs = 563; goto _test_eof; 
	_test_eof564: cs = 564; goto _test_eof; 
	_test_eof565: cs = 565; goto _test_eof; 
	_test_eof566: cs = 566; goto _test_eof; 
	_test_eof567: cs = 567; goto _test_eof; 
	_test_eof568: cs = 568; goto _test_eof; 
	_test_eof569: cs = 569; goto _test_eof; 
	_test_eof570: cs = 570; goto _test_eof; 
	_test_eof571: cs = 571; goto _test_eof; 
	_test_eof572: cs = 572; goto _test_eof; 
	_test_eof573: cs = 573; goto _test_eof; 
	_test_eof574: cs = 574; goto _test_eof; 
	_test_eof575: cs = 575; goto _test_eof; 
	_test_eof576: cs = 576; goto _test_eof; 
	_test_eof577: cs = 577; goto _test_eof; 
	_test_eof578: cs = 578; goto _test_eof; 
	_test_eof579: cs = 579; goto _test_eof; 
	_test_eof580: cs = 580; goto _test_eof; 
	_test_eof581: cs = 581; goto _test_eof; 
	_test_eof582: cs = 582; goto _test_eof; 
	_test_eof583: cs = 583; goto _test_eof; 
	_test_eof584: cs = 584; goto _test_eof; 
	_test_eof585: cs = 585; goto _test_eof; 
	_test_eof586: cs = 586; goto _test_eof; 
	_test_eof587: cs = 587; goto _test_eof; 
	_test_eof588: cs = 588; goto _test_eof; 
	_test_eof589: cs = 589; goto _test_eof; 
	_test_eof590: cs = 590; goto _test_eof; 
	_test_eof591: cs = 591; goto _test_eof; 
	_test_eof592: cs = 592; goto _test_eof; 
	_test_eof593: cs = 593; goto _test_eof; 
	_test_eof594: cs = 594; goto _test_eof; 
	_test_eof595: cs = 595; goto _test_eof; 
	_test_eof596: cs = 596; goto _test_eof; 
	_test_eof597: cs = 597; goto _test_eof; 
	_test_eof598: cs = 598; goto _test_eof; 
	_test_eof599: cs = 599; goto _test_eof; 
	_test_eof600: cs = 600; goto _test_eof; 
	_test_eof601: cs = 601; goto _test_eof; 
	_test_eof602: cs = 602; goto _test_eof; 
	_test_eof603: cs = 603; goto _test_eof; 
	_test_eof604: cs = 604; goto _test_eof; 
	_test_eof605: cs = 605; goto _test_eof; 
	_test_eof606: cs = 606; goto _test_eof; 
	_test_eof607: cs = 607; goto _test_eof; 
	_test_eof608: cs = 608; goto _test_eof; 
	_test_eof609: cs = 609; goto _test_eof; 
	_test_eof610: cs = 610; goto _test_eof; 
	_test_eof611: cs = 611; goto _test_eof; 
	_test_eof612: cs = 612; goto _test_eof; 
	_test_eof613: cs = 613; goto _test_eof; 
	_test_eof614: cs = 614; goto _test_eof; 
	_test_eof615: cs = 615; goto _test_eof; 
	_test_eof616: cs = 616; goto _test_eof; 
	_test_eof617: cs = 617; goto _test_eof; 
	_test_eof618: cs = 618; goto _test_eof; 
	_test_eof619: cs = 619; goto _test_eof; 
	_test_eof620: cs = 620; goto _test_eof; 
	_test_eof621: cs = 621; goto _test_eof; 
	_test_eof622: cs = 622; goto _test_eof; 
	_test_eof623: cs = 623; goto _test_eof; 
	_test_eof624: cs = 624; goto _test_eof; 
	_test_eof625: cs = 625; goto _test_eof; 
	_test_eof626: cs = 626; goto _test_eof; 
	_test_eof627: cs = 627; goto _test_eof; 
	_test_eof628: cs = 628; goto _test_eof; 
	_test_eof629: cs = 629; goto _test_eof; 
	_test_eof630: cs = 630; goto _test_eof; 
	_test_eof631: cs = 631; goto _test_eof; 
	_test_eof632: cs = 632; goto _test_eof; 
	_test_eof633: cs = 633; goto _test_eof; 
	_test_eof634: cs = 634; goto _test_eof; 
	_test_eof635: cs = 635; goto _test_eof; 
	_test_eof636: cs = 636; goto _test_eof; 
	_test_eof637: cs = 637; goto _test_eof; 
	_test_eof638: cs = 638; goto _test_eof; 
	_test_eof639: cs = 639; goto _test_eof; 
	_test_eof640: cs = 640; goto _test_eof; 
	_test_eof641: cs = 641; goto _test_eof; 
	_test_eof642: cs = 642; goto _test_eof; 
	_test_eof643: cs = 643; goto _test_eof; 
	_test_eof644: cs = 644; goto _test_eof; 
	_test_eof645: cs = 645; goto _test_eof; 
	_test_eof646: cs = 646; goto _test_eof; 
	_test_eof647: cs = 647; goto _test_eof; 
	_test_eof648: cs = 648; goto _test_eof; 
	_test_eof649: cs = 649; goto _test_eof; 
	_test_eof650: cs = 650; goto _test_eof; 
	_test_eof651: cs = 651; goto _test_eof; 
	_test_eof652: cs = 652; goto _test_eof; 
	_test_eof653: cs = 653; goto _test_eof; 
	_test_eof654: cs = 654; goto _test_eof; 
	_test_eof655: cs = 655; goto _test_eof; 
	_test_eof656: cs = 656; goto _test_eof; 
	_test_eof657: cs = 657; goto _test_eof; 
	_test_eof658: cs = 658; goto _test_eof; 
	_test_eof659: cs = 659; goto _test_eof; 
	_test_eof660: cs = 660; goto _test_eof; 
	_test_eof661: cs = 661; goto _test_eof; 
	_test_eof662: cs = 662; goto _test_eof; 
	_test_eof663: cs = 663; goto _test_eof; 
	_test_eof726: cs = 726; goto _test_eof; 
	_test_eof664: cs = 664; goto _test_eof; 
	_test_eof665: cs = 665; goto _test_eof; 
	_test_eof727: cs = 727; goto _test_eof; 
	_test_eof666: cs = 666; goto _test_eof; 
	_test_eof667: cs = 667; goto _test_eof; 
	_test_eof728: cs = 728; goto _test_eof; 
	_test_eof668: cs = 668; goto _test_eof; 
	_test_eof669: cs = 669; goto _test_eof; 
	_test_eof729: cs = 729; goto _test_eof; 
	_test_eof670: cs = 670; goto _test_eof; 
	_test_eof671: cs = 671; goto _test_eof; 
	_test_eof730: cs = 730; goto _test_eof; 
	_test_eof672: cs = 672; goto _test_eof; 
	_test_eof673: cs = 673; goto _test_eof; 
	_test_eof731: cs = 731; goto _test_eof; 
	_test_eof674: cs = 674; goto _test_eof; 
	_test_eof675: cs = 675; goto _test_eof; 
	_test_eof732: cs = 732; goto _test_eof; 
	_test_eof676: cs = 676; goto _test_eof; 
	_test_eof677: cs = 677; goto _test_eof; 
	_test_eof733: cs = 733; goto _test_eof; 
	_test_eof678: cs = 678; goto _test_eof; 
	_test_eof679: cs = 679; goto _test_eof; 
	_test_eof734: cs = 734; goto _test_eof; 
	_test_eof680: cs = 680; goto _test_eof; 
	_test_eof681: cs = 681; goto _test_eof; 
	_test_eof735: cs = 735; goto _test_eof; 
	_test_eof682: cs = 682; goto _test_eof; 
	_test_eof683: cs = 683; goto _test_eof; 
	_test_eof736: cs = 736; goto _test_eof; 
	_test_eof684: cs = 684; goto _test_eof; 
	_test_eof685: cs = 685; goto _test_eof; 
	_test_eof737: cs = 737; goto _test_eof; 
	_test_eof686: cs = 686; goto _test_eof; 
	_test_eof687: cs = 687; goto _test_eof; 
	_test_eof738: cs = 738; goto _test_eof; 
	_test_eof688: cs = 688; goto _test_eof; 
	_test_eof689: cs = 689; goto _test_eof; 
	_test_eof739: cs = 739; goto _test_eof; 
	_test_eof690: cs = 690; goto _test_eof; 
	_test_eof691: cs = 691; goto _test_eof; 
	_test_eof740: cs = 740; goto _test_eof; 
	_test_eof692: cs = 692; goto _test_eof; 
	_test_eof693: cs = 693; goto _test_eof; 
	_test_eof741: cs = 741; goto _test_eof; 
	_test_eof694: cs = 694; goto _test_eof; 
	_test_eof695: cs = 695; goto _test_eof; 
	_test_eof696: cs = 696; goto _test_eof; 
	_test_eof742: cs = 742; goto _test_eof; 
	_test_eof697: cs = 697; goto _test_eof; 
	_test_eof698: cs = 698; goto _test_eof; 
	_test_eof743: cs = 743; goto _test_eof; 
	_test_eof699: cs = 699; goto _test_eof; 
	_test_eof700: cs = 700; goto _test_eof; 
	_test_eof701: cs = 701; goto _test_eof; 
	_test_eof744: cs = 744; goto _test_eof; 
	_test_eof702: cs = 702; goto _test_eof; 
	_test_eof703: cs = 703; goto _test_eof; 
	_test_eof745: cs = 745; goto _test_eof; 
	_test_eof704: cs = 704; goto _test_eof; 
	_test_eof705: cs = 705; goto _test_eof; 
	_test_eof706: cs = 706; goto _test_eof; 
	_test_eof746: cs = 746; goto _test_eof; 
	_test_eof707: cs = 707; goto _test_eof; 
	_test_eof708: cs = 708; goto _test_eof; 
	_test_eof747: cs = 747; goto _test_eof; 
	_test_eof709: cs = 709; goto _test_eof; 
	_test_eof710: cs = 710; goto _test_eof; 
	_test_eof711: cs = 711; goto _test_eof; 
	_test_eof748: cs = 748; goto _test_eof; 
	_test_eof712: cs = 712; goto _test_eof; 
	_test_eof713: cs = 713; goto _test_eof; 
	_test_eof749: cs = 749; goto _test_eof; 
	_test_eof714: cs = 714; goto _test_eof; 
	_test_eof715: cs = 715; goto _test_eof; 
	_test_eof716: cs = 716; goto _test_eof; 
	_test_eof750: cs = 750; goto _test_eof; 
	_test_eof717: cs = 717; goto _test_eof; 
	_test_eof718: cs = 718; goto _test_eof; 
	_test_eof751: cs = 751; goto _test_eof; 
	_test_eof719: cs = 719; goto _test_eof; 
	_test_eof720: cs = 720; goto _test_eof; 

	_test_eof: {}
	if ( p == eof )
	{
	switch ( cs ) {
	case 1: 
	case 2: 
	case 3: 
	case 4: 
	case 5: 
	case 6: 
	case 7: 
	case 8: 
	case 9: 
	case 10: 
	case 11: 
	case 12: 
	case 13: 
	case 14: 
	case 15: 
	case 16: 
	case 17: 
	case 18: 
	case 19: 
	case 20: 
	case 21: 
	case 22: 
	case 23: 
	case 24: 
	case 25: 
	case 26: 
	case 27: 
	case 28: 
	case 29: 
	case 30: 
	case 31: 
	case 32: 
	case 33: 
	case 34: 
	case 35: 
	case 36: 
	case 37: 
	case 38: 
	case 39: 
	case 40: 
	case 41: 
	case 42: 
	case 43: 
	case 44: 
	case 45: 
	case 46: 
	case 47: 
	case 48: 
	case 49: 
	case 50: 
	case 51: 
	case 52: 
	case 53: 
	case 54: 
	case 55: 
	case 56: 
	case 57: 
	case 58: 
	case 59: 
	case 60: 
	case 61: 
	case 62: 
	case 63: 
	case 64: 
	case 65: 
	case 66: 
	case 67: 
	case 68: 
	case 69: 
	case 70: 
	case 71: 
	case 72: 
	case 73: 
	case 74: 
	case 75: 
	case 76: 
	case 77: 
	case 78: 
	case 79: 
	case 80: 
	case 81: 
	case 82: 
	case 83: 
	case 84: 
	case 85: 
	case 86: 
	case 87: 
	case 88: 
	case 89: 
	case 90: 
	case 91: 
	case 92: 
	case 93: 
	case 94: 
	case 95: 
	case 96: 
	case 97: 
	case 98: 
	case 99: 
	case 100: 
	case 101: 
	case 102: 
	case 103: 
	case 104: 
	case 105: 
	case 106: 
	case 107: 
	case 108: 
	case 109: 
	case 110: 
	case 111: 
	case 112: 
	case 113: 
	case 114: 
	case 115: 
	case 116: 
	case 117: 
	case 118: 
	case 119: 
	case 120: 
	case 121: 
	case 122: 
	case 123: 
	case 124: 
	case 125: 
	case 126: 
	case 127: 
	case 128: 
	case 129: 
	case 130: 
	case 131: 
	case 132: 
	case 133: 
	case 134: 
	case 135: 
	case 136: 
	case 137: 
	case 138: 
	case 139: 
	case 140: 
	case 141: 
	case 142: 
	case 143: 
	case 144: 
	case 145: 
	case 146: 
	case 147: 
	case 148: 
	case 149: 
	case 150: 
	case 151: 
	case 152: 
	case 153: 
	case 154: 
	case 155: 
	case 156: 
	case 157: 
	case 158: 
	case 159: 
	case 160: 
	case 161: 
	case 162: 
	case 163: 
	case 164: 
	case 165: 
	case 166: 
	case 167: 
	case 168: 
	case 169: 
	case 170: 
	case 171: 
	case 172: 
	case 173: 
	case 174: 
	case 175: 
	case 176: 
	case 177: 
	case 178: 
	case 179: 
	case 180: 
	case 181: 
	case 182: 
	case 183: 
	case 184: 
	case 185: 
	case 186: 
	case 187: 
	case 188: 
	case 189: 
	case 190: 
	case 191: 
	case 192: 
	case 193: 
	case 194: 
	case 195: 
	case 196: 
	case 197: 
	case 198: 
	case 199: 
	case 200: 
	case 201: 
	case 202: 
	case 203: 
	case 204: 
	case 205: 
	case 206: 
	case 207: 
	case 208: 
	case 209: 
	case 210: 
	case 211: 
	case 212: 
	case 213: 
	case 214: 
	case 215: 
	case 216: 
	case 217: 
	case 218: 
	case 219: 
	case 220: 
	case 221: 
	case 222: 
	case 223: 
	case 224: 
	case 225: 
	case 226: 
	case 227: 
	case 228: 
	case 229: 
	case 230: 
	case 231: 
	case 232: 
	case 233: 
	case 234: 
	case 235: 
	case 236: 
	case 237: 
	case 238: 
	case 239: 
	case 240: 
	case 241: 
	case 242: 
	case 243: 
	case 244: 
	case 245: 
	case 246: 
	case 247: 
	case 248: 
	case 249: 
	case 250: 
	case 251: 
	case 252: 
	case 253: 
	case 254: 
	case 255: 
	case 256: 
	case 257: 
	case 258: 
	case 259: 
	case 260: 
	case 261: 
	case 262: 
	case 263: 
	case 264: 
	case 265: 
	case 266: 
	case 267: 
	case 268: 
	case 269: 
	case 270: 
	case 271: 
	case 272: 
	case 273: 
	case 274: 
	case 275: 
	case 276: 
	case 277: 
	case 278: 
	case 279: 
	case 280: 
	case 281: 
	case 282: 
	case 283: 
	case 284: 
	case 285: 
	case 286: 
	case 287: 
	case 288: 
	case 289: 
	case 290: 
	case 291: 
	case 292: 
	case 293: 
	case 294: 
	case 295: 
	case 296: 
	case 297: 
	case 298: 
	case 299: 
	case 300: 
	case 301: 
	case 302: 
	case 303: 
	case 304: 
	case 305: 
	case 306: 
	case 307: 
	case 308: 
	case 309: 
	case 310: 
	case 311: 
	case 312: 
	case 313: 
	case 314: 
	case 315: 
	case 316: 
	case 317: 
	case 318: 
	case 319: 
	case 320: 
	case 321: 
	case 322: 
	case 323: 
	case 324: 
	case 325: 
	case 326: 
	case 327: 
	case 328: 
	case 329: 
	case 330: 
	case 331: 
	case 332: 
	case 333: 
	case 334: 
	case 335: 
	case 336: 
	case 337: 
	case 338: 
	case 339: 
	case 340: 
	case 341: 
	case 342: 
	case 343: 
	case 344: 
	case 345: 
	case 346: 
	case 347: 
	case 348: 
	case 349: 
	case 350: 
	case 351: 
	case 352: 
	case 353: 
	case 354: 
	case 355: 
	case 356: 
	case 357: 
	case 358: 
	case 359: 
	case 360: 
	case 361: 
	case 362: 
	case 363: 
	case 364: 
	case 365: 
	case 366: 
	case 367: 
	case 368: 
	case 369: 
	case 370: 
	case 371: 
	case 372: 
	case 373: 
	case 374: 
	case 375: 
	case 376: 
	case 377: 
	case 378: 
	case 379: 
	case 380: 
	case 381: 
	case 382: 
	case 383: 
	case 384: 
	case 385: 
	case 386: 
	case 387: 
	case 388: 
	case 389: 
	case 390: 
	case 391: 
	case 392: 
	case 393: 
	case 394: 
	case 395: 
	case 396: 
	case 397: 
	case 398: 
	case 399: 
	case 400: 
	case 401: 
	case 402: 
	case 403: 
	case 404: 
	case 405: 
	case 406: 
	case 407: 
	case 408: 
	case 409: 
	case 410: 
	case 411: 
	case 412: 
	case 413: 
	case 414: 
	case 415: 
	case 416: 
	case 417: 
	case 418: 
	case 419: 
	case 420: 
	case 421: 
	case 422: 
	case 423: 
	case 424: 
	case 425: 
	case 426: 
	case 427: 
	case 428: 
	case 429: 
	case 430: 
	case 431: 
	case 432: 
	case 433: 
	case 434: 
	case 435: 
	case 436: 
	case 437: 
	case 438: 
	case 439: 
	case 440: 
	case 441: 
	case 442: 
	case 443: 
	case 444: 
	case 445: 
	case 446: 
	case 447: 
	case 448: 
	case 449: 
	case 450: 
	case 451: 
	case 452: 
	case 453: 
	case 454: 
	case 455: 
	case 456: 
	case 457: 
	case 458: 
	case 459: 
	case 460: 
	case 461: 
	case 462: 
	case 463: 
	case 464: 
	case 465: 
	case 466: 
	case 467: 
	case 468: 
	case 469: 
	case 470: 
	case 471: 
	case 472: 
	case 473: 
	case 474: 
	case 475: 
	case 476: 
	case 477: 
	case 478: 
	case 479: 
	case 480: 
	case 481: 
	case 482: 
	case 483: 
	case 484: 
	case 485: 
	case 486: 
	case 487: 
	case 488: 
	case 489: 
	case 490: 
	case 491: 
	case 492: 
	case 493: 
	case 494: 
	case 495: 
	case 496: 
	case 497: 
	case 498: 
	case 499: 
	case 500: 
	case 501: 
	case 502: 
	case 503: 
	case 504: 
	case 505: 
	case 506: 
	case 507: 
	case 508: 
	case 509: 
	case 510: 
	case 511: 
	case 512: 
	case 513: 
	case 514: 
	case 515: 
	case 516: 
	case 517: 
	case 518: 
	case 519: 
	case 520: 
	case 521: 
	case 522: 
	case 523: 
	case 524: 
	case 525: 
	case 526: 
	case 527: 
	case 528: 
	case 529: 
	case 530: 
	case 531: 
	case 532: 
	case 533: 
	case 534: 
	case 535: 
	case 536: 
	case 537: 
	case 538: 
	case 539: 
	case 540: 
	case 541: 
	case 542: 
	case 543: 
	case 544: 
	case 545: 
	case 546: 
	case 547: 
	case 548: 
	case 549: 
	case 550: 
	case 551: 
	case 552: 
	case 553: 
	case 554: 
	case 555: 
	case 556: 
	case 557: 
	case 558: 
	case 559: 
	case 560: 
	case 561: 
	case 562: 
	case 563: 
	case 564: 
	case 565: 
	case 566: 
	case 567: 
	case 568: 
	case 569: 
	case 570: 
	case 571: 
	case 572: 
	case 573: 
	case 574: 
	case 575: 
	case 576: 
	case 577: 
	case 578: 
	case 579: 
	case 580: 
	case 581: 
	case 582: 
	case 583: 
	case 584: 
	case 585: 
	case 586: 
	case 587: 
	case 588: 
	case 589: 
	case 590: 
	case 591: 
	case 592: 
	case 593: 
	case 594: 
	case 595: 
	case 596: 
	case 597: 
	case 598: 
	case 599: 
	case 600: 
	case 601: 
	case 602: 
	case 603: 
	case 604: 
	case 605: 
	case 606: 
	case 607: 
	case 608: 
	case 609: 
	case 610: 
	case 611: 
	case 612: 
	case 613: 
	case 614: 
	case 615: 
	case 616: 
	case 617: 
	case 618: 
	case 619: 
	case 620: 
	case 621: 
	case 622: 
	case 623: 
	case 624: 
	case 625: 
	case 626: 
	case 627: 
	case 628: 
	case 629: 
	case 630: 
	case 631: 
	case 632: 
	case 633: 
	case 634: 
	case 635: 
	case 636: 
	case 637: 
	case 638: 
	case 639: 
	case 640: 
	case 641: 
	case 642: 
	case 643: 
	case 644: 
	case 645: 
	case 646: 
	case 647: 
	case 648: 
	case 649: 
	case 650: 
	case 651: 
	case 652: 
	case 653: 
	case 654: 
	case 655: 
	case 656: 
	case 657: 
	case 658: 
	case 659: 
	case 660: 
	case 661: 
	case 662: 
	case 663: 
	case 664: 
	case 665: 
	case 666: 
	case 667: 
	case 668: 
	case 669: 
	case 670: 
	case 671: 
	case 672: 
	case 673: 
	case 674: 
	case 675: 
	case 676: 
	case 677: 
	case 678: 
	case 679: 
	case 680: 
	case 681: 
	case 682: 
	case 683: 
	case 684: 
	case 685: 
	case 686: 
	case 687: 
	case 688: 
	case 689: 
	case 690: 
	case 691: 
	case 692: 
	case 693: 
	case 694: 
	case 695: 
	case 696: 
	case 697: 
	case 698: 
	case 699: 
	case 700: 
	case 701: 
	case 702: 
	case 703: 
	case 704: 
	case 705: 
	case 706: 
	case 707: 
	case 708: 
	case 709: 
	case 710: 
	case 711: 
	case 712: 
	case 713: 
	case 714: 
	case 715: 
	case 716: 
	case 717: 
	case 718: 
	case 719: 
	case 720: 
#line 343 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"
	{
        process_error(begin, userdata);
        result = 1;
        goto error_detected;
    }
	break;
#line 43448 "src/trusted/validator_ragel/gen/validator-x86_64.c"
	}
	}

	_out: {}
	}

#line 504 "src/trusted/validator_ragel/unreviewed/validator-x86_64.rl"

    if (restricted_register == REG_RBP) {
      PrintError("Incorrectly sandboxed %%rbp\n", begin - data);
      result = 1;
      goto error_detected;
    } else if (restricted_register == REG_RSP) {
      PrintError("Incorrectly sandboxed %%rsp\n", begin - data);
      result = 1;
      goto error_detected;
    }
  }

  if (CheckJumpTargets(valid_targets, jump_dests, size)) {
    return 1;
  }

error_detected:
  return result;
}
